/* Generated by Cython 3.0.0 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_TRACE",
                "1"
            ]
        ],
        "depends": [
            "/tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/core/include/numpy/arrayscalars.h",
            "/tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/core/include/numpy/ndarrayobject.h",
            "/tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/core/include/numpy/ndarraytypes.h",
            "/tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/core/include/numpy/ufuncobject.h",
            "pyseobnr/eob/utils/eob_parameters.h"
        ],
        "extra_compile_args": [
            "-O3"
        ],
        "include_dirs": [
            "pyseobnr/eob/utils",
            "/tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/core/include"
        ],
        "name": "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C",
        "sources": [
            "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx"
        ]
    },
    "module_name": "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#define CYTHON_ABI "3_0_0"
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030000F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject *co=NULL, *result=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(p))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto end;
        if (!(empty = PyTuple_New(0))) goto end;
        result = (PyCodeObject*) PyObject_Call(replace, empty, kwds);
    end:
        Py_XDECREF((PyObject*) co);
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE(obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__pyseobnr__eob__hamiltonian__Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C
#define __PYX_HAVE_API__pyseobnr__eob__hamiltonian__Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C
/* Early includes */
#include <string.h>
#include <stdio.h>

    /* Using NumPy API declarations from "numpy/__init__.cython-30.pxd" */
    
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"
#include "eob_parameters.h"
#include <math.h>
#include "pythread.h"
#include <stdlib.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else  // Py < 3.12
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif (defined(_Complex_I) && !defined(_MSC_VER)) || ((defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) && !defined(__STDC_NO_COMPLEX__))
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "<stringsource>",
  "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx",
  "__init__.cython-30.pxd",
  "type.pxd",
  "pyseobnr/eob/utils/containers.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* BufferFormatStructs.proto */
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;

/* Atomics.proto */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_incr_aligned(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_decr_aligned(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_incr_aligned(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_decr_aligned(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_incr_aligned(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_aligned(value) __sync_fetch_and_sub(value, 1)
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_nonatomic_int_type long
    #pragma intrinsic (_InterlockedExchangeAdd)
    #define __pyx_atomic_incr_aligned(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_aligned(value) _InterlockedExchangeAdd(value, -1)
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif
#if CYTHON_ATOMICS
    #define __pyx_add_acquisition_count(memview)\
             __pyx_atomic_incr_aligned(__pyx_get_slice_count_pointer(memview))
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_atomic_decr_aligned(__pyx_get_slice_count_pointer(memview))
#else
    #define __pyx_add_acquisition_count(memview)\
            __pyx_add_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_sub_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
#endif

/* MemviewSliceStruct.proto */
struct __pyx_memoryview_obj;
typedef struct {
  struct __pyx_memoryview_obj *memview;
  char *data;
  Py_ssize_t shape[8];
  Py_ssize_t strides[8];
  Py_ssize_t suboffsets[8];
} __Pyx_memviewslice;
#define __Pyx_MemoryView_Len(m)  (m.shape[0])

/* #### Code section: numeric_typedefs ### */

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":730
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":731
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":732
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":733
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":737
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":738
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":739
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":740
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":744
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":745
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":754
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":755
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":757
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":758
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":760
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":761
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":763
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":764
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":765
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* #### Code section: complex_type_declarations ### */
/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams;
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs;
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_Dynamics;
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_FluxParams;
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams;
struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C;
struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
struct __pyx_array_obj;
struct __pyx_MemviewEnum_obj;
struct __pyx_memoryview_obj;
struct __pyx_memoryviewslice_obj;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":767
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":768
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":769
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":771
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_ctuple_double__and_double;
typedef struct __pyx_ctuple_double__and_double __pyx_ctuple_double__and_double;
struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call;

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":11
 * from libc.math cimport log, sqrt, exp, abs, tgamma,sin,cos
 * 
 * cpdef (double,double) evaluate_H(double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,double M, double nu,             # <<<<<<<<<<<<<<
 * double X_1, double X_2, double a6, double dSO):
 *         """
 */
struct __pyx_ctuple_double__and_double {
  double f0;
  double f1;
};

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":154
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call {
  int __pyx_n;
  int verbose;
};

/* "pyseobnr/eob/utils/containers.pxd":8
 * 
 * 
 * cdef class PhysicalParams:             # <<<<<<<<<<<<<<
 *     cdef public double m_1,m_2,nu,M,X_1,X_2,delta,chi_1,chi_2,chi_S,chi_A,a,ap,am
 *     cdef public double chi1_L, chi2_L,a1,a2, H_val
 */
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams {
  PyObject_HEAD
  struct __pyx_vtabstruct_8pyseobnr_3eob_5utils_10containers_PhysicalParams *__pyx_vtab;
  double m_1;
  double m_2;
  double nu;
  double M;
  double X_1;
  double X_2;
  double delta;
  double chi_1;
  double chi_2;
  double chi_S;
  double chi_A;
  double a;
  double ap;
  double am;
  double chi1_L;
  double chi2_L;
  double a1;
  double a2;
  double H_val;
  __Pyx_memviewslice chi1_v;
  __Pyx_memviewslice chi2_v;
  __Pyx_memviewslice lN;
  double omega;
  double omega_circ;
};


/* "pyseobnr/eob/utils/containers.pxd":23
 *     cdef public double flagNLOSO,flagNLOSO2,flagNLOSO3,flagNLOSS,flagNLOSS2,flagS3
 * '''
 * cdef class CalibCoeffs:             # <<<<<<<<<<<<<<
 *     cdef public dict dc
 * 
 */
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs {
  PyObject_HEAD
  PyObject *dc;
};


/* "pyseobnr/eob/utils/containers.pxd":26
 *     cdef public dict dc
 * 
 * cdef class Dynamics:             # <<<<<<<<<<<<<<
 *     cdef public double[:] p_circ
 * 
 */
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_Dynamics {
  PyObject_HEAD
  __Pyx_memviewslice p_circ;
};


/* "pyseobnr/eob/utils/containers.pxd":29
 *     cdef public double[:] p_circ
 * 
 * cdef class FluxParams:             # <<<<<<<<<<<<<<
 *     # Coefficients entering the amplitude residual
 *     cdef public double[:,:,:] rho_coeffs
 */
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_FluxParams {
  PyObject_HEAD
  __Pyx_memviewslice rho_coeffs;
  __Pyx_memviewslice rho_coeffs_log;
  __Pyx_memviewslice f_coeffs;
  __Pyx_memviewslice f_coeffs_vh;
  __Pyx_memviewslice delta_coeffs;
  __Pyx_memviewslice delta_coeffs_vh;
  __Pyx_memviewslice prefixes;
  __Pyx_memviewslice prefixes_abs;
  __Pyx_memviewslice Tlm;
  __Pyx_memviewslice rholm;
  __Pyx_memviewslice deltalm;
  __Pyx_memviewslice nqc_coeffs;
  __Pyx_memviewslice extra_coeffs;
  __Pyx_memviewslice extra_coeffs_log;
  PyObject *special_modes;
  int rho_initialized;
  int extra_PN_terms;
};


/* "pyseobnr/eob/utils/containers.pxd":67
 *     cdef public bint extra_PN_terms
 * 
 * cdef class EOBParams:             # <<<<<<<<<<<<<<
 *     cdef public PhysicalParams p_params
 *     cdef public CalibCoeffs c_coeffs
 */
struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams {
  PyObject_HEAD
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams *p_params;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *c_coeffs;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_FluxParams *flux_params;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_Dynamics *dynamics;
  PyObject *mode_array;
  int aligned;
};


/* "pyseobnr/eob/hamiltonian/Hamiltonian_C.pxd":3
 * cimport cython
 * from pyseobnr.eob.utils.containers cimport EOBParams
 * cdef class Hamiltonian_C:             # <<<<<<<<<<<<<<
 *     cdef public EOBParams EOBpars
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2)
 */
struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C {
  PyObject_HEAD
  struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *__pyx_vtab;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams *EOBpars;
};


/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":145
 * 
 * 
 * cdef class Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(Hamiltonian_C):             # <<<<<<<<<<<<<<
 *     cdef public CalibCoeffs calibration_coeffs
 *     #cdef public EOBParams EOBpars
 */
struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C {
  struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C __pyx_base;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *calibration_coeffs;
};


/* "View.MemoryView":114
 * @cython.collection_type("sequence")
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
struct __pyx_array_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_array *__pyx_vtab;
  char *data;
  Py_ssize_t len;
  char *format;
  int ndim;
  Py_ssize_t *_shape;
  Py_ssize_t *_strides;
  Py_ssize_t itemsize;
  PyObject *mode;
  PyObject *_format;
  void (*callback_free_data)(void *);
  int free_data;
  int dtype_is_object;
};


/* "View.MemoryView":302
 * 
 * @cname('__pyx_MemviewEnum')
 * cdef class Enum(object):             # <<<<<<<<<<<<<<
 *     cdef object name
 *     def __init__(self, name):
 */
struct __pyx_MemviewEnum_obj {
  PyObject_HEAD
  PyObject *name;
};


/* "View.MemoryView":337
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview:             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */
struct __pyx_memoryview_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_memoryview *__pyx_vtab;
  PyObject *obj;
  PyObject *_size;
  PyObject *_array_interface;
  PyThread_type_lock lock;
  __pyx_atomic_int_type acquisition_count;
  Py_buffer view;
  int flags;
  int dtype_is_object;
  __Pyx_TypeInfo *typeinfo;
};


/* "View.MemoryView":952
 * @cython.collection_type("sequence")
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */
struct __pyx_memoryviewslice_obj {
  struct __pyx_memoryview_obj __pyx_base;
  __Pyx_memviewslice from_slice;
  PyObject *from_object;
  PyObject *(*to_object_func)(char *);
  int (*to_dtype_func)(char *, PyObject *);
};



/* "pyseobnr/eob/utils/containers.pxd":8
 * 
 * 
 * cdef class PhysicalParams:             # <<<<<<<<<<<<<<
 *     cdef public double m_1,m_2,nu,M,X_1,X_2,delta,chi_1,chi_2,chi_S,chi_A,a,ap,am
 *     cdef public double chi1_L, chi2_L,a1,a2, H_val
 */

struct __pyx_vtabstruct_8pyseobnr_3eob_5utils_10containers_PhysicalParams {
  PyObject *(*update_spins)(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams *, double, double, int __pyx_skip_dispatch);
  PyObject *(*_compute_derived_quants)(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams *);
};
static struct __pyx_vtabstruct_8pyseobnr_3eob_5utils_10containers_PhysicalParams *__pyx_vtabptr_8pyseobnr_3eob_5utils_10containers_PhysicalParams;


/* "pyseobnr/eob/hamiltonian/Hamiltonian_C.pxd":3
 * cimport cython
 * from pyseobnr.eob.utils.containers cimport EOBParams
 * cdef class Hamiltonian_C:             # <<<<<<<<<<<<<<
 *     cdef public EOBParams EOBpars
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2)
 */

struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C {
  PyObject *(*_call)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
  PyObject *(*grad)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
  PyObject *(*hessian)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
  double (*csi)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
  PyObject *(*dynamics)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
  double (*omega)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
  PyObject *(*auxderivs)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *__pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C;


/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":145
 * 
 * 
 * cdef class Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(Hamiltonian_C):             # <<<<<<<<<<<<<<
 *     cdef public CalibCoeffs calibration_coeffs
 *     #cdef public EOBParams EOBpars
 */

struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C {
  struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C __pyx_base;
  PyObject *(*_call)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch, struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call *__pyx_optional_args);
  double (*xi)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double);
};
static struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;


/* "View.MemoryView":114
 * @cython.collection_type("sequence")
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */

struct __pyx_vtabstruct_array {
  PyObject *(*get_memview)(struct __pyx_array_obj *);
};
static struct __pyx_vtabstruct_array *__pyx_vtabptr_array;


/* "View.MemoryView":337
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview:             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */

struct __pyx_vtabstruct_memoryview {
  char *(*get_item_pointer)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*is_slice)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_slice_assignment)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*setitem_slice_assign_scalar)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_indexed)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*convert_item_to_object)(struct __pyx_memoryview_obj *, char *);
  PyObject *(*assign_item_from_object)(struct __pyx_memoryview_obj *, char *, PyObject *);
  PyObject *(*_get_base)(struct __pyx_memoryview_obj *);
};
static struct __pyx_vtabstruct_memoryview *__pyx_vtabptr_memoryview;


/* "View.MemoryView":952
 * @cython.collection_type("sequence")
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */

struct __pyx_vtabstruct__memoryviewslice {
  struct __pyx_vtabstruct_memoryview __pyx_base;
};
static struct __pyx_vtabstruct__memoryviewslice *__pyx_vtabptr__memoryviewslice;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* Profile.proto */
#ifndef CYTHON_PROFILE
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
  #define CYTHON_PROFILE 0
#else
  #define CYTHON_PROFILE 1
#endif
#endif
#ifndef CYTHON_TRACE_NOGIL
  #define CYTHON_TRACE_NOGIL 0
#else
  #if CYTHON_TRACE_NOGIL && !defined(CYTHON_TRACE)
    #define CYTHON_TRACE 1
  #endif
#endif
#ifndef CYTHON_TRACE
  #define CYTHON_TRACE 0
#endif
#if CYTHON_TRACE
  #undef CYTHON_PROFILE_REUSE_FRAME
#endif
#ifndef CYTHON_PROFILE_REUSE_FRAME
  #define CYTHON_PROFILE_REUSE_FRAME 0
#endif
#if CYTHON_PROFILE || CYTHON_TRACE
  #include "compile.h"
  #include "frameobject.h"
  #include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #if CYTHON_PROFILE_REUSE_FRAME
    #define CYTHON_FRAME_MODIFIER static
    #define CYTHON_FRAME_DEL(frame)
  #else
    #define CYTHON_FRAME_MODIFIER
    #define CYTHON_FRAME_DEL(frame) Py_CLEAR(frame)
  #endif
  #define __Pyx_TraceDeclarations\
      static PyCodeObject *__pyx_frame_code = NULL;\
      CYTHON_FRAME_MODIFIER PyFrameObject *__pyx_frame = NULL;\
      int __Pyx_use_tracing = 0;
  #define __Pyx_TraceFrameInit(codeobj)\
      if (codeobj) __pyx_frame_code = (PyCodeObject*) codeobj;
#if PY_VERSION_HEX >= 0x030b00a2
  #if PY_VERSION_HEX >= 0x030C00b1
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     ((!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #else
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     (unlikely((tstate)->cframe->use_tracing) &&\
         (!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #endif
  #define __Pyx_EnterTracing(tstate)  PyThreadState_EnterTracing(tstate)
  #define __Pyx_LeaveTracing(tstate)  PyThreadState_LeaveTracing(tstate)
#elif PY_VERSION_HEX >= 0x030a00b1
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     (unlikely((tstate)->cframe->use_tracing) &&\
         (!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #define __Pyx_EnterTracing(tstate)\
      do { tstate->tracing++; tstate->cframe->use_tracing = 0; } while (0)
  #define __Pyx_LeaveTracing(tstate)\
      do {\
          tstate->tracing--;\
          tstate->cframe->use_tracing = ((CYTHON_TRACE && tstate->c_tracefunc != NULL)\
                                 || tstate->c_profilefunc != NULL);\
      } while (0)
#else
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     (unlikely((tstate)->use_tracing) &&\
         (!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #define __Pyx_EnterTracing(tstate)\
      do { tstate->tracing++; tstate->use_tracing = 0; } while (0)
  #define __Pyx_LeaveTracing(tstate)\
      do {\
          tstate->tracing--;\
          tstate->use_tracing = ((CYTHON_TRACE && tstate->c_tracefunc != NULL)\
                                         || tstate->c_profilefunc != NULL);\
      } while (0)
#endif
  #ifdef WITH_THREAD
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)\
  if (nogil) {\
      if (CYTHON_TRACE_NOGIL) {\
          PyThreadState *tstate;\
          PyGILState_STATE state = PyGILState_Ensure();\
          tstate = __Pyx_PyThreadState_Current;\
          if (__Pyx_IsTracing(tstate, 1, 1)) {\
              __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          }\
          PyGILState_Release(state);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  } else {\
      PyThreadState* tstate = PyThreadState_GET();\
      if (__Pyx_IsTracing(tstate, 1, 1)) {\
          __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  }
  #else
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)\
  {   PyThreadState* tstate = PyThreadState_GET();\
      if (__Pyx_IsTracing(tstate, 1, 1)) {\
          __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  }
  #endif
  #define __Pyx_TraceException()\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (__Pyx_IsTracing(tstate, 0, 1)) {\
          __Pyx_EnterTracing(tstate);\
          PyObject *exc_info = __Pyx_GetExceptionTuple(tstate);\
          if (exc_info) {\
              if (CYTHON_TRACE && tstate->c_tracefunc)\
                  tstate->c_tracefunc(\
                      tstate->c_traceobj, __pyx_frame, PyTrace_EXCEPTION, exc_info);\
              tstate->c_profilefunc(\
                  tstate->c_profileobj, __pyx_frame, PyTrace_EXCEPTION, exc_info);\
              Py_DECREF(exc_info);\
          }\
          __Pyx_LeaveTracing(tstate);\
      }\
  }
  static void __Pyx_call_return_trace_func(PyThreadState *tstate, PyFrameObject *frame, PyObject *result) {
      PyObject *type, *value, *traceback;
      __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
      __Pyx_EnterTracing(tstate);
      if (CYTHON_TRACE && tstate->c_tracefunc)
          tstate->c_tracefunc(tstate->c_traceobj, frame, PyTrace_RETURN, result);
      if (tstate->c_profilefunc)
          tstate->c_profilefunc(tstate->c_profileobj, frame, PyTrace_RETURN, result);
      CYTHON_FRAME_DEL(frame);
      __Pyx_LeaveTracing(tstate);
      __Pyx_ErrRestoreInState(tstate, type, value, traceback);
  }
  #ifdef WITH_THREAD
  #define __Pyx_TraceReturn(result, nogil)\
  if (likely(!__Pyx_use_tracing)); else {\
      if (nogil) {\
          if (CYTHON_TRACE_NOGIL) {\
              PyThreadState *tstate;\
              PyGILState_STATE state = PyGILState_Ensure();\
              tstate = __Pyx_PyThreadState_Current;\
              if (__Pyx_IsTracing(tstate, 0, 0)) {\
                  __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
              }\
              PyGILState_Release(state);\
          }\
      } else {\
          PyThreadState* tstate = __Pyx_PyThreadState_Current;\
          if (__Pyx_IsTracing(tstate, 0, 0)) {\
              __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
          }\
      }\
  }
  #else
  #define __Pyx_TraceReturn(result, nogil)\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (__Pyx_IsTracing(tstate, 0, 0)) {\
          __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
      }\
  }
  #endif
  static PyCodeObject *__Pyx_createFrameCodeObject(const char *funcname, const char *srcfile, int firstlineno);
  static int __Pyx_TraceSetupAndCall(PyCodeObject** code, PyFrameObject** frame, PyThreadState* tstate, const char *funcname, const char *srcfile, int firstlineno);
#else
  #define __Pyx_TraceDeclarations
  #define __Pyx_TraceFrameInit(codeobj)
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)   if ((1)); else goto_error;
  #define __Pyx_TraceException()
  #define __Pyx_TraceReturn(result, nogil)
#endif
#if CYTHON_TRACE
  static int __Pyx_call_line_trace_func(PyThreadState *tstate, PyFrameObject *frame, int lineno) {
      int ret;
      PyObject *type, *value, *traceback;
      __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
      __Pyx_PyFrame_SetLineNumber(frame, lineno);
      __Pyx_EnterTracing(tstate);
      ret = tstate->c_tracefunc(tstate->c_traceobj, frame, PyTrace_LINE, NULL);
      __Pyx_LeaveTracing(tstate);
      if (likely(!ret)) {
          __Pyx_ErrRestoreInState(tstate, type, value, traceback);
      } else {
          Py_XDECREF(type);
          Py_XDECREF(value);
          Py_XDECREF(traceback);
      }
      return ret;
  }
  #ifdef WITH_THREAD
  #define __Pyx_TraceLine(lineno, nogil, goto_error)\
  if (likely(!__Pyx_use_tracing)); else {\
      if (nogil) {\
          if (CYTHON_TRACE_NOGIL) {\
              int ret = 0;\
              PyThreadState *tstate;\
              PyGILState_STATE state = __Pyx_PyGILState_Ensure();\
              tstate = __Pyx_PyThreadState_Current;\
              if (__Pyx_IsTracing(tstate, 0, 0) && tstate->c_tracefunc && __pyx_frame->f_trace) {\
                  ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
              }\
              __Pyx_PyGILState_Release(state);\
              if (unlikely(ret)) goto_error;\
          }\
      } else {\
          PyThreadState* tstate = __Pyx_PyThreadState_Current;\
          if (__Pyx_IsTracing(tstate, 0, 0) && tstate->c_tracefunc && __pyx_frame->f_trace) {\
              int ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
              if (unlikely(ret)) goto_error;\
          }\
      }\
  }
  #else
  #define __Pyx_TraceLine(lineno, nogil, goto_error)\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (__Pyx_IsTracing(tstate, 0, 0) && tstate->c_tracefunc && __pyx_frame->f_trace) {\
          int ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
          if (unlikely(ret)) goto_error;\
      }\
  }
  #endif
#else
  #define __Pyx_TraceLine(lineno, nogil, goto_error)   if ((1)); else goto_error;
#endif

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *); /*proto*/
/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* DivInt[Py_ssize_t].proto */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t, Py_ssize_t);

/* UnaryNegOverflows.proto */
#define __Pyx_UNARY_NEG_WOULD_OVERFLOW(x)\
        (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* AssertionsEnabled.proto */
#define __Pyx_init_assertions_enabled()
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define __pyx_assertions_enabled() (1)
#elif PY_VERSION_HEX < 0x03080000  ||  CYTHON_COMPILING_IN_PYPY  ||  defined(Py_LIMITED_API)
  #define __pyx_assertions_enabled() (!Py_OptimizeFlag)
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030900A6
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #undef __Pyx_init_assertions_enabled
  static void __Pyx_init_assertions_enabled(void) {
    __pyx_assertions_enabled_flag = ! _PyInterpreterState_GetConfig(__Pyx_PyThreadState_Current->interp)->optimization_level;
  }
#else
  #define __pyx_assertions_enabled() (!Py_OptimizeFlag)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* ssize_strlen.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PySequenceMultiply.proto */
#define __Pyx_PySequence_Multiply_Left(mul, seq)  __Pyx_PySequence_Multiply(seq, mul)
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* DivInt[long].proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* SoftComplexToDouble.proto */
static double __Pyx_SoftComplexToDouble(__pyx_t_double_complex value, int have_gil);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_0
#define __PYX_HAVE_RT_ImportType_proto_3_0_0
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_0(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_0(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_0 {
   __Pyx_ImportType_CheckSize_Error_3_0_0 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_0 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_0 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_0(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_0 check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_IsCyOrPyCFunction(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

/* MemviewSliceIsContig.proto */
static int __pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim);

/* OverlappingSlices.proto */
static int __pyx_slices_overlap(__Pyx_memviewslice *slice1,
                                __Pyx_memviewslice *slice2,
                                int ndim, size_t itemsize);

/* IsLittleEndian.proto */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void);

/* BufferFormatCheck.proto */
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type);

/* TypeInfoCompare.proto */
static int __pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b);

/* MemviewSliceValidateAndInit.proto */
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_double(PyObject *, int writable_flag);

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* ToPyCTupleUtility.proto */
static PyObject* __pyx_convert__to_py___pyx_ctuple_double__and_double(__pyx_ctuple_double__and_double);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_double(const char *itemp);
static CYTHON_INLINE int __pyx_memview_set_double(const char *itemp, PyObject *obj);

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* MemviewSliceCopyTemplate.proto */
static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object);

/* MemviewSliceInit.proto */
#define __Pyx_BUF_MAX_NDIMS %(BUF_MAX_NDIMS)d
#define __Pyx_MEMVIEW_DIRECT   1
#define __Pyx_MEMVIEW_PTR      2
#define __Pyx_MEMVIEW_FULL     4
#define __Pyx_MEMVIEW_CONTIG   8
#define __Pyx_MEMVIEW_STRIDED  16
#define __Pyx_MEMVIEW_FOLLOW   32
#define __Pyx_IS_C_CONTIG 1
#define __Pyx_IS_F_CONTIG 2
static int __Pyx_init_memviewslice(
                struct __pyx_memoryview_obj *memview,
                int ndim,
                __Pyx_memviewslice *memviewslice,
                int memview_is_new_reference);
static CYTHON_INLINE int __pyx_add_acquisition_count_locked(
    __pyx_atomic_int_type *acquisition_count, PyThread_type_lock lock);
static CYTHON_INLINE int __pyx_sub_acquisition_count_locked(
    __pyx_atomic_int_type *acquisition_count, PyThread_type_lock lock);
#define __pyx_get_slice_count_pointer(memview) (&memview->acquisition_count)
#define __PYX_INC_MEMVIEW(slice, have_gil) __Pyx_INC_MEMVIEW(slice, have_gil, __LINE__)
#define __PYX_XCLEAR_MEMVIEW(slice, have_gil) __Pyx_XCLEAR_MEMVIEW(slice, have_gil, __LINE__)
static CYTHON_INLINE void __Pyx_INC_MEMVIEW(__Pyx_memviewslice *, int, int);
static CYTHON_INLINE void __Pyx_XCLEAR_MEMVIEW(__Pyx_memviewslice *, int, int);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self); /* proto*/
static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto*/
static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview__get_base(struct __pyx_memoryview_obj *__pyx_v_self); /* proto*/
static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryviewslice__get_base(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self); /* proto*/
PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2, int __pyx_skip_dispatch, struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call *__pyx_optional_args); /* proto*/
PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call__pyx_wrap_1(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_grad(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_hessian(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch); /* proto*/
static double __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_xi(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2); /* proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_dynamics(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch); /* proto*/
static double __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_omega(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_auxderivs(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "cython.view" */

/* Module declarations from "cython.dataclasses" */

/* Module declarations from "cython" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "numpy" */

/* Module declarations from "numpy" */

/* Module declarations from "pyseobnr.eob.utils.containers" */

/* Module declarations from "pyseobnr.eob.hamiltonian.Hamiltonian_C" */

/* Module declarations from "libc.math" */

/* Module declarations from "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C" */
static PyObject *__pyx_collections_abc_Sequence = 0;
static PyObject *generic = 0;
static PyObject *strided = 0;
static PyObject *indirect = 0;
static PyObject *contiguous = 0;
static PyObject *indirect_contiguous = 0;
static int __pyx_memoryview_thread_locks_used;
static PyThread_type_lock __pyx_memoryview_thread_locks[8];
static __pyx_ctuple_double__and_double __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, double, double, double, double, double, double, int __pyx_skip_dispatch); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_double(double *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_double(double *, Py_ssize_t); /*proto*/
static int __pyx_array_allocate_buffer(struct __pyx_array_obj *); /*proto*/
static struct __pyx_array_obj *__pyx_array_new(PyObject *, Py_ssize_t, char *, char *, char *); /*proto*/
static PyObject *__pyx_memoryview_new(PyObject *, int, int, __Pyx_TypeInfo *); /*proto*/
static CYTHON_INLINE int __pyx_memoryview_check(PyObject *); /*proto*/
static PyObject *_unellipsify(PyObject *, int); /*proto*/
static int assert_direct_dimensions(Py_ssize_t *, int); /*proto*/
static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *, PyObject *); /*proto*/
static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int, int); /*proto*/
static char *__pyx_pybuffer_index(Py_buffer *, char *, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memslice_transpose(__Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice, int, PyObject *(*)(char *), int (*)(char *, PyObject *), int); /*proto*/
static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *); /*proto*/
static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static Py_ssize_t abs_py_ssize_t(Py_ssize_t); /*proto*/
static char __pyx_get_best_slice_order(__Pyx_memviewslice *, int); /*proto*/
static void _copy_strided_to_strided(char *, Py_ssize_t *, char *, Py_ssize_t *, Py_ssize_t *, Py_ssize_t *, int, size_t); /*proto*/
static void copy_strided_to_strided(__Pyx_memviewslice *, __Pyx_memviewslice *, int, size_t); /*proto*/
static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *, int); /*proto*/
static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *, Py_ssize_t *, Py_ssize_t, int, char); /*proto*/
static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *, __Pyx_memviewslice *, char, int); /*proto*/
static int __pyx_memoryview_err_extents(int, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memoryview_err_dim(PyObject *, PyObject *, int); /*proto*/
static int __pyx_memoryview_err(PyObject *, PyObject *); /*proto*/
static int __pyx_memoryview_err_no_memory(void); /*proto*/
static int __pyx_memoryview_copy_contents(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int); /*proto*/
static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *, int, int); /*proto*/
static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *, int, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *, int, size_t, void *, int); /*proto*/
static void __pyx_memoryview__slice_assign_scalar(char *, Py_ssize_t *, Py_ssize_t *, int, size_t, void *); /*proto*/
static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
static __Pyx_TypeInfo __Pyx_TypeInfo_double = { "double", NULL, sizeof(double), { 0 }, 0, 'R', 0, 0 };
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C"
extern int __pyx_module_is_main_pyseobnr__eob__hamiltonian__Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
int __pyx_module_is_main_pyseobnr__eob__hamiltonian__Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C = 0;

/* Implementation of "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_AssertionError;
static PyObject *__pyx_builtin_Ellipsis;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_ImportError;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = ": ";
static const char __pyx_k_M[] = "M";
static const char __pyx_k_O[] = "O";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_q[] = "q";
static const char __pyx_k__2[] = ".";
static const char __pyx_k__3[] = "*";
static const char __pyx_k__6[] = "'";
static const char __pyx_k__7[] = ")";
static const char __pyx_k_a6[] = "a6";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_nu[] = "nu";
static const char __pyx_k_X_1[] = "X_1";
static const char __pyx_k_X_2[] = "X_2";
static const char __pyx_k__38[] = "?";
static const char __pyx_k_abc[] = "abc";
static const char __pyx_k_and[] = " and ";
static const char __pyx_k_dSO[] = "dSO";
static const char __pyx_k_got[] = " (got ";
static const char __pyx_k_m_1[] = "m_1";
static const char __pyx_k_m_2[] = "m_2";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_call[] = "_call";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_grad[] = "grad";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_ndim[] = "ndim";
static const char __pyx_k_pack[] = "pack";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_ASCII[] = "ASCII";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_chi_1[] = "chi_1";
static const char __pyx_k_chi_2[] = "chi_2";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_omega[] = "omega";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_shape[] = "shape";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_params[] = "params";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_struct[] = "struct";
static const char __pyx_k_unpack[] = "unpack";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_fortran[] = "fortran";
static const char __pyx_k_hessian[] = "hessian";
static const char __pyx_k_memview[] = "memview";
static const char __pyx_k_reshape[] = "reshape";
static const char __pyx_k_verbose[] = "verbose";
static const char __pyx_k_Ellipsis[] = "Ellipsis";
static const char __pyx_k_Sequence[] = "Sequence";
static const char __pyx_k_dynamics[] = "dynamics";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_itemsize[] = "itemsize";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_auxderivs[] = "auxderivs";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_evaluate_H[] = "evaluate_H";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_AssertionError[] = "AssertionError";
static const char __pyx_k_View_MemoryView[] = "View.MemoryView";
static const char __pyx_k_allocate_buffer[] = "allocate_buffer";
static const char __pyx_k_collections_abc[] = "collections.abc";
static const char __pyx_k_dtype_is_object[] = "dtype_is_object";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_pyx_unpickle_Enum[] = "__pyx_unpickle_Enum";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_strided_and_direct[] = "<strided and direct>";
static const char __pyx_k_strided_and_indirect[] = "<strided and indirect>";
static const char __pyx_k_Invalid_shape_in_axis[] = "Invalid shape in axis ";
static const char __pyx_k_contiguous_and_direct[] = "<contiguous and direct>";
static const char __pyx_k_Cannot_index_with_type[] = "Cannot index with type '";
static const char __pyx_k_MemoryView_of_r_object[] = "<MemoryView of %r object>";
static const char __pyx_k_MemoryView_of_r_at_0x_x[] = "<MemoryView of %r at 0x%x>";
static const char __pyx_k_contiguous_and_indirect[] = "<contiguous and indirect>";
static const char __pyx_k_Dimension_d_is_not_direct[] = "Dimension %d is not direct";
static const char __pyx_k_Index_out_of_bounds_axis_d[] = "Index out of bounds (axis %d)";
static const char __pyx_k_Step_may_not_be_zero_axis_d[] = "Step may not be zero (axis %d)";
static const char __pyx_k_itemsize_0_for_cython_array[] = "itemsize <= 0 for cython.array";
static const char __pyx_k_unable_to_allocate_array_data[] = "unable to allocate array data.";
static const char __pyx_k_strided_and_direct_or_indirect[] = "<strided and direct or indirect>";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_All_dimensions_preceding_dimensi[] = "All dimensions preceding dimension %d must be indexed and not sliced";
static const char __pyx_k_Buffer_view_does_not_expose_stri[] = "Buffer view does not expose strides";
static const char __pyx_k_Can_only_create_a_buffer_that_is[] = "Can only create a buffer that is contiguous in memory.";
static const char __pyx_k_Cannot_assign_to_read_only_memor[] = "Cannot assign to read-only memoryview";
static const char __pyx_k_Cannot_create_writable_memory_vi[] = "Cannot create writable memory view from read-only memoryview";
static const char __pyx_k_Cannot_transpose_memoryview_with[] = "Cannot transpose memoryview with indirect dimensions";
static const char __pyx_k_Empty_shape_tuple_for_cython_arr[] = "Empty shape tuple for cython.array";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))";
static const char __pyx_k_Indirect_dimensions_not_supporte[] = "Indirect dimensions not supported";
static const char __pyx_k_Invalid_mode_expected_c_or_fortr[] = "Invalid mode, expected 'c' or 'fortran', got ";
static const char __pyx_k_Out_of_bounds_on_buffer_access_a[] = "Out of bounds on buffer access (axis ";
static const char __pyx_k_Unable_to_convert_item_to_object[] = "Unable to convert item to object";
static const char __pyx_k_got_differing_extents_in_dimensi[] = "got differing extents in dimension ";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_pyseobnr_eob_hamiltonian_Ham_ali[] = "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx";
static const char __pyx_k_unable_to_allocate_shape_and_str[] = "unable to allocate shape and strides.";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_2[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C._call";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_3[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.grad";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_4[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.hessian";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_5[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.dynamics";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_6[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.omega";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_7[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.auxderivs";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_8[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__reduce_cython__";
static const char __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_9[] = "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__setstate_cython__";
static const char __pyx_k_pyseobnr_eob_hamiltonian_Ham_ali_2[] = "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C";
/* #### Code section: decls ### */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object); /* proto */
static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, double __pyx_v_M, double __pyx_v_nu, double __pyx_v_X_1, double __pyx_v_X_2, double __pyx_v_a6, double __pyx_v_dSO); /* proto */
static int __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C___cinit__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_2__call__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_v_verbose); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_4_call(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_v_verbose); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_6grad(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_8hessian(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_10dynamics(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_12omega(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_14auxderivs(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs___get__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self); /* proto */
static int __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_2__set__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_4__del__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_5numpy_dtype;
  PyTypeObject *__pyx_ptype_5numpy_flatiter;
  PyTypeObject *__pyx_ptype_5numpy_broadcast;
  PyTypeObject *__pyx_ptype_5numpy_ndarray;
  PyTypeObject *__pyx_ptype_5numpy_generic;
  PyTypeObject *__pyx_ptype_5numpy_number;
  PyTypeObject *__pyx_ptype_5numpy_integer;
  PyTypeObject *__pyx_ptype_5numpy_signedinteger;
  PyTypeObject *__pyx_ptype_5numpy_unsignedinteger;
  PyTypeObject *__pyx_ptype_5numpy_inexact;
  PyTypeObject *__pyx_ptype_5numpy_floating;
  PyTypeObject *__pyx_ptype_5numpy_complexfloating;
  PyTypeObject *__pyx_ptype_5numpy_flexible;
  PyTypeObject *__pyx_ptype_5numpy_character;
  PyTypeObject *__pyx_ptype_5numpy_ufunc;
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams;
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs;
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics;
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams;
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams;
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
  PyObject *__pyx_type___pyx_array;
  PyObject *__pyx_type___pyx_MemviewEnum;
  PyObject *__pyx_type___pyx_memoryview;
  PyObject *__pyx_type___pyx_memoryviewslice;
  #endif
  PyTypeObject *__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
  PyTypeObject *__pyx_array_type;
  PyTypeObject *__pyx_MemviewEnum_type;
  PyTypeObject *__pyx_memoryview_type;
  PyTypeObject *__pyx_memoryviewslice_type;
  PyObject *__pyx_kp_u_;
  PyObject *__pyx_n_s_ASCII;
  PyObject *__pyx_kp_s_All_dimensions_preceding_dimensi;
  PyObject *__pyx_n_s_AssertionError;
  PyObject *__pyx_kp_s_Buffer_view_does_not_expose_stri;
  PyObject *__pyx_kp_s_Can_only_create_a_buffer_that_is;
  PyObject *__pyx_kp_s_Cannot_assign_to_read_only_memor;
  PyObject *__pyx_kp_s_Cannot_create_writable_memory_vi;
  PyObject *__pyx_kp_u_Cannot_index_with_type;
  PyObject *__pyx_kp_s_Cannot_transpose_memoryview_with;
  PyObject *__pyx_kp_s_Dimension_d_is_not_direct;
  PyObject *__pyx_n_s_Ellipsis;
  PyObject *__pyx_kp_s_Empty_shape_tuple_for_cython_arr;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8;
  PyObject *__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9;
  PyObject *__pyx_n_s_ImportError;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_n_s_IndexError;
  PyObject *__pyx_kp_s_Index_out_of_bounds_axis_d;
  PyObject *__pyx_kp_s_Indirect_dimensions_not_supporte;
  PyObject *__pyx_kp_u_Invalid_mode_expected_c_or_fortr;
  PyObject *__pyx_kp_u_Invalid_shape_in_axis;
  PyObject *__pyx_n_s_M;
  PyObject *__pyx_n_s_MemoryError;
  PyObject *__pyx_kp_s_MemoryView_of_r_at_0x_x;
  PyObject *__pyx_kp_s_MemoryView_of_r_object;
  PyObject *__pyx_n_b_O;
  PyObject *__pyx_kp_u_Out_of_bounds_on_buffer_access_a;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_s_Sequence;
  PyObject *__pyx_kp_s_Step_may_not_be_zero_axis_d;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_kp_s_Unable_to_convert_item_to_object;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_View_MemoryView;
  PyObject *__pyx_n_s_X_1;
  PyObject *__pyx_n_s_X_2;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_n_s__3;
  PyObject *__pyx_n_s__38;
  PyObject *__pyx_kp_u__6;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_n_s_a6;
  PyObject *__pyx_n_u_a6;
  PyObject *__pyx_n_s_abc;
  PyObject *__pyx_n_s_allocate_buffer;
  PyObject *__pyx_kp_u_and;
  PyObject *__pyx_n_s_array;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_auxderivs;
  PyObject *__pyx_n_s_base;
  PyObject *__pyx_n_s_c;
  PyObject *__pyx_n_u_c;
  PyObject *__pyx_n_s_call;
  PyObject *__pyx_n_s_chi_1;
  PyObject *__pyx_n_s_chi_2;
  PyObject *__pyx_n_s_class;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_collections;
  PyObject *__pyx_kp_s_collections_abc;
  PyObject *__pyx_kp_s_contiguous_and_direct;
  PyObject *__pyx_kp_s_contiguous_and_indirect;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_dSO;
  PyObject *__pyx_n_u_dSO;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_dtype_is_object;
  PyObject *__pyx_n_s_dynamics;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_encode;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_n_s_evaluate_H;
  PyObject *__pyx_n_s_flags;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_fortran;
  PyObject *__pyx_n_u_fortran;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_kp_u_got;
  PyObject *__pyx_kp_u_got_differing_extents_in_dimensi;
  PyObject *__pyx_n_s_grad;
  PyObject *__pyx_n_s_hessian;
  PyObject *__pyx_n_s_id;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_itemsize;
  PyObject *__pyx_kp_s_itemsize_0_for_cython_array;
  PyObject *__pyx_n_s_m_1;
  PyObject *__pyx_n_s_m_2;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_memview;
  PyObject *__pyx_n_s_mode;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_ndim;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
  PyObject *__pyx_n_s_np;
  PyObject *__pyx_n_s_nu;
  PyObject *__pyx_n_s_numpy;
  PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
  PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_omega;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_s_pack;
  PyObject *__pyx_n_s_params;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali;
  PyObject *__pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_Enum;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_q;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_register;
  PyObject *__pyx_n_s_reshape;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_shape;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_start;
  PyObject *__pyx_n_s_step;
  PyObject *__pyx_n_s_stop;
  PyObject *__pyx_kp_s_strided_and_direct;
  PyObject *__pyx_kp_s_strided_and_direct_or_indirect;
  PyObject *__pyx_kp_s_strided_and_indirect;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_struct;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_kp_s_unable_to_allocate_array_data;
  PyObject *__pyx_kp_s_unable_to_allocate_shape_and_str;
  PyObject *__pyx_n_s_unpack;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_verbose;
  PyObject *__pyx_n_s_version_info;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_112105877;
  PyObject *__pyx_int_136983863;
  PyObject *__pyx_int_184977713;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_slice__5;
  PyObject *__pyx_tuple__4;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_tuple__10;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__21;
  PyObject *__pyx_tuple__22;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__26;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__28;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__30;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__33;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__35;
  PyObject *__pyx_tuple__36;
  PyObject *__pyx_tuple__37;
  PyObject *__pyx_codeobj__11;
  PyObject *__pyx_codeobj__12;
  PyObject *__pyx_codeobj__13;
  PyObject *__pyx_codeobj__14;
  PyObject *__pyx_codeobj__16;
  PyObject *__pyx_codeobj__17;
  PyObject *__pyx_codeobj__18;
  PyObject *__pyx_codeobj__19;
  PyObject *__pyx_codeobj__20;
  PyObject *__pyx_codeobj__31;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_dtype);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flatiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_broadcast);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ndarray);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_generic);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_number);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_integer);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_inexact);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_floating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flexible);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_character);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ufunc);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C);
  Py_CLEAR(clear_module_state->__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);
  Py_CLEAR(clear_module_state->__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);
  Py_CLEAR(clear_module_state->__pyx_array_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_array);
  Py_CLEAR(clear_module_state->__pyx_MemviewEnum_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_MemviewEnum);
  Py_CLEAR(clear_module_state->__pyx_memoryview_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_memoryview);
  Py_CLEAR(clear_module_state->__pyx_memoryviewslice_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_memoryviewslice);
  Py_CLEAR(clear_module_state->__pyx_kp_u_);
  Py_CLEAR(clear_module_state->__pyx_n_s_ASCII);
  Py_CLEAR(clear_module_state->__pyx_kp_s_All_dimensions_preceding_dimensi);
  Py_CLEAR(clear_module_state->__pyx_n_s_AssertionError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Buffer_view_does_not_expose_stri);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Can_only_create_a_buffer_that_is);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_assign_to_read_only_memor);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_create_writable_memory_vi);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_index_with_type);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_transpose_memoryview_with);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Dimension_d_is_not_direct);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ellipsis);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Empty_shape_tuple_for_cython_arr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_ImportError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_IndexError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Index_out_of_bounds_axis_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Indirect_dimensions_not_supporte);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_mode_expected_c_or_fortr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_shape_in_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_MemoryError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MemoryView_of_r_at_0x_x);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MemoryView_of_r_object);
  Py_CLEAR(clear_module_state->__pyx_n_b_O);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Sequence);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Step_may_not_be_zero_axis_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unable_to_convert_item_to_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_View_MemoryView);
  Py_CLEAR(clear_module_state->__pyx_n_s_X_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_X_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_n_s__3);
  Py_CLEAR(clear_module_state->__pyx_n_s__38);
  Py_CLEAR(clear_module_state->__pyx_kp_u__6);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_n_s_a6);
  Py_CLEAR(clear_module_state->__pyx_n_u_a6);
  Py_CLEAR(clear_module_state->__pyx_n_s_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_allocate_buffer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_auxderivs);
  Py_CLEAR(clear_module_state->__pyx_n_s_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_u_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_call);
  Py_CLEAR(clear_module_state->__pyx_n_s_chi_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_chi_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_collections);
  Py_CLEAR(clear_module_state->__pyx_kp_s_collections_abc);
  Py_CLEAR(clear_module_state->__pyx_kp_s_contiguous_and_direct);
  Py_CLEAR(clear_module_state->__pyx_kp_s_contiguous_and_indirect);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_dSO);
  Py_CLEAR(clear_module_state->__pyx_n_u_dSO);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype_is_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_dynamics);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_encode);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_evaluate_H);
  Py_CLEAR(clear_module_state->__pyx_n_s_flags);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_fortran);
  Py_CLEAR(clear_module_state->__pyx_n_u_fortran);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_got);
  Py_CLEAR(clear_module_state->__pyx_kp_u_got_differing_extents_in_dimensi);
  Py_CLEAR(clear_module_state->__pyx_n_s_grad);
  Py_CLEAR(clear_module_state->__pyx_n_s_hessian);
  Py_CLEAR(clear_module_state->__pyx_n_s_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_itemsize);
  Py_CLEAR(clear_module_state->__pyx_kp_s_itemsize_0_for_cython_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_memview);
  Py_CLEAR(clear_module_state->__pyx_n_s_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ndim);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_CLEAR(clear_module_state->__pyx_n_s_np);
  Py_CLEAR(clear_module_state->__pyx_n_s_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_numpy);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy_core_multiarray_failed_to);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy_core_umath_failed_to_impor);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_omega);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_pack);
  Py_CLEAR(clear_module_state->__pyx_n_s_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_Enum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_q);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_register);
  Py_CLEAR(clear_module_state->__pyx_n_s_reshape);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_shape);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_direct);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_direct_or_indirect);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_indirect);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_struct);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unable_to_allocate_array_data);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unable_to_allocate_shape_and_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_unpack);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_info);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_112105877);
  Py_CLEAR(clear_module_state->__pyx_int_136983863);
  Py_CLEAR(clear_module_state->__pyx_int_184977713);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_slice__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__4);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_tuple__10);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__21);
  Py_CLEAR(clear_module_state->__pyx_tuple__22);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__26);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__28);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__30);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__33);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__35);
  Py_CLEAR(clear_module_state->__pyx_tuple__36);
  Py_CLEAR(clear_module_state->__pyx_tuple__37);
  Py_CLEAR(clear_module_state->__pyx_codeobj__11);
  Py_CLEAR(clear_module_state->__pyx_codeobj__12);
  Py_CLEAR(clear_module_state->__pyx_codeobj__13);
  Py_CLEAR(clear_module_state->__pyx_codeobj__14);
  Py_CLEAR(clear_module_state->__pyx_codeobj__16);
  Py_CLEAR(clear_module_state->__pyx_codeobj__17);
  Py_CLEAR(clear_module_state->__pyx_codeobj__18);
  Py_CLEAR(clear_module_state->__pyx_codeobj__19);
  Py_CLEAR(clear_module_state->__pyx_codeobj__20);
  Py_CLEAR(clear_module_state->__pyx_codeobj__31);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_dtype);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flatiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_broadcast);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ndarray);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_generic);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_number);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_integer);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_inexact);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_floating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flexible);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_character);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ufunc);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C);
  Py_VISIT(traverse_module_state->__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);
  Py_VISIT(traverse_module_state->__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);
  Py_VISIT(traverse_module_state->__pyx_array_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_array);
  Py_VISIT(traverse_module_state->__pyx_MemviewEnum_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_MemviewEnum);
  Py_VISIT(traverse_module_state->__pyx_memoryview_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_memoryview);
  Py_VISIT(traverse_module_state->__pyx_memoryviewslice_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_memoryviewslice);
  Py_VISIT(traverse_module_state->__pyx_kp_u_);
  Py_VISIT(traverse_module_state->__pyx_n_s_ASCII);
  Py_VISIT(traverse_module_state->__pyx_kp_s_All_dimensions_preceding_dimensi);
  Py_VISIT(traverse_module_state->__pyx_n_s_AssertionError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Buffer_view_does_not_expose_stri);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Can_only_create_a_buffer_that_is);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_assign_to_read_only_memor);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_create_writable_memory_vi);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_index_with_type);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_transpose_memoryview_with);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Dimension_d_is_not_direct);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ellipsis);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Empty_shape_tuple_for_cython_arr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_ImportError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_IndexError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Index_out_of_bounds_axis_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Indirect_dimensions_not_supporte);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_mode_expected_c_or_fortr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_shape_in_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_MemoryError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MemoryView_of_r_at_0x_x);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MemoryView_of_r_object);
  Py_VISIT(traverse_module_state->__pyx_n_b_O);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Sequence);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Step_may_not_be_zero_axis_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unable_to_convert_item_to_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_View_MemoryView);
  Py_VISIT(traverse_module_state->__pyx_n_s_X_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_X_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_n_s__3);
  Py_VISIT(traverse_module_state->__pyx_n_s__38);
  Py_VISIT(traverse_module_state->__pyx_kp_u__6);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_n_s_a6);
  Py_VISIT(traverse_module_state->__pyx_n_u_a6);
  Py_VISIT(traverse_module_state->__pyx_n_s_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_allocate_buffer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_auxderivs);
  Py_VISIT(traverse_module_state->__pyx_n_s_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_u_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_call);
  Py_VISIT(traverse_module_state->__pyx_n_s_chi_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_chi_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_collections);
  Py_VISIT(traverse_module_state->__pyx_kp_s_collections_abc);
  Py_VISIT(traverse_module_state->__pyx_kp_s_contiguous_and_direct);
  Py_VISIT(traverse_module_state->__pyx_kp_s_contiguous_and_indirect);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_dSO);
  Py_VISIT(traverse_module_state->__pyx_n_u_dSO);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype_is_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_dynamics);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_encode);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_evaluate_H);
  Py_VISIT(traverse_module_state->__pyx_n_s_flags);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_fortran);
  Py_VISIT(traverse_module_state->__pyx_n_u_fortran);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_got);
  Py_VISIT(traverse_module_state->__pyx_kp_u_got_differing_extents_in_dimensi);
  Py_VISIT(traverse_module_state->__pyx_n_s_grad);
  Py_VISIT(traverse_module_state->__pyx_n_s_hessian);
  Py_VISIT(traverse_module_state->__pyx_n_s_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_itemsize);
  Py_VISIT(traverse_module_state->__pyx_kp_s_itemsize_0_for_cython_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_memview);
  Py_VISIT(traverse_module_state->__pyx_n_s_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ndim);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_VISIT(traverse_module_state->__pyx_n_s_np);
  Py_VISIT(traverse_module_state->__pyx_n_s_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_numpy);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy_core_multiarray_failed_to);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy_core_umath_failed_to_impor);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_omega);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_pack);
  Py_VISIT(traverse_module_state->__pyx_n_s_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_Enum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_q);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_register);
  Py_VISIT(traverse_module_state->__pyx_n_s_reshape);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_shape);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_direct);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_direct_or_indirect);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_indirect);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_struct);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unable_to_allocate_array_data);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unable_to_allocate_shape_and_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_unpack);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_info);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_112105877);
  Py_VISIT(traverse_module_state->__pyx_int_136983863);
  Py_VISIT(traverse_module_state->__pyx_int_184977713);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_slice__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__4);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_tuple__10);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__21);
  Py_VISIT(traverse_module_state->__pyx_tuple__22);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__26);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__28);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__30);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__33);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__35);
  Py_VISIT(traverse_module_state->__pyx_tuple__36);
  Py_VISIT(traverse_module_state->__pyx_tuple__37);
  Py_VISIT(traverse_module_state->__pyx_codeobj__11);
  Py_VISIT(traverse_module_state->__pyx_codeobj__12);
  Py_VISIT(traverse_module_state->__pyx_codeobj__13);
  Py_VISIT(traverse_module_state->__pyx_codeobj__14);
  Py_VISIT(traverse_module_state->__pyx_codeobj__16);
  Py_VISIT(traverse_module_state->__pyx_codeobj__17);
  Py_VISIT(traverse_module_state->__pyx_codeobj__18);
  Py_VISIT(traverse_module_state->__pyx_codeobj__19);
  Py_VISIT(traverse_module_state->__pyx_codeobj__20);
  Py_VISIT(traverse_module_state->__pyx_codeobj__31);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_5numpy_dtype __pyx_mstate_global->__pyx_ptype_5numpy_dtype
#define __pyx_ptype_5numpy_flatiter __pyx_mstate_global->__pyx_ptype_5numpy_flatiter
#define __pyx_ptype_5numpy_broadcast __pyx_mstate_global->__pyx_ptype_5numpy_broadcast
#define __pyx_ptype_5numpy_ndarray __pyx_mstate_global->__pyx_ptype_5numpy_ndarray
#define __pyx_ptype_5numpy_generic __pyx_mstate_global->__pyx_ptype_5numpy_generic
#define __pyx_ptype_5numpy_number __pyx_mstate_global->__pyx_ptype_5numpy_number
#define __pyx_ptype_5numpy_integer __pyx_mstate_global->__pyx_ptype_5numpy_integer
#define __pyx_ptype_5numpy_signedinteger __pyx_mstate_global->__pyx_ptype_5numpy_signedinteger
#define __pyx_ptype_5numpy_unsignedinteger __pyx_mstate_global->__pyx_ptype_5numpy_unsignedinteger
#define __pyx_ptype_5numpy_inexact __pyx_mstate_global->__pyx_ptype_5numpy_inexact
#define __pyx_ptype_5numpy_floating __pyx_mstate_global->__pyx_ptype_5numpy_floating
#define __pyx_ptype_5numpy_complexfloating __pyx_mstate_global->__pyx_ptype_5numpy_complexfloating
#define __pyx_ptype_5numpy_flexible __pyx_mstate_global->__pyx_ptype_5numpy_flexible
#define __pyx_ptype_5numpy_character __pyx_mstate_global->__pyx_ptype_5numpy_character
#define __pyx_ptype_5numpy_ufunc __pyx_mstate_global->__pyx_ptype_5numpy_ufunc
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams
#define __pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs
#define __pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics
#define __pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams
#define __pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C __pyx_mstate_global->__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C
#define __pyx_type___pyx_array __pyx_mstate_global->__pyx_type___pyx_array
#define __pyx_type___pyx_MemviewEnum __pyx_mstate_global->__pyx_type___pyx_MemviewEnum
#define __pyx_type___pyx_memoryview __pyx_mstate_global->__pyx_type___pyx_memoryview
#define __pyx_type___pyx_memoryviewslice __pyx_mstate_global->__pyx_type___pyx_memoryviewslice
#endif
#define __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C __pyx_mstate_global->__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C
#define __pyx_array_type __pyx_mstate_global->__pyx_array_type
#define __pyx_MemviewEnum_type __pyx_mstate_global->__pyx_MemviewEnum_type
#define __pyx_memoryview_type __pyx_mstate_global->__pyx_memoryview_type
#define __pyx_memoryviewslice_type __pyx_mstate_global->__pyx_memoryviewslice_type
#define __pyx_kp_u_ __pyx_mstate_global->__pyx_kp_u_
#define __pyx_n_s_ASCII __pyx_mstate_global->__pyx_n_s_ASCII
#define __pyx_kp_s_All_dimensions_preceding_dimensi __pyx_mstate_global->__pyx_kp_s_All_dimensions_preceding_dimensi
#define __pyx_n_s_AssertionError __pyx_mstate_global->__pyx_n_s_AssertionError
#define __pyx_kp_s_Buffer_view_does_not_expose_stri __pyx_mstate_global->__pyx_kp_s_Buffer_view_does_not_expose_stri
#define __pyx_kp_s_Can_only_create_a_buffer_that_is __pyx_mstate_global->__pyx_kp_s_Can_only_create_a_buffer_that_is
#define __pyx_kp_s_Cannot_assign_to_read_only_memor __pyx_mstate_global->__pyx_kp_s_Cannot_assign_to_read_only_memor
#define __pyx_kp_s_Cannot_create_writable_memory_vi __pyx_mstate_global->__pyx_kp_s_Cannot_create_writable_memory_vi
#define __pyx_kp_u_Cannot_index_with_type __pyx_mstate_global->__pyx_kp_u_Cannot_index_with_type
#define __pyx_kp_s_Cannot_transpose_memoryview_with __pyx_mstate_global->__pyx_kp_s_Cannot_transpose_memoryview_with
#define __pyx_kp_s_Dimension_d_is_not_direct __pyx_mstate_global->__pyx_kp_s_Dimension_d_is_not_direct
#define __pyx_n_s_Ellipsis __pyx_mstate_global->__pyx_n_s_Ellipsis
#define __pyx_kp_s_Empty_shape_tuple_for_cython_arr __pyx_mstate_global->__pyx_kp_s_Empty_shape_tuple_for_cython_arr
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8
#define __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9 __pyx_mstate_global->__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9
#define __pyx_n_s_ImportError __pyx_mstate_global->__pyx_n_s_ImportError
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_n_s_IndexError __pyx_mstate_global->__pyx_n_s_IndexError
#define __pyx_kp_s_Index_out_of_bounds_axis_d __pyx_mstate_global->__pyx_kp_s_Index_out_of_bounds_axis_d
#define __pyx_kp_s_Indirect_dimensions_not_supporte __pyx_mstate_global->__pyx_kp_s_Indirect_dimensions_not_supporte
#define __pyx_kp_u_Invalid_mode_expected_c_or_fortr __pyx_mstate_global->__pyx_kp_u_Invalid_mode_expected_c_or_fortr
#define __pyx_kp_u_Invalid_shape_in_axis __pyx_mstate_global->__pyx_kp_u_Invalid_shape_in_axis
#define __pyx_n_s_M __pyx_mstate_global->__pyx_n_s_M
#define __pyx_n_s_MemoryError __pyx_mstate_global->__pyx_n_s_MemoryError
#define __pyx_kp_s_MemoryView_of_r_at_0x_x __pyx_mstate_global->__pyx_kp_s_MemoryView_of_r_at_0x_x
#define __pyx_kp_s_MemoryView_of_r_object __pyx_mstate_global->__pyx_kp_s_MemoryView_of_r_object
#define __pyx_n_b_O __pyx_mstate_global->__pyx_n_b_O
#define __pyx_kp_u_Out_of_bounds_on_buffer_access_a __pyx_mstate_global->__pyx_kp_u_Out_of_bounds_on_buffer_access_a
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_s_Sequence __pyx_mstate_global->__pyx_n_s_Sequence
#define __pyx_kp_s_Step_may_not_be_zero_axis_d __pyx_mstate_global->__pyx_kp_s_Step_may_not_be_zero_axis_d
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_kp_s_Unable_to_convert_item_to_object __pyx_mstate_global->__pyx_kp_s_Unable_to_convert_item_to_object
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_View_MemoryView __pyx_mstate_global->__pyx_n_s_View_MemoryView
#define __pyx_n_s_X_1 __pyx_mstate_global->__pyx_n_s_X_1
#define __pyx_n_s_X_2 __pyx_mstate_global->__pyx_n_s_X_2
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_n_s__3 __pyx_mstate_global->__pyx_n_s__3
#define __pyx_n_s__38 __pyx_mstate_global->__pyx_n_s__38
#define __pyx_kp_u__6 __pyx_mstate_global->__pyx_kp_u__6
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_n_s_a6 __pyx_mstate_global->__pyx_n_s_a6
#define __pyx_n_u_a6 __pyx_mstate_global->__pyx_n_u_a6
#define __pyx_n_s_abc __pyx_mstate_global->__pyx_n_s_abc
#define __pyx_n_s_allocate_buffer __pyx_mstate_global->__pyx_n_s_allocate_buffer
#define __pyx_kp_u_and __pyx_mstate_global->__pyx_kp_u_and
#define __pyx_n_s_array __pyx_mstate_global->__pyx_n_s_array
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_auxderivs __pyx_mstate_global->__pyx_n_s_auxderivs
#define __pyx_n_s_base __pyx_mstate_global->__pyx_n_s_base
#define __pyx_n_s_c __pyx_mstate_global->__pyx_n_s_c
#define __pyx_n_u_c __pyx_mstate_global->__pyx_n_u_c
#define __pyx_n_s_call __pyx_mstate_global->__pyx_n_s_call
#define __pyx_n_s_chi_1 __pyx_mstate_global->__pyx_n_s_chi_1
#define __pyx_n_s_chi_2 __pyx_mstate_global->__pyx_n_s_chi_2
#define __pyx_n_s_class __pyx_mstate_global->__pyx_n_s_class
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_collections __pyx_mstate_global->__pyx_n_s_collections
#define __pyx_kp_s_collections_abc __pyx_mstate_global->__pyx_kp_s_collections_abc
#define __pyx_kp_s_contiguous_and_direct __pyx_mstate_global->__pyx_kp_s_contiguous_and_direct
#define __pyx_kp_s_contiguous_and_indirect __pyx_mstate_global->__pyx_kp_s_contiguous_and_indirect
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_dSO __pyx_mstate_global->__pyx_n_s_dSO
#define __pyx_n_u_dSO __pyx_mstate_global->__pyx_n_u_dSO
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_dtype_is_object __pyx_mstate_global->__pyx_n_s_dtype_is_object
#define __pyx_n_s_dynamics __pyx_mstate_global->__pyx_n_s_dynamics
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_encode __pyx_mstate_global->__pyx_n_s_encode
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_n_s_evaluate_H __pyx_mstate_global->__pyx_n_s_evaluate_H
#define __pyx_n_s_flags __pyx_mstate_global->__pyx_n_s_flags
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_fortran __pyx_mstate_global->__pyx_n_s_fortran
#define __pyx_n_u_fortran __pyx_mstate_global->__pyx_n_u_fortran
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_kp_u_got __pyx_mstate_global->__pyx_kp_u_got
#define __pyx_kp_u_got_differing_extents_in_dimensi __pyx_mstate_global->__pyx_kp_u_got_differing_extents_in_dimensi
#define __pyx_n_s_grad __pyx_mstate_global->__pyx_n_s_grad
#define __pyx_n_s_hessian __pyx_mstate_global->__pyx_n_s_hessian
#define __pyx_n_s_id __pyx_mstate_global->__pyx_n_s_id
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_itemsize __pyx_mstate_global->__pyx_n_s_itemsize
#define __pyx_kp_s_itemsize_0_for_cython_array __pyx_mstate_global->__pyx_kp_s_itemsize_0_for_cython_array
#define __pyx_n_s_m_1 __pyx_mstate_global->__pyx_n_s_m_1
#define __pyx_n_s_m_2 __pyx_mstate_global->__pyx_n_s_m_2
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_memview __pyx_mstate_global->__pyx_n_s_memview
#define __pyx_n_s_mode __pyx_mstate_global->__pyx_n_s_mode
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_ndim __pyx_mstate_global->__pyx_n_s_ndim
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_kp_s_no_default___reduce___due_to_non __pyx_mstate_global->__pyx_kp_s_no_default___reduce___due_to_non
#define __pyx_n_s_np __pyx_mstate_global->__pyx_n_s_np
#define __pyx_n_s_nu __pyx_mstate_global->__pyx_n_s_nu
#define __pyx_n_s_numpy __pyx_mstate_global->__pyx_n_s_numpy
#define __pyx_kp_u_numpy_core_multiarray_failed_to __pyx_mstate_global->__pyx_kp_u_numpy_core_multiarray_failed_to
#define __pyx_kp_u_numpy_core_umath_failed_to_impor __pyx_mstate_global->__pyx_kp_u_numpy_core_umath_failed_to_impor
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_omega __pyx_mstate_global->__pyx_n_s_omega
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_s_pack __pyx_mstate_global->__pyx_n_s_pack
#define __pyx_n_s_params __pyx_mstate_global->__pyx_n_s_params
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali __pyx_mstate_global->__pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali
#define __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2 __pyx_mstate_global->__pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_Enum __pyx_mstate_global->__pyx_n_s_pyx_unpickle_Enum
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_q __pyx_mstate_global->__pyx_n_s_q
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_register __pyx_mstate_global->__pyx_n_s_register
#define __pyx_n_s_reshape __pyx_mstate_global->__pyx_n_s_reshape
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_shape __pyx_mstate_global->__pyx_n_s_shape
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_start __pyx_mstate_global->__pyx_n_s_start
#define __pyx_n_s_step __pyx_mstate_global->__pyx_n_s_step
#define __pyx_n_s_stop __pyx_mstate_global->__pyx_n_s_stop
#define __pyx_kp_s_strided_and_direct __pyx_mstate_global->__pyx_kp_s_strided_and_direct
#define __pyx_kp_s_strided_and_direct_or_indirect __pyx_mstate_global->__pyx_kp_s_strided_and_direct_or_indirect
#define __pyx_kp_s_strided_and_indirect __pyx_mstate_global->__pyx_kp_s_strided_and_indirect
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_struct __pyx_mstate_global->__pyx_n_s_struct
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_kp_s_unable_to_allocate_array_data __pyx_mstate_global->__pyx_kp_s_unable_to_allocate_array_data
#define __pyx_kp_s_unable_to_allocate_shape_and_str __pyx_mstate_global->__pyx_kp_s_unable_to_allocate_shape_and_str
#define __pyx_n_s_unpack __pyx_mstate_global->__pyx_n_s_unpack
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_verbose __pyx_mstate_global->__pyx_n_s_verbose
#define __pyx_n_s_version_info __pyx_mstate_global->__pyx_n_s_version_info
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_112105877 __pyx_mstate_global->__pyx_int_112105877
#define __pyx_int_136983863 __pyx_mstate_global->__pyx_int_136983863
#define __pyx_int_184977713 __pyx_mstate_global->__pyx_int_184977713
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_slice__5 __pyx_mstate_global->__pyx_slice__5
#define __pyx_tuple__4 __pyx_mstate_global->__pyx_tuple__4
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_tuple__10 __pyx_mstate_global->__pyx_tuple__10
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__21 __pyx_mstate_global->__pyx_tuple__21
#define __pyx_tuple__22 __pyx_mstate_global->__pyx_tuple__22
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__26 __pyx_mstate_global->__pyx_tuple__26
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__28 __pyx_mstate_global->__pyx_tuple__28
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__30 __pyx_mstate_global->__pyx_tuple__30
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__33 __pyx_mstate_global->__pyx_tuple__33
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__35 __pyx_mstate_global->__pyx_tuple__35
#define __pyx_tuple__36 __pyx_mstate_global->__pyx_tuple__36
#define __pyx_tuple__37 __pyx_mstate_global->__pyx_tuple__37
#define __pyx_codeobj__11 __pyx_mstate_global->__pyx_codeobj__11
#define __pyx_codeobj__12 __pyx_mstate_global->__pyx_codeobj__12
#define __pyx_codeobj__13 __pyx_mstate_global->__pyx_codeobj__13
#define __pyx_codeobj__14 __pyx_mstate_global->__pyx_codeobj__14
#define __pyx_codeobj__16 __pyx_mstate_global->__pyx_codeobj__16
#define __pyx_codeobj__17 __pyx_mstate_global->__pyx_codeobj__17
#define __pyx_codeobj__18 __pyx_mstate_global->__pyx_codeobj__18
#define __pyx_codeobj__19 __pyx_mstate_global->__pyx_codeobj__19
#define __pyx_codeobj__20 __pyx_mstate_global->__pyx_codeobj__20
#define __pyx_codeobj__31 __pyx_mstate_global->__pyx_codeobj__31
/* #### Code section: module_code ### */

/* "carray.to_py":114
 * 
 * @cname("__Pyx_carray_to_py_double")
 * cdef inline list __Pyx_carray_to_py_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_double(double *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_double", 0);
  __Pyx_TraceCall("__Pyx_carray_to_py_double", __pyx_f[0], 114, 0, __PYX_ERR(0, 114, __pyx_L1_error));

  /* "carray.to_py":117
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __Pyx_TraceLine(117,0,__PYX_ERR(0, 117, __pyx_L1_error))
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":118
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __Pyx_TraceLine(118,0,__PYX_ERR(0, 118, __pyx_L1_error))
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":119
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __Pyx_TraceLine(119,0,__PYX_ERR(0, 119, __pyx_L1_error))
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":120
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    __Pyx_TraceLine(120,0,__PYX_ERR(0, 120, __pyx_L1_error))
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":121
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    __Pyx_TraceLine(121,0,__PYX_ERR(0, 121, __pyx_L1_error))
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":122
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(122,0,__PYX_ERR(0, 122, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":114
 * 
 * @cname("__Pyx_carray_to_py_double")
 * cdef inline list __Pyx_carray_to_py_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_double", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":126
 * 
 * @cname("__Pyx_carray_to_tuple_double")
 * cdef inline tuple __Pyx_carray_to_tuple_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_double(double *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_double", 0);
  __Pyx_TraceCall("__Pyx_carray_to_tuple_double", __pyx_f[0], 126, 0, __PYX_ERR(0, 126, __pyx_L1_error));

  /* "carray.to_py":129
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __Pyx_TraceLine(129,0,__PYX_ERR(0, 129, __pyx_L1_error))
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":130
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __Pyx_TraceLine(130,0,__PYX_ERR(0, 130, __pyx_L1_error))
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":131
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __Pyx_TraceLine(131,0,__PYX_ERR(0, 131, __pyx_L1_error))
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":132
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    __Pyx_TraceLine(132,0,__PYX_ERR(0, 132, __pyx_L1_error))
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":133
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    __Pyx_TraceLine(133,0,__PYX_ERR(0, 133, __pyx_L1_error))
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":134
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_TraceLine(134,0,__PYX_ERR(0, 134, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":126
 * 
 * @cname("__Pyx_carray_to_tuple_double")
 * cdef inline tuple __Pyx_carray_to_tuple_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_double", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

/* Python wrapper */
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_shape = 0;
  Py_ssize_t __pyx_v_itemsize;
  PyObject *__pyx_v_format = 0;
  PyObject *__pyx_v_mode = 0;
  int __pyx_v_allocate_buffer;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_shape,&__pyx_n_s_itemsize,&__pyx_n_s_format,&__pyx_n_s_mode,&__pyx_n_s_allocate_buffer,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[3] = ((PyObject *)__pyx_n_s_c);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_shape)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_itemsize)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 1); __PYX_ERR(0, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_format)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 2); __PYX_ERR(0, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[3] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_allocate_buffer);
          if (value) { values[4] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 131, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_shape = ((PyObject*)values[0]);
    __pyx_v_itemsize = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_itemsize == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L3_error)
    __pyx_v_format = values[2];
    __pyx_v_mode = values[3];
    if (values[4]) {
      __pyx_v_allocate_buffer = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_allocate_buffer == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 132, __pyx_L3_error)
    } else {

      /* "View.MemoryView":132
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,
 *                   mode="c", bint allocate_buffer=True):             # <<<<<<<<<<<<<<
 * 
 *         cdef int idx
 */
      __pyx_v_allocate_buffer = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 131, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_shape), (&PyTuple_Type), 1, "shape", 1))) __PYX_ERR(0, 131, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_format) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "format"); __PYX_ERR(0, 131, __pyx_L1_error)
  }
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v_shape, __pyx_v_itemsize, __pyx_v_format, __pyx_v_mode, __pyx_v_allocate_buffer);

  /* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_v_dim;
  char __pyx_v_order;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  char *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_INCREF(__pyx_v_format);

  /* "View.MemoryView":137
 *         cdef Py_ssize_t dim
 * 
 *         self.ndim = <int> len(shape)             # <<<<<<<<<<<<<<
 *         self.itemsize = itemsize
 * 
 */
  if (unlikely(__pyx_v_shape == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 137, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_GET_SIZE(__pyx_v_shape); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 137, __pyx_L1_error)
  __pyx_v_self->ndim = ((int)__pyx_t_1);

  /* "View.MemoryView":138
 * 
 *         self.ndim = <int> len(shape)
 *         self.itemsize = itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not self.ndim:
 */
  __pyx_v_self->itemsize = __pyx_v_itemsize;

  /* "View.MemoryView":140
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->ndim != 0));
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":141
 * 
 *         if not self.ndim:
 *             raise ValueError, "Empty shape tuple for cython.array"             # <<<<<<<<<<<<<<
 * 
 *         if itemsize <= 0:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Empty_shape_tuple_for_cython_arr, 0, 0);
    __PYX_ERR(0, 141, __pyx_L1_error)

    /* "View.MemoryView":140
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 */
  }

  /* "View.MemoryView":143
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 */
  __pyx_t_2 = (__pyx_v_itemsize <= 0);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":144
 * 
 *         if itemsize <= 0:
 *             raise ValueError, "itemsize <= 0 for cython.array"             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(format, bytes):
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_itemsize_0_for_cython_array, 0, 0);
    __PYX_ERR(0, 144, __pyx_L1_error)

    /* "View.MemoryView":143
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 */
  }

  /* "View.MemoryView":146
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_format); 
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "View.MemoryView":147
 * 
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')             # <<<<<<<<<<<<<<
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_format, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_s_ASCII};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_format, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "View.MemoryView":146
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  }

  /* "View.MemoryView":148
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string             # <<<<<<<<<<<<<<
 *         self.format = self._format
 * 
 */
  if (!(likely(PyBytes_CheckExact(__pyx_v_format))||((__pyx_v_format) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_v_format))) __PYX_ERR(0, 148, __pyx_L1_error)
  __pyx_t_4 = __pyx_v_format;
  __Pyx_INCREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_format);
  __Pyx_DECREF(__pyx_v_self->_format);
  __pyx_v_self->_format = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "View.MemoryView":149
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_self->_format == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 149, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyBytes_AsWritableString(__pyx_v_self->_format); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) __PYX_ERR(0, 149, __pyx_L1_error)
  __pyx_v_self->format = __pyx_t_8;

  /* "View.MemoryView":152
 * 
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)             # <<<<<<<<<<<<<<
 *         self._strides = self._shape + self.ndim
 * 
 */
  __pyx_v_self->_shape = ((Py_ssize_t *)PyObject_Malloc((((sizeof(Py_ssize_t)) * __pyx_v_self->ndim) * 2)));

  /* "View.MemoryView":153
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)
 *         self._strides = self._shape + self.ndim             # <<<<<<<<<<<<<<
 * 
 *         if not self._shape:
 */
  __pyx_v_self->_strides = (__pyx_v_self->_shape + __pyx_v_self->ndim);

  /* "View.MemoryView":155
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError, "unable to allocate shape and strides."
 * 
 */
  __pyx_t_3 = (!(__pyx_v_self->_shape != 0));
  if (unlikely(__pyx_t_3)) {

    /* "View.MemoryView":156
 * 
 *         if not self._shape:
 *             raise MemoryError, "unable to allocate shape and strides."             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_builtin_MemoryError, __pyx_kp_s_unable_to_allocate_shape_and_str, 0, 0);
    __PYX_ERR(0, 156, __pyx_L1_error)

    /* "View.MemoryView":155
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError, "unable to allocate shape and strides."
 * 
 */
  }

  /* "View.MemoryView":159
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 */
  __pyx_t_7 = 0;
  __pyx_t_4 = __pyx_v_shape; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
  for (;;) {
    if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely((0 < 0))) __PYX_ERR(0, 159, __pyx_L1_error)
    #else
    __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_9;
    __pyx_v_idx = __pyx_t_7;
    __pyx_t_7 = (__pyx_t_7 + 1);

    /* "View.MemoryView":160
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim
 */
    __pyx_t_3 = (__pyx_v_dim <= 0);
    if (unlikely(__pyx_t_3)) {

      /* "View.MemoryView":161
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."             # <<<<<<<<<<<<<<
 *             self._shape[idx] = dim
 * 
 */
      __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = 0;
      __pyx_t_10 = 127;
      __Pyx_INCREF(__pyx_kp_u_Invalid_shape_in_axis);
      __pyx_t_9 += 22;
      __Pyx_GIVEREF(__pyx_kp_u_Invalid_shape_in_axis);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_Invalid_shape_in_axis);
      __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_idx, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u_);
      __pyx_t_9 += 2;
      __Pyx_GIVEREF(__pyx_kp_u_);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_);
      __pyx_t_6 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__2);
      __pyx_t_9 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__2);
      PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_kp_u__2);
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_6, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 161, __pyx_L1_error)

      /* "View.MemoryView":160
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim
 */
    }

    /* "View.MemoryView":162
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim             # <<<<<<<<<<<<<<
 * 
 *         cdef char order
 */
    (__pyx_v_self->_shape[__pyx_v_idx]) = __pyx_v_dim;

    /* "View.MemoryView":159
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "View.MemoryView":165
 * 
 *         cdef char order
 *         if mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_c, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 165, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "View.MemoryView":166
 *         cdef char order
 *         if mode == 'c':
 *             order = b'C'             # <<<<<<<<<<<<<<
 *             self.mode = u'c'
 *         elif mode == 'fortran':
 */
    __pyx_v_order = 'C';

    /* "View.MemoryView":167
 *         if mode == 'c':
 *             order = b'C'
 *             self.mode = u'c'             # <<<<<<<<<<<<<<
 *         elif mode == 'fortran':
 *             order = b'F'
 */
    __Pyx_INCREF(__pyx_n_u_c);
    __Pyx_GIVEREF(__pyx_n_u_c);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_c;

    /* "View.MemoryView":165
 * 
 *         cdef char order
 *         if mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":168
 *             order = b'C'
 *             self.mode = u'c'
 *         elif mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_fortran, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 168, __pyx_L1_error)
  if (likely(__pyx_t_3)) {

    /* "View.MemoryView":169
 *             self.mode = u'c'
 *         elif mode == 'fortran':
 *             order = b'F'             # <<<<<<<<<<<<<<
 *             self.mode = u'fortran'
 *         else:
 */
    __pyx_v_order = 'F';

    /* "View.MemoryView":170
 *         elif mode == 'fortran':
 *             order = b'F'
 *             self.mode = u'fortran'             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"
 */
    __Pyx_INCREF(__pyx_n_u_fortran);
    __Pyx_GIVEREF(__pyx_n_u_fortran);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_fortran;

    /* "View.MemoryView":168
 *             order = b'C'
 *             self.mode = u'c'
 *         elif mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":172
 *             self.mode = u'fortran'
 *         else:
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"             # <<<<<<<<<<<<<<
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_mode, __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Invalid_mode_expected_c_or_fortr, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_6, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 172, __pyx_L1_error)
  }
  __pyx_L11:;

  /* "View.MemoryView":174
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)             # <<<<<<<<<<<<<<
 * 
 *         self.free_data = allocate_buffer
 */
  __pyx_v_self->len = __pyx_fill_contig_strides_array(__pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_itemsize, __pyx_v_self->ndim, __pyx_v_order);

  /* "View.MemoryView":176
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)
 * 
 *         self.free_data = allocate_buffer             # <<<<<<<<<<<<<<
 *         self.dtype_is_object = format == b'O'
 * 
 */
  __pyx_v_self->free_data = __pyx_v_allocate_buffer;

  /* "View.MemoryView":177
 * 
 *         self.free_data = allocate_buffer
 *         self.dtype_is_object = format == b'O'             # <<<<<<<<<<<<<<
 * 
 *         if allocate_buffer:
 */
  __pyx_t_6 = PyObject_RichCompare(__pyx_v_format, __pyx_n_b_O, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 177, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_self->dtype_is_object = __pyx_t_3;

  /* "View.MemoryView":179
 *         self.dtype_is_object = format == b'O'
 * 
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 *             _allocate_buffer(self)
 * 
 */
  if (__pyx_v_allocate_buffer) {

    /* "View.MemoryView":180
 * 
 *         if allocate_buffer:
 *             _allocate_buffer(self)             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_t_7 = __pyx_array_allocate_buffer(__pyx_v_self); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 180, __pyx_L1_error)

    /* "View.MemoryView":179
 *         self.dtype_is_object = format == b'O'
 * 
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 *             _allocate_buffer(self)
 * 
 */
  }

  /* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_format);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":182
 *             _allocate_buffer(self)
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 */

/* Python wrapper */
CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(((struct __pyx_array_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_bufmode;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  char *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":184
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1             # <<<<<<<<<<<<<<
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":
 */
  __pyx_v_bufmode = -1;

  /* "View.MemoryView":185
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):             # <<<<<<<<<<<<<<
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  __pyx_t_1 = ((__pyx_v_flags & ((PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS) | PyBUF_ANY_CONTIGUOUS)) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":186
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 186, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":187
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
      __pyx_v_bufmode = (PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

      /* "View.MemoryView":186
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":188
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_fortran, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 188, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":189
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 */
      __pyx_v_bufmode = (PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

      /* "View.MemoryView":188
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 */
    }
    __pyx_L4:;

    /* "View.MemoryView":190
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 */
    __pyx_t_1 = (!((__pyx_v_flags & __pyx_v_bufmode) != 0));
    if (unlikely(__pyx_t_1)) {

      /* "View.MemoryView":191
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."             # <<<<<<<<<<<<<<
 *         info.buf = self.data
 *         info.len = self.len
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Can_only_create_a_buffer_that_is, 0, 0);
      __PYX_ERR(0, 191, __pyx_L1_error)

      /* "View.MemoryView":190
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 */
    }

    /* "View.MemoryView":185
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):             # <<<<<<<<<<<<<<
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  }

  /* "View.MemoryView":192
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data             # <<<<<<<<<<<<<<
 *         info.len = self.len
 * 
 */
  __pyx_t_2 = __pyx_v_self->data;
  __pyx_v_info->buf = __pyx_t_2;

  /* "View.MemoryView":193
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 *         info.len = self.len             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  __pyx_t_3 = __pyx_v_self->len;
  __pyx_v_info->len = __pyx_t_3;

  /* "View.MemoryView":195
 *         info.len = self.len
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":196
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.ndim = self.ndim             # <<<<<<<<<<<<<<
 *             info.shape = self._shape
 *             info.strides = self._strides
 */
    __pyx_t_4 = __pyx_v_self->ndim;
    __pyx_v_info->ndim = __pyx_t_4;

    /* "View.MemoryView":197
 *         if flags & PyBUF_STRIDES:
 *             info.ndim = self.ndim
 *             info.shape = self._shape             # <<<<<<<<<<<<<<
 *             info.strides = self._strides
 *         else:
 */
    __pyx_t_5 = __pyx_v_self->_shape;
    __pyx_v_info->shape = __pyx_t_5;

    /* "View.MemoryView":198
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 *             info.strides = self._strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.ndim = 1
 */
    __pyx_t_5 = __pyx_v_self->_strides;
    __pyx_v_info->strides = __pyx_t_5;

    /* "View.MemoryView":195
 *         info.len = self.len
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":200
 *             info.strides = self._strides
 *         else:
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.shape = &self.len if flags & PyBUF_ND else NULL
 *             info.strides = NULL
 */
  /*else*/ {
    __pyx_v_info->ndim = 1;

    /* "View.MemoryView":201
 *         else:
 *             info.ndim = 1
 *             info.shape = &self.len if flags & PyBUF_ND else NULL             # <<<<<<<<<<<<<<
 *             info.strides = NULL
 * 
 */
    if (((__pyx_v_flags & PyBUF_ND) != 0)) {
      __pyx_t_5 = (&__pyx_v_self->len);
    } else {
      __pyx_t_5 = NULL;
    }
    __pyx_v_info->shape = __pyx_t_5;

    /* "View.MemoryView":202
 *             info.ndim = 1
 *             info.shape = &self.len if flags & PyBUF_ND else NULL
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.suboffsets = NULL
 */
    __pyx_v_info->strides = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":204
 *             info.strides = NULL
 * 
 *         info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 */
  __pyx_v_info->suboffsets = NULL;

  /* "View.MemoryView":205
 * 
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize             # <<<<<<<<<<<<<<
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 */
  __pyx_t_3 = __pyx_v_self->itemsize;
  __pyx_v_info->itemsize = __pyx_t_3;

  /* "View.MemoryView":206
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize
 *         info.readonly = 0             # <<<<<<<<<<<<<<
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 *         info.obj = self
 */
  __pyx_v_info->readonly = 0;

  /* "View.MemoryView":207
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  if (((__pyx_v_flags & PyBUF_FORMAT) != 0)) {
    __pyx_t_2 = __pyx_v_self->format;
  } else {
    __pyx_t_2 = NULL;
  }
  __pyx_v_info->format = __pyx_t_2;

  /* "View.MemoryView":208
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(array self):
 */
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":182
 *             _allocate_buffer(self)
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":210
 *         info.obj = self
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

/* Python wrapper */
static void __pyx_array___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_array___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "View.MemoryView":211
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 */
  __pyx_t_1 = (__pyx_v_self->callback_free_data != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":212
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)             # <<<<<<<<<<<<<<
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:
 */
    __pyx_v_self->callback_free_data(__pyx_v_self->data);

    /* "View.MemoryView":211
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":213
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 */
  if (__pyx_v_self->free_data) {
  } else {
    __pyx_t_1 = __pyx_v_self->free_data;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->data != NULL);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":214
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 */
    if (__pyx_v_self->dtype_is_object) {

      /* "View.MemoryView":215
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)             # <<<<<<<<<<<<<<
 *             free(self.data)
 *         PyObject_Free(self._shape)
 */
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_self->data, __pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_self->ndim, 0);

      /* "View.MemoryView":214
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 */
    }

    /* "View.MemoryView":216
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)             # <<<<<<<<<<<<<<
 *         PyObject_Free(self._shape)
 * 
 */
    free(__pyx_v_self->data);

    /* "View.MemoryView":213
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":217
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 *         PyObject_Free(self._shape)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  PyObject_Free(__pyx_v_self->_shape);

  /* "View.MemoryView":210
 *         info.obj = self
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":219
 *         PyObject_Free(self._shape)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def memview(self):
 *         return self.get_memview()
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_5array_7memview___get__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":221
 *     @property
 *     def memview(self):
 *         return self.get_memview()             # <<<<<<<<<<<<<<
 * 
 *     @cname('get_memview')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_array *)__pyx_v_self->__pyx_vtab)->get_memview(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":219
 *         PyObject_Free(self._shape)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def memview(self):
 *         return self.get_memview()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.memview.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":224
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self) {
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_memview", 0);

  /* "View.MemoryView":225
 *     @cname('get_memview')
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE             # <<<<<<<<<<<<<<
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 */
  __pyx_v_flags = ((PyBUF_ANY_CONTIGUOUS | PyBUF_FORMAT) | PyBUF_WRITABLE);

  /* "View.MemoryView":226
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":224
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.array.get_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":228
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "View.MemoryView":229
 * 
 *     def __len__(self):
 *         return self._shape[0]             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, attr):
 */
  __pyx_r = (__pyx_v_self->_shape[0]);
  goto __pyx_L0;

  /* "View.MemoryView":228
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":231
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr); /*proto*/
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_attr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "View.MemoryView":232
 * 
 *     def __getattr__(self, attr):
 *         return getattr(self.memview, attr)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, item):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":231
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":234
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "View.MemoryView":235
 * 
 *     def __getitem__(self, item):
 *         return self.memview[item]             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, item, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_item); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":234
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":237
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

/* Python wrapper */
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /*proto*/
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "View.MemoryView":238
 * 
 *     def __setitem__(self, item, value):
 *         self.memview[item] = value             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_item, __pyx_v_value) < 0))) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":237
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_array___reduce_cython__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(0, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_array_2__setstate_cython__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":248
 * 
 * @cname("__pyx_array_allocate_buffer")
 * cdef int _allocate_buffer(array self) except -1:             # <<<<<<<<<<<<<<
 * 
 * 
 */

static int __pyx_array_allocate_buffer(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_v_i;
  PyObject **__pyx_v_p;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_allocate_buffer", 0);

  /* "View.MemoryView":254
 *     cdef PyObject **p
 * 
 *     self.free_data = True             # <<<<<<<<<<<<<<
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:
 */
  __pyx_v_self->free_data = 1;

  /* "View.MemoryView":255
 * 
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)             # <<<<<<<<<<<<<<
 *     if not self.data:
 *         raise MemoryError, "unable to allocate array data."
 */
  __pyx_v_self->data = ((char *)malloc(__pyx_v_self->len));

  /* "View.MemoryView":256
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:             # <<<<<<<<<<<<<<
 *         raise MemoryError, "unable to allocate array data."
 * 
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":257
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:
 *         raise MemoryError, "unable to allocate array data."             # <<<<<<<<<<<<<<
 * 
 *     if self.dtype_is_object:
 */
    __Pyx_Raise(__pyx_builtin_MemoryError, __pyx_kp_s_unable_to_allocate_array_data, 0, 0);
    __PYX_ERR(0, 257, __pyx_L1_error)

    /* "View.MemoryView":256
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:             # <<<<<<<<<<<<<<
 *         raise MemoryError, "unable to allocate array data."
 * 
 */
  }

  /* "View.MemoryView":259
 *         raise MemoryError, "unable to allocate array data."
 * 
 *     if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 */
  if (__pyx_v_self->dtype_is_object) {

    /* "View.MemoryView":260
 * 
 *     if self.dtype_is_object:
 *         p = <PyObject **> self.data             # <<<<<<<<<<<<<<
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None
 */
    __pyx_v_p = ((PyObject **)__pyx_v_self->data);

    /* "View.MemoryView":261
 *     if self.dtype_is_object:
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):             # <<<<<<<<<<<<<<
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)
 */
    if (unlikely(__pyx_v_self->itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(0, 261, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_self->itemsize == (Py_ssize_t)-1)  && unlikely(__Pyx_UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(0, 261, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_div_Py_ssize_t(__pyx_v_self->len, __pyx_v_self->itemsize);
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":262
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None             # <<<<<<<<<<<<<<
 *             Py_INCREF(Py_None)
 *     return 0
 */
      (__pyx_v_p[__pyx_v_i]) = Py_None;

      /* "View.MemoryView":263
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
      Py_INCREF(Py_None);
    }

    /* "View.MemoryView":259
 *         raise MemoryError, "unable to allocate array data."
 * 
 *     if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 */
  }

  /* "View.MemoryView":264
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":248
 * 
 * @cname("__pyx_array_allocate_buffer")
 * cdef int _allocate_buffer(array self) except -1:             # <<<<<<<<<<<<<<
 * 
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._allocate_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":268
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):             # <<<<<<<<<<<<<<
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 */

static struct __pyx_array_obj *__pyx_array_new(PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, char *__pyx_v_format, char *__pyx_v_c_mode, char *__pyx_v_buf) {
  struct __pyx_array_obj *__pyx_v_result = 0;
  PyObject *__pyx_v_mode = 0;
  struct __pyx_array_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("array_cwrapper", 0);

  /* "View.MemoryView":270
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.             # <<<<<<<<<<<<<<
 * 
 *     if buf is NULL:
 */
  if (((__pyx_v_c_mode[0]) == 'f')) {
    __Pyx_INCREF(__pyx_n_s_fortran);
    __pyx_t_1 = __pyx_n_s_fortran;
  } else {
    __Pyx_INCREF(__pyx_n_s_c);
    __pyx_t_1 = __pyx_n_s_c;
  }
  __pyx_v_mode = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":272
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 * 
 *     if buf is NULL:             # <<<<<<<<<<<<<<
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_buf == NULL);
  if (__pyx_t_2) {

    /* "View.MemoryView":273
 * 
 *     if buf is NULL:
 *         result = array.__new__(array, shape, itemsize, format, mode)             # <<<<<<<<<<<<<<
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)
 */
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_v_mode);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = ((PyObject *)__pyx_tp_new_array(((PyTypeObject *)__pyx_array_type), __pyx_t_4, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":272
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 * 
 *     if buf is NULL:             # <<<<<<<<<<<<<<
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":275
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)             # <<<<<<<<<<<<<<
 *         result.data = buf
 * 
 */
  /*else*/ {
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4);
    __Pyx_INCREF(__pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_mode);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_allocate_buffer, Py_False) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
    __pyx_t_3 = ((PyObject *)__pyx_tp_new_array(((PyTypeObject *)__pyx_array_type), __pyx_t_1, __pyx_t_4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":276
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)
 *         result.data = buf             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __pyx_v_result->data = __pyx_v_buf;
  }
  __pyx_L3:;

  /* "View.MemoryView":278
 *         result.data = buf
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":268
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):             # <<<<<<<<<<<<<<
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.array_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_mode);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":304
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

/* Python wrapper */
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 304, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 304, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_name = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 304, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.Enum.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "View.MemoryView":305
 *     cdef object name
 *     def __init__(self, name):
 *         self.name = name             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return self.name
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_name;

  /* "View.MemoryView":304
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":306
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "View.MemoryView":307
 *         self.name = name
 *     def __repr__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* "View.MemoryView":306
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_MemviewEnum___reduce_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.name,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->name);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->name != Py_None);
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_136983863);
    __Pyx_GIVEREF(__pyx_int_136983863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_136983863);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_136983863);
    __Pyx_GIVEREF(__pyx_int_136983863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_136983863);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.Enum.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(0, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 16, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_MemviewEnum_2__setstate_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle_Enum__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":349
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

/* Python wrapper */
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_obj = 0;
  int __pyx_v_flags;
  int __pyx_v_dtype_is_object;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,&__pyx_n_s_flags,&__pyx_n_s_dtype_is_object,0};
    PyObject* values[3] = {0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flags)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(0, 349, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtype_is_object);
          if (value) { values[2] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 349, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_obj = values[0];
    __pyx_v_flags = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_dtype_is_object = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_dtype_is_object == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
    } else {
      __pyx_v_dtype_is_object = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 349, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_obj, __pyx_v_flags, __pyx_v_dtype_is_object);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_intptr_t __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "View.MemoryView":350
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj             # <<<<<<<<<<<<<<
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 */
  __Pyx_INCREF(__pyx_v_obj);
  __Pyx_GIVEREF(__pyx_v_obj);
  __Pyx_GOTREF(__pyx_v_self->obj);
  __Pyx_DECREF(__pyx_v_self->obj);
  __pyx_v_self->obj = __pyx_v_obj;

  /* "View.MemoryView":351
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj
 *         self.flags = flags             # <<<<<<<<<<<<<<
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 */
  __pyx_v_self->flags = __pyx_v_flags;

  /* "View.MemoryView":352
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  __pyx_t_2 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_memoryview_type));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_obj != Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":353
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)             # <<<<<<<<<<<<<<
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 */
    __pyx_t_3 = __Pyx_GetBuffer(__pyx_v_obj, (&__pyx_v_self->view), __pyx_v_flags); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 353, __pyx_L1_error)

    /* "View.MemoryView":354
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->view.obj) == NULL);
    if (__pyx_t_1) {

      /* "View.MemoryView":355
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None             # <<<<<<<<<<<<<<
 *                 Py_INCREF(Py_None)
 * 
 */
      ((Py_buffer *)(&__pyx_v_self->view))->obj = Py_None;

      /* "View.MemoryView":356
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 */
      Py_INCREF(Py_None);

      /* "View.MemoryView":354
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    }

    /* "View.MemoryView":352
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  }

  /* "View.MemoryView":358
 *                 Py_INCREF(Py_None)
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():             # <<<<<<<<<<<<<<
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 */
  __pyx_t_1 = (!__PYX_CYTHON_ATOMICS_ENABLED());
  if (__pyx_t_1) {

    /* "View.MemoryView":360
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:             # <<<<<<<<<<<<<<
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 */
    __pyx_t_1 = (__pyx_memoryview_thread_locks_used < 8);
    if (__pyx_t_1) {

      /* "View.MemoryView":361
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]             # <<<<<<<<<<<<<<
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:
 */
      __pyx_v_self->lock = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);

      /* "View.MemoryView":362
 *             if __pyx_memoryview_thread_locks_used < 8:
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1             # <<<<<<<<<<<<<<
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 */
      __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used + 1);

      /* "View.MemoryView":360
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:             # <<<<<<<<<<<<<<
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 */
    }

    /* "View.MemoryView":363
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 */
    __pyx_t_1 = (__pyx_v_self->lock == NULL);
    if (__pyx_t_1) {

      /* "View.MemoryView":364
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()             # <<<<<<<<<<<<<<
 *                 if self.lock is NULL:
 *                     raise MemoryError
 */
      __pyx_v_self->lock = PyThread_allocate_lock();

      /* "View.MemoryView":365
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
      __pyx_t_1 = (__pyx_v_self->lock == NULL);
      if (unlikely(__pyx_t_1)) {

        /* "View.MemoryView":366
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
        PyErr_NoMemory(); __PYX_ERR(0, 366, __pyx_L1_error)

        /* "View.MemoryView":365
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
      }

      /* "View.MemoryView":363
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 */
    }

    /* "View.MemoryView":358
 *                 Py_INCREF(Py_None)
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():             # <<<<<<<<<<<<<<
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 */
  }

  /* "View.MemoryView":368
 *                     raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":369
 * 
 *         if flags & PyBUF_FORMAT:
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')             # <<<<<<<<<<<<<<
 *         else:
 *             self.dtype_is_object = dtype_is_object
 */
    __pyx_t_2 = ((__pyx_v_self->view.format[0]) == 'O');
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_2 = ((__pyx_v_self->view.format[1]) == '\x00');
    __pyx_t_1 = __pyx_t_2;
    __pyx_L12_bool_binop_done:;
    __pyx_v_self->dtype_is_object = __pyx_t_1;

    /* "View.MemoryView":368
 *                     raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":371
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 *             self.dtype_is_object = dtype_is_object             # <<<<<<<<<<<<<<
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0
 */
  /*else*/ {
    __pyx_v_self->dtype_is_object = __pyx_v_dtype_is_object;
  }
  __pyx_L11:;

  /* "View.MemoryView":373
 *             self.dtype_is_object = dtype_is_object
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0             # <<<<<<<<<<<<<<
 *         self.typeinfo = NULL
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_4 = ((Py_intptr_t)((void *)(&__pyx_v_self->acquisition_count)));
    __pyx_t_5 = (sizeof(__pyx_atomic_int_type));
    if (unlikely(__pyx_t_5 == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(0, 373, __pyx_L1_error)
    }
    __pyx_t_1 = ((__pyx_t_4 % __pyx_t_5) == 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 373, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 373, __pyx_L1_error)
  #endif

  /* "View.MemoryView":374
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0
 *         self.typeinfo = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(memoryview self):
 */
  __pyx_v_self->typeinfo = NULL;

  /* "View.MemoryView":349
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":376
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

/* Python wrapper */
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self) {
  int __pyx_v_i;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyThread_type_lock __pyx_t_5;
  PyThread_type_lock __pyx_t_6;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "View.MemoryView":377
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
  __pyx_t_1 = (__pyx_v_self->obj != Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":378
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)             # <<<<<<<<<<<<<<
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 */
    __Pyx_ReleaseBuffer((&__pyx_v_self->view));

    /* "View.MemoryView":377
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":379
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  __pyx_t_1 = (((Py_buffer *)(&__pyx_v_self->view))->obj == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":381
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL             # <<<<<<<<<<<<<<
 *             Py_DECREF(Py_None)
 * 
 */
    ((Py_buffer *)(&__pyx_v_self->view))->obj = NULL;

    /* "View.MemoryView":382
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 *             Py_DECREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         cdef int i
 */
    Py_DECREF(Py_None);

    /* "View.MemoryView":379
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":386
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  __pyx_t_1 = (__pyx_v_self->lock != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":387
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):             # <<<<<<<<<<<<<<
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 */
    __pyx_t_2 = __pyx_memoryview_thread_locks_used;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":388
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      __pyx_t_1 = ((__pyx_memoryview_thread_locks[__pyx_v_i]) == __pyx_v_self->lock);
      if (__pyx_t_1) {

        /* "View.MemoryView":389
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1             # <<<<<<<<<<<<<<
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 */
        __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used - 1);

        /* "View.MemoryView":390
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        __pyx_t_1 = (__pyx_v_i != __pyx_memoryview_thread_locks_used);
        if (__pyx_t_1) {

          /* "View.MemoryView":392
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])             # <<<<<<<<<<<<<<
 *                     break
 *             else:
 */
          __pyx_t_5 = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);
          __pyx_t_6 = (__pyx_memoryview_thread_locks[__pyx_v_i]);

          /* "View.MemoryView":391
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (             # <<<<<<<<<<<<<<
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break
 */
          (__pyx_memoryview_thread_locks[__pyx_v_i]) = __pyx_t_5;
          (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]) = __pyx_t_6;

          /* "View.MemoryView":390
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        }

        /* "View.MemoryView":393
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 PyThread_free_lock(self.lock)
 */
        goto __pyx_L6_break;

        /* "View.MemoryView":388
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      }
    }
    /*else*/ {

      /* "View.MemoryView":395
 *                     break
 *             else:
 *                 PyThread_free_lock(self.lock)             # <<<<<<<<<<<<<<
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 */
      PyThread_free_lock(__pyx_v_self->lock);
    }
    __pyx_L6_break:;

    /* "View.MemoryView":386
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  }

  /* "View.MemoryView":376
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":397
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  Py_ssize_t __pyx_v_dim;
  char *__pyx_v_itemp;
  PyObject *__pyx_v_idx = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item_pointer", 0);

  /* "View.MemoryView":399
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf             # <<<<<<<<<<<<<<
 * 
 *         for dim, idx in enumerate(index):
 */
  __pyx_v_itemp = ((char *)__pyx_v_self->view.buf);

  /* "View.MemoryView":401
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_v_index)) || PyTuple_CheckExact(__pyx_v_index)) {
    __pyx_t_2 = __pyx_v_index; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 401, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 401, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 401, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 401, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_idx, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_1;
    __pyx_t_1 = (__pyx_t_1 + 1);

    /* "View.MemoryView":402
 * 
 *         for dim, idx in enumerate(index):
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)             # <<<<<<<<<<<<<<
 * 
 *         return itemp
 */
    __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_v_idx); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 402, __pyx_L1_error)
    __pyx_t_7 = __pyx_pybuffer_index((&__pyx_v_self->view), __pyx_v_itemp, __pyx_t_6, __pyx_v_dim); if (unlikely(__pyx_t_7 == ((char *)NULL))) __PYX_ERR(0, 402, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_7;

    /* "View.MemoryView":401
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":404
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 *         return itemp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_itemp;
  goto __pyx_L0;

  /* "View.MemoryView":397
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.get_item_pointer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":407
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_indices = NULL;
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "View.MemoryView":408
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  __pyx_t_1 = (__pyx_v_index == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "View.MemoryView":409
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:
 *             return self             # <<<<<<<<<<<<<<
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __pyx_r = ((PyObject *)__pyx_v_self);
    goto __pyx_L0;

    /* "View.MemoryView":408
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  }

  /* "View.MemoryView":411
 *             return self
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *itemp
 */
  __pyx_t_2 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(__pyx_t_2 != Py_None)) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 411, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 411, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_indices = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "View.MemoryView":414
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 414, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "View.MemoryView":415
 *         cdef char *itemp
 *         if have_slices:
 *             return memview_slice(self, indices)             # <<<<<<<<<<<<<<
 *         else:
 *             itemp = self.get_item_pointer(indices)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_memview_slice(__pyx_v_self, __pyx_v_indices)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":414
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  }

  /* "View.MemoryView":417
 *             return memview_slice(self, indices)
 *         else:
 *             itemp = self.get_item_pointer(indices)             # <<<<<<<<<<<<<<
 *             return self.convert_item_to_object(itemp)
 * 
 */
  /*else*/ {
    __pyx_t_5 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_indices); if (unlikely(__pyx_t_5 == ((char *)NULL))) __PYX_ERR(0, 417, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_5;

    /* "View.MemoryView":418
 *         else:
 *             itemp = self.get_item_pointer(indices)
 *             return self.convert_item_to_object(itemp)             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(memoryview self, object index, object value):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->convert_item_to_object(__pyx_v_self, __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":407
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_indices);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":420
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"
 */

/* Python wrapper */
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /*proto*/
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_obj = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);
  __Pyx_INCREF(__pyx_v_index);

  /* "View.MemoryView":421
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 */
  if (unlikely(__pyx_v_self->view.readonly)) {

    /* "View.MemoryView":422
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"             # <<<<<<<<<<<<<<
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 */
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_Cannot_assign_to_read_only_memor, 0, 0);
    __PYX_ERR(0, 422, __pyx_L1_error)

    /* "View.MemoryView":421
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 */
  }

  /* "View.MemoryView":424
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         if have_slices:
 */
  __pyx_t_1 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 424, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 424, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "View.MemoryView":426
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 426, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "View.MemoryView":427
 * 
 *         if have_slices:
 *             obj = self.is_slice(value)             # <<<<<<<<<<<<<<
 *             if obj:
 *                 self.setitem_slice_assignment(self[index], obj)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->is_slice(__pyx_v_self, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_obj = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "View.MemoryView":428
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_obj); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 428, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "View.MemoryView":429
 *             obj = self.is_slice(value)
 *             if obj:
 *                 self.setitem_slice_assignment(self[index], obj)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)
 */
      __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assignment(__pyx_v_self, __pyx_t_1, __pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "View.MemoryView":428
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":431
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)             # <<<<<<<<<<<<<<
 *         else:
 *             self.setitem_indexed(index, value)
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_memoryview_type))))) __PYX_ERR(0, 431, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assign_scalar(__pyx_v_self, ((struct __pyx_memoryview_obj *)__pyx_t_3), __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "View.MemoryView":426
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":433
 *                 self.setitem_slice_assign_scalar(self[index], value)
 *         else:
 *             self.setitem_indexed(index, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef is_slice(self, obj):
 */
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_indexed(__pyx_v_self, __pyx_v_index, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "View.MemoryView":420
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":435
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_slice", 0);
  __Pyx_INCREF(__pyx_v_obj);

  /* "View.MemoryView":436
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_memoryview_type); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "View.MemoryView":438
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_6 = __Pyx_PyInt_From_int(((__pyx_v_self->flags & (~PyBUF_WRITABLE)) | PyBUF_ANY_CONTIGUOUS)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "View.MemoryView":439
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 return None
 */
        __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 439, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "View.MemoryView":438
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_obj);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7);
        __pyx_t_6 = 0;
        __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "View.MemoryView":440
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 return None
 * 
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(0, 440, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "View.MemoryView":441
 *                                  self.dtype_is_object)
 *             except TypeError:
 *                 return None             # <<<<<<<<<<<<<<
 * 
 *         return obj
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;

      /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L0;
      __pyx_L9_try_end:;
    }

    /* "View.MemoryView":436
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  }

  /* "View.MemoryView":443
 *                 return None
 * 
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assignment(self, dst, src):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "View.MemoryView":435
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":445
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src) {
  __Pyx_memviewslice __pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_src_slice;
  __Pyx_memviewslice __pyx_v_msrc;
  __Pyx_memviewslice __pyx_v_mdst;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assignment", 0);

  /* "View.MemoryView":448
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 *         cdef __Pyx_memviewslice msrc = get_slice_from_memview(src, &src_slice)[0]             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]
 * 
 */
  if (!(likely(((__pyx_v_src) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_src, __pyx_memoryview_type))))) __PYX_ERR(0, 448, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_src), (&__pyx_v_src_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(0, 448, __pyx_L1_error)
  __pyx_v_msrc = (__pyx_t_1[0]);

  /* "View.MemoryView":449
 *         cdef __Pyx_memviewslice src_slice
 *         cdef __Pyx_memviewslice msrc = get_slice_from_memview(src, &src_slice)[0]
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]             # <<<<<<<<<<<<<<
 * 
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 */
  if (!(likely(((__pyx_v_dst) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dst, __pyx_memoryview_type))))) __PYX_ERR(0, 449, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_dst), (&__pyx_v_dst_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(0, 449, __pyx_L1_error)
  __pyx_v_mdst = (__pyx_t_1[0]);

  /* "View.MemoryView":451
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]
 * 
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_src, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dst, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_memoryview_copy_contents(__pyx_v_msrc, __pyx_v_mdst, __pyx_t_3, __pyx_t_4, __pyx_v_self->dtype_is_object); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 451, __pyx_L1_error)

  /* "View.MemoryView":445
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":453
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value) {
  int __pyx_v_array[0x80];
  void *__pyx_v_tmp;
  void *__pyx_v_item;
  __Pyx_memviewslice *__pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_tmp_slice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assign_scalar", 0);

  /* "View.MemoryView":455
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 *         cdef int array[128]
 *         cdef void *tmp = NULL             # <<<<<<<<<<<<<<
 *         cdef void *item
 * 
 */
  __pyx_v_tmp = NULL;

  /* "View.MemoryView":460
 *         cdef __Pyx_memviewslice *dst_slice
 *         cdef __Pyx_memviewslice tmp_slice
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)             # <<<<<<<<<<<<<<
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_dst, (&__pyx_v_tmp_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(0, 460, __pyx_L1_error)
  __pyx_v_dst_slice = __pyx_t_1;

  /* "View.MemoryView":462
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
  __pyx_t_2 = (((size_t)__pyx_v_self->view.itemsize) > (sizeof(__pyx_v_array)));
  if (__pyx_t_2) {

    /* "View.MemoryView":463
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)             # <<<<<<<<<<<<<<
 *             if tmp == NULL:
 *                 raise MemoryError
 */
    __pyx_v_tmp = PyMem_Malloc(__pyx_v_self->view.itemsize);

    /* "View.MemoryView":464
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    __pyx_t_2 = (__pyx_v_tmp == NULL);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":465
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             item = tmp
 *         else:
 */
      PyErr_NoMemory(); __PYX_ERR(0, 465, __pyx_L1_error)

      /* "View.MemoryView":464
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    }

    /* "View.MemoryView":466
 *             if tmp == NULL:
 *                 raise MemoryError
 *             item = tmp             # <<<<<<<<<<<<<<
 *         else:
 *             item = <void *> array
 */
    __pyx_v_item = __pyx_v_tmp;

    /* "View.MemoryView":462
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":468
 *             item = tmp
 *         else:
 *             item = <void *> array             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __pyx_v_item = ((void *)__pyx_v_array);
  }
  __pyx_L3:;

  /* "View.MemoryView":470
 *             item = <void *> array
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value
 */
  /*try:*/ {

    /* "View.MemoryView":471
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
    if (__pyx_v_self->dtype_is_object) {

      /* "View.MemoryView":472
 *         try:
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value             # <<<<<<<<<<<<<<
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)
 */
      (((PyObject **)__pyx_v_item)[0]) = ((PyObject *)__pyx_v_value);

      /* "View.MemoryView":471
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":474
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, ((char *)__pyx_v_item), __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 474, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "View.MemoryView":478
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    __pyx_t_2 = (__pyx_v_self->view.suboffsets != NULL);
    if (__pyx_t_2) {

      /* "View.MemoryView":479
 * 
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)             # <<<<<<<<<<<<<<
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 *                                 item, self.dtype_is_object)
 */
      __pyx_t_4 = assert_direct_dimensions(__pyx_v_self->view.suboffsets, __pyx_v_self->view.ndim); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 479, __pyx_L6_error)

      /* "View.MemoryView":478
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    }

    /* "View.MemoryView":480
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,             # <<<<<<<<<<<<<<
 *                                 item, self.dtype_is_object)
 *         finally:
 */
    __pyx_memoryview_slice_assign_scalar(__pyx_v_dst_slice, __pyx_v_dst->view.ndim, __pyx_v_self->view.itemsize, __pyx_v_item, __pyx_v_self->dtype_is_object);
  }

  /* "View.MemoryView":483
 *                                 item, self.dtype_is_object)
 *         finally:
 *             PyMem_Free(tmp)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_indexed(self, index, value):
 */
  /*finally:*/ {
    /*normal exit:*/{
      PyMem_Free(__pyx_v_tmp);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {
        PyMem_Free(__pyx_v_tmp);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "View.MemoryView":453
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assign_scalar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":485
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_indexed", 0);

  /* "View.MemoryView":486
 * 
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)             # <<<<<<<<<<<<<<
 *         self.assign_item_from_object(itemp, value)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_index); if (unlikely(__pyx_t_1 == ((char *)NULL))) __PYX_ERR(0, 486, __pyx_L1_error)
  __pyx_v_itemp = __pyx_t_1;

  /* "View.MemoryView":487
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":485
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_indexed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":489
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_v_struct = NULL;
  PyObject *__pyx_v_bytesitem = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 0);

  /* "View.MemoryView":492
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef bytes bytesitem
 * 
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_struct, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":495
 *         cdef bytes bytesitem
 * 
 *         bytesitem = itemp[:self.view.itemsize]             # <<<<<<<<<<<<<<
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 */
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_itemp + 0, __pyx_v_self->view.itemsize - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bytesitem = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "View.MemoryView":497
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)             # <<<<<<<<<<<<<<
 *         except struct.error:
 *             raise ValueError, "Unable to convert item to object"
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_unpack); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 497, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 497, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_6, __pyx_v_bytesitem};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    }

    /* "View.MemoryView":501
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
    /*else:*/ {
      __pyx_t_9 = __Pyx_ssize_strlen(__pyx_v_self->view.format); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 501, __pyx_L5_except_error)
      __pyx_t_10 = (__pyx_t_9 == 1);
      if (__pyx_t_10) {

        /* "View.MemoryView":502
 *         else:
 *             if len(self.view.format) == 1:
 *                 return result[0]             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_result, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L6_except_return;

        /* "View.MemoryView":501
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
      }

      /* "View.MemoryView":503
 *             if len(self.view.format) == 1:
 *                 return result[0]
 *             return result             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_result);
      __pyx_r = __pyx_v_result;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":498
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_error); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 498, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    __pyx_t_1 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 498, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "View.MemoryView":499
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 *             raise ValueError, "Unable to convert item to object"             # <<<<<<<<<<<<<<
 *         else:
 *             if len(self.view.format) == 1:
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Unable_to_convert_item_to_object, 0, 0);
      __PYX_ERR(0, 499, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "View.MemoryView":489
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesitem);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":505
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_struct = NULL;
  char __pyx_v_c;
  PyObject *__pyx_v_bytesvalue = 0;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  char *__pyx_t_10;
  char *__pyx_t_11;
  char *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 0);

  /* "View.MemoryView":508
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef char c
 *         cdef bytes bytesvalue
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_struct, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":513
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_value); 
  if (__pyx_t_2) {

    /* "View.MemoryView":514
 * 
 *         if isinstance(value, tuple):
 *             bytesvalue = struct.pack(self.view.format, *value)             # <<<<<<<<<<<<<<
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(0, 514, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":513
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":516
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)             # <<<<<<<<<<<<<<
 * 
 *         for i, c in enumerate(bytesvalue):
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_1, __pyx_v_value};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(0, 516, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":518
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
  __pyx_t_7 = 0;
  if (unlikely(__pyx_v_bytesvalue == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(0, 518, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_bytesvalue);
  __pyx_t_8 = __pyx_v_bytesvalue;
  __pyx_t_10 = PyBytes_AS_STRING(__pyx_t_8);
  __pyx_t_11 = (__pyx_t_10 + PyBytes_GET_SIZE(__pyx_t_8));
  for (__pyx_t_12 = __pyx_t_10; __pyx_t_12 < __pyx_t_11; __pyx_t_12++) {
    __pyx_t_9 = __pyx_t_12;
    __pyx_v_c = (__pyx_t_9[0]);

    /* "View.MemoryView":519
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_v_i = __pyx_t_7;

    /* "View.MemoryView":518
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
    __pyx_t_7 = (__pyx_t_7 + 1);

    /* "View.MemoryView":519
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    (__pyx_v_itemp[__pyx_v_i]) = __pyx_v_c;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "View.MemoryView":505
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":521
 *             itemp[i] = c
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 */

/* Python wrapper */
CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  char *__pyx_t_4;
  void *__pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":523
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 */
  __pyx_t_2 = ((__pyx_v_flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":524
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_ND:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Cannot_create_writable_memory_vi, 0, 0);
    __PYX_ERR(0, 524, __pyx_L1_error)

    /* "View.MemoryView":523
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 */
  }

  /* "View.MemoryView":526
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_ND) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":527
 * 
 *         if flags & PyBUF_ND:
 *             info.shape = self.view.shape             # <<<<<<<<<<<<<<
 *         else:
 *             info.shape = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.shape;
    __pyx_v_info->shape = __pyx_t_3;

    /* "View.MemoryView":526
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":529
 *             info.shape = self.view.shape
 *         else:
 *             info.shape = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  /*else*/ {
    __pyx_v_info->shape = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":531
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":532
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.strides = self.view.strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.strides = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.strides;
    __pyx_v_info->strides = __pyx_t_3;

    /* "View.MemoryView":531
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
    goto __pyx_L7;
  }

  /* "View.MemoryView":534
 *             info.strides = self.view.strides
 *         else:
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_INDIRECT:
 */
  /*else*/ {
    __pyx_v_info->strides = NULL;
  }
  __pyx_L7:;

  /* "View.MemoryView":536
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_INDIRECT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":537
 * 
 *         if flags & PyBUF_INDIRECT:
 *             info.suboffsets = self.view.suboffsets             # <<<<<<<<<<<<<<
 *         else:
 *             info.suboffsets = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.suboffsets;
    __pyx_v_info->suboffsets = __pyx_t_3;

    /* "View.MemoryView":536
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
    goto __pyx_L8;
  }

  /* "View.MemoryView":539
 *             info.suboffsets = self.view.suboffsets
 *         else:
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
  /*else*/ {
    __pyx_v_info->suboffsets = NULL;
  }
  __pyx_L8:;

  /* "View.MemoryView":541
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":542
 * 
 *         if flags & PyBUF_FORMAT:
 *             info.format = self.view.format             # <<<<<<<<<<<<<<
 *         else:
 *             info.format = NULL
 */
    __pyx_t_4 = __pyx_v_self->view.format;
    __pyx_v_info->format = __pyx_t_4;

    /* "View.MemoryView":541
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":544
 *             info.format = self.view.format
 *         else:
 *             info.format = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.buf = self.view.buf
 */
  /*else*/ {
    __pyx_v_info->format = NULL;
  }
  __pyx_L9:;

  /* "View.MemoryView":546
 *             info.format = NULL
 * 
 *         info.buf = self.view.buf             # <<<<<<<<<<<<<<
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 */
  __pyx_t_5 = __pyx_v_self->view.buf;
  __pyx_v_info->buf = __pyx_t_5;

  /* "View.MemoryView":547
 * 
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim             # <<<<<<<<<<<<<<
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 */
  __pyx_t_6 = __pyx_v_self->view.ndim;
  __pyx_v_info->ndim = __pyx_t_6;

  /* "View.MemoryView":548
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize             # <<<<<<<<<<<<<<
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 */
  __pyx_t_7 = __pyx_v_self->view.itemsize;
  __pyx_v_info->itemsize = __pyx_t_7;

  /* "View.MemoryView":549
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len             # <<<<<<<<<<<<<<
 *         info.readonly = self.view.readonly
 *         info.obj = self
 */
  __pyx_t_7 = __pyx_v_self->view.len;
  __pyx_v_info->len = __pyx_t_7;

  /* "View.MemoryView":550
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_v_info->readonly = __pyx_t_1;

  /* "View.MemoryView":551
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":521
 *             itemp[i] = c
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":554
 * 
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":556
 *     @property
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&result.from_slice)
 *         return result
 */
  __pyx_t_1 = __pyx_memoryview_copy_object(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_memoryviewslice_type))))) __PYX_ERR(0, 556, __pyx_L1_error)
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":557
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_2 = __pyx_memslice_transpose((&__pyx_v_result->from_slice)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 557, __pyx_L1_error)

  /* "View.MemoryView":558
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":554
 * 
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.T.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":560
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         return self._get_base()
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":562
 *     @property
 *     def base(self):
 *         return self._get_base()             # <<<<<<<<<<<<<<
 * 
 *     cdef _get_base(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->_get_base(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":560
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         return self._get_base()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.base.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":564
 *         return self._get_base()
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

static PyObject *__pyx_memoryview__get_base(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_base", 0);

  /* "View.MemoryView":565
 * 
 *     cdef _get_base(self):
 *         return self.obj             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->obj);
  __pyx_r = __pyx_v_self->obj;
  goto __pyx_L0;

  /* "View.MemoryView":564
 *         return self._get_base()
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":567
 *         return self.obj
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_7genexpr__pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":569
 *     @property
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
      __pyx_t_2 = __pyx_t_4;
      __pyx_7genexpr__pyx_v_length = (__pyx_t_2[0]);
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_7genexpr__pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  } /* exit inner scope */
  __pyx_t_5 = PyList_AsTuple(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":567
 *         return self.obj
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.shape.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":571
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def strides(self):
 *         if self.view.strides == NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_8genexpr1__pyx_v_stride;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":573
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError, "Buffer view does not expose strides"
 */
  __pyx_t_1 = (__pyx_v_self->view.strides == NULL);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":575
 *         if self.view.strides == NULL:
 * 
 *             raise ValueError, "Buffer view does not expose strides"             # <<<<<<<<<<<<<<
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Buffer_view_does_not_expose_stri, 0, 0);
    __PYX_ERR(0, 575, __pyx_L1_error)

    /* "View.MemoryView":573
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError, "Buffer view does not expose strides"
 */
  }

  /* "View.MemoryView":577
 *             raise ValueError, "Buffer view does not expose strides"
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__pyx_v_self->view.strides + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.strides; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_8genexpr1__pyx_v_stride = (__pyx_t_3[0]);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_8genexpr1__pyx_v_stride); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  } /* exit inner scope */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":571
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def strides(self):
 *         if self.view.strides == NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.strides.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":579
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_8genexpr2__pyx_v_suboffset;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":581
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.suboffsets == NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":582
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PySequence_Multiply(__pyx_tuple__4, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":581
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  }

  /* "View.MemoryView":584
 *             return (-1,) * self.view.ndim
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__pyx_v_self->view.suboffsets + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.suboffsets; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_8genexpr2__pyx_v_suboffset = (__pyx_t_3[0]);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_8genexpr2__pyx_v_suboffset); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  } /* exit inner scope */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":579
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.suboffsets.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":586
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ndim(self):
 *         return self.view.ndim
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":588
 *     @property
 *     def ndim(self):
 *         return self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":586
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ndim(self):
 *         return self.view.ndim
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.ndim.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":590
 *         return self.view.ndim
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def itemsize(self):
 *         return self.view.itemsize
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":592
 *     @property
 *     def itemsize(self):
 *         return self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":590
 *         return self.view.ndim
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def itemsize(self):
 *         return self.view.itemsize
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.itemsize.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":594
 *         return self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nbytes(self):
 *         return self.size * self.view.itemsize
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":596
 *     @property
 *     def nbytes(self):
 *         return self.size * self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":594
 *         return self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nbytes(self):
 *         return self.size * self.view.itemsize
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.nbytes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":598
 *         return self.size * self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def size(self):
 *         if self._size is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":600
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_size == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":601
 *     def size(self):
 *         if self._size is None:
 *             result = 1             # <<<<<<<<<<<<<<
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 */
    __Pyx_INCREF(__pyx_int_1);
    __pyx_v_result = __pyx_int_1;

    /* "View.MemoryView":603
 *             result = 1
 * 
 *             for length in self.view.shape[:self.view.ndim]:             # <<<<<<<<<<<<<<
 *                 result *= length
 * 
 */
    __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
      __pyx_t_2 = __pyx_t_4;
      __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_2[0])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "View.MemoryView":604
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 *                 result *= length             # <<<<<<<<<<<<<<
 * 
 *             self._size = result
 */
      __pyx_t_5 = PyNumber_InPlaceMultiply(__pyx_v_result, __pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_5);
      __pyx_t_5 = 0;
    }

    /* "View.MemoryView":606
 *                 result *= length
 * 
 *             self._size = result             # <<<<<<<<<<<<<<
 * 
 *         return self._size
 */
    __Pyx_INCREF(__pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __Pyx_GOTREF(__pyx_v_self->_size);
    __Pyx_DECREF(__pyx_v_self->_size);
    __pyx_v_self->_size = __pyx_v_result;

    /* "View.MemoryView":600
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  }

  /* "View.MemoryView":608
 *             self._size = result
 * 
 *         return self._size             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_size);
  __pyx_r = __pyx_v_self->_size;
  goto __pyx_L0;

  /* "View.MemoryView":598
 *         return self.size * self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def size(self):
 *         if self._size is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":610
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

/* Python wrapper */
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "View.MemoryView":611
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.ndim >= 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":612
 *     def __len__(self):
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = (__pyx_v_self->view.shape[0]);
    goto __pyx_L0;

    /* "View.MemoryView":611
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  }

  /* "View.MemoryView":614
 *             return self.view.shape[0]
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":610
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":616
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "View.MemoryView":617
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":618
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "View.MemoryView":617
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":616
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":620
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "View.MemoryView":621
 * 
 *     def __str__(self):
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_object, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":620
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":624
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_c_contig (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_c_contig", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_c_contig", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_c_contig", 0);

  /* "View.MemoryView":627
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(0, 627, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":628
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def is_f_contig(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'C', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":624
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_c_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":630
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_f_contig (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_f_contig", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_f_contig", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_f_contig", 0);

  /* "View.MemoryView":633
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(0, 633, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":634
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'F', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":630
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_f_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":636
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_mslice;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "View.MemoryView":638
 *     def copy(self):
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &mslice)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_F_CONTIGUOUS));

  /* "View.MemoryView":640
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 * 
 *         slice_copy(self, &mslice)             # <<<<<<<<<<<<<<
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,
 *                                    self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_mslice));

  /* "View.MemoryView":641
 * 
 *         slice_copy(self, &mslice)
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                    self.view.itemsize,
 *                                    flags|PyBUF_C_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_mslice), ((char *)"c"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_C_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 641, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":646
 *                                    self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &mslice)             # <<<<<<<<<<<<<<
 * 
 *     def copy_fortran(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_mslice)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":636
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":648
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy_fortran (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy_fortran", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy_fortran", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_fortran", 0);

  /* "View.MemoryView":650
 *     def copy_fortran(self):
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &src)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_C_CONTIGUOUS));

  /* "View.MemoryView":652
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 * 
 *         slice_copy(self, &src)             # <<<<<<<<<<<<<<
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,
 *                                 self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_src));

  /* "View.MemoryView":653
 * 
 *         slice_copy(self, &src)
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                 self.view.itemsize,
 *                                 flags|PyBUF_F_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_src), ((char *)"fortran"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_F_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 653, __pyx_L1_error)
  __pyx_v_dst = __pyx_t_1;

  /* "View.MemoryView":658
 *                                 self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &dst)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_dst)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":648
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy_fortran", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_memoryview___reduce_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(0, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_memoryview_2__setstate_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":662
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

static PyObject *__pyx_memoryview_new(PyObject *__pyx_v_o, int __pyx_v_flags, int __pyx_v_dtype_is_object, __Pyx_TypeInfo *__pyx_v_typeinfo) {
  struct __pyx_memoryview_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_cwrapper", 0);

  /* "View.MemoryView":663
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)             # <<<<<<<<<<<<<<
 *     result.typeinfo = typeinfo
 *     return result
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryview_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":664
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
  __pyx_v_result->typeinfo = __pyx_v_typeinfo;

  /* "View.MemoryView":665
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_check')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":662
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":668
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

static CYTHON_INLINE int __pyx_memoryview_check(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("memoryview_check", 0);

  /* "View.MemoryView":669
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:
 *     return isinstance(o, memoryview)             # <<<<<<<<<<<<<<
 * 
 * cdef tuple _unellipsify(object index, int ndim):
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_o, __pyx_memoryview_type); 
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":668
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":671
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

static PyObject *_unellipsify(PyObject *__pyx_v_index, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_idx;
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_v_result = NULL;
  int __pyx_v_have_slices;
  int __pyx_v_seen_ellipsis;
  PyObject *__pyx_v_item = NULL;
  Py_ssize_t __pyx_v_nslices;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unellipsify", 0);

  /* "View.MemoryView":677
 *     """
 *     cdef Py_ssize_t idx
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)             # <<<<<<<<<<<<<<
 * 
 *     result = [slice(None)] * ndim
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_index); 
  if (__pyx_t_2) {
    __Pyx_INCREF(((PyObject*)__pyx_v_index));
    __pyx_t_1 = __pyx_v_index;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_index);
    __Pyx_GIVEREF(__pyx_v_index);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_index);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_v_tup = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":679
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)
 * 
 *     result = [slice(None)] * ndim             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_t_1 = PyList_New(1 * ((__pyx_v_ndim<0) ? 0:__pyx_v_ndim)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < __pyx_v_ndim; __pyx_temp++) {
      __Pyx_INCREF(__pyx_slice__5);
      __Pyx_GIVEREF(__pyx_slice__5);
      PyList_SET_ITEM(__pyx_t_1, __pyx_temp, __pyx_slice__5);
    }
  }
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":680
 * 
 *     result = [slice(None)] * ndim
 *     have_slices = False             # <<<<<<<<<<<<<<
 *     seen_ellipsis = False
 *     idx = 0
 */
  __pyx_v_have_slices = 0;

  /* "View.MemoryView":681
 *     result = [slice(None)] * ndim
 *     have_slices = False
 *     seen_ellipsis = False             # <<<<<<<<<<<<<<
 *     idx = 0
 *     for item in tup:
 */
  __pyx_v_seen_ellipsis = 0;

  /* "View.MemoryView":682
 *     have_slices = False
 *     seen_ellipsis = False
 *     idx = 0             # <<<<<<<<<<<<<<
 *     for item in tup:
 *         if item is Ellipsis:
 */
  __pyx_v_idx = 0;

  /* "View.MemoryView":683
 *     seen_ellipsis = False
 *     idx = 0
 *     for item in tup:             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  if (unlikely(__pyx_v_tup == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 683, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_tup; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 683, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":684
 *     idx = 0
 *     for item in tup:
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 */
    __pyx_t_2 = (__pyx_v_item == __pyx_builtin_Ellipsis);
    if (__pyx_t_2) {

      /* "View.MemoryView":685
 *     for item in tup:
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 */
      __pyx_t_2 = (!__pyx_v_seen_ellipsis);
      if (__pyx_t_2) {

        /* "View.MemoryView":686
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)             # <<<<<<<<<<<<<<
 *                 seen_ellipsis = True
 *             have_slices = True
 */
        if (unlikely(__pyx_v_tup == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 686, __pyx_L1_error)
        }
        __pyx_t_5 = PyTuple_GET_SIZE(__pyx_v_tup); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 686, __pyx_L1_error)
        __pyx_v_idx = (__pyx_v_idx + (__pyx_v_ndim - __pyx_t_5));

        /* "View.MemoryView":687
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True             # <<<<<<<<<<<<<<
 *             have_slices = True
 *         else:
 */
        __pyx_v_seen_ellipsis = 1;

        /* "View.MemoryView":685
 *     for item in tup:
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 */
      }

      /* "View.MemoryView":688
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 *             have_slices = True             # <<<<<<<<<<<<<<
 *         else:
 *             if isinstance(item, slice):
 */
      __pyx_v_have_slices = 1;

      /* "View.MemoryView":684
 *     idx = 0
 *     for item in tup:
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":690
 *             have_slices = True
 *         else:
 *             if isinstance(item, slice):             # <<<<<<<<<<<<<<
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 */
    /*else*/ {
      __pyx_t_2 = PySlice_Check(__pyx_v_item); 
      if (__pyx_t_2) {

        /* "View.MemoryView":691
 *         else:
 *             if isinstance(item, slice):
 *                 have_slices = True             # <<<<<<<<<<<<<<
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 */
        __pyx_v_have_slices = 1;

        /* "View.MemoryView":690
 *             have_slices = True
 *         else:
 *             if isinstance(item, slice):             # <<<<<<<<<<<<<<
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":692
 *             if isinstance(item, slice):
 *                 have_slices = True
 *             elif not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 */
      __pyx_t_2 = (!(PyIndex_Check(__pyx_v_item) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "View.MemoryView":693
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"             # <<<<<<<<<<<<<<
 *             result[idx] = item
 *         idx += 1
 */
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = 0;
        __pyx_t_6 = 127;
        __Pyx_INCREF(__pyx_kp_u_Cannot_index_with_type);
        __pyx_t_5 += 24;
        __Pyx_GIVEREF(__pyx_kp_u_Cannot_index_with_type);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Cannot_index_with_type);
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_item)), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
        __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_INCREF(__pyx_kp_u__6);
        __pyx_t_5 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__6);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__6);
        __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_builtin_TypeError, __pyx_t_7, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __PYX_ERR(0, 693, __pyx_L1_error)

        /* "View.MemoryView":692
 *             if isinstance(item, slice):
 *                 have_slices = True
 *             elif not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 */
      }
      __pyx_L7:;

      /* "View.MemoryView":694
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item             # <<<<<<<<<<<<<<
 *         idx += 1
 * 
 */
      if (unlikely((__Pyx_SetItemInt(__pyx_v_result, __pyx_v_idx, __pyx_v_item, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1) < 0))) __PYX_ERR(0, 694, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "View.MemoryView":695
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 *         idx += 1             # <<<<<<<<<<<<<<
 * 
 *     nslices = ndim - idx
 */
    __pyx_v_idx = (__pyx_v_idx + 1);

    /* "View.MemoryView":683
 *     seen_ellipsis = False
 *     idx = 0
 *     for item in tup:             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":697
 *         idx += 1
 * 
 *     nslices = ndim - idx             # <<<<<<<<<<<<<<
 *     return have_slices or nslices, tuple(result)
 * 
 */
  __pyx_v_nslices = (__pyx_v_ndim - __pyx_v_idx);

  /* "View.MemoryView":698
 * 
 *     nslices = ndim - idx
 *     return have_slices or nslices, tuple(result)             # <<<<<<<<<<<<<<
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 */
  __Pyx_XDECREF(__pyx_r);
  if (!__pyx_v_have_slices) {
  } else {
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_have_slices); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_7 = PyInt_FromSsize_t(__pyx_v_nslices); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __pyx_t_7;
  __pyx_t_7 = 0;
  __pyx_L9_bool_binop_done:;
  __pyx_t_7 = PyList_AsTuple(__pyx_v_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7);
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":671
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView._unellipsify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

static int assert_direct_dimensions(Py_ssize_t *__pyx_v_suboffsets, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_suboffset;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t *__pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assert_direct_dimensions", 0);

  /* "View.MemoryView":701
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"
 */
  __pyx_t_2 = (__pyx_v_suboffsets + __pyx_v_ndim);
  for (__pyx_t_3 = __pyx_v_suboffsets; __pyx_t_3 < __pyx_t_2; __pyx_t_3++) {
    __pyx_t_1 = __pyx_t_3;
    __pyx_v_suboffset = (__pyx_t_1[0]);

    /* "View.MemoryView":702
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag
 */
    __pyx_t_4 = (__pyx_v_suboffset >= 0);
    if (unlikely(__pyx_t_4)) {

      /* "View.MemoryView":703
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"             # <<<<<<<<<<<<<<
 *     return 0  # return type just used as an error flag
 * 
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Indirect_dimensions_not_supporte, 0, 0);
      __PYX_ERR(0, 703, __pyx_L1_error)

      /* "View.MemoryView":702
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag
 */
    }
  }

  /* "View.MemoryView":704
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.assert_direct_dimensions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":711
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *__pyx_v_memview, PyObject *__pyx_v_indices) {
  int __pyx_v_new_ndim;
  int __pyx_v_suboffset_dim;
  int __pyx_v_dim;
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  __Pyx_memviewslice *__pyx_v_p_src;
  struct __pyx_memoryviewslice_obj *__pyx_v_memviewsliceobj = 0;
  __Pyx_memviewslice *__pyx_v_p_dst;
  int *__pyx_v_p_suboffset_dim;
  Py_ssize_t __pyx_v_start;
  Py_ssize_t __pyx_v_stop;
  Py_ssize_t __pyx_v_step;
  Py_ssize_t __pyx_v_cindex;
  int __pyx_v_have_start;
  int __pyx_v_have_stop;
  int __pyx_v_have_step;
  PyObject *__pyx_v_index = NULL;
  struct __pyx_memoryview_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_memoryview_obj *__pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memview_slice", 0);

  /* "View.MemoryView":712
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim             # <<<<<<<<<<<<<<
 *     cdef bint negative_step
 *     cdef __Pyx_memviewslice src, dst
 */
  __pyx_v_new_ndim = 0;
  __pyx_v_suboffset_dim = -1;

  /* "View.MemoryView":719
 * 
 * 
 *     memset(&dst, 0, sizeof(dst))             # <<<<<<<<<<<<<<
 * 
 *     cdef _memoryviewslice memviewsliceobj
 */
  (void)(memset((&__pyx_v_dst), 0, (sizeof(__pyx_v_dst))));

  /* "View.MemoryView":723
 *     cdef _memoryviewslice memviewsliceobj
 * 
 *     assert memview.view.ndim > 0             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_memview->view.ndim > 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 723, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 723, __pyx_L1_error)
  #endif

  /* "View.MemoryView":725
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":726
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview             # <<<<<<<<<<<<<<
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(0, 726, __pyx_L1_error)
    __pyx_t_2 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_memviewsliceobj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":727
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, &src)
 */
    __pyx_v_p_src = (&__pyx_v_memviewsliceobj->from_slice);

    /* "View.MemoryView":725
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":729
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 *         slice_copy(memview, &src)             # <<<<<<<<<<<<<<
 *         p_src = &src
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_src));

    /* "View.MemoryView":730
 *     else:
 *         slice_copy(memview, &src)
 *         p_src = &src             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_p_src = (&__pyx_v_src);
  }
  __pyx_L3:;

  /* "View.MemoryView":736
 * 
 * 
 *     dst.memview = p_src.memview             # <<<<<<<<<<<<<<
 *     dst.data = p_src.data
 * 
 */
  __pyx_t_3 = __pyx_v_p_src->memview;
  __pyx_v_dst.memview = __pyx_t_3;

  /* "View.MemoryView":737
 * 
 *     dst.memview = p_src.memview
 *     dst.data = p_src.data             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_v_p_src->data;
  __pyx_v_dst.data = __pyx_t_4;

  /* "View.MemoryView":742
 * 
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst             # <<<<<<<<<<<<<<
 *     cdef int *p_suboffset_dim = &suboffset_dim
 *     cdef Py_ssize_t start, stop, step, cindex
 */
  __pyx_v_p_dst = (&__pyx_v_dst);

  /* "View.MemoryView":743
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst
 *     cdef int *p_suboffset_dim = &suboffset_dim             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t start, stop, step, cindex
 *     cdef bint have_start, have_stop, have_step
 */
  __pyx_v_p_suboffset_dim = (&__pyx_v_suboffset_dim);

  /* "View.MemoryView":747
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             cindex = index
 */
  __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_v_indices)) || PyTuple_CheckExact(__pyx_v_indices)) {
    __pyx_t_2 = __pyx_v_indices; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_indices); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 747, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 747, __pyx_L1_error)
        #else
        __pyx_t_8 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 747, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 747, __pyx_L1_error)
        #else
        __pyx_t_8 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 747, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      }
    } else {
      __pyx_t_8 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_8)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 747, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_v_dim = __pyx_t_5;
    __pyx_t_5 = (__pyx_t_5 + 1);

    /* "View.MemoryView":748
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             cindex = index
 *             slice_memviewslice(
 */
    __pyx_t_1 = (PyIndex_Check(__pyx_v_index) != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":749
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):
 *             cindex = index             # <<<<<<<<<<<<<<
 *             slice_memviewslice(
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 */
      __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 749, __pyx_L1_error)
      __pyx_v_cindex = __pyx_t_9;

      /* "View.MemoryView":750
 *         if PyIndex_Check(index):
 *             cindex = index
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_10 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_cindex, 0, 0, 0, 0, 0, 0); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 750, __pyx_L1_error)

      /* "View.MemoryView":748
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             cindex = index
 *             slice_memviewslice(
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":756
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
    __pyx_t_1 = (__pyx_v_index == Py_None);
    if (__pyx_t_1) {

      /* "View.MemoryView":757
 *                 False)
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1             # <<<<<<<<<<<<<<
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 */
      (__pyx_v_p_dst->shape[__pyx_v_new_ndim]) = 1;

      /* "View.MemoryView":758
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0             # <<<<<<<<<<<<<<
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1
 */
      (__pyx_v_p_dst->strides[__pyx_v_new_ndim]) = 0;

      /* "View.MemoryView":759
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1             # <<<<<<<<<<<<<<
 *             new_ndim += 1
 *         else:
 */
      (__pyx_v_p_dst->suboffsets[__pyx_v_new_ndim]) = -1L;

      /* "View.MemoryView":760
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 *         else:
 *             start = index.start or 0
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);

      /* "View.MemoryView":756
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":762
 *             new_ndim += 1
 *         else:
 *             start = index.start or 0             # <<<<<<<<<<<<<<
 *             stop = index.stop or 0
 *             step = index.step or 0
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 762, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 762, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L7_bool_binop_done:;
      __pyx_v_start = __pyx_t_9;

      /* "View.MemoryView":763
 *         else:
 *             start = index.start or 0
 *             stop = index.stop or 0             # <<<<<<<<<<<<<<
 *             step = index.step or 0
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 763, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 763, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L9_bool_binop_done:;
      __pyx_v_stop = __pyx_t_9;

      /* "View.MemoryView":764
 *             start = index.start or 0
 *             stop = index.stop or 0
 *             step = index.step or 0             # <<<<<<<<<<<<<<
 * 
 *             have_start = index.start is not None
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 764, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 764, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L11_bool_binop_done:;
      __pyx_v_step = __pyx_t_9;

      /* "View.MemoryView":766
 *             step = index.step or 0
 * 
 *             have_start = index.start is not None             # <<<<<<<<<<<<<<
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_start = __pyx_t_1;

      /* "View.MemoryView":767
 * 
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None             # <<<<<<<<<<<<<<
 *             have_step = index.step is not None
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 767, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_stop = __pyx_t_1;

      /* "View.MemoryView":768
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None             # <<<<<<<<<<<<<<
 * 
 *             slice_memviewslice(
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 768, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_step = __pyx_t_1;

      /* "View.MemoryView":770
 *             have_step = index.step is not None
 * 
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_10 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_start, __pyx_v_stop, __pyx_v_step, __pyx_v_have_start, __pyx_v_have_stop, __pyx_v_have_step, 1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 770, __pyx_L1_error)

      /* "View.MemoryView":776
 *                 have_start, have_stop, have_step,
 *                 True)
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);
    }
    __pyx_L6:;

    /* "View.MemoryView":747
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             cindex = index
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":778
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":779
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);

    /* "View.MemoryView":780
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_dtype_func,
 *                                     memview.dtype_is_object)
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(0, 780, __pyx_L1_error) }

    /* "View.MemoryView":781
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 *     else:
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(0, 781, __pyx_L1_error) }

    /* "View.MemoryView":779
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, __pyx_v_memviewsliceobj->to_object_func, __pyx_v_memviewsliceobj->to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_memoryview_type))))) __PYX_ERR(0, 779, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":778
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  }

  /* "View.MemoryView":784
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
  /*else*/ {
    __Pyx_XDECREF((PyObject *)__pyx_r);

    /* "View.MemoryView":785
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,
 *                                     memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, NULL, NULL, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "View.MemoryView":784
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_memoryview_type))))) __PYX_ERR(0, 784, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":711
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memview_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_memviewsliceobj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":793
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *__pyx_v_dst, Py_ssize_t __pyx_v_shape, Py_ssize_t __pyx_v_stride, Py_ssize_t __pyx_v_suboffset, int __pyx_v_dim, int __pyx_v_new_ndim, int *__pyx_v_suboffset_dim, Py_ssize_t __pyx_v_start, Py_ssize_t __pyx_v_stop, Py_ssize_t __pyx_v_step, int __pyx_v_have_start, int __pyx_v_have_stop, int __pyx_v_have_step, int __pyx_v_is_slice) {
  Py_ssize_t __pyx_v_new_shape;
  int __pyx_v_negative_step;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":813
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
  __pyx_t_1 = (!__pyx_v_is_slice);
  if (__pyx_t_1) {

    /* "View.MemoryView":815
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    __pyx_t_1 = (__pyx_v_start < 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":816
 * 
 *         if start < 0:
 *             start += shape             # <<<<<<<<<<<<<<
 *         if not 0 <= start < shape:
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 */
      __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

      /* "View.MemoryView":815
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    }

    /* "View.MemoryView":817
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    __pyx_t_1 = (0 <= __pyx_v_start);
    if (__pyx_t_1) {
      __pyx_t_1 = (__pyx_v_start < __pyx_v_shape);
    }
    __pyx_t_2 = (!__pyx_t_1);
    if (__pyx_t_2) {

      /* "View.MemoryView":818
 *             start += shape
 *         if not 0 <= start < shape:
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)             # <<<<<<<<<<<<<<
 *     else:
 * 
 */
      __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_IndexError, __pyx_kp_s_Index_out_of_bounds_axis_d, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 818, __pyx_L1_error)

      /* "View.MemoryView":817
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    }

    /* "View.MemoryView":813
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":821
 *     else:
 * 
 *         if have_step:             # <<<<<<<<<<<<<<
 *             negative_step = step < 0
 *             if step == 0:
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_have_step != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":822
 * 
 *         if have_step:
 *             negative_step = step < 0             # <<<<<<<<<<<<<<
 *             if step == 0:
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 */
      __pyx_v_negative_step = (__pyx_v_step < 0);

      /* "View.MemoryView":823
 *         if have_step:
 *             negative_step = step < 0
 *             if step == 0:             # <<<<<<<<<<<<<<
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 */
      __pyx_t_2 = (__pyx_v_step == 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":824
 *             negative_step = step < 0
 *             if step == 0:
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             negative_step = False
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_ValueError, __pyx_kp_s_Step_may_not_be_zero_axis_d, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 824, __pyx_L1_error)

        /* "View.MemoryView":823
 *         if have_step:
 *             negative_step = step < 0
 *             if step == 0:             # <<<<<<<<<<<<<<
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 */
      }

      /* "View.MemoryView":821
 *     else:
 * 
 *         if have_step:             # <<<<<<<<<<<<<<
 *             negative_step = step < 0
 *             if step == 0:
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":826
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 *             negative_step = False             # <<<<<<<<<<<<<<
 *             step = 1
 * 
 */
    /*else*/ {
      __pyx_v_negative_step = 0;

      /* "View.MemoryView":827
 *         else:
 *             negative_step = False
 *             step = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_step = 1;
    }
    __pyx_L6:;

    /* "View.MemoryView":830
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
    __pyx_t_2 = (__pyx_v_have_start != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":831
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
      __pyx_t_2 = (__pyx_v_start < 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":832
 *         if have_start:
 *             if start < 0:
 *                 start += shape             # <<<<<<<<<<<<<<
 *                 if start < 0:
 *                     start = 0
 */
        __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

        /* "View.MemoryView":833
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        __pyx_t_2 = (__pyx_v_start < 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":834
 *                 start += shape
 *                 if start < 0:
 *                     start = 0             # <<<<<<<<<<<<<<
 *             elif start >= shape:
 *                 if negative_step:
 */
          __pyx_v_start = 0;

          /* "View.MemoryView":833
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        }

        /* "View.MemoryView":831
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
        goto __pyx_L9;
      }

      /* "View.MemoryView":835
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      __pyx_t_2 = (__pyx_v_start >= __pyx_v_shape);
      if (__pyx_t_2) {

        /* "View.MemoryView":836
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
        if (__pyx_v_negative_step) {

          /* "View.MemoryView":837
 *             elif start >= shape:
 *                 if negative_step:
 *                     start = shape - 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     start = shape
 */
          __pyx_v_start = (__pyx_v_shape - 1);

          /* "View.MemoryView":836
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
          goto __pyx_L11;
        }

        /* "View.MemoryView":839
 *                     start = shape - 1
 *                 else:
 *                     start = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        /*else*/ {
          __pyx_v_start = __pyx_v_shape;
        }
        __pyx_L11:;

        /* "View.MemoryView":835
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      }
      __pyx_L9:;

      /* "View.MemoryView":830
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":841
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
    /*else*/ {
      if (__pyx_v_negative_step) {

        /* "View.MemoryView":842
 *         else:
 *             if negative_step:
 *                 start = shape - 1             # <<<<<<<<<<<<<<
 *             else:
 *                 start = 0
 */
        __pyx_v_start = (__pyx_v_shape - 1);

        /* "View.MemoryView":841
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
        goto __pyx_L12;
      }

      /* "View.MemoryView":844
 *                 start = shape - 1
 *             else:
 *                 start = 0             # <<<<<<<<<<<<<<
 * 
 *         if have_stop:
 */
      /*else*/ {
        __pyx_v_start = 0;
      }
      __pyx_L12:;
    }
    __pyx_L8:;

    /* "View.MemoryView":846
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
    __pyx_t_2 = (__pyx_v_have_stop != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":847
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
      __pyx_t_2 = (__pyx_v_stop < 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":848
 *         if have_stop:
 *             if stop < 0:
 *                 stop += shape             # <<<<<<<<<<<<<<
 *                 if stop < 0:
 *                     stop = 0
 */
        __pyx_v_stop = (__pyx_v_stop + __pyx_v_shape);

        /* "View.MemoryView":849
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        __pyx_t_2 = (__pyx_v_stop < 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":850
 *                 stop += shape
 *                 if stop < 0:
 *                     stop = 0             # <<<<<<<<<<<<<<
 *             elif stop > shape:
 *                 stop = shape
 */
          __pyx_v_stop = 0;

          /* "View.MemoryView":849
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        }

        /* "View.MemoryView":847
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
        goto __pyx_L14;
      }

      /* "View.MemoryView":851
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      __pyx_t_2 = (__pyx_v_stop > __pyx_v_shape);
      if (__pyx_t_2) {

        /* "View.MemoryView":852
 *                     stop = 0
 *             elif stop > shape:
 *                 stop = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        __pyx_v_stop = __pyx_v_shape;

        /* "View.MemoryView":851
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      }
      __pyx_L14:;

      /* "View.MemoryView":846
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
      goto __pyx_L13;
    }

    /* "View.MemoryView":854
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
    /*else*/ {
      if (__pyx_v_negative_step) {

        /* "View.MemoryView":855
 *         else:
 *             if negative_step:
 *                 stop = -1             # <<<<<<<<<<<<<<
 *             else:
 *                 stop = shape
 */
        __pyx_v_stop = -1L;

        /* "View.MemoryView":854
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
        goto __pyx_L16;
      }

      /* "View.MemoryView":857
 *                 stop = -1
 *             else:
 *                 stop = shape             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else*/ {
        __pyx_v_stop = __pyx_v_shape;
      }
      __pyx_L16:;
    }
    __pyx_L13:;

    /* "View.MemoryView":861
 * 
 *         with cython.cdivision(True):
 *             new_shape = (stop - start) // step             # <<<<<<<<<<<<<<
 * 
 *             if (stop - start) - step * new_shape:
 */
    __pyx_v_new_shape = ((__pyx_v_stop - __pyx_v_start) / __pyx_v_step);

    /* "View.MemoryView":863
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    __pyx_t_2 = (((__pyx_v_stop - __pyx_v_start) - (__pyx_v_step * __pyx_v_new_shape)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":864
 * 
 *             if (stop - start) - step * new_shape:
 *                 new_shape += 1             # <<<<<<<<<<<<<<
 * 
 *         if new_shape < 0:
 */
      __pyx_v_new_shape = (__pyx_v_new_shape + 1);

      /* "View.MemoryView":863
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    }

    /* "View.MemoryView":866
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    __pyx_t_2 = (__pyx_v_new_shape < 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":867
 * 
 *         if new_shape < 0:
 *             new_shape = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_new_shape = 0;

      /* "View.MemoryView":866
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    }

    /* "View.MemoryView":870
 * 
 * 
 *         dst.strides[new_ndim] = stride * step             # <<<<<<<<<<<<<<
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset
 */
    (__pyx_v_dst->strides[__pyx_v_new_ndim]) = (__pyx_v_stride * __pyx_v_step);

    /* "View.MemoryView":871
 * 
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape             # <<<<<<<<<<<<<<
 *         dst.suboffsets[new_ndim] = suboffset
 * 
 */
    (__pyx_v_dst->shape[__pyx_v_new_ndim]) = __pyx_v_new_shape;

    /* "View.MemoryView":872
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_dst->suboffsets[__pyx_v_new_ndim]) = __pyx_v_suboffset;
  }
  __pyx_L3:;

  /* "View.MemoryView":875
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_suboffset_dim[0]) < 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":876
 * 
 *     if suboffset_dim[0] < 0:
 *         dst.data += start * stride             # <<<<<<<<<<<<<<
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 */
    __pyx_v_dst->data = (__pyx_v_dst->data + (__pyx_v_start * __pyx_v_stride));

    /* "View.MemoryView":875
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
    goto __pyx_L19;
  }

  /* "View.MemoryView":878
 *         dst.data += start * stride
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride             # <<<<<<<<<<<<<<
 * 
 *     if suboffset >= 0:
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_suboffset_dim[0]);
    (__pyx_v_dst->suboffsets[__pyx_t_3]) = ((__pyx_v_dst->suboffsets[__pyx_t_3]) + (__pyx_v_start * __pyx_v_stride));
  }
  __pyx_L19:;

  /* "View.MemoryView":880
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  __pyx_t_2 = (__pyx_v_suboffset >= 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":881
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
    __pyx_t_2 = (!__pyx_v_is_slice);
    if (__pyx_t_2) {

      /* "View.MemoryView":882
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
      __pyx_t_2 = (__pyx_v_new_ndim == 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":883
 *         if not is_slice:
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "
 */
        __pyx_v_dst->data = ((((char **)__pyx_v_dst->data)[0]) + __pyx_v_suboffset);

        /* "View.MemoryView":882
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
        goto __pyx_L22;
      }

      /* "View.MemoryView":885
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "             # <<<<<<<<<<<<<<
 *                                      "must be indexed and not sliced", dim)
 *         else:
 */
      /*else*/ {

        /* "View.MemoryView":886
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "
 *                                      "must be indexed and not sliced", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             suboffset_dim[0] = new_ndim
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_IndexError, __pyx_kp_s_All_dimensions_preceding_dimensi, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 885, __pyx_L1_error)
      }
      __pyx_L22:;

      /* "View.MemoryView":881
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
      goto __pyx_L21;
    }

    /* "View.MemoryView":888
 *                                      "must be indexed and not sliced", dim)
 *         else:
 *             suboffset_dim[0] = new_ndim             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
    /*else*/ {
      (__pyx_v_suboffset_dim[0]) = __pyx_v_new_ndim;
    }
    __pyx_L21:;

    /* "View.MemoryView":880
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  }

  /* "View.MemoryView":890
 *             suboffset_dim[0] = new_ndim
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":793
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.slice_memviewslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":896
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

static char *__pyx_pybuffer_index(Py_buffer *__pyx_v_view, char *__pyx_v_bufp, Py_ssize_t __pyx_v_index, Py_ssize_t __pyx_v_dim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_suboffset;
  Py_ssize_t __pyx_v_itemsize;
  char *__pyx_v_resultp;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pybuffer_index", 0);

  /* "View.MemoryView":898
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t itemsize = view.itemsize
 *     cdef char *resultp
 */
  __pyx_v_suboffset = -1L;

  /* "View.MemoryView":899
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 *     cdef Py_ssize_t itemsize = view.itemsize             # <<<<<<<<<<<<<<
 *     cdef char *resultp
 * 
 */
  __pyx_t_1 = __pyx_v_view->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":902
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len // itemsize
 *         stride = itemsize
 */
  __pyx_t_2 = (__pyx_v_view->ndim == 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":903
 * 
 *     if view.ndim == 0:
 *         shape = view.len // itemsize             # <<<<<<<<<<<<<<
 *         stride = itemsize
 *     else:
 */
    if (unlikely(__pyx_v_itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(0, 903, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_itemsize == (Py_ssize_t)-1)  && unlikely(__Pyx_UNARY_NEG_WOULD_OVERFLOW(__pyx_v_view->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(0, 903, __pyx_L1_error)
    }
    __pyx_v_shape = __Pyx_div_Py_ssize_t(__pyx_v_view->len, __pyx_v_itemsize);

    /* "View.MemoryView":904
 *     if view.ndim == 0:
 *         shape = view.len // itemsize
 *         stride = itemsize             # <<<<<<<<<<<<<<
 *     else:
 *         shape = view.shape[dim]
 */
    __pyx_v_stride = __pyx_v_itemsize;

    /* "View.MemoryView":902
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len // itemsize
 *         stride = itemsize
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":906
 *         stride = itemsize
 *     else:
 *         shape = view.shape[dim]             # <<<<<<<<<<<<<<
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 */
  /*else*/ {
    __pyx_v_shape = (__pyx_v_view->shape[__pyx_v_dim]);

    /* "View.MemoryView":907
 *     else:
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]             # <<<<<<<<<<<<<<
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]
 */
    __pyx_v_stride = (__pyx_v_view->strides[__pyx_v_dim]);

    /* "View.MemoryView":908
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    __pyx_t_2 = (__pyx_v_view->suboffsets != NULL);
    if (__pyx_t_2) {

      /* "View.MemoryView":909
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]             # <<<<<<<<<<<<<<
 * 
 *     if index < 0:
 */
      __pyx_v_suboffset = (__pyx_v_view->suboffsets[__pyx_v_dim]);

      /* "View.MemoryView":908
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":911
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  __pyx_t_2 = (__pyx_v_index < 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":912
 * 
 *     if index < 0:
 *         index += view.shape[dim]             # <<<<<<<<<<<<<<
 *         if index < 0:
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 */
    __pyx_v_index = (__pyx_v_index + (__pyx_v_view->shape[__pyx_v_dim]));

    /* "View.MemoryView":913
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
    __pyx_t_2 = (__pyx_v_index < 0);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":914
 *         index += view.shape[dim]
 *         if index < 0:
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"             # <<<<<<<<<<<<<<
 * 
 *     if index >= shape:
 */
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = 0;
      __pyx_t_4 = 127;
      __Pyx_INCREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      __pyx_t_1 += 37;
      __Pyx_GIVEREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      __pyx_t_5 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u__7);
      __pyx_t_1 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__7);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__7);
      __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_5, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 914, __pyx_L1_error)

      /* "View.MemoryView":913
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
    }

    /* "View.MemoryView":911
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  }

  /* "View.MemoryView":916
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
  __pyx_t_2 = (__pyx_v_index >= __pyx_v_shape);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":917
 * 
 *     if index >= shape:
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"             # <<<<<<<<<<<<<<
 * 
 *     resultp = bufp + index * stride
 */
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = 0;
    __pyx_t_4 = 127;
    __Pyx_INCREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    __pyx_t_1 += 37;
    __Pyx_GIVEREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    __pyx_t_3 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u__7);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__7);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u__7);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_3, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 917, __pyx_L1_error)

    /* "View.MemoryView":916
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
  }

  /* "View.MemoryView":919
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     resultp = bufp + index * stride             # <<<<<<<<<<<<<<
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset
 */
  __pyx_v_resultp = (__pyx_v_bufp + (__pyx_v_index * __pyx_v_stride));

  /* "View.MemoryView":920
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  __pyx_t_2 = (__pyx_v_suboffset >= 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":921
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset             # <<<<<<<<<<<<<<
 * 
 *     return resultp
 */
    __pyx_v_resultp = ((((char **)__pyx_v_resultp)[0]) + __pyx_v_suboffset);

    /* "View.MemoryView":920
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  }

  /* "View.MemoryView":923
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 *     return resultp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_resultp;
  goto __pyx_L0;

  /* "View.MemoryView":896
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.pybuffer_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":929
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

static int __pyx_memslice_transpose(__Pyx_memviewslice *__pyx_v_memslice) {
  int __pyx_v_ndim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_r;
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":930
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:
 *     cdef int ndim = memslice.memview.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 */
  __pyx_t_1 = __pyx_v_memslice->memview->view.ndim;
  __pyx_v_ndim = __pyx_t_1;

  /* "View.MemoryView":932
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 *     cdef Py_ssize_t *shape = memslice.shape             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t *strides = memslice.strides
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->shape;
  __pyx_v_shape = __pyx_t_2;

  /* "View.MemoryView":933
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 *     cdef Py_ssize_t *strides = memslice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->strides;
  __pyx_v_strides = __pyx_t_2;

  /* "View.MemoryView":937
 * 
 *     cdef int i, j
 *     for i in range(ndim // 2):             # <<<<<<<<<<<<<<
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 */
  __pyx_t_3 = __Pyx_div_long(__pyx_v_ndim, 2);
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_4; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":938
 *     cdef int i, j
 *     for i in range(ndim // 2):
 *         j = ndim - 1 - i             # <<<<<<<<<<<<<<
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]
 */
    __pyx_v_j = ((__pyx_v_ndim - 1) - __pyx_v_i);

    /* "View.MemoryView":939
 *     for i in range(ndim // 2):
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]             # <<<<<<<<<<<<<<
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 */
    __pyx_t_5 = (__pyx_v_strides[__pyx_v_j]);
    __pyx_t_6 = (__pyx_v_strides[__pyx_v_i]);
    (__pyx_v_strides[__pyx_v_i]) = __pyx_t_5;
    (__pyx_v_strides[__pyx_v_j]) = __pyx_t_6;

    /* "View.MemoryView":940
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]             # <<<<<<<<<<<<<<
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 */
    __pyx_t_6 = (__pyx_v_shape[__pyx_v_j]);
    __pyx_t_5 = (__pyx_v_shape[__pyx_v_i]);
    (__pyx_v_shape[__pyx_v_i]) = __pyx_t_6;
    (__pyx_v_shape[__pyx_v_j]) = __pyx_t_5;

    /* "View.MemoryView":942
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    __pyx_t_8 = ((__pyx_v_memslice->suboffsets[__pyx_v_i]) >= 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_8 = ((__pyx_v_memslice->suboffsets[__pyx_v_j]) >= 0);
    __pyx_t_7 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_7) {

      /* "View.MemoryView":943
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
      __pyx_t_9 = __pyx_memoryview_err(PyExc_ValueError, __pyx_kp_s_Cannot_transpose_memoryview_with); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 943, __pyx_L1_error)

      /* "View.MemoryView":942
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    }
  }

  /* "View.MemoryView":945
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":929
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.transpose_memslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":963
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 */

/* Python wrapper */
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "View.MemoryView":964
 * 
 *     def __dealloc__(self):
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __PYX_XCLEAR_MEMVIEW((&__pyx_v_self->from_slice), 1);

  /* "View.MemoryView":963
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":966
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 0);

  /* "View.MemoryView":967
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->to_object_func != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":968
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)             # <<<<<<<<<<<<<<
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_self->to_object_func(__pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":967
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  }

  /* "View.MemoryView":970
 *             return self.to_object_func(itemp)
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_memoryview_convert_item_to_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":966
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":972
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 0);

  /* "View.MemoryView":973
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->to_dtype_func != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":974
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)             # <<<<<<<<<<<<<<
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)
 */
    __pyx_t_2 = __pyx_v_self->to_dtype_func(__pyx_v_itemp, __pyx_v_value); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(0, 974, __pyx_L1_error)

    /* "View.MemoryView":973
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":976
 *             self.to_dtype_func(itemp, value)
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef _get_base(self):
 */
  /*else*/ {
    __pyx_t_3 = __pyx_memoryview_assign_item_from_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":972
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":978
 *             memoryview.assign_item_from_object(self, itemp, value)
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

static PyObject *__pyx_memoryviewslice__get_base(struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_base", 0);

  /* "View.MemoryView":979
 * 
 *     cdef _get_base(self):
 *         return self.from_object             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->from_object);
  __pyx_r = __pyx_v_self->from_object;
  goto __pyx_L0;

  /* "View.MemoryView":978
 *             memoryview.assign_item_from_object(self, itemp, value)
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_memoryviewslice___reduce_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(0, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_memoryviewslice_2__setstate_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice __pyx_v_memviewslice, int __pyx_v_ndim, PyObject *(*__pyx_v_to_object_func)(char *), int (*__pyx_v_to_dtype_func)(char *, PyObject *), int __pyx_v_dtype_is_object) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  Py_ssize_t __pyx_v_suboffset;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_TypeInfo *__pyx_t_4;
  Py_buffer __pyx_t_5;
  Py_ssize_t *__pyx_t_6;
  Py_ssize_t *__pyx_t_7;
  Py_ssize_t *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_fromslice", 0);

  /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_memviewslice.memview) == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":1008
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  }

  /* "View.MemoryView":1013
 * 
 * 
 *     result = _memoryviewslice.__new__(_memoryviewslice, None, 0, dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     result.from_slice = memviewslice
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_3, 0, Py_None);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_tp_new__memoryviewslice(((PyTypeObject *)__pyx_memoryviewslice_type), __pyx_t_3, NULL)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":1015
 *     result = _memoryviewslice.__new__(_memoryviewslice, None, 0, dtype_is_object)
 * 
 *     result.from_slice = memviewslice             # <<<<<<<<<<<<<<
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 */
  __pyx_v_result->from_slice = __pyx_v_memviewslice;

  /* "View.MemoryView":1016
 * 
 *     result.from_slice = memviewslice
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)             # <<<<<<<<<<<<<<
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()
 */
  __PYX_INC_MEMVIEW((&__pyx_v_memviewslice), 1);

  /* "View.MemoryView":1018
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()             # <<<<<<<<<<<<<<
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->__pyx_vtab)->_get_base(((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->from_object);
  __Pyx_DECREF(__pyx_v_result->from_object);
  __pyx_v_result->from_object = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "View.MemoryView":1019
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()
 *     result.typeinfo = memviewslice.memview.typeinfo             # <<<<<<<<<<<<<<
 * 
 *     result.view = memviewslice.memview.view
 */
  __pyx_t_4 = __pyx_v_memviewslice.memview->typeinfo;
  __pyx_v_result->__pyx_base.typeinfo = __pyx_t_4;

  /* "View.MemoryView":1021
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 *     result.view = memviewslice.memview.view             # <<<<<<<<<<<<<<
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 */
  __pyx_t_5 = __pyx_v_memviewslice.memview->view;
  __pyx_v_result->__pyx_base.view = __pyx_t_5;

  /* "View.MemoryView":1022
 * 
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data             # <<<<<<<<<<<<<<
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 */
  __pyx_v_result->__pyx_base.view.buf = ((void *)__pyx_v_memviewslice.data);

  /* "View.MemoryView":1023
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim             # <<<<<<<<<<<<<<
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)
 */
  __pyx_v_result->__pyx_base.view.ndim = __pyx_v_ndim;

  /* "View.MemoryView":1024
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None             # <<<<<<<<<<<<<<
 *     Py_INCREF(Py_None)
 * 
 */
  ((Py_buffer *)(&__pyx_v_result->__pyx_base.view))->obj = Py_None;

  /* "View.MemoryView":1025
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 */
  Py_INCREF(Py_None);

  /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
  __pyx_t_1 = ((((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1028
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 *         result.flags = PyBUF_RECORDS             # <<<<<<<<<<<<<<
 *     else:
 *         result.flags = PyBUF_RECORDS_RO
 */
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS;

    /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":1030
 *         result.flags = PyBUF_RECORDS
 *     else:
 *         result.flags = PyBUF_RECORDS_RO             # <<<<<<<<<<<<<<
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 */
  /*else*/ {
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS_RO;
  }
  __pyx_L4:;

  /* "View.MemoryView":1032
 *         result.flags = PyBUF_RECORDS_RO
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape             # <<<<<<<<<<<<<<
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides
 * 
 */
  __pyx_v_result->__pyx_base.view.shape = ((Py_ssize_t *)__pyx_v_result->from_slice.shape);

  /* "View.MemoryView":1033
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_result->__pyx_base.view.strides = ((Py_ssize_t *)__pyx_v_result->from_slice.strides);

  /* "View.MemoryView":1036
 * 
 * 
 *     result.view.suboffsets = NULL             # <<<<<<<<<<<<<<
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 */
  __pyx_v_result->__pyx_base.view.suboffsets = NULL;

  /* "View.MemoryView":1037
 * 
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 */
  __pyx_t_7 = (__pyx_v_result->from_slice.suboffsets + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->from_slice.suboffsets; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_v_suboffset = (__pyx_t_6[0]);

    /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    __pyx_t_1 = (__pyx_v_suboffset >= 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":1039
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_result->__pyx_base.view.suboffsets = ((Py_ssize_t *)__pyx_v_result->from_slice.suboffsets);

      /* "View.MemoryView":1040
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break             # <<<<<<<<<<<<<<
 * 
 *     result.view.len = result.view.itemsize
 */
      goto __pyx_L6_break;

      /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    }
  }
  __pyx_L6_break:;

  /* "View.MemoryView":1042
 *             break
 * 
 *     result.view.len = result.view.itemsize             # <<<<<<<<<<<<<<
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length
 */
  __pyx_t_9 = __pyx_v_result->__pyx_base.view.itemsize;
  __pyx_v_result->__pyx_base.view.len = __pyx_t_9;

  /* "View.MemoryView":1043
 * 
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         result.view.len *= length
 * 
 */
  __pyx_t_7 = (__pyx_v_result->__pyx_base.view.shape + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->__pyx_base.view.shape; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_t_2 = PyInt_FromSsize_t((__pyx_t_6[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1044
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length             # <<<<<<<<<<<<<<
 * 
 *     result.to_object_func = to_object_func
 */
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_result->__pyx_base.view.len); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_InPlaceMultiply(__pyx_t_2, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_result->__pyx_base.view.len = __pyx_t_9;
  }

  /* "View.MemoryView":1046
 *         result.view.len *= length
 * 
 *     result.to_object_func = to_object_func             # <<<<<<<<<<<<<<
 *     result.to_dtype_func = to_dtype_func
 * 
 */
  __pyx_v_result->to_object_func = __pyx_v_to_object_func;

  /* "View.MemoryView":1047
 * 
 *     result.to_object_func = to_object_func
 *     result.to_dtype_func = to_dtype_func             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  __pyx_v_result->to_dtype_func = __pyx_v_to_dtype_func;

  /* "View.MemoryView":1049
 *     result.to_dtype_func = to_dtype_func
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_fromslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_mslice) {
  struct __pyx_memoryviewslice_obj *__pyx_v_obj = 0;
  __Pyx_memviewslice *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_slice_from_memview", 0);

  /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":1056
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview             # <<<<<<<<<<<<<<
 *         return &obj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(0, 1056, __pyx_L1_error)
    __pyx_t_2 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_obj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1057
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview
 *         return &obj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, mslice)
 */
    __pyx_r = (&__pyx_v_obj->from_slice);
    goto __pyx_L0;

    /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  }

  /* "View.MemoryView":1059
 *         return &obj.from_slice
 *     else:
 *         slice_copy(memview, mslice)             # <<<<<<<<<<<<<<
 *         return mslice
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, __pyx_v_mslice);

    /* "View.MemoryView":1060
 *     else:
 *         slice_copy(memview, mslice)
 *         return mslice             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_slice_copy')
 */
    __pyx_r = __pyx_v_mslice;
    goto __pyx_L0;
  }

  /* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.get_slice_from_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_obj);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst) noexcept:             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_dst) {
  int __pyx_v_dim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  Py_ssize_t *__pyx_v_suboffsets;
  __Pyx_RefNannyDeclarations
  Py_ssize_t *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  __Pyx_RefNannySetupContext("slice_copy", 0);

  /* "View.MemoryView":1067
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 * 
 *     shape = memview.view.shape             # <<<<<<<<<<<<<<
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets
 */
  __pyx_t_1 = __pyx_v_memview->view.shape;
  __pyx_v_shape = __pyx_t_1;

  /* "View.MemoryView":1068
 * 
 *     shape = memview.view.shape
 *     strides = memview.view.strides             # <<<<<<<<<<<<<<
 *     suboffsets = memview.view.suboffsets
 * 
 */
  __pyx_t_1 = __pyx_v_memview->view.strides;
  __pyx_v_strides = __pyx_t_1;

  /* "View.MemoryView":1069
 *     shape = memview.view.shape
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets             # <<<<<<<<<<<<<<
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 */
  __pyx_t_1 = __pyx_v_memview->view.suboffsets;
  __pyx_v_suboffsets = __pyx_t_1;

  /* "View.MemoryView":1071
 *     suboffsets = memview.view.suboffsets
 * 
 *     dst.memview = <__pyx_memoryview *> memview             # <<<<<<<<<<<<<<
 *     dst.data = <char *> memview.view.buf
 * 
 */
  __pyx_v_dst->memview = ((struct __pyx_memoryview_obj *)__pyx_v_memview);

  /* "View.MemoryView":1072
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 *     dst.data = <char *> memview.view.buf             # <<<<<<<<<<<<<<
 * 
 *     for dim in range(memview.view.ndim):
 */
  __pyx_v_dst->data = ((char *)__pyx_v_memview->view.buf);

  /* "View.MemoryView":1074
 *     dst.data = <char *> memview.view.buf
 * 
 *     for dim in range(memview.view.ndim):             # <<<<<<<<<<<<<<
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 */
  __pyx_t_2 = __pyx_v_memview->view.ndim;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_dim = __pyx_t_4;

    /* "View.MemoryView":1075
 * 
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]             # <<<<<<<<<<<<<<
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 */
    (__pyx_v_dst->shape[__pyx_v_dim]) = (__pyx_v_shape[__pyx_v_dim]);

    /* "View.MemoryView":1076
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]             # <<<<<<<<<<<<<<
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 * 
 */
    (__pyx_v_dst->strides[__pyx_v_dim]) = (__pyx_v_strides[__pyx_v_dim]);

    /* "View.MemoryView":1077
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object')
 */
    if ((__pyx_v_suboffsets != 0)) {
      __pyx_t_5 = (__pyx_v_suboffsets[__pyx_v_dim]);
    } else {
      __pyx_t_5 = -1L;
    }
    (__pyx_v_dst->suboffsets[__pyx_v_dim]) = __pyx_t_5;
  }

  /* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst) noexcept:             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *__pyx_v_memview) {
  __Pyx_memviewslice __pyx_v_memviewslice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy", 0);

  /* "View.MemoryView":1083
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)             # <<<<<<<<<<<<<<
 *     return memoryview_copy_from_slice(memview, &memviewslice)
 * 
 */
  __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_memviewslice));

  /* "View.MemoryView":1084
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)
 *     return memoryview_copy_from_slice(memview, &memviewslice)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_copy_object_from_slice(__pyx_v_memview, (&__pyx_v_memviewslice)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_memviewslice) {
  PyObject *(*__pyx_v_to_object_func)(char *);
  int (*__pyx_v_to_dtype_func)(char *, PyObject *);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *(*__pyx_t_2)(char *);
  int (*__pyx_t_3)(char *, PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy_from_slice", 0);

  /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":1095
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func             # <<<<<<<<<<<<<<
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 */
    __pyx_t_2 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_object_func;
    __pyx_v_to_object_func = __pyx_t_2;

    /* "View.MemoryView":1096
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func             # <<<<<<<<<<<<<<
 *     else:
 *         to_object_func = NULL
 */
    __pyx_t_3 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_dtype_func;
    __pyx_v_to_dtype_func = __pyx_t_3;

    /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1098
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 *         to_object_func = NULL             # <<<<<<<<<<<<<<
 *         to_dtype_func = NULL
 * 
 */
  /*else*/ {
    __pyx_v_to_object_func = NULL;

    /* "View.MemoryView":1099
 *     else:
 *         to_object_func = NULL
 *         to_dtype_func = NULL             # <<<<<<<<<<<<<<
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 */
    __pyx_v_to_dtype_func = NULL;
  }
  __pyx_L3:;

  /* "View.MemoryView":1101
 *         to_dtype_func = NULL
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,             # <<<<<<<<<<<<<<
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)
 */
  __Pyx_XDECREF(__pyx_r);

  /* "View.MemoryView":1103
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_memoryview_fromslice((__pyx_v_memviewslice[0]), __pyx_v_memview->view.ndim, __pyx_v_to_object_func, __pyx_v_to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_from_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:             # <<<<<<<<<<<<<<
 *     return -arg if arg < 0 else arg
 * 
 */

static Py_ssize_t abs_py_ssize_t(Py_ssize_t __pyx_v_arg) {
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;

  /* "View.MemoryView":1110
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:
 *     return -arg if arg < 0 else arg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_get_best_slice_order')
 */
  if ((__pyx_v_arg < 0)) {
    __pyx_t_1 = (-__pyx_v_arg);
  } else {
    __pyx_t_1 = __pyx_v_arg;
  }
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:             # <<<<<<<<<<<<<<
 *     return -arg if arg < 0 else arg
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1113
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

static char __pyx_get_best_slice_order(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim) {
  int __pyx_v_i;
  Py_ssize_t __pyx_v_c_stride;
  Py_ssize_t __pyx_v_f_stride;
  char __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1118
 *     """
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t f_stride = 0
 * 
 */
  __pyx_v_c_stride = 0;

  /* "View.MemoryView":1119
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0
 *     cdef Py_ssize_t f_stride = 0             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_f_stride = 0;

  /* "View.MemoryView":1121
 *     cdef Py_ssize_t f_stride = 0
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1122
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = ((__pyx_v_mslice->shape[__pyx_v_i]) > 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1123
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_c_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1124
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
      goto __pyx_L4_break;

      /* "View.MemoryView":1122
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L4_break:;

  /* "View.MemoryView":1126
 *             break
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 */
  __pyx_t_1 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1127
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = ((__pyx_v_mslice->shape[__pyx_v_i]) > 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1128
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_f_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1129
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 */
      goto __pyx_L7_break;

      /* "View.MemoryView":1127
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L7_break:;

  /* "View.MemoryView":1131
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  __pyx_t_2 = (abs_py_ssize_t(__pyx_v_c_stride) <= abs_py_ssize_t(__pyx_v_f_stride));
  if (__pyx_t_2) {

    /* "View.MemoryView":1132
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 *         return 'C'             # <<<<<<<<<<<<<<
 *     else:
 *         return 'F'
 */
    __pyx_r = 'C';
    goto __pyx_L0;

    /* "View.MemoryView":1131
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  }

  /* "View.MemoryView":1134
 *         return 'C'
 *     else:
 *         return 'F'             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
  /*else*/ {
    __pyx_r = 'F';
    goto __pyx_L0;
  }

  /* "View.MemoryView":1113
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1137
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

static void _copy_strided_to_strided(char *__pyx_v_src_data, Py_ssize_t *__pyx_v_src_strides, char *__pyx_v_dst_data, Py_ssize_t *__pyx_v_dst_strides, Py_ssize_t *__pyx_v_src_shape, Py_ssize_t *__pyx_v_dst_shape, int __pyx_v_ndim, size_t __pyx_v_itemsize) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  CYTHON_UNUSED Py_ssize_t __pyx_v_src_extent;
  Py_ssize_t __pyx_v_dst_extent;
  Py_ssize_t __pyx_v_src_stride;
  Py_ssize_t __pyx_v_dst_stride;
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;

  /* "View.MemoryView":1144
 * 
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 */
  __pyx_v_src_extent = (__pyx_v_src_shape[0]);

  /* "View.MemoryView":1145
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 */
  __pyx_v_dst_extent = (__pyx_v_dst_shape[0]);

  /* "View.MemoryView":1146
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 */
  __pyx_v_src_stride = (__pyx_v_src_strides[0]);

  /* "View.MemoryView":1147
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_dst_stride = (__pyx_v_dst_strides[0]);

  /* "View.MemoryView":1149
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
  __pyx_t_1 = (__pyx_v_ndim == 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    __pyx_t_2 = (__pyx_v_src_stride > 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_dst_stride > 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }

    /* "View.MemoryView":1151
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):             # <<<<<<<<<<<<<<
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 *         else:
 */
    __pyx_t_2 = (((size_t)__pyx_v_src_stride) == __pyx_v_itemsize);
    if (__pyx_t_2) {
      __pyx_t_2 = (__pyx_v_itemsize == ((size_t)__pyx_v_dst_stride));
    }
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;

    /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    if (__pyx_t_1) {

      /* "View.MemoryView":1152
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)             # <<<<<<<<<<<<<<
 *         else:
 *             for i in range(dst_extent):
 */
      (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, (__pyx_v_itemsize * __pyx_v_dst_extent)));

      /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":1154
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 *         else:
 *             for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride
 */
    /*else*/ {
      __pyx_t_3 = __pyx_v_dst_extent;
      __pyx_t_4 = __pyx_t_3;
      for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
        __pyx_v_i = __pyx_t_5;

        /* "View.MemoryView":1155
 *         else:
 *             for i in range(dst_extent):
 *                 memcpy(dst_data, src_data, itemsize)             # <<<<<<<<<<<<<<
 *                 src_data += src_stride
 *                 dst_data += dst_stride
 */
        (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, __pyx_v_itemsize));

        /* "View.MemoryView":1156
 *             for i in range(dst_extent):
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride             # <<<<<<<<<<<<<<
 *                 dst_data += dst_stride
 *     else:
 */
        __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

        /* "View.MemoryView":1157
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride
 *                 dst_data += dst_stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(dst_extent):
 */
        __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
      }
    }
    __pyx_L4:;

    /* "View.MemoryView":1149
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1159
 *                 dst_data += dst_stride
 *     else:
 *         for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *             _copy_strided_to_strided(src_data, src_strides + 1,
 *                                      dst_data, dst_strides + 1,
 */
  /*else*/ {
    __pyx_t_3 = __pyx_v_dst_extent;
    __pyx_t_4 = __pyx_t_3;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "View.MemoryView":1160
 *     else:
 *         for i in range(dst_extent):
 *             _copy_strided_to_strided(src_data, src_strides + 1,             # <<<<<<<<<<<<<<
 *                                      dst_data, dst_strides + 1,
 *                                      src_shape + 1, dst_shape + 1,
 */
      _copy_strided_to_strided(__pyx_v_src_data, (__pyx_v_src_strides + 1), __pyx_v_dst_data, (__pyx_v_dst_strides + 1), (__pyx_v_src_shape + 1), (__pyx_v_dst_shape + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize);

      /* "View.MemoryView":1164
 *                                      src_shape + 1, dst_shape + 1,
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride             # <<<<<<<<<<<<<<
 *             dst_data += dst_stride
 * 
 */
      __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

      /* "View.MemoryView":1165
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride
 *             dst_data += dst_stride             # <<<<<<<<<<<<<<
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,
 */
      __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1137
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

  /* function exit code */
}

/* "View.MemoryView":1167
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 */

static void copy_strided_to_strided(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize) {

  /* "View.MemoryView":1170
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 *     _copy_strided_to_strided(src.data, src.strides, dst.data, dst.strides,             # <<<<<<<<<<<<<<
 *                              src.shape, dst.shape, ndim, itemsize)
 * 
 */
  _copy_strided_to_strided(__pyx_v_src->data, __pyx_v_src->strides, __pyx_v_dst->data, __pyx_v_dst->strides, __pyx_v_src->shape, __pyx_v_dst->shape, __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1167
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1174
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *__pyx_v_src, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_size;
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;

  /* "View.MemoryView":1176
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     for shape in src.shape[:ndim]:
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_size = __pyx_t_1;

  /* "View.MemoryView":1178
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 * 
 *     for shape in src.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         size *= shape
 * 
 */
  __pyx_t_3 = (__pyx_v_src->shape + __pyx_v_ndim);
  for (__pyx_t_4 = __pyx_v_src->shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_2 = __pyx_t_4;
    __pyx_v_shape = (__pyx_t_2[0]);

    /* "View.MemoryView":1179
 * 
 *     for shape in src.shape[:ndim]:
 *         size *= shape             # <<<<<<<<<<<<<<
 * 
 *     return size
 */
    __pyx_v_size = (__pyx_v_size * __pyx_v_shape);
  }

  /* "View.MemoryView":1181
 *         size *= shape
 * 
 *     return size             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_fill_contig_strides_array')
 */
  __pyx_r = __pyx_v_size;
  goto __pyx_L0;

  /* "View.MemoryView":1174
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1184
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) noexcept nogil:
 */

static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, Py_ssize_t __pyx_v_stride, int __pyx_v_ndim, char __pyx_v_order) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1193
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
  __pyx_t_1 = (__pyx_v_order == 'F');
  if (__pyx_t_1) {

    /* "View.MemoryView":1194
 * 
 *     if order == 'F':
 *         for idx in range(ndim):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
    __pyx_t_2 = __pyx_v_ndim;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_idx = __pyx_t_4;

      /* "View.MemoryView":1195
 *     if order == 'F':
 *         for idx in range(ndim):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 *     else:
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1196
 *         for idx in range(ndim):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }

    /* "View.MemoryView":1193
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1198
 *             stride *= shape[idx]
 *     else:
 *         for idx in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
  /*else*/ {
    for (__pyx_t_2 = (__pyx_v_ndim - 1); __pyx_t_2 > -1; __pyx_t_2-=1) {
      __pyx_v_idx = __pyx_t_2;

      /* "View.MemoryView":1199
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 * 
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1200
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 * 
 *     return stride
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1202
 *             stride *= shape[idx]
 * 
 *     return stride             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 */
  __pyx_r = __pyx_v_stride;
  goto __pyx_L0;

  /* "View.MemoryView":1184
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) noexcept nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1205
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_tmpslice, char __pyx_v_order, int __pyx_v_ndim) {
  int __pyx_v_i;
  void *__pyx_v_result;
  size_t __pyx_v_itemsize;
  size_t __pyx_v_size;
  void *__pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_memoryview_obj *__pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":1216
 *     cdef void *result
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1217
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef size_t size = slice_get_size(src, ndim)             # <<<<<<<<<<<<<<
 * 
 *     result = malloc(size)
 */
  __pyx_v_size = __pyx_memoryview_slice_get_size(__pyx_v_src, __pyx_v_ndim);

  /* "View.MemoryView":1219
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 *     result = malloc(size)             # <<<<<<<<<<<<<<
 *     if not result:
 *         _err_no_memory()
 */
  __pyx_v_result = malloc(__pyx_v_size);

  /* "View.MemoryView":1220
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err_no_memory()
 * 
 */
  __pyx_t_2 = (!(__pyx_v_result != 0));
  if (__pyx_t_2) {

    /* "View.MemoryView":1221
 *     result = malloc(size)
 *     if not result:
 *         _err_no_memory()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __pyx_memoryview_err_no_memory(); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1221, __pyx_L1_error)

    /* "View.MemoryView":1220
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err_no_memory()
 * 
 */
  }

  /* "View.MemoryView":1224
 * 
 * 
 *     tmpslice.data = <char *> result             # <<<<<<<<<<<<<<
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 */
  __pyx_v_tmpslice->data = ((char *)__pyx_v_result);

  /* "View.MemoryView":1225
 * 
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview             # <<<<<<<<<<<<<<
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 */
  __pyx_t_4 = __pyx_v_src->memview;
  __pyx_v_tmpslice->memview = __pyx_t_4;

  /* "View.MemoryView":1226
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1227
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]             # <<<<<<<<<<<<<<
 *         tmpslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_tmpslice->shape[__pyx_v_i]) = (__pyx_v_src->shape[__pyx_v_i]);

    /* "View.MemoryView":1228
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize, ndim, order)
 */
    (__pyx_v_tmpslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1230
 *         tmpslice.suboffsets[i] = -1
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize, ndim, order)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  (void)(__pyx_fill_contig_strides_array((&(__pyx_v_tmpslice->shape[0])), (&(__pyx_v_tmpslice->strides[0])), __pyx_v_itemsize, __pyx_v_ndim, __pyx_v_order));

  /* "View.MemoryView":1233
 * 
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1234
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    __pyx_t_2 = ((__pyx_v_tmpslice->shape[__pyx_v_i]) == 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1235
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     if slice_is_contig(src[0], order, ndim):
 */
      (__pyx_v_tmpslice->strides[__pyx_v_i]) = 0;

      /* "View.MemoryView":1234
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    }
  }

  /* "View.MemoryView":1237
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
  __pyx_t_2 = __pyx_memviewslice_is_contig((__pyx_v_src[0]), __pyx_v_order, __pyx_v_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1238
 * 
 *     if slice_is_contig(src[0], order, ndim):
 *         memcpy(result, src.data, size)             # <<<<<<<<<<<<<<
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 */
    (void)(memcpy(__pyx_v_result, __pyx_v_src->data, __pyx_v_size));

    /* "View.MemoryView":1237
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":1240
 *         memcpy(result, src.data, size)
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  /*else*/ {
    copy_strided_to_strided(__pyx_v_src, __pyx_v_tmpslice, __pyx_v_ndim, __pyx_v_itemsize);
  }
  __pyx_L9:;

  /* "View.MemoryView":1242
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":1205
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.copy_data_to_temp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1247
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"
 */

static int __pyx_memoryview_err_extents(int __pyx_v_i, Py_ssize_t __pyx_v_extent1, Py_ssize_t __pyx_v_extent2) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_extents", 0);

  /* "View.MemoryView":1249
 * cdef int _err_extents(int i, Py_ssize_t extent1,
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_dim')
 */
  __pyx_t_1 = PyTuple_New(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u_got_differing_extents_in_dimensi);
  __pyx_t_2 += 35;
  __Pyx_GIVEREF(__pyx_kp_u_got_differing_extents_in_dimensi);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_got_differing_extents_in_dimensi);
  __pyx_t_4 = __Pyx_PyUnicode_From_int(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_got);
  __pyx_t_2 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_got);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_got);
  __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_extent1, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_and);
  __pyx_t_2 += 5;
  __Pyx_GIVEREF(__pyx_kp_u_and);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_and);
  __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_extent2, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__7);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__7);
  PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u__7);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 7, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_4, 0, 0);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(0, 1249, __pyx_L1_error)

  /* "View.MemoryView":1247
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView._err_extents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1252
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg % dim
 * 
 */

static int __pyx_memoryview_err_dim(PyObject *__pyx_v_error, PyObject *__pyx_v_msg, int __pyx_v_dim) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_dim", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "View.MemoryView":1253
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:
 *     raise <object>error, msg % dim             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err')
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_dim); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_FormatSafe(__pyx_v_msg, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(((PyObject *)__pyx_v_error), __pyx_t_2, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 1253, __pyx_L1_error)

  /* "View.MemoryView":1252
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg % dim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._err_dim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1256
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg
 * 
 */

static int __pyx_memoryview_err(PyObject *__pyx_v_error, PyObject *__pyx_v_msg) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "View.MemoryView":1257
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:
 *     raise <object>error, msg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 */
  __Pyx_Raise(((PyObject *)__pyx_v_error), __pyx_v_msg, 0, 0);
  __PYX_ERR(0, 1257, __pyx_L1_error)

  /* "View.MemoryView":1256
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._err", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1260
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise MemoryError
 * 
 */

static int __pyx_memoryview_err_no_memory(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_no_memory", 0);

  /* "View.MemoryView":1261
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:
 *     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  PyErr_NoMemory(); __PYX_ERR(0, 1261, __pyx_L1_error)

  /* "View.MemoryView":1260
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise MemoryError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._err_no_memory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1265
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

static int __pyx_memoryview_copy_contents(__Pyx_memviewslice __pyx_v_src, __Pyx_memviewslice __pyx_v_dst, int __pyx_v_src_ndim, int __pyx_v_dst_ndim, int __pyx_v_dtype_is_object) {
  void *__pyx_v_tmpdata;
  size_t __pyx_v_itemsize;
  int __pyx_v_i;
  char __pyx_v_order;
  int __pyx_v_broadcasting;
  int __pyx_v_direct_copy;
  __Pyx_memviewslice __pyx_v_tmp;
  int __pyx_v_ndim;
  int __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  void *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":1273
 *     Check for overlapping memory and verify the shapes.
 *     """
 *     cdef void *tmpdata = NULL             # <<<<<<<<<<<<<<
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 */
  __pyx_v_tmpdata = NULL;

  /* "View.MemoryView":1274
 *     """
 *     cdef void *tmpdata = NULL
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 */
  __pyx_t_1 = __pyx_v_src.memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1276
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)             # <<<<<<<<<<<<<<
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False
 */
  __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_src), __pyx_v_src_ndim);

  /* "View.MemoryView":1277
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False             # <<<<<<<<<<<<<<
 *     cdef bint direct_copy = False
 *     cdef __Pyx_memviewslice tmp
 */
  __pyx_v_broadcasting = 0;

  /* "View.MemoryView":1278
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False             # <<<<<<<<<<<<<<
 *     cdef __Pyx_memviewslice tmp
 * 
 */
  __pyx_v_direct_copy = 0;

  /* "View.MemoryView":1281
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
  __pyx_t_2 = (__pyx_v_src_ndim < __pyx_v_dst_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1282
 * 
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_src), __pyx_v_src_ndim, __pyx_v_dst_ndim);

    /* "View.MemoryView":1281
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1283
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  __pyx_t_2 = (__pyx_v_dst_ndim < __pyx_v_src_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1284
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)             # <<<<<<<<<<<<<<
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_dst), __pyx_v_dst_ndim, __pyx_v_src_ndim);

    /* "View.MemoryView":1283
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":1286
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
  __pyx_t_3 = __pyx_v_dst_ndim;
  __pyx_t_4 = __pyx_v_src_ndim;
  if ((__pyx_t_3 > __pyx_t_4)) {
    __pyx_t_5 = __pyx_t_3;
  } else {
    __pyx_t_5 = __pyx_t_4;
  }
  __pyx_v_ndim = __pyx_t_5;

  /* "View.MemoryView":1288
 *     cdef int ndim = max(src_ndim, dst_ndim)
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 */
  __pyx_t_5 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_5;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1289
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    __pyx_t_2 = ((__pyx_v_src.shape[__pyx_v_i]) != (__pyx_v_dst.shape[__pyx_v_i]));
    if (__pyx_t_2) {

      /* "View.MemoryView":1290
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
      __pyx_t_2 = ((__pyx_v_src.shape[__pyx_v_i]) == 1);
      if (__pyx_t_2) {

        /* "View.MemoryView":1291
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 *                 broadcasting = True             # <<<<<<<<<<<<<<
 *                 src.strides[i] = 0
 *             else:
 */
        __pyx_v_broadcasting = 1;

        /* "View.MemoryView":1292
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 *                 src.strides[i] = 0             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 */
        (__pyx_v_src.strides[__pyx_v_i]) = 0;

        /* "View.MemoryView":1290
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":1294
 *                 src.strides[i] = 0
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])             # <<<<<<<<<<<<<<
 * 
 *         if src.suboffsets[i] >= 0:
 */
      /*else*/ {
        __pyx_t_6 = __pyx_memoryview_err_extents(__pyx_v_i, (__pyx_v_dst.shape[__pyx_v_i]), (__pyx_v_src.shape[__pyx_v_i])); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 1294, __pyx_L1_error)
      }
      __pyx_L7:;

      /* "View.MemoryView":1289
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    }

    /* "View.MemoryView":1296
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 */
    __pyx_t_2 = ((__pyx_v_src.suboffsets[__pyx_v_i]) >= 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1297
 * 
 *         if src.suboffsets[i] >= 0:
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)             # <<<<<<<<<<<<<<
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 */
      __pyx_t_6 = __pyx_memoryview_err_dim(PyExc_ValueError, __pyx_kp_s_Dimension_d_is_not_direct, __pyx_v_i); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 1297, __pyx_L1_error)

      /* "View.MemoryView":1296
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 */
    }
  }

  /* "View.MemoryView":1299
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  __pyx_t_2 = __pyx_slices_overlap((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);
  if (__pyx_t_2) {

    /* "View.MemoryView":1301
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    __pyx_t_2 = (!__pyx_memviewslice_is_contig(__pyx_v_src, __pyx_v_order, __pyx_v_ndim));
    if (__pyx_t_2) {

      /* "View.MemoryView":1302
 * 
 *         if not slice_is_contig(src, order, ndim):
 *             order = get_best_order(&dst, ndim)             # <<<<<<<<<<<<<<
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 */
      __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim);

      /* "View.MemoryView":1301
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    }

    /* "View.MemoryView":1304
 *             order = get_best_order(&dst, ndim)
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)             # <<<<<<<<<<<<<<
 *         src = tmp
 * 
 */
    __pyx_t_7 = __pyx_memoryview_copy_data_to_temp((&__pyx_v_src), (&__pyx_v_tmp), __pyx_v_order, __pyx_v_ndim); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(0, 1304, __pyx_L1_error)
    __pyx_v_tmpdata = __pyx_t_7;

    /* "View.MemoryView":1305
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 *         src = tmp             # <<<<<<<<<<<<<<
 * 
 *     if not broadcasting:
 */
    __pyx_v_src = __pyx_v_tmp;

    /* "View.MemoryView":1299
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  }

  /* "View.MemoryView":1307
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (!__pyx_v_broadcasting);
  if (__pyx_t_2) {

    /* "View.MemoryView":1310
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
    __pyx_t_2 = __pyx_memviewslice_is_contig(__pyx_v_src, 'C', __pyx_v_ndim);
    if (__pyx_t_2) {

      /* "View.MemoryView":1311
 * 
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)             # <<<<<<<<<<<<<<
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'C', __pyx_v_ndim);

      /* "View.MemoryView":1310
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
      goto __pyx_L12;
    }

    /* "View.MemoryView":1312
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    __pyx_t_2 = __pyx_memviewslice_is_contig(__pyx_v_src, 'F', __pyx_v_ndim);
    if (__pyx_t_2) {

      /* "View.MemoryView":1313
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)             # <<<<<<<<<<<<<<
 * 
 *         if direct_copy:
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'F', __pyx_v_ndim);

      /* "View.MemoryView":1312
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    }
    __pyx_L12:;

    /* "View.MemoryView":1315
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    if (__pyx_v_direct_copy) {

      /* "View.MemoryView":1317
 *         if direct_copy:
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

      /* "View.MemoryView":1318
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))             # <<<<<<<<<<<<<<
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)
 */
      (void)(memcpy(__pyx_v_dst.data, __pyx_v_src.data, __pyx_memoryview_slice_get_size((&__pyx_v_src), __pyx_v_ndim)));

      /* "View.MemoryView":1319
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 *             free(tmpdata)
 *             return 0
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

      /* "View.MemoryView":1320
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
      free(__pyx_v_tmpdata);

      /* "View.MemoryView":1321
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "View.MemoryView":1315
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    }

    /* "View.MemoryView":1307
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1323
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (__pyx_v_order == 'F');
  if (__pyx_t_2) {
    __pyx_t_2 = ('F' == __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim));
  }
  if (__pyx_t_2) {

    /* "View.MemoryView":1326
 * 
 * 
 *         transpose_memslice(&src)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&dst)
 * 
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_src)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1326, __pyx_L1_error)

    /* "View.MemoryView":1327
 * 
 *         transpose_memslice(&src)
 *         transpose_memslice(&dst)             # <<<<<<<<<<<<<<
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_dst)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1327, __pyx_L1_error)

    /* "View.MemoryView":1323
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1329
 *         transpose_memslice(&dst)
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1330
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)             # <<<<<<<<<<<<<<
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 * 
 */
  copy_strided_to_strided((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1331
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 * 
 *     free(tmpdata)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1333
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 * 
 *     free(tmpdata)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
  free(__pyx_v_tmpdata);

  /* "View.MemoryView":1334
 * 
 *     free(tmpdata)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1265
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_contents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1337
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) noexcept nogil:
 */

static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim, int __pyx_v_ndim_other) {
  int __pyx_v_i;
  int __pyx_v_offset;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "View.MemoryView":1341
 *                             int ndim_other) noexcept nogil:
 *     cdef int i
 *     cdef int offset = ndim_other - ndim             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_offset = (__pyx_v_ndim_other - __pyx_v_ndim);

  /* "View.MemoryView":1343
 *     cdef int offset = ndim_other - ndim
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1344
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]             # <<<<<<<<<<<<<<
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 */
    (__pyx_v_mslice->shape[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->shape[__pyx_v_i]);

    /* "View.MemoryView":1345
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 */
    (__pyx_v_mslice->strides[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->strides[__pyx_v_i]);

    /* "View.MemoryView":1346
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(offset):
 */
    (__pyx_v_mslice->suboffsets[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->suboffsets[__pyx_v_i]);
  }

  /* "View.MemoryView":1348
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 *     for i in range(offset):             # <<<<<<<<<<<<<<
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 */
  __pyx_t_1 = __pyx_v_offset;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1349
 * 
 *     for i in range(offset):
 *         mslice.shape[i] = 1             # <<<<<<<<<<<<<<
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1
 */
    (__pyx_v_mslice->shape[__pyx_v_i]) = 1;

    /* "View.MemoryView":1350
 *     for i in range(offset):
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_mslice->strides[__pyx_v_i]) = (__pyx_v_mslice->strides[0]);

    /* "View.MemoryView":1351
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_mslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1337
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1359
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:             # <<<<<<<<<<<<<<
 * 
 *     if dtype_is_object:
 */

static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_dtype_is_object, int __pyx_v_ndim, int __pyx_v_inc) {

  /* "View.MemoryView":1361
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)
 * 
 */
  if (__pyx_v_dtype_is_object) {

    /* "View.MemoryView":1362
 * 
 *     if dtype_is_object:
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 */
    __pyx_memoryview_refcount_objects_in_slice_with_gil(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_inc);

    /* "View.MemoryView":1361
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)
 * 
 */
  }

  /* "View.MemoryView":1359
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:             # <<<<<<<<<<<<<<
 * 
 *     if dtype_is_object:
 */

  /* function exit code */
}

/* "View.MemoryView":1365
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 */

static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  __Pyx_RefNannyDeclarations
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("refcount_objects_in_slice_with_gil", 0);

  /* "View.MemoryView":1368
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 *     refcount_objects_in_slice(data, shape, strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 */
  __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, __pyx_v_shape, __pyx_v_strides, __pyx_v_ndim, __pyx_v_inc);

  /* "View.MemoryView":1365
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 */

static void __pyx_memoryview_refcount_objects_in_slice(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("refcount_objects_in_slice", 0);

  /* "View.MemoryView":1374
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(shape[0]):
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1376
 *     cdef Py_ssize_t stride = strides[0]
 * 
 *     for i in range(shape[0]):             # <<<<<<<<<<<<<<
 *         if ndim == 1:
 *             if inc:
 */
  __pyx_t_1 = (__pyx_v_shape[0]);
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1377
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
    __pyx_t_4 = (__pyx_v_ndim == 1);
    if (__pyx_t_4) {

      /* "View.MemoryView":1378
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
      if (__pyx_v_inc) {

        /* "View.MemoryView":1379
 *         if ndim == 1:
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])
 */
        Py_INCREF((((PyObject **)__pyx_v_data)[0]));

        /* "View.MemoryView":1378
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
        goto __pyx_L6;
      }

      /* "View.MemoryView":1381
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)
 */
      /*else*/ {
        Py_DECREF((((PyObject **)__pyx_v_data)[0]));
      }
      __pyx_L6:;

      /* "View.MemoryView":1377
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":1383
 *                 Py_DECREF((<PyObject **> data)[0])
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)             # <<<<<<<<<<<<<<
 * 
 *         data += stride
 */
    /*else*/ {
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_inc);
    }
    __pyx_L5:;

    /* "View.MemoryView":1385
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)
 * 
 *         data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
  }

  /* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":1391
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 */

static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item, int __pyx_v_dtype_is_object) {

  /* "View.MemoryView":1394
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1395
 *                               bint dtype_is_object) noexcept nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)             # <<<<<<<<<<<<<<
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)
 * 
 */
  __pyx_memoryview__slice_assign_scalar(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_itemsize, __pyx_v_item);

  /* "View.MemoryView":1396
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1391
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1400
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) noexcept nogil:
 */

static void __pyx_memoryview__slice_assign_scalar(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_extent;
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;

  /* "View.MemoryView":1404
 *                               size_t itemsize, void *item) noexcept nogil:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t extent = shape[0]
 * 
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1405
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]
 *     cdef Py_ssize_t extent = shape[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_extent = (__pyx_v_shape[0]);

  /* "View.MemoryView":1407
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
  __pyx_t_1 = (__pyx_v_ndim == 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":1408
 * 
 *     if ndim == 1:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             memcpy(data, item, itemsize)
 *             data += stride
 */
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1409
 *     if ndim == 1:
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)             # <<<<<<<<<<<<<<
 *             data += stride
 *     else:
 */
      (void)(memcpy(__pyx_v_data, __pyx_v_item, __pyx_v_itemsize));

      /* "View.MemoryView":1410
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 *             data += stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(extent):
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }

    /* "View.MemoryView":1407
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1412
 *             data += stride
 *     else:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)
 *             data += stride
 */
  /*else*/ {
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1413
 *     else:
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)             # <<<<<<<<<<<<<<
 *             data += stride
 * 
 */
      __pyx_memoryview__slice_assign_scalar(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize, __pyx_v_item);

      /* "View.MemoryView":1414
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)
 *             data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1400
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) noexcept nogil:
 */

  /* function exit code */
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum = {"__pyx_unpickle_Enum", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 1); __PYX_ERR(0, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 2); __PYX_ERR(0, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_Enum") < 0)) __PYX_ERR(0, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__8, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_MemviewEnum_type), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(0, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_unpickle_Enum__set_state(((struct __pyx_MemviewEnum_obj *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->name);
  __Pyx_DECREF(__pyx_v___pyx_result->name);
  __pyx_v___pyx_result->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 13, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 > 1);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 13, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 14, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":245
 * 
 *         @property
 *         cdef inline PyObject* base(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self) {
  PyObject *__pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":248
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 *             return PyArray_BASE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_BASE(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":245
 * 
 *         @property
 *         cdef inline PyObject* base(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":251
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self) {
  PyArray_Descr *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyArray_Descr *__pyx_t_1;
  __Pyx_RefNannySetupContext("descr", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":254
 *             """Returns an owned reference to the dtype of the array.
 *             """
 *             return <dtype>PyArray_DESCR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyArray_DESCR(__pyx_v_self);
  __Pyx_INCREF((PyObject *)((PyArray_Descr *)__pyx_t_1));
  __pyx_r = ((PyArray_Descr *)__pyx_t_1);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":251
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":257
 * 
 *         @property
 *         cdef inline int ndim(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self) {
  int __pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":260
 *             """Returns the number of dimensions in the array.
 *             """
 *             return PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_NDIM(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":257
 * 
 *         @property
 *         cdef inline int ndim(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":263
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":268
 *             Can return NULL for 0-dimensional arrays.
 *             """
 *             return PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_DIMS(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":263
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":271
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":275
 *             The number of elements matches the number of dimensions of the array (ndim).
 *             """
 *             return PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_STRIDES(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":271
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":278
 * 
 *         @property
 *         cdef inline npy_intp size(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":281
 *             """Returns the total size (in number of elements) of the array.
 *             """
 *             return PyArray_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_SIZE(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":278
 * 
 *         @property
 *         cdef inline npy_intp size(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":284
 * 
 *         @property
 *         cdef inline char* data(self) nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self) {
  char *__pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":290
 *             of `PyArray_DATA()` instead, which returns a 'void*'.
 *             """
 *             return PyArray_BYTES(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef unsigned char      npy_bool
 */
  __pyx_r = PyArray_BYTES(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":284
 * 
 *         @property
 *         cdef inline char* data(self) nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":774
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":776
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":777
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":776
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":779
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":780
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":779
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":782
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":783
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":782
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":785
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":786
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":785
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":788
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":789
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = PyDataType_HASSUBARRAY(__pyx_v_d);
  if (__pyx_t_1) {

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":790
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":789
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":792
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":788
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":967
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":968
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":969
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_t_1 = PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 969, __pyx_L1_error)

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":967
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("numpy.set_array_base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":971
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":972
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":973
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = (__pyx_v_base == NULL);
  if (__pyx_t_1) {

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":974
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":973
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":975
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":971
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":979
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":980
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":981
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 981, __pyx_L3_error)

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":980
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":982
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 982, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":983
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 983, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 983, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":980
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":979
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":985
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":986
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":987
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 987, __pyx_L3_error)

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":986
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":988
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 988, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":989
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 989, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 989, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":986
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":985
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":991
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":992
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":993
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 993, __pyx_L3_error)

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":992
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":994
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 994, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":995
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 995, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 995, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":992
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":991
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":998
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_timedelta64_object", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1010
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":998
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1013
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_datetime64_object", 0);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1025
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1013
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1028
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1035
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1028
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1038
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1042
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1038
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1045
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1049
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1045
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":11
 * from libc.math cimport log, sqrt, exp, abs, tgamma,sin,cos
 * 
 * cpdef (double,double) evaluate_H(double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,double M, double nu,             # <<<<<<<<<<<<<<
 * double X_1, double X_2, double a6, double dSO):
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1evaluate_H(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static __pyx_ctuple_double__and_double __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2, double __pyx_v_M, double __pyx_v_nu, double __pyx_v_X_1, double __pyx_v_X_2, double __pyx_v_a6, double __pyx_v_dSO, CYTHON_UNUSED int __pyx_skip_dispatch) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  CYTHON_UNUSED double __pyx_v_pphi;
  double __pyx_v_r2;
  double __pyx_v_r3;
  double __pyx_v_r4;
  double __pyx_v_r5;
  double __pyx_v_L2;
  double __pyx_v_L4;
  double __pyx_v_lr;
  double __pyx_v_nu2;
  double __pyx_v_nu3;
  double __pyx_v_nu4;
  double __pyx_v_prst2;
  double __pyx_v_prst4;
  double __pyx_v_prst6;
  double __pyx_v_prst8;
  double __pyx_v_d5;
  double __pyx_v_Dbpm;
  double __pyx_v_Apm;
  double __pyx_v_ap;
  double __pyx_v_ap2;
  double __pyx_v_xi;
  double __pyx_v_pr;
  double __pyx_v_flagNLOSS2;
  double __pyx_v_delta;
  double __pyx_v_am;
  double __pyx_v_apam;
  double __pyx_v_am2;
  double __pyx_v_apamd;
  double __pyx_v_QSalign2;
  double __pyx_v_flagQPN55;
  double __pyx_v_flagQPN5;
  double __pyx_v_flagQPN4;
  double __pyx_v_Qpm;
  double __pyx_v_Qq;
  double __pyx_v_Bnpa;
  double __pyx_v_flagNLOSS;
  double __pyx_v_BnpSalign2;
  double __pyx_v_Bnp;
  double __pyx_v_ASalignCal2;
  double __pyx_v_ASalign2;
  double __pyx_v_A;
  double __pyx_v_lap;
  double __pyx_v_Heven;
  double __pyx_v_lam;
  double __pyx_v_Ga3;
  double __pyx_v_SOcalib;
  double __pyx_v_flagNLOSO2;
  double __pyx_v_flagNLOSO;
  double __pyx_v_gam;
  double __pyx_v_gap;
  double __pyx_v_Hodd;
  double __pyx_v_Heff;
  double __pyx_v_H;
  __pyx_ctuple_double__and_double __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  double __pyx_t_2;
  __pyx_ctuple_double__and_double __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__11)
  __Pyx_RefNannySetupContext("evaluate_H", 0);
  __Pyx_TraceCall("evaluate_H", __pyx_f[1], 11, 0, __PYX_ERR(1, 11, __pyx_L1_error));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":36
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(36,0,__PYX_ERR(1, 36, __pyx_L1_error))
  __pyx_t_1 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_1 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":37
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(37,0,__PYX_ERR(1, 37, __pyx_L1_error))
  __pyx_t_1 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_1 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":39
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(39,0,__PYX_ERR(1, 39, __pyx_L1_error))
  __pyx_t_1 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_1 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":40
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(40,0,__PYX_ERR(1, 40, __pyx_L1_error))
  __pyx_t_1 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_1 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":42
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(42,0,__PYX_ERR(1, 42, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":45
 * 
 * 
 *         cdef double r2 = r*r             # <<<<<<<<<<<<<<
 *         cdef double r3 = r2*r
 *         cdef double r4 = r2*r2
 */
  __Pyx_TraceLine(45,0,__PYX_ERR(1, 45, __pyx_L1_error))
  __pyx_v_r2 = (__pyx_v_r * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":46
 * 
 *         cdef double r2 = r*r
 *         cdef double r3 = r2*r             # <<<<<<<<<<<<<<
 *         cdef double r4 = r2*r2
 *         cdef double r5 = r*r4
 */
  __Pyx_TraceLine(46,0,__PYX_ERR(1, 46, __pyx_L1_error))
  __pyx_v_r3 = (__pyx_v_r2 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":47
 *         cdef double r2 = r*r
 *         cdef double r3 = r2*r
 *         cdef double r4 = r2*r2             # <<<<<<<<<<<<<<
 *         cdef double r5 = r*r4
 * 
 */
  __Pyx_TraceLine(47,0,__PYX_ERR(1, 47, __pyx_L1_error))
  __pyx_v_r4 = (__pyx_v_r2 * __pyx_v_r2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":48
 *         cdef double r3 = r2*r
 *         cdef double r4 = r2*r2
 *         cdef double r5 = r*r4             # <<<<<<<<<<<<<<
 * 
 *         cdef double L2 = L*L
 */
  __Pyx_TraceLine(48,0,__PYX_ERR(1, 48, __pyx_L1_error))
  __pyx_v_r5 = (__pyx_v_r * __pyx_v_r4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":50
 *         cdef double r5 = r*r4
 * 
 *         cdef double L2 = L*L             # <<<<<<<<<<<<<<
 *         cdef double L4 = L2*L2
 *         cdef double lr = log(r)
 */
  __Pyx_TraceLine(50,0,__PYX_ERR(1, 50, __pyx_L1_error))
  __pyx_v_L2 = (__pyx_v_L * __pyx_v_L);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":51
 * 
 *         cdef double L2 = L*L
 *         cdef double L4 = L2*L2             # <<<<<<<<<<<<<<
 *         cdef double lr = log(r)
 * 
 */
  __Pyx_TraceLine(51,0,__PYX_ERR(1, 51, __pyx_L1_error))
  __pyx_v_L4 = (__pyx_v_L2 * __pyx_v_L2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":52
 *         cdef double L2 = L*L
 *         cdef double L4 = L2*L2
 *         cdef double lr = log(r)             # <<<<<<<<<<<<<<
 * 
 *         cdef double nu2 = nu*nu
 */
  __Pyx_TraceLine(52,0,__PYX_ERR(1, 52, __pyx_L1_error))
  __pyx_v_lr = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":54
 *         cdef double lr = log(r)
 * 
 *         cdef double nu2 = nu*nu             # <<<<<<<<<<<<<<
 *         cdef double nu3 = nu2*nu
 *         cdef double nu4 = nu3*nu
 */
  __Pyx_TraceLine(54,0,__PYX_ERR(1, 54, __pyx_L1_error))
  __pyx_v_nu2 = (__pyx_v_nu * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":55
 * 
 *         cdef double nu2 = nu*nu
 *         cdef double nu3 = nu2*nu             # <<<<<<<<<<<<<<
 *         cdef double nu4 = nu3*nu
 * 
 */
  __Pyx_TraceLine(55,0,__PYX_ERR(1, 55, __pyx_L1_error))
  __pyx_v_nu3 = (__pyx_v_nu2 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":56
 *         cdef double nu2 = nu*nu
 *         cdef double nu3 = nu2*nu
 *         cdef double nu4 = nu3*nu             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst2 = prst*prst
 */
  __Pyx_TraceLine(56,0,__PYX_ERR(1, 56, __pyx_L1_error))
  __pyx_v_nu4 = (__pyx_v_nu3 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":58
 *         cdef double nu4 = nu3*nu
 * 
 *         cdef double prst2 = prst*prst             # <<<<<<<<<<<<<<
 *         cdef double prst4 = prst2*prst2
 *         cdef double prst6 = prst4*prst2
 */
  __Pyx_TraceLine(58,0,__PYX_ERR(1, 58, __pyx_L1_error))
  __pyx_v_prst2 = (__pyx_v_prst * __pyx_v_prst);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":59
 * 
 *         cdef double prst2 = prst*prst
 *         cdef double prst4 = prst2*prst2             # <<<<<<<<<<<<<<
 *         cdef double prst6 = prst4*prst2
 *         cdef double prst8 = prst6*prst2
 */
  __Pyx_TraceLine(59,0,__PYX_ERR(1, 59, __pyx_L1_error))
  __pyx_v_prst4 = (__pyx_v_prst2 * __pyx_v_prst2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":60
 *         cdef double prst2 = prst*prst
 *         cdef double prst4 = prst2*prst2
 *         cdef double prst6 = prst4*prst2             # <<<<<<<<<<<<<<
 *         cdef double prst8 = prst6*prst2
 * 
 */
  __Pyx_TraceLine(60,0,__PYX_ERR(1, 60, __pyx_L1_error))
  __pyx_v_prst6 = (__pyx_v_prst4 * __pyx_v_prst2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":61
 *         cdef double prst4 = prst2*prst2
 *         cdef double prst6 = prst4*prst2
 *         cdef double prst8 = prst6*prst2             # <<<<<<<<<<<<<<
 * 
 *         # Actual Hamiltonian expressions
 */
  __Pyx_TraceLine(61,0,__PYX_ERR(1, 61, __pyx_L1_error))
  __pyx_v_prst8 = (__pyx_v_prst6 * __pyx_v_prst2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":64
 * 
 *         # Actual Hamiltonian expressions
 *         cdef double d5 = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double Dbpm = r*(6730497718123.02*nu3 + 22295347200.0*nu2*d5 + 133772083200.0*nu2*r2 + 1822680546449.21*nu2*r + 80059249540278.2*nu2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu2 - 25392914995744.3*nu - 879923036160.0*r2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*lr + 5787938193408.0*lr**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu3 - 42636451.6032331*nu2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r3*(-138240.0*nu2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r2*(-197773496.793534*nu2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu3 + 70778880.0*nu2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*lr**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r3 + 283115520.0*r2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu2 + 409207698.136075*nu - 2119671837.36038))*lr)
 */
  __Pyx_TraceLine(64,0,__PYX_ERR(1, 64, __pyx_L1_error))
  __pyx_v_d5 = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":66
 *         cdef double d5 = 0
 * 
 *         cdef double Dbpm = r*(6730497718123.02*nu3 + 22295347200.0*nu2*d5 + 133772083200.0*nu2*r2 + 1822680546449.21*nu2*r + 80059249540278.2*nu2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu2 - 25392914995744.3*nu - 879923036160.0*r2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*lr + 5787938193408.0*lr**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu3 - 42636451.6032331*nu2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r3*(-138240.0*nu2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r2*(-197773496.793534*nu2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu3 + 70778880.0*nu2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*lr**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r3 + 283115520.0*r2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu2 + 409207698.136075*nu - 2119671837.36038))*lr)             # <<<<<<<<<<<<<<
 * 
 *         cdef double Apm = 7680.0*r4*(-5416406.59541186*nu2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*lr - 7.0*r*(-185763.092693281*nu2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu4 + 1120.0*nu3*(-17833256.898555*r2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r5 - 3089250703.76879*r4 - 6178501407.53758*r3 + 2064783811.32587*r2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu2*lr**2 + 53760.0*nu*(7680.0*a6*(r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r4 + 4264.6962773603*r3 + 8529.39255472061*r2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r4 + 1926.0*r3 + 3852.0*r2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu2 - 38842241.4769507*nu + 161280.0*r5 + 480.0*r4*(756.0*nu + 1079.0) + 960.0*r3*(756.0*nu + 1079.0) + 1920.0*r2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*lr + 13212057600.0*r5)
 */
  __Pyx_TraceLine(66,0,__PYX_ERR(1, 66, __pyx_L1_error))
  __pyx_v_Dbpm = ((__pyx_v_r * ((((((((((((((((6730497718123.02 * __pyx_v_nu3) + ((22295347200.0 * __pyx_v_nu2) * __pyx_v_d5)) + ((133772083200.0 * __pyx_v_nu2) * __pyx_v_r2)) + ((1822680546449.21 * __pyx_v_nu2) * __pyx_v_r)) + (80059249540278.2 * __pyx_v_nu2)) + (((22295347200.0 * __pyx_v_nu) * __pyx_v_d5) * __pyx_v_r)) - ((193226342400.0 * __pyx_v_nu) * __pyx_v_d5)) + ((2589101062873.81 * __pyx_v_nu) * __pyx_v_r2)) + ((10611661054566.2 * __pyx_v_nu) * __pyx_v_r)) - (12049908701745.2 * __pyx_v_nu)) + (5107745331375.71 * __pyx_v_r2)) - ((326837426.241486 * __pyx_v_r) * ((14700.0 * __pyx_v_nu) + 42911.0))) - (39476764256925.6 * __pyx_v_r)) - ((((((-5041721180160.0 * __pyx_v_nu2) - (25392914995744.3 * __pyx_v_nu)) - (879923036160.0 * __pyx_v_r2)) - ((283115520.0 * __pyx_v_r) * ((14700.0 * __pyx_v_nu) + 42911.0))) + 104186110149937.0) * __pyx_v_lr)) + (5787938193408.0 * pow(__pyx_v_lr, 2.0))) + 275059053208689.0)) / (((((((55296.0 * __pyx_v_nu) * (((((14515200.0 * __pyx_v_nu3) - (42636451.6032331 * __pyx_v_nu2)) - ((7680.0 * __pyx_v_nu) * ((315.0 * __pyx_v_d5) + 890888.810272497))) + (4331361844.61149 * __pyx_v_nu)) + 1002013764.01019)) - ((967680.0 * __pyx_v_r3) * (((-138240.0 * __pyx_v_nu2) - (2675575.66847905 * __pyx_v_nu)) - 5278341.3229329))) - ((9216.0 * __pyx_v_r2) * ((((-197773496.793534 * __pyx_v_nu2) - ((7680.0 * __pyx_v_nu) * ((315.0 * __pyx_v_d5) + 405152.309729121))) + (2481453539.84635 * __pyx_v_nu)) + 5805304367.87913))) + (__pyx_v_r * (((((((5927865218923.02 * __pyx_v_nu3) + ((70778880.0 * __pyx_v_nu2) * ((315.0 * __pyx_v_d5) + 2561145.80918574))) - (138141470005001.0 * __pyx_v_nu2)) - ((4718592.0 * __pyx_v_nu) * ((40950.0 * __pyx_v_d5) + 86207832.4415642))) + (450172889755120.0 * __pyx_v_nu)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0))) + ((5787938193408.0 * __pyx_v_r) * pow(__pyx_v_lr, 2.0))) + ((((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + (879923036160.0 * __pyx_v_r3)) + ((283115520.0 * __pyx_v_r2) * ((14700.0 * __pyx_v_nu) + 42911.0))) + ((49152.0 * __pyx_v_r) * (((102574080.0 * __pyx_v_nu2) + (409207698.136075 * __pyx_v_nu)) - 2119671837.36038))) * __pyx_v_lr)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":68
 *         cdef double Dbpm = r*(6730497718123.02*nu3 + 22295347200.0*nu2*d5 + 133772083200.0*nu2*r2 + 1822680546449.21*nu2*r + 80059249540278.2*nu2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu2 - 25392914995744.3*nu - 879923036160.0*r2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*lr + 5787938193408.0*lr**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu3 - 42636451.6032331*nu2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r3*(-138240.0*nu2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r2*(-197773496.793534*nu2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu3 + 70778880.0*nu2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*lr**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r3 + 283115520.0*r2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu2 + 409207698.136075*nu - 2119671837.36038))*lr)
 * 
 *         cdef double Apm = 7680.0*r4*(-5416406.59541186*nu2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*lr - 7.0*r*(-185763.092693281*nu2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu4 + 1120.0*nu3*(-17833256.898555*r2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r5 - 3089250703.76879*r4 - 6178501407.53758*r3 + 2064783811.32587*r2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu2*lr**2 + 53760.0*nu*(7680.0*a6*(r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r4 + 4264.6962773603*r3 + 8529.39255472061*r2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r4 + 1926.0*r3 + 3852.0*r2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu2 - 38842241.4769507*nu + 161280.0*r5 + 480.0*r4*(756.0*nu + 1079.0) + 960.0*r3*(756.0*nu + 1079.0) + 1920.0*r2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*lr + 13212057600.0*r5)             # <<<<<<<<<<<<<<
 * 
 *         cdef double ap = chi_1*X_1 + chi_2*X_2
 */
  __Pyx_TraceLine(68,0,__PYX_ERR(1, 68, __pyx_L1_error))
  __pyx_v_Apm = (((7680.0 * __pyx_v_r4) * (((((-5416406.59541186 * __pyx_v_nu2) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) + (((2048.0 * __pyx_v_nu) * (((756.0 * __pyx_v_nu) + (336.0 * __pyx_v_r)) + 407.0)) * __pyx_v_lr)) - ((7.0 * __pyx_v_r) * (((-185763.092693281 * __pyx_v_nu2) + (938918.400156317 * __pyx_v_nu)) - 245760.0))) - 3440640.0)) / (((((((241555486248.807 * __pyx_v_nu4) + ((1120.0 * __pyx_v_nu3) * (((-17833256.898555 * __pyx_v_r2) - (163683964.822551 * __pyx_v_r)) - 1188987459.03162))) + ((7.0 * __pyx_v_nu2) * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (1426660551.8844 * __pyx_v_r5)) - (3089250703.76879 * __pyx_v_r4)) - (6178501407.53758 * __pyx_v_r3)) + (2064783811.32587 * __pyx_v_r2)) + (122635399361.987 * __pyx_v_r)) + 276057889687.011))) + ((67645734912.0 * __pyx_v_nu2) * pow(__pyx_v_lr, 2.0))) + ((53760.0 * __pyx_v_nu) * (((((7680.0 * __pyx_v_a6) * ((((__pyx_v_r4 + (2.0 * __pyx_v_r3)) + (4.0 * __pyx_v_r2)) + (8.0 * __pyx_v_r)) + 16.0)) + ((128.0 * __pyx_v_r) * (((((-6852.34813868015 * __pyx_v_r4) + (4264.6962773603 * __pyx_v_r3)) + (8529.39255472061 * __pyx_v_r2)) + (13218.7851094412 * __pyx_v_r)) - 33722.4297811176))) + ((113485.217444961 * __pyx_v_r) * (((((-__pyx_v_r4) + (2.0 * __pyx_v_r3)) + (4.0 * __pyx_v_r2)) + (8.0 * __pyx_v_r)) + 16.0))) + ((148.04406601634 * __pyx_v_r) * (((((349.0 * __pyx_v_r4) + (1926.0 * __pyx_v_r3)) + (3852.0 * __pyx_v_r2)) + (7704.0 * __pyx_v_r)) + 36400.0))))) + (((32768.0 * __pyx_v_nu) * ((((((((-1882456.23663972 * __pyx_v_nu2) - (38842241.4769507 * __pyx_v_nu)) + (161280.0 * __pyx_v_r5)) + ((480.0 * __pyx_v_r4) * ((756.0 * __pyx_v_nu) + 1079.0))) + ((960.0 * __pyx_v_r3) * ((756.0 * __pyx_v_nu) + 1079.0))) + ((1920.0 * __pyx_v_r2) * ((588.0 * __pyx_v_nu) + 1079.0))) + ((240.0 * __pyx_v_r) * (((-3024.0 * __pyx_v_nu2) - (7466.27061066206 * __pyx_v_nu)) + 17264.0))) + 13447680.0)) * __pyx_v_lr)) + (13212057600.0 * __pyx_v_r5)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":70
 *         cdef double Apm = 7680.0*r4*(-5416406.59541186*nu2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*lr - 7.0*r*(-185763.092693281*nu2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu4 + 1120.0*nu3*(-17833256.898555*r2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r5 - 3089250703.76879*r4 - 6178501407.53758*r3 + 2064783811.32587*r2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu2*lr**2 + 53760.0*nu*(7680.0*a6*(r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r4 + 4264.6962773603*r3 + 8529.39255472061*r2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r4 + 1926.0*r3 + 3852.0*r2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu2 - 38842241.4769507*nu + 161280.0*r5 + 480.0*r4*(756.0*nu + 1079.0) + 960.0*r3*(756.0*nu + 1079.0) + 1920.0*r2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*lr + 13212057600.0*r5)
 * 
 *         cdef double ap = chi_1*X_1 + chi_2*X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double ap2 = ap*ap
 */
  __Pyx_TraceLine(70,0,__PYX_ERR(1, 70, __pyx_L1_error))
  __pyx_v_ap = ((__pyx_v_chi_1 * __pyx_v_X_1) + (__pyx_v_chi_2 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":72
 *         cdef double ap = chi_1*X_1 + chi_2*X_2
 * 
 *         cdef double ap2 = ap*ap             # <<<<<<<<<<<<<<
 * 
 *         cdef double xi = sqrt(Dbpm)*r2*(Apm + ap2/r2)/(ap2 + r2)
 */
  __Pyx_TraceLine(72,0,__PYX_ERR(1, 72, __pyx_L1_error))
  __pyx_v_ap2 = (__pyx_v_ap * __pyx_v_ap);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":74
 *         cdef double ap2 = ap*ap
 * 
 *         cdef double xi = sqrt(Dbpm)*r2*(Apm + ap2/r2)/(ap2 + r2)             # <<<<<<<<<<<<<<
 * 
 *         cdef double pr = prst/xi
 */
  __Pyx_TraceLine(74,0,__PYX_ERR(1, 74, __pyx_L1_error))
  __pyx_v_xi = (((sqrt(__pyx_v_Dbpm) * __pyx_v_r2) * (__pyx_v_Apm + (__pyx_v_ap2 / __pyx_v_r2))) / (__pyx_v_ap2 + __pyx_v_r2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":76
 *         cdef double xi = sqrt(Dbpm)*r2*(Apm + ap2/r2)/(ap2 + r2)
 * 
 *         cdef double pr = prst/xi             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSS2 = 1.00000000000000
 */
  __Pyx_TraceLine(76,0,__PYX_ERR(1, 76, __pyx_L1_error))
  __pyx_v_pr = (__pyx_v_prst / __pyx_v_xi);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":78
 *         cdef double pr = prst/xi
 * 
 *         cdef double flagNLOSS2 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double delta = X_1 - X_2
 */
  __Pyx_TraceLine(78,0,__PYX_ERR(1, 78, __pyx_L1_error))
  __pyx_v_flagNLOSS2 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":80
 *         cdef double flagNLOSS2 = 1.00000000000000
 * 
 *         cdef double delta = X_1 - X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double am = chi_1*X_1 - chi_2*X_2
 */
  __Pyx_TraceLine(80,0,__PYX_ERR(1, 80, __pyx_L1_error))
  __pyx_v_delta = (__pyx_v_X_1 - __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":82
 *         cdef double delta = X_1 - X_2
 * 
 *         cdef double am = chi_1*X_1 - chi_2*X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double apam = am*ap
 */
  __Pyx_TraceLine(82,0,__PYX_ERR(1, 82, __pyx_L1_error))
  __pyx_v_am = ((__pyx_v_chi_1 * __pyx_v_X_1) - (__pyx_v_chi_2 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":84
 *         cdef double am = chi_1*X_1 - chi_2*X_2
 * 
 *         cdef double apam = am*ap             # <<<<<<<<<<<<<<
 * 
 *         cdef double am2 = am*am
 */
  __Pyx_TraceLine(84,0,__PYX_ERR(1, 84, __pyx_L1_error))
  __pyx_v_apam = (__pyx_v_am * __pyx_v_ap);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":86
 *         cdef double apam = am*ap
 * 
 *         cdef double am2 = am*am             # <<<<<<<<<<<<<<
 * 
 *         cdef double apamd = apam*delta
 */
  __Pyx_TraceLine(86,0,__PYX_ERR(1, 86, __pyx_L1_error))
  __pyx_v_am2 = (__pyx_v_am * __pyx_v_am);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":88
 *         cdef double am2 = am*am
 * 
 *         cdef double apamd = apam*delta             # <<<<<<<<<<<<<<
 * 
 *         cdef double QSalign2 = flagNLOSS2*pr**4*(-0.46875*am2*(4.0*nu2 - 5.0*nu + 1.0) - 0.15625*ap2*(32.0*nu2 - 33.0*nu - 5.0) + 0.3125*apamd*(18.0*nu - 1.0))/r3
 */
  __Pyx_TraceLine(88,0,__PYX_ERR(1, 88, __pyx_L1_error))
  __pyx_v_apamd = (__pyx_v_apam * __pyx_v_delta);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":90
 *         cdef double apamd = apam*delta
 * 
 *         cdef double QSalign2 = flagNLOSS2*pr**4*(-0.46875*am2*(4.0*nu2 - 5.0*nu + 1.0) - 0.15625*ap2*(32.0*nu2 - 33.0*nu - 5.0) + 0.3125*apamd*(18.0*nu - 1.0))/r3             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagQPN55 = 1.00000000000000
 */
  __Pyx_TraceLine(90,0,__PYX_ERR(1, 90, __pyx_L1_error))
  __pyx_v_QSalign2 = (((__pyx_v_flagNLOSS2 * pow(__pyx_v_pr, 4.0)) * ((((-0.46875 * __pyx_v_am2) * (((4.0 * __pyx_v_nu2) - (5.0 * __pyx_v_nu)) + 1.0)) - ((0.15625 * __pyx_v_ap2) * (((32.0 * __pyx_v_nu2) - (33.0 * __pyx_v_nu)) - 5.0))) + ((0.3125 * __pyx_v_apamd) * ((18.0 * __pyx_v_nu) - 1.0)))) / __pyx_v_r3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":92
 *         cdef double QSalign2 = flagNLOSS2*pr**4*(-0.46875*am2*(4.0*nu2 - 5.0*nu + 1.0) - 0.15625*ap2*(32.0*nu2 - 33.0*nu - 5.0) + 0.3125*apamd*(18.0*nu - 1.0))/r3
 * 
 *         cdef double flagQPN55 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagQPN5 = 1.00000000000000
 */
  __Pyx_TraceLine(92,0,__PYX_ERR(1, 92, __pyx_L1_error))
  __pyx_v_flagQPN55 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":94
 *         cdef double flagQPN55 = 1.00000000000000
 * 
 *         cdef double flagQPN5 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagQPN4 = 1.00000000000000
 */
  __Pyx_TraceLine(94,0,__PYX_ERR(1, 94, __pyx_L1_error))
  __pyx_v_flagQPN5 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":96
 *         cdef double flagQPN5 = 1.00000000000000
 * 
 *         cdef double flagQPN4 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double Qpm = flagQPN4*(0.121954868780449*nu*prst8/r + prst6*(6.0*nu3 - 5.4*nu2 - 2.78300763695006*nu)/r2 + prst4*(10.0*nu3 - 131.0*nu2 + 92.7110442849544*nu)/r3) + flagQPN5*(prst8*(-6.0*nu4 + 3.42857142857143*nu3 + 3.33842023648322*nu2 + 1.38977750996128*nu)/r2 + prst6*(-14.0*nu4 + 188.0*nu3 - 89.5298327361234*nu2 - 33.9782122170436*nu)/r3 + prst4*(602.318540416564*nu3 + nu2*(118.4*lr - 1796.13660498019) + nu*(452.542166996693 - 51.6952380952381*lr))/r4) + flagQPN55*(1.48275342024365*nu*prst8/r**2.5 - 11.3175085791863*nu*prst6/r**3.5 + 147.443752990146*nu*prst4/r**4.5) + prst4*(-6.0*nu2 + 8.0*nu)/r2
 */
  __Pyx_TraceLine(96,0,__PYX_ERR(1, 96, __pyx_L1_error))
  __pyx_v_flagQPN4 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":98
 *         cdef double flagQPN4 = 1.00000000000000
 * 
 *         cdef double Qpm = flagQPN4*(0.121954868780449*nu*prst8/r + prst6*(6.0*nu3 - 5.4*nu2 - 2.78300763695006*nu)/r2 + prst4*(10.0*nu3 - 131.0*nu2 + 92.7110442849544*nu)/r3) + flagQPN5*(prst8*(-6.0*nu4 + 3.42857142857143*nu3 + 3.33842023648322*nu2 + 1.38977750996128*nu)/r2 + prst6*(-14.0*nu4 + 188.0*nu3 - 89.5298327361234*nu2 - 33.9782122170436*nu)/r3 + prst4*(602.318540416564*nu3 + nu2*(118.4*lr - 1796.13660498019) + nu*(452.542166996693 - 51.6952380952381*lr))/r4) + flagQPN55*(1.48275342024365*nu*prst8/r**2.5 - 11.3175085791863*nu*prst6/r**3.5 + 147.443752990146*nu*prst4/r**4.5) + prst4*(-6.0*nu2 + 8.0*nu)/r2             # <<<<<<<<<<<<<<
 * 
 *         cdef double Qq = QSalign2 + Qpm
 */
  __Pyx_TraceLine(98,0,__PYX_ERR(1, 98, __pyx_L1_error))
  __pyx_t_2 = __Pyx_SoftComplexToDouble(__Pyx_c_sum_double(__Pyx_c_sum_double(__pyx_t_double_complex_from_parts(((__pyx_v_flagQPN4 * (((((0.121954868780449 * __pyx_v_nu) * __pyx_v_prst8) / __pyx_v_r) + ((__pyx_v_prst6 * (((6.0 * __pyx_v_nu3) - (5.4 * __pyx_v_nu2)) - (2.78300763695006 * __pyx_v_nu))) / __pyx_v_r2)) + ((__pyx_v_prst4 * (((10.0 * __pyx_v_nu3) - (131.0 * __pyx_v_nu2)) + (92.7110442849544 * __pyx_v_nu))) / __pyx_v_r3))) + (__pyx_v_flagQPN5 * ((((__pyx_v_prst8 * ((((-6.0 * __pyx_v_nu4) + (3.42857142857143 * __pyx_v_nu3)) + (3.33842023648322 * __pyx_v_nu2)) + (1.38977750996128 * __pyx_v_nu))) / __pyx_v_r2) + ((__pyx_v_prst6 * ((((-14.0 * __pyx_v_nu4) + (188.0 * __pyx_v_nu3)) - (89.5298327361234 * __pyx_v_nu2)) - (33.9782122170436 * __pyx_v_nu))) / __pyx_v_r3)) + ((__pyx_v_prst4 * (((602.318540416564 * __pyx_v_nu3) + (__pyx_v_nu2 * ((118.4 * __pyx_v_lr) - 1796.13660498019))) + (__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_lr))))) / __pyx_v_r4)))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_flagQPN55, 0), __Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_quot_double(__pyx_t_double_complex_from_parts(((1.48275342024365 * __pyx_v_nu) * __pyx_v_prst8), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(2.5, 0))), __Pyx_c_quot_double(__pyx_t_double_complex_from_parts(((11.3175085791863 * __pyx_v_nu) * __pyx_v_prst6), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(3.5, 0)))), __Pyx_c_quot_double(__pyx_t_double_complex_from_parts(((147.443752990146 * __pyx_v_nu) * __pyx_v_prst4), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(4.5, 0)))))), __pyx_t_double_complex_from_parts(((__pyx_v_prst4 * ((-6.0 * __pyx_v_nu2) + (8.0 * __pyx_v_nu))) / __pyx_v_r2), 0)), 1); if (unlikely(__pyx_t_2 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 98, __pyx_L1_error)
  __pyx_v_Qpm = __pyx_t_2;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":100
 *         cdef double Qpm = flagQPN4*(0.121954868780449*nu*prst8/r + prst6*(6.0*nu3 - 5.4*nu2 - 2.78300763695006*nu)/r2 + prst4*(10.0*nu3 - 131.0*nu2 + 92.7110442849544*nu)/r3) + flagQPN5*(prst8*(-6.0*nu4 + 3.42857142857143*nu3 + 3.33842023648322*nu2 + 1.38977750996128*nu)/r2 + prst6*(-14.0*nu4 + 188.0*nu3 - 89.5298327361234*nu2 - 33.9782122170436*nu)/r3 + prst4*(602.318540416564*nu3 + nu2*(118.4*lr - 1796.13660498019) + nu*(452.542166996693 - 51.6952380952381*lr))/r4) + flagQPN55*(1.48275342024365*nu*prst8/r**2.5 - 11.3175085791863*nu*prst6/r**3.5 + 147.443752990146*nu*prst4/r**4.5) + prst4*(-6.0*nu2 + 8.0*nu)/r2
 * 
 *         cdef double Qq = QSalign2 + Qpm             # <<<<<<<<<<<<<<
 * 
 *         cdef double Bnpa = -r*(r + 2.0)/(ap2*r*(r + 2.0) + r4)
 */
  __Pyx_TraceLine(100,0,__PYX_ERR(1, 100, __pyx_L1_error))
  __pyx_v_Qq = (__pyx_v_QSalign2 + __pyx_v_Qpm);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":102
 *         cdef double Qq = QSalign2 + Qpm
 * 
 *         cdef double Bnpa = -r*(r + 2.0)/(ap2*r*(r + 2.0) + r4)             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSS = 1.00000000000000
 */
  __Pyx_TraceLine(102,0,__PYX_ERR(1, 102, __pyx_L1_error))
  __pyx_v_Bnpa = (((-__pyx_v_r) * (__pyx_v_r + 2.0)) / (((__pyx_v_ap2 * __pyx_v_r) * (__pyx_v_r + 2.0)) + __pyx_v_r4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":104
 *         cdef double Bnpa = -r*(r + 2.0)/(ap2*r*(r + 2.0) + r4)
 * 
 *         cdef double flagNLOSS = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double BnpSalign2 = flagNLOSS*(0.1875*am2*(4.0*nu - 1.0) + ap2*(3.0*nu + 2.8125) - 2.625*apamd)/r3 + flagNLOSS2*(0.015625*am2*(4.0*nu2 + 115.0*nu - 37.0) + 0.015625*ap2*(-1171.0*nu - 861.0) + 0.03125*apamd*(26.0*nu + 449.0))/r4
 */
  __Pyx_TraceLine(104,0,__PYX_ERR(1, 104, __pyx_L1_error))
  __pyx_v_flagNLOSS = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":106
 *         cdef double flagNLOSS = 1.00000000000000
 * 
 *         cdef double BnpSalign2 = flagNLOSS*(0.1875*am2*(4.0*nu - 1.0) + ap2*(3.0*nu + 2.8125) - 2.625*apamd)/r3 + flagNLOSS2*(0.015625*am2*(4.0*nu2 + 115.0*nu - 37.0) + 0.015625*ap2*(-1171.0*nu - 861.0) + 0.03125*apamd*(26.0*nu + 449.0))/r4             # <<<<<<<<<<<<<<
 * 
 *         cdef double Bnp = Apm*Dbpm + BnpSalign2 + ap2/r2 - 1.0
 */
  __Pyx_TraceLine(106,0,__PYX_ERR(1, 106, __pyx_L1_error))
  __pyx_v_BnpSalign2 = (((__pyx_v_flagNLOSS * ((((0.1875 * __pyx_v_am2) * ((4.0 * __pyx_v_nu) - 1.0)) + (__pyx_v_ap2 * ((3.0 * __pyx_v_nu) + 2.8125))) - (2.625 * __pyx_v_apamd))) / __pyx_v_r3) + ((__pyx_v_flagNLOSS2 * ((((0.015625 * __pyx_v_am2) * (((4.0 * __pyx_v_nu2) + (115.0 * __pyx_v_nu)) - 37.0)) + ((0.015625 * __pyx_v_ap2) * ((-1171.0 * __pyx_v_nu) - 861.0))) + ((0.03125 * __pyx_v_apamd) * ((26.0 * __pyx_v_nu) + 449.0)))) / __pyx_v_r4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":108
 *         cdef double BnpSalign2 = flagNLOSS*(0.1875*am2*(4.0*nu - 1.0) + ap2*(3.0*nu + 2.8125) - 2.625*apamd)/r3 + flagNLOSS2*(0.015625*am2*(4.0*nu2 + 115.0*nu - 37.0) + 0.015625*ap2*(-1171.0*nu - 861.0) + 0.03125*apamd*(26.0*nu + 449.0))/r4
 * 
 *         cdef double Bnp = Apm*Dbpm + BnpSalign2 + ap2/r2 - 1.0             # <<<<<<<<<<<<<<
 * 
 *         cdef double ASalignCal2 = 0.0
 */
  __Pyx_TraceLine(108,0,__PYX_ERR(1, 108, __pyx_L1_error))
  __pyx_v_Bnp = ((((__pyx_v_Apm * __pyx_v_Dbpm) + __pyx_v_BnpSalign2) + (__pyx_v_ap2 / __pyx_v_r2)) - 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":110
 *         cdef double Bnp = Apm*Dbpm + BnpSalign2 + ap2/r2 - 1.0
 * 
 *         cdef double ASalignCal2 = 0.0             # <<<<<<<<<<<<<<
 * 
 *         cdef double ASalign2 = flagNLOSS*(0.125*am2*(4.0*nu + 1.0) + 1.125*ap2 - 1.25*apamd)/r4 + flagNLOSS2*(0.046875*am2*(28.0*nu2 - 27.0*nu - 3.0) - 0.390625*ap2*(7.0*nu + 9.0) - 1.21875*apamd*(2.0*nu - 3.0))/r**5
 */
  __Pyx_TraceLine(110,0,__PYX_ERR(1, 110, __pyx_L1_error))
  __pyx_v_ASalignCal2 = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":112
 *         cdef double ASalignCal2 = 0.0
 * 
 *         cdef double ASalign2 = flagNLOSS*(0.125*am2*(4.0*nu + 1.0) + 1.125*ap2 - 1.25*apamd)/r4 + flagNLOSS2*(0.046875*am2*(28.0*nu2 - 27.0*nu - 3.0) - 0.390625*ap2*(7.0*nu + 9.0) - 1.21875*apamd*(2.0*nu - 3.0))/r**5             # <<<<<<<<<<<<<<
 * 
 *         cdef double A = (ASalign2 + ASalignCal2 + Apm + ap2/r2)/(ap2*(1.0 + 2.0/r)/r2 + 1.0)
 */
  __Pyx_TraceLine(112,0,__PYX_ERR(1, 112, __pyx_L1_error))
  __pyx_v_ASalign2 = (((__pyx_v_flagNLOSS * ((((0.125 * __pyx_v_am2) * ((4.0 * __pyx_v_nu) + 1.0)) + (1.125 * __pyx_v_ap2)) - (1.25 * __pyx_v_apamd))) / __pyx_v_r4) + ((__pyx_v_flagNLOSS2 * ((((0.046875 * __pyx_v_am2) * (((28.0 * __pyx_v_nu2) - (27.0 * __pyx_v_nu)) - 3.0)) - ((0.390625 * __pyx_v_ap2) * ((7.0 * __pyx_v_nu) + 9.0))) - ((1.21875 * __pyx_v_apamd) * ((2.0 * __pyx_v_nu) - 3.0)))) / pow(__pyx_v_r, 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":114
 *         cdef double ASalign2 = flagNLOSS*(0.125*am2*(4.0*nu + 1.0) + 1.125*ap2 - 1.25*apamd)/r4 + flagNLOSS2*(0.046875*am2*(28.0*nu2 - 27.0*nu - 3.0) - 0.390625*ap2*(7.0*nu + 9.0) - 1.21875*apamd*(2.0*nu - 3.0))/r**5
 * 
 *         cdef double A = (ASalign2 + ASalignCal2 + Apm + ap2/r2)/(ap2*(1.0 + 2.0/r)/r2 + 1.0)             # <<<<<<<<<<<<<<
 * 
 *         cdef double lap = ap
 */
  __Pyx_TraceLine(114,0,__PYX_ERR(1, 114, __pyx_L1_error))
  __pyx_v_A = ((((__pyx_v_ASalign2 + __pyx_v_ASalignCal2) + __pyx_v_Apm) + (__pyx_v_ap2 / __pyx_v_r2)) / (((__pyx_v_ap2 * (1.0 + (2.0 / __pyx_v_r))) / __pyx_v_r2) + 1.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":116
 *         cdef double A = (ASalign2 + ASalignCal2 + Apm + ap2/r2)/(ap2*(1.0 + 2.0/r)/r2 + 1.0)
 * 
 *         cdef double lap = ap             # <<<<<<<<<<<<<<
 * 
 *         cdef double Heven = sqrt(A*(Bnpa*L2*lap**2/r2 + L2/r2 + Qq + prst2*(Bnp + 1.0)/xi**2 + 1.0))
 */
  __Pyx_TraceLine(116,0,__PYX_ERR(1, 116, __pyx_L1_error))
  __pyx_v_lap = __pyx_v_ap;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":118
 *         cdef double lap = ap
 * 
 *         cdef double Heven = sqrt(A*(Bnpa*L2*lap**2/r2 + L2/r2 + Qq + prst2*(Bnp + 1.0)/xi**2 + 1.0))             # <<<<<<<<<<<<<<
 * 
 *         cdef double lam = am
 */
  __Pyx_TraceLine(118,0,__PYX_ERR(1, 118, __pyx_L1_error))
  __pyx_v_Heven = sqrt((__pyx_v_A * (((((((__pyx_v_Bnpa * __pyx_v_L2) * pow(__pyx_v_lap, 2.0)) / __pyx_v_r2) + (__pyx_v_L2 / __pyx_v_r2)) + __pyx_v_Qq) + ((__pyx_v_prst2 * (__pyx_v_Bnp + 1.0)) / pow(__pyx_v_xi, 2.0))) + 1.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":120
 *         cdef double Heven = sqrt(A*(Bnpa*L2*lap**2/r2 + L2/r2 + Qq + prst2*(Bnp + 1.0)/xi**2 + 1.0))
 * 
 *         cdef double lam = am             # <<<<<<<<<<<<<<
 * 
 *         cdef double Ga3 = 0.0416666666666667*L*ap2*delta*lam/r2 + L*lap*(-0.25*ap2 + 0.208333333333333*apamd)/r2
 */
  __Pyx_TraceLine(120,0,__PYX_ERR(1, 120, __pyx_L1_error))
  __pyx_v_lam = __pyx_v_am;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":122
 *         cdef double lam = am
 * 
 *         cdef double Ga3 = 0.0416666666666667*L*ap2*delta*lam/r2 + L*lap*(-0.25*ap2 + 0.208333333333333*apamd)/r2             # <<<<<<<<<<<<<<
 * 
 *         cdef double SOcalib = L*nu*dSO*lap/r3
 */
  __Pyx_TraceLine(122,0,__PYX_ERR(1, 122, __pyx_L1_error))
  __pyx_v_Ga3 = ((((((0.0416666666666667 * __pyx_v_L) * __pyx_v_ap2) * __pyx_v_delta) * __pyx_v_lam) / __pyx_v_r2) + (((__pyx_v_L * __pyx_v_lap) * ((-0.25 * __pyx_v_ap2) + (0.208333333333333 * __pyx_v_apamd))) / __pyx_v_r2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":124
 *         cdef double Ga3 = 0.0416666666666667*L*ap2*delta*lam/r2 + L*lap*(-0.25*ap2 + 0.208333333333333*apamd)/r2
 * 
 *         cdef double SOcalib = L*nu*dSO*lap/r3             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSO2 = 1.00000000000000
 */
  __Pyx_TraceLine(124,0,__PYX_ERR(1, 124, __pyx_L1_error))
  __pyx_v_SOcalib = ((((__pyx_v_L * __pyx_v_nu) * __pyx_v_dSO) * __pyx_v_lap) / __pyx_v_r3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":126
 *         cdef double SOcalib = L*nu*dSO*lap/r3
 * 
 *         cdef double flagNLOSO2 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSO = 1.00000000000000
 */
  __Pyx_TraceLine(126,0,__PYX_ERR(1, 126, __pyx_L1_error))
  __pyx_v_flagNLOSO2 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":128
 *         cdef double flagNLOSO2 = 1.00000000000000
 * 
 *         cdef double flagNLOSO = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double gam = flagNLOSO*(L2*(0.46875 - 0.28125*nu)/r2 + (0.34375*nu + 0.09375)/r) + flagNLOSO2*(L4*(0.29296875*nu2 - 0.3515625*nu - 0.41015625)/r4 + L2*(-0.798177083333333*nu2 - 0.2734375*nu - 0.23046875)/r3 + (0.536458333333333*nu2 - 0.03125*nu + 0.078125)/r2) + 0.25
 */
  __Pyx_TraceLine(128,0,__PYX_ERR(1, 128, __pyx_L1_error))
  __pyx_v_flagNLOSO = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":130
 *         cdef double flagNLOSO = 1.00000000000000
 * 
 *         cdef double gam = flagNLOSO*(L2*(0.46875 - 0.28125*nu)/r2 + (0.34375*nu + 0.09375)/r) + flagNLOSO2*(L4*(0.29296875*nu2 - 0.3515625*nu - 0.41015625)/r4 + L2*(-0.798177083333333*nu2 - 0.2734375*nu - 0.23046875)/r3 + (0.536458333333333*nu2 - 0.03125*nu + 0.078125)/r2) + 0.25             # <<<<<<<<<<<<<<
 * 
 *         cdef double gap = flagNLOSO*(L2*(-1.40625*nu - 0.46875)/r2 + (0.71875*nu - 0.09375)/r) + flagNLOSO2*(L4*(1.34765625*nu2 + 0.5859375*nu + 0.41015625)/r4 + L2*(-2.07161458333333*nu2 - 2.0859375*nu + 0.23046875)/r3 + (0.567708333333333*nu2 - 5.53125*nu - 0.078125)/r2) + 1.75
 */
  __Pyx_TraceLine(130,0,__PYX_ERR(1, 130, __pyx_L1_error))
  __pyx_v_gam = (((__pyx_v_flagNLOSO * (((__pyx_v_L2 * (0.46875 - (0.28125 * __pyx_v_nu))) / __pyx_v_r2) + (((0.34375 * __pyx_v_nu) + 0.09375) / __pyx_v_r))) + (__pyx_v_flagNLOSO2 * ((((__pyx_v_L4 * (((0.29296875 * __pyx_v_nu2) - (0.3515625 * __pyx_v_nu)) - 0.41015625)) / __pyx_v_r4) + ((__pyx_v_L2 * (((-0.798177083333333 * __pyx_v_nu2) - (0.2734375 * __pyx_v_nu)) - 0.23046875)) / __pyx_v_r3)) + ((((0.536458333333333 * __pyx_v_nu2) - (0.03125 * __pyx_v_nu)) + 0.078125) / __pyx_v_r2)))) + 0.25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":132
 *         cdef double gam = flagNLOSO*(L2*(0.46875 - 0.28125*nu)/r2 + (0.34375*nu + 0.09375)/r) + flagNLOSO2*(L4*(0.29296875*nu2 - 0.3515625*nu - 0.41015625)/r4 + L2*(-0.798177083333333*nu2 - 0.2734375*nu - 0.23046875)/r3 + (0.536458333333333*nu2 - 0.03125*nu + 0.078125)/r2) + 0.25
 * 
 *         cdef double gap = flagNLOSO*(L2*(-1.40625*nu - 0.46875)/r2 + (0.71875*nu - 0.09375)/r) + flagNLOSO2*(L4*(1.34765625*nu2 + 0.5859375*nu + 0.41015625)/r4 + L2*(-2.07161458333333*nu2 - 2.0859375*nu + 0.23046875)/r3 + (0.567708333333333*nu2 - 5.53125*nu - 0.078125)/r2) + 1.75             # <<<<<<<<<<<<<<
 * 
 *         cdef double Hodd = (Ga3 + L*delta*gam*lam + L*gap*lap + SOcalib)/(2.0*ap2 + 2.0*r2 + r*(ap2 + r2 - 2.0*r))
 */
  __Pyx_TraceLine(132,0,__PYX_ERR(1, 132, __pyx_L1_error))
  __pyx_v_gap = (((__pyx_v_flagNLOSO * (((__pyx_v_L2 * ((-1.40625 * __pyx_v_nu) - 0.46875)) / __pyx_v_r2) + (((0.71875 * __pyx_v_nu) - 0.09375) / __pyx_v_r))) + (__pyx_v_flagNLOSO2 * ((((__pyx_v_L4 * (((1.34765625 * __pyx_v_nu2) + (0.5859375 * __pyx_v_nu)) + 0.41015625)) / __pyx_v_r4) + ((__pyx_v_L2 * (((-2.07161458333333 * __pyx_v_nu2) - (2.0859375 * __pyx_v_nu)) + 0.23046875)) / __pyx_v_r3)) + ((((0.567708333333333 * __pyx_v_nu2) - (5.53125 * __pyx_v_nu)) - 0.078125) / __pyx_v_r2)))) + 1.75);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":134
 *         cdef double gap = flagNLOSO*(L2*(-1.40625*nu - 0.46875)/r2 + (0.71875*nu - 0.09375)/r) + flagNLOSO2*(L4*(1.34765625*nu2 + 0.5859375*nu + 0.41015625)/r4 + L2*(-2.07161458333333*nu2 - 2.0859375*nu + 0.23046875)/r3 + (0.567708333333333*nu2 - 5.53125*nu - 0.078125)/r2) + 1.75
 * 
 *         cdef double Hodd = (Ga3 + L*delta*gam*lam + L*gap*lap + SOcalib)/(2.0*ap2 + 2.0*r2 + r*(ap2 + r2 - 2.0*r))             # <<<<<<<<<<<<<<
 * 
 *         cdef double Heff = Heven + Hodd
 */
  __Pyx_TraceLine(134,0,__PYX_ERR(1, 134, __pyx_L1_error))
  __pyx_v_Hodd = ((((__pyx_v_Ga3 + (((__pyx_v_L * __pyx_v_delta) * __pyx_v_gam) * __pyx_v_lam)) + ((__pyx_v_L * __pyx_v_gap) * __pyx_v_lap)) + __pyx_v_SOcalib) / (((2.0 * __pyx_v_ap2) + (2.0 * __pyx_v_r2)) + (__pyx_v_r * ((__pyx_v_ap2 + __pyx_v_r2) - (2.0 * __pyx_v_r)))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":136
 *         cdef double Hodd = (Ga3 + L*delta*gam*lam + L*gap*lap + SOcalib)/(2.0*ap2 + 2.0*r2 + r*(ap2 + r2 - 2.0*r))
 * 
 *         cdef double Heff = Heven + Hodd             # <<<<<<<<<<<<<<
 * 
 *         # Evaluate H_real/nu
 */
  __Pyx_TraceLine(136,0,__PYX_ERR(1, 136, __pyx_L1_error))
  __pyx_v_Heff = (__pyx_v_Heven + __pyx_v_Hodd);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":139
 * 
 *         # Evaluate H_real/nu
 *         cdef double H = M * sqrt(1+2*nu*(Heff-1)) / nu             # <<<<<<<<<<<<<<
 * 
 *         return H,xi
 */
  __Pyx_TraceLine(139,0,__PYX_ERR(1, 139, __pyx_L1_error))
  __pyx_v_H = ((__pyx_v_M * sqrt((1.0 + ((2.0 * __pyx_v_nu) * (__pyx_v_Heff - 1.0))))) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":141
 *         cdef double H = M * sqrt(1+2*nu*(Heff-1)) / nu
 * 
 *         return H,xi             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(141,0,__PYX_ERR(1, 141, __pyx_L1_error))
  __pyx_t_3.f0 = __pyx_v_H;
  __pyx_t_3.f1 = __pyx_v_xi;
  __pyx_r = __pyx_t_3;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":11
 * from libc.math cimport log, sqrt, exp, abs, tgamma,sin,cos
 * 
 * cpdef (double,double) evaluate_H(double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,double M, double nu,             # <<<<<<<<<<<<<<
 * double X_1, double X_2, double a6, double dSO):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.evaluate_H", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1evaluate_H(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H, "\n        Evaluate the Hamiltonian and xi\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n          M (double): Total mass.\n          nu (double): Reduced mass ratio.\n          X_1 (double): m_1/M\n          X_2 (double): m_2/M\n          a6 (doubble): nonspinning calibration parameter\n          dSO (double): spin-orbit calibration parameter\n\n        Returns:\n           (tuple)  H,xi\n\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1evaluate_H = {"evaluate_H", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1evaluate_H, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1evaluate_H(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evaluate_H (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,&__pyx_n_s_M,&__pyx_n_s_nu,&__pyx_n_s_X_1,&__pyx_n_s_X_2,&__pyx_n_s_a6,&__pyx_n_s_dSO,0};
    PyObject* values[12] = {0,0,0,0,0,0,0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 1); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 2); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 3); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 4); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 5); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 6); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 7); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_X_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 8); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_X_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 9); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a6)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 10); __PYX_ERR(1, 11, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dSO)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, 11); __PYX_ERR(1, 11, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "evaluate_H") < 0)) __PYX_ERR(1, 11, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 12)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
      values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
      values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
      values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
      values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
      values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
      values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_M = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_M == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_nu = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_nu == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L3_error)
    __pyx_v_X_1 = __pyx_PyFloat_AsDouble(values[8]); if (unlikely((__pyx_v_X_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L3_error)
    __pyx_v_X_2 = __pyx_PyFloat_AsDouble(values[9]); if (unlikely((__pyx_v_X_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L3_error)
    __pyx_v_a6 = __pyx_PyFloat_AsDouble(values[10]); if (unlikely((__pyx_v_a6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L3_error)
    __pyx_v_dSO = __pyx_PyFloat_AsDouble(values[11]); if (unlikely((__pyx_v_dSO == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("evaluate_H", 1, 12, 12, __pyx_nargs); __PYX_ERR(1, 11, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.evaluate_H", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__pyx_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_M, __pyx_v_nu, __pyx_v_X_1, __pyx_v_X_2, __pyx_v_a6, __pyx_v_dSO);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, double __pyx_v_M, double __pyx_v_nu, double __pyx_v_X_1, double __pyx_v_X_2, double __pyx_v_a6, double __pyx_v_dSO) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __pyx_ctuple_double__and_double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__11)
  __Pyx_RefNannySetupContext("evaluate_H", 0);
  __Pyx_TraceCall("evaluate_H (wrapper)", __pyx_f[1], 11, 0, __PYX_ERR(1, 11, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 11, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 11, __pyx_L1_error) }
  __pyx_t_1 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_M, __pyx_v_nu, __pyx_v_X_1, __pyx_v_X_2, __pyx_v_a6, __pyx_v_dSO, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 11, __pyx_L1_error)
  __pyx_t_2 = __pyx_convert__to_py___pyx_ctuple_double__and_double(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.evaluate_H", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":148
 *     cdef public CalibCoeffs calibration_coeffs
 *     #cdef public EOBParams EOBpars
 *     def __cinit__(self,EOBParams params):             # <<<<<<<<<<<<<<
 *         self.EOBpars = params
 * 
 */

/* Python wrapper */
static int __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams *__pyx_v_params = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_params,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_params)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 148, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(1, 148, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_params = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 148, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_params), __pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams, 1, "params", 0))) __PYX_ERR(1, 148, __pyx_L1_error)
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C___cinit__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_params);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C___cinit__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams *__pyx_v_params) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_TraceCall("__cinit__", __pyx_f[1], 148, 0, __PYX_ERR(1, 148, __pyx_L1_error));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":149
 *     #cdef public EOBParams EOBpars
 *     def __cinit__(self,EOBParams params):
 *         self.EOBpars = params             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):
 */
  __Pyx_TraceLine(149,0,__PYX_ERR(1, 149, __pyx_L1_error))
  __Pyx_INCREF((PyObject *)__pyx_v_params);
  __Pyx_GIVEREF((PyObject *)__pyx_v_params);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->__pyx_base.EOBpars);
  __Pyx_DECREF((PyObject *)__pyx_v_self->__pyx_base.EOBpars);
  __pyx_v_self->__pyx_base.EOBpars = __pyx_v_params;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":148
 *     cdef public CalibCoeffs calibration_coeffs
 *     #cdef public EOBParams EOBpars
 *     def __cinit__(self,EOBParams params):             # <<<<<<<<<<<<<<
 *         self.EOBpars = params
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":151
 *         self.EOBpars = params
 * 
 *     def __call__(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  int __pyx_v_verbose;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,&__pyx_n_s_verbose,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 0, 6, 7, 1); __PYX_ERR(1, 151, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 0, 6, 7, 2); __PYX_ERR(1, 151, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 0, 6, 7, 3); __PYX_ERR(1, 151, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 0, 6, 7, 4); __PYX_ERR(1, 151, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 0, 6, 7, 5); __PYX_ERR(1, 151, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_verbose);
          if (value) { values[6] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__call__") < 0)) __PYX_ERR(1, 151, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 151, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 151, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
    if (values[6]) {
      __pyx_v_verbose = __Pyx_PyObject_IsTrue(values[6]); if (unlikely((__pyx_v_verbose == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 151, __pyx_L3_error)
    } else {
      __pyx_v_verbose = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 6, 7, __pyx_nargs); __PYX_ERR(1, 151, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_2__call__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_verbose);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_2__call__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_v_verbose) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);
  __Pyx_TraceCall("__call__", __pyx_f[1], 151, 0, __PYX_ERR(1, 151, __pyx_L1_error));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":152
 * 
 *     def __call__(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)             # <<<<<<<<<<<<<<
 * 
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):
 */
  __Pyx_TraceLine(152,0,__PYX_ERR(1, 152, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.verbose = __pyx_v_verbose;
  __pyx_t_1 = ((struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self->__pyx_base.__pyx_vtab)->_call(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":151
 *         self.EOBpars = params
 * 
 *     def __call__(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":154
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2, int __pyx_skip_dispatch, struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call *__pyx_optional_args) {
  int __pyx_v_verbose = ((int)0);
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  CYTHON_UNUSED double __pyx_v_pphi;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_r2;
  double __pyx_v_r3;
  double __pyx_v_r4;
  double __pyx_v_r5;
  double __pyx_v_L2;
  double __pyx_v_lr;
  double __pyx_v_nu2;
  double __pyx_v_nu3;
  double __pyx_v_nu4;
  double __pyx_v_d5;
  double __pyx_v_Dbpm;
  double __pyx_v_Apm;
  double __pyx_v_ap;
  double __pyx_v_ap2;
  double __pyx_v_xi;
  double __pyx_v_pr;
  double __pyx_v_flagNLOSS2;
  double __pyx_v_delta;
  double __pyx_v_am;
  double __pyx_v_apam;
  double __pyx_v_am2;
  double __pyx_v_apamd;
  double __pyx_v_QSalign2;
  double __pyx_v_flagQPN55;
  double __pyx_v_flagQPN5;
  double __pyx_v_flagQPN4;
  double __pyx_v_Qpm;
  double __pyx_v_Qq;
  double __pyx_v_Bnpa;
  double __pyx_v_flagNLOSS;
  double __pyx_v_BnpSalign2;
  double __pyx_v_Bnp;
  double __pyx_v_ASalignCal2;
  double __pyx_v_ASalign2;
  double __pyx_v_A;
  double __pyx_v_lap;
  double __pyx_v_Heven;
  double __pyx_v_lam;
  double __pyx_v_Ga3;
  double __pyx_v_SOcalib;
  double __pyx_v_flagNLOSO2;
  double __pyx_v_flagNLOSO;
  double __pyx_v_gam;
  double __pyx_v_gap;
  double __pyx_v_Hodd;
  double __pyx_v_Heff;
  double __pyx_v_H;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  double __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__12)
  __Pyx_RefNannySetupContext("_call", 0);
  __Pyx_TraceCall("_call", __pyx_f[1], 154, 0, __PYX_ERR(1, 154, __pyx_L1_error));
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_verbose = __pyx_optional_args->verbose;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_call); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #ifdef __Pyx_CyFunction_USED
      if (!__Pyx_IsCyOrPyCFunction(__pyx_t_1)
      #else
      if (!PyCFunction_Check(__pyx_t_1)
      #endif
              || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call)) {
        __Pyx_XDECREF(__pyx_r);
        if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 154, __pyx_L1_error) }
        __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_q, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 154, __pyx_L1_error) }
        __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_p, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyFloat_FromDouble(__pyx_v_chi_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyFloat_FromDouble(__pyx_v_chi_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyFloat_FromDouble(__pyx_v_m_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_m_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyBool_FromLong(__pyx_v_verbose); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_10 = __pyx_t_1; __pyx_t_11 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
            __pyx_t_12 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[8] = {__pyx_t_11, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8, __pyx_t_9};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_12, 7+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 154, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":177
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(177,0,__PYX_ERR(1, 177, __pyx_L1_error))
  __pyx_t_13 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_13 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":178
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(178,0,__PYX_ERR(1, 178, __pyx_L1_error))
  __pyx_t_13 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_13 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":180
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(180,0,__PYX_ERR(1, 180, __pyx_L1_error))
  __pyx_t_13 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_13 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":181
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(181,0,__PYX_ERR(1, 181, __pyx_L1_error))
  __pyx_t_13 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_13 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":183
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(183,0,__PYX_ERR(1, 183, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":185
 *         cdef double pphi = L
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']
 */
  __Pyx_TraceLine(185,0,__PYX_ERR(1, 185, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":186
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs['dSO']
 * 
 */
  __Pyx_TraceLine(186,0,__PYX_ERR(1, 186, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_a6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_14 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_a6 = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":187
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(187,0,__PYX_ERR(1, 187, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_dSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_14 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_dSO = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":191
 * 
 *         # Extra quantities used in the Hamiltonian
 *         cdef double M = self.EOBpars.p_params.M             # <<<<<<<<<<<<<<
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 */
  __Pyx_TraceLine(191,0,__PYX_ERR(1, 191, __pyx_L1_error))
  __pyx_t_14 = __pyx_v_self->__pyx_base.EOBpars->p_params->M;
  __pyx_v_M = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":192
 *         # Extra quantities used in the Hamiltonian
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu             # <<<<<<<<<<<<<<
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 */
  __Pyx_TraceLine(192,0,__PYX_ERR(1, 192, __pyx_L1_error))
  __pyx_t_14 = __pyx_v_self->__pyx_base.EOBpars->p_params->nu;
  __pyx_v_nu = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":193
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1             # <<<<<<<<<<<<<<
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 * 
 */
  __Pyx_TraceLine(193,0,__PYX_ERR(1, 193, __pyx_L1_error))
  __pyx_t_14 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_1;
  __pyx_v_X_1 = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":194
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double r2 = r*r
 */
  __Pyx_TraceLine(194,0,__PYX_ERR(1, 194, __pyx_L1_error))
  __pyx_t_14 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_2;
  __pyx_v_X_2 = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":196
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 * 
 *         cdef double r2 = r*r             # <<<<<<<<<<<<<<
 *         cdef double r3 = r2*r
 *         cdef double r4 = r2*r2
 */
  __Pyx_TraceLine(196,0,__PYX_ERR(1, 196, __pyx_L1_error))
  __pyx_v_r2 = (__pyx_v_r * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":197
 * 
 *         cdef double r2 = r*r
 *         cdef double r3 = r2*r             # <<<<<<<<<<<<<<
 *         cdef double r4 = r2*r2
 *         cdef double r5 = r*r4
 */
  __Pyx_TraceLine(197,0,__PYX_ERR(1, 197, __pyx_L1_error))
  __pyx_v_r3 = (__pyx_v_r2 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":198
 *         cdef double r2 = r*r
 *         cdef double r3 = r2*r
 *         cdef double r4 = r2*r2             # <<<<<<<<<<<<<<
 *         cdef double r5 = r*r4
 *         cdef double L2 = L*L
 */
  __Pyx_TraceLine(198,0,__PYX_ERR(1, 198, __pyx_L1_error))
  __pyx_v_r4 = (__pyx_v_r2 * __pyx_v_r2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":199
 *         cdef double r3 = r2*r
 *         cdef double r4 = r2*r2
 *         cdef double r5 = r*r4             # <<<<<<<<<<<<<<
 *         cdef double L2 = L*L
 *         cdef double lr = log(r)
 */
  __Pyx_TraceLine(199,0,__PYX_ERR(1, 199, __pyx_L1_error))
  __pyx_v_r5 = (__pyx_v_r * __pyx_v_r4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":200
 *         cdef double r4 = r2*r2
 *         cdef double r5 = r*r4
 *         cdef double L2 = L*L             # <<<<<<<<<<<<<<
 *         cdef double lr = log(r)
 * 
 */
  __Pyx_TraceLine(200,0,__PYX_ERR(1, 200, __pyx_L1_error))
  __pyx_v_L2 = (__pyx_v_L * __pyx_v_L);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":201
 *         cdef double r5 = r*r4
 *         cdef double L2 = L*L
 *         cdef double lr = log(r)             # <<<<<<<<<<<<<<
 * 
 *         cdef double nu2 = nu*nu
 */
  __Pyx_TraceLine(201,0,__PYX_ERR(1, 201, __pyx_L1_error))
  __pyx_v_lr = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":203
 *         cdef double lr = log(r)
 * 
 *         cdef double nu2 = nu*nu             # <<<<<<<<<<<<<<
 *         cdef double nu3 = nu2*nu
 *         cdef double nu4 = nu3*nu
 */
  __Pyx_TraceLine(203,0,__PYX_ERR(1, 203, __pyx_L1_error))
  __pyx_v_nu2 = (__pyx_v_nu * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":204
 * 
 *         cdef double nu2 = nu*nu
 *         cdef double nu3 = nu2*nu             # <<<<<<<<<<<<<<
 *         cdef double nu4 = nu3*nu
 *         # Actual Hamiltonian expressions
 */
  __Pyx_TraceLine(204,0,__PYX_ERR(1, 204, __pyx_L1_error))
  __pyx_v_nu3 = (__pyx_v_nu2 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":205
 *         cdef double nu2 = nu*nu
 *         cdef double nu3 = nu2*nu
 *         cdef double nu4 = nu3*nu             # <<<<<<<<<<<<<<
 *         # Actual Hamiltonian expressions
 *         cdef double d5 = 0
 */
  __Pyx_TraceLine(205,0,__PYX_ERR(1, 205, __pyx_L1_error))
  __pyx_v_nu4 = (__pyx_v_nu3 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":207
 *         cdef double nu4 = nu3*nu
 *         # Actual Hamiltonian expressions
 *         cdef double d5 = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double Dbpm = r*(6730497718123.02*nu3 + 22295347200.0*nu2*d5 + 133772083200.0*nu2*r2 + 1822680546449.21*nu2*r + 80059249540278.2*nu2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu2 - 25392914995744.3*nu - 879923036160.0*r2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*lr + 5787938193408.0*lr**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu3 - 42636451.6032331*nu2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r3*(-138240.0*nu2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r2*(-197773496.793534*nu2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu3 + 70778880.0*nu2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*lr**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r3 + 283115520.0*r2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu2 + 409207698.136075*nu - 2119671837.36038))*lr)
 */
  __Pyx_TraceLine(207,0,__PYX_ERR(1, 207, __pyx_L1_error))
  __pyx_v_d5 = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":209
 *         cdef double d5 = 0
 * 
 *         cdef double Dbpm = r*(6730497718123.02*nu3 + 22295347200.0*nu2*d5 + 133772083200.0*nu2*r2 + 1822680546449.21*nu2*r + 80059249540278.2*nu2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu2 - 25392914995744.3*nu - 879923036160.0*r2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*lr + 5787938193408.0*lr**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu3 - 42636451.6032331*nu2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r3*(-138240.0*nu2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r2*(-197773496.793534*nu2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu3 + 70778880.0*nu2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*lr**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r3 + 283115520.0*r2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu2 + 409207698.136075*nu - 2119671837.36038))*lr)             # <<<<<<<<<<<<<<
 * 
 *         cdef double Apm = 7680.0*r4*(-5416406.59541186*nu2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*lr - 7.0*r*(-185763.092693281*nu2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu4 + 1120.0*nu3*(-17833256.898555*r2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r5 - 3089250703.76879*r4 - 6178501407.53758*r3 + 2064783811.32587*r2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu2*lr**2 + 53760.0*nu*(7680.0*a6*(r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r4 + 4264.6962773603*r3 + 8529.39255472061*r2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r4 + 1926.0*r3 + 3852.0*r2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu2 - 38842241.4769507*nu + 161280.0*r5 + 480.0*r4*(756.0*nu + 1079.0) + 960.0*r3*(756.0*nu + 1079.0) + 1920.0*r2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*lr + 13212057600.0*r5)
 */
  __Pyx_TraceLine(209,0,__PYX_ERR(1, 209, __pyx_L1_error))
  __pyx_v_Dbpm = ((__pyx_v_r * ((((((((((((((((6730497718123.02 * __pyx_v_nu3) + ((22295347200.0 * __pyx_v_nu2) * __pyx_v_d5)) + ((133772083200.0 * __pyx_v_nu2) * __pyx_v_r2)) + ((1822680546449.21 * __pyx_v_nu2) * __pyx_v_r)) + (80059249540278.2 * __pyx_v_nu2)) + (((22295347200.0 * __pyx_v_nu) * __pyx_v_d5) * __pyx_v_r)) - ((193226342400.0 * __pyx_v_nu) * __pyx_v_d5)) + ((2589101062873.81 * __pyx_v_nu) * __pyx_v_r2)) + ((10611661054566.2 * __pyx_v_nu) * __pyx_v_r)) - (12049908701745.2 * __pyx_v_nu)) + (5107745331375.71 * __pyx_v_r2)) - ((326837426.241486 * __pyx_v_r) * ((14700.0 * __pyx_v_nu) + 42911.0))) - (39476764256925.6 * __pyx_v_r)) - ((((((-5041721180160.0 * __pyx_v_nu2) - (25392914995744.3 * __pyx_v_nu)) - (879923036160.0 * __pyx_v_r2)) - ((283115520.0 * __pyx_v_r) * ((14700.0 * __pyx_v_nu) + 42911.0))) + 104186110149937.0) * __pyx_v_lr)) + (5787938193408.0 * pow(__pyx_v_lr, 2.0))) + 275059053208689.0)) / (((((((55296.0 * __pyx_v_nu) * (((((14515200.0 * __pyx_v_nu3) - (42636451.6032331 * __pyx_v_nu2)) - ((7680.0 * __pyx_v_nu) * ((315.0 * __pyx_v_d5) + 890888.810272497))) + (4331361844.61149 * __pyx_v_nu)) + 1002013764.01019)) - ((967680.0 * __pyx_v_r3) * (((-138240.0 * __pyx_v_nu2) - (2675575.66847905 * __pyx_v_nu)) - 5278341.3229329))) - ((9216.0 * __pyx_v_r2) * ((((-197773496.793534 * __pyx_v_nu2) - ((7680.0 * __pyx_v_nu) * ((315.0 * __pyx_v_d5) + 405152.309729121))) + (2481453539.84635 * __pyx_v_nu)) + 5805304367.87913))) + (__pyx_v_r * (((((((5927865218923.02 * __pyx_v_nu3) + ((70778880.0 * __pyx_v_nu2) * ((315.0 * __pyx_v_d5) + 2561145.80918574))) - (138141470005001.0 * __pyx_v_nu2)) - ((4718592.0 * __pyx_v_nu) * ((40950.0 * __pyx_v_d5) + 86207832.4415642))) + (450172889755120.0 * __pyx_v_nu)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0))) + ((5787938193408.0 * __pyx_v_r) * pow(__pyx_v_lr, 2.0))) + ((((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + (879923036160.0 * __pyx_v_r3)) + ((283115520.0 * __pyx_v_r2) * ((14700.0 * __pyx_v_nu) + 42911.0))) + ((49152.0 * __pyx_v_r) * (((102574080.0 * __pyx_v_nu2) + (409207698.136075 * __pyx_v_nu)) - 2119671837.36038))) * __pyx_v_lr)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":211
 *         cdef double Dbpm = r*(6730497718123.02*nu3 + 22295347200.0*nu2*d5 + 133772083200.0*nu2*r2 + 1822680546449.21*nu2*r + 80059249540278.2*nu2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu2 - 25392914995744.3*nu - 879923036160.0*r2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*lr + 5787938193408.0*lr**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu3 - 42636451.6032331*nu2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r3*(-138240.0*nu2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r2*(-197773496.793534*nu2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu3 + 70778880.0*nu2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*lr**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r3 + 283115520.0*r2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu2 + 409207698.136075*nu - 2119671837.36038))*lr)
 * 
 *         cdef double Apm = 7680.0*r4*(-5416406.59541186*nu2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*lr - 7.0*r*(-185763.092693281*nu2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu4 + 1120.0*nu3*(-17833256.898555*r2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r5 - 3089250703.76879*r4 - 6178501407.53758*r3 + 2064783811.32587*r2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu2*lr**2 + 53760.0*nu*(7680.0*a6*(r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r4 + 4264.6962773603*r3 + 8529.39255472061*r2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r4 + 1926.0*r3 + 3852.0*r2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu2 - 38842241.4769507*nu + 161280.0*r5 + 480.0*r4*(756.0*nu + 1079.0) + 960.0*r3*(756.0*nu + 1079.0) + 1920.0*r2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*lr + 13212057600.0*r5)             # <<<<<<<<<<<<<<
 * 
 *         cdef double ap = chi_1*X_1 + chi_2*X_2
 */
  __Pyx_TraceLine(211,0,__PYX_ERR(1, 211, __pyx_L1_error))
  __pyx_v_Apm = (((7680.0 * __pyx_v_r4) * (((((-5416406.59541186 * __pyx_v_nu2) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) + (((2048.0 * __pyx_v_nu) * (((756.0 * __pyx_v_nu) + (336.0 * __pyx_v_r)) + 407.0)) * __pyx_v_lr)) - ((7.0 * __pyx_v_r) * (((-185763.092693281 * __pyx_v_nu2) + (938918.400156317 * __pyx_v_nu)) - 245760.0))) - 3440640.0)) / (((((((241555486248.807 * __pyx_v_nu4) + ((1120.0 * __pyx_v_nu3) * (((-17833256.898555 * __pyx_v_r2) - (163683964.822551 * __pyx_v_r)) - 1188987459.03162))) + ((7.0 * __pyx_v_nu2) * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (1426660551.8844 * __pyx_v_r5)) - (3089250703.76879 * __pyx_v_r4)) - (6178501407.53758 * __pyx_v_r3)) + (2064783811.32587 * __pyx_v_r2)) + (122635399361.987 * __pyx_v_r)) + 276057889687.011))) + ((67645734912.0 * __pyx_v_nu2) * pow(__pyx_v_lr, 2.0))) + ((53760.0 * __pyx_v_nu) * (((((7680.0 * __pyx_v_a6) * ((((__pyx_v_r4 + (2.0 * __pyx_v_r3)) + (4.0 * __pyx_v_r2)) + (8.0 * __pyx_v_r)) + 16.0)) + ((128.0 * __pyx_v_r) * (((((-6852.34813868015 * __pyx_v_r4) + (4264.6962773603 * __pyx_v_r3)) + (8529.39255472061 * __pyx_v_r2)) + (13218.7851094412 * __pyx_v_r)) - 33722.4297811176))) + ((113485.217444961 * __pyx_v_r) * (((((-__pyx_v_r4) + (2.0 * __pyx_v_r3)) + (4.0 * __pyx_v_r2)) + (8.0 * __pyx_v_r)) + 16.0))) + ((148.04406601634 * __pyx_v_r) * (((((349.0 * __pyx_v_r4) + (1926.0 * __pyx_v_r3)) + (3852.0 * __pyx_v_r2)) + (7704.0 * __pyx_v_r)) + 36400.0))))) + (((32768.0 * __pyx_v_nu) * ((((((((-1882456.23663972 * __pyx_v_nu2) - (38842241.4769507 * __pyx_v_nu)) + (161280.0 * __pyx_v_r5)) + ((480.0 * __pyx_v_r4) * ((756.0 * __pyx_v_nu) + 1079.0))) + ((960.0 * __pyx_v_r3) * ((756.0 * __pyx_v_nu) + 1079.0))) + ((1920.0 * __pyx_v_r2) * ((588.0 * __pyx_v_nu) + 1079.0))) + ((240.0 * __pyx_v_r) * (((-3024.0 * __pyx_v_nu2) - (7466.27061066206 * __pyx_v_nu)) + 17264.0))) + 13447680.0)) * __pyx_v_lr)) + (13212057600.0 * __pyx_v_r5)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":213
 *         cdef double Apm = 7680.0*r4*(-5416406.59541186*nu2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*lr - 7.0*r*(-185763.092693281*nu2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu4 + 1120.0*nu3*(-17833256.898555*r2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r5 - 3089250703.76879*r4 - 6178501407.53758*r3 + 2064783811.32587*r2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu2*lr**2 + 53760.0*nu*(7680.0*a6*(r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r4 + 4264.6962773603*r3 + 8529.39255472061*r2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r4 + 2.0*r3 + 4.0*r2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r4 + 1926.0*r3 + 3852.0*r2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu2 - 38842241.4769507*nu + 161280.0*r5 + 480.0*r4*(756.0*nu + 1079.0) + 960.0*r3*(756.0*nu + 1079.0) + 1920.0*r2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*lr + 13212057600.0*r5)
 * 
 *         cdef double ap = chi_1*X_1 + chi_2*X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double ap2 = ap*ap
 */
  __Pyx_TraceLine(213,0,__PYX_ERR(1, 213, __pyx_L1_error))
  __pyx_v_ap = ((__pyx_v_chi_1 * __pyx_v_X_1) + (__pyx_v_chi_2 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":215
 *         cdef double ap = chi_1*X_1 + chi_2*X_2
 * 
 *         cdef double ap2 = ap*ap             # <<<<<<<<<<<<<<
 * 
 *         cdef double xi = sqrt(Dbpm)*r2*(Apm + ap2/r2)/(ap2 + r2)
 */
  __Pyx_TraceLine(215,0,__PYX_ERR(1, 215, __pyx_L1_error))
  __pyx_v_ap2 = (__pyx_v_ap * __pyx_v_ap);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":217
 *         cdef double ap2 = ap*ap
 * 
 *         cdef double xi = sqrt(Dbpm)*r2*(Apm + ap2/r2)/(ap2 + r2)             # <<<<<<<<<<<<<<
 * 
 *         cdef double pr = prst/xi
 */
  __Pyx_TraceLine(217,0,__PYX_ERR(1, 217, __pyx_L1_error))
  __pyx_v_xi = (((sqrt(__pyx_v_Dbpm) * __pyx_v_r2) * (__pyx_v_Apm + (__pyx_v_ap2 / __pyx_v_r2))) / (__pyx_v_ap2 + __pyx_v_r2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":219
 *         cdef double xi = sqrt(Dbpm)*r2*(Apm + ap2/r2)/(ap2 + r2)
 * 
 *         cdef double pr = prst/xi             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSS2 = 1.00000000000000
 */
  __Pyx_TraceLine(219,0,__PYX_ERR(1, 219, __pyx_L1_error))
  __pyx_v_pr = (__pyx_v_prst / __pyx_v_xi);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":221
 *         cdef double pr = prst/xi
 * 
 *         cdef double flagNLOSS2 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double delta = X_1 - X_2
 */
  __Pyx_TraceLine(221,0,__PYX_ERR(1, 221, __pyx_L1_error))
  __pyx_v_flagNLOSS2 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":223
 *         cdef double flagNLOSS2 = 1.00000000000000
 * 
 *         cdef double delta = X_1 - X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double am = chi_1*X_1 - chi_2*X_2
 */
  __Pyx_TraceLine(223,0,__PYX_ERR(1, 223, __pyx_L1_error))
  __pyx_v_delta = (__pyx_v_X_1 - __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":225
 *         cdef double delta = X_1 - X_2
 * 
 *         cdef double am = chi_1*X_1 - chi_2*X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double apam = am*ap
 */
  __Pyx_TraceLine(225,0,__PYX_ERR(1, 225, __pyx_L1_error))
  __pyx_v_am = ((__pyx_v_chi_1 * __pyx_v_X_1) - (__pyx_v_chi_2 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":227
 *         cdef double am = chi_1*X_1 - chi_2*X_2
 * 
 *         cdef double apam = am*ap             # <<<<<<<<<<<<<<
 * 
 *         cdef double am2 = am*am
 */
  __Pyx_TraceLine(227,0,__PYX_ERR(1, 227, __pyx_L1_error))
  __pyx_v_apam = (__pyx_v_am * __pyx_v_ap);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":229
 *         cdef double apam = am*ap
 * 
 *         cdef double am2 = am*am             # <<<<<<<<<<<<<<
 * 
 *         cdef double apamd = apam*delta
 */
  __Pyx_TraceLine(229,0,__PYX_ERR(1, 229, __pyx_L1_error))
  __pyx_v_am2 = (__pyx_v_am * __pyx_v_am);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":231
 *         cdef double am2 = am*am
 * 
 *         cdef double apamd = apam*delta             # <<<<<<<<<<<<<<
 * 
 *         cdef double QSalign2 = flagNLOSS2*pr**4*(-0.46875*am2*(4.0*nu2 - 5.0*nu + 1.0) - 0.15625*ap2*(32.0*nu2 - 33.0*nu - 5.0) + 0.3125*apamd*(18.0*nu - 1.0))/r3
 */
  __Pyx_TraceLine(231,0,__PYX_ERR(1, 231, __pyx_L1_error))
  __pyx_v_apamd = (__pyx_v_apam * __pyx_v_delta);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":233
 *         cdef double apamd = apam*delta
 * 
 *         cdef double QSalign2 = flagNLOSS2*pr**4*(-0.46875*am2*(4.0*nu2 - 5.0*nu + 1.0) - 0.15625*ap2*(32.0*nu2 - 33.0*nu - 5.0) + 0.3125*apamd*(18.0*nu - 1.0))/r3             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagQPN55 = 1.00000000000000
 */
  __Pyx_TraceLine(233,0,__PYX_ERR(1, 233, __pyx_L1_error))
  __pyx_v_QSalign2 = (((__pyx_v_flagNLOSS2 * pow(__pyx_v_pr, 4.0)) * ((((-0.46875 * __pyx_v_am2) * (((4.0 * __pyx_v_nu2) - (5.0 * __pyx_v_nu)) + 1.0)) - ((0.15625 * __pyx_v_ap2) * (((32.0 * __pyx_v_nu2) - (33.0 * __pyx_v_nu)) - 5.0))) + ((0.3125 * __pyx_v_apamd) * ((18.0 * __pyx_v_nu) - 1.0)))) / __pyx_v_r3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":235
 *         cdef double QSalign2 = flagNLOSS2*pr**4*(-0.46875*am2*(4.0*nu2 - 5.0*nu + 1.0) - 0.15625*ap2*(32.0*nu2 - 33.0*nu - 5.0) + 0.3125*apamd*(18.0*nu - 1.0))/r3
 * 
 *         cdef double flagQPN55 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagQPN5 = 1.00000000000000
 */
  __Pyx_TraceLine(235,0,__PYX_ERR(1, 235, __pyx_L1_error))
  __pyx_v_flagQPN55 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":237
 *         cdef double flagQPN55 = 1.00000000000000
 * 
 *         cdef double flagQPN5 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagQPN4 = 1.00000000000000
 */
  __Pyx_TraceLine(237,0,__PYX_ERR(1, 237, __pyx_L1_error))
  __pyx_v_flagQPN5 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":239
 *         cdef double flagQPN5 = 1.00000000000000
 * 
 *         cdef double flagQPN4 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double Qpm = flagQPN4*(0.121954868780449*nu*prst**8/r + prst**6*(6.0*nu3 - 5.4*nu2 - 2.78300763695006*nu)/r2 + prst**4*(10.0*nu3 - 131.0*nu2 + 92.7110442849544*nu)/r3) + flagQPN5*(prst**8*(-6.0*nu4 + 3.42857142857143*nu3 + 3.33842023648322*nu2 + 1.38977750996128*nu)/r2 + prst**6*(-14.0*nu4 + 188.0*nu3 - 89.5298327361234*nu2 - 33.9782122170436*nu)/r3 + prst**4*(602.318540416564*nu3 + nu2*(118.4*lr - 1796.13660498019) + nu*(452.542166996693 - 51.6952380952381*lr))/r4) + flagQPN55*(1.48275342024365*nu*prst**8/r**2.5 - 11.3175085791863*nu*prst**6/r**3.5 + 147.443752990146*nu*prst**4/r**4.5) + prst**4*(-6.0*nu2 + 8.0*nu)/r2
 */
  __Pyx_TraceLine(239,0,__PYX_ERR(1, 239, __pyx_L1_error))
  __pyx_v_flagQPN4 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":241
 *         cdef double flagQPN4 = 1.00000000000000
 * 
 *         cdef double Qpm = flagQPN4*(0.121954868780449*nu*prst**8/r + prst**6*(6.0*nu3 - 5.4*nu2 - 2.78300763695006*nu)/r2 + prst**4*(10.0*nu3 - 131.0*nu2 + 92.7110442849544*nu)/r3) + flagQPN5*(prst**8*(-6.0*nu4 + 3.42857142857143*nu3 + 3.33842023648322*nu2 + 1.38977750996128*nu)/r2 + prst**6*(-14.0*nu4 + 188.0*nu3 - 89.5298327361234*nu2 - 33.9782122170436*nu)/r3 + prst**4*(602.318540416564*nu3 + nu2*(118.4*lr - 1796.13660498019) + nu*(452.542166996693 - 51.6952380952381*lr))/r4) + flagQPN55*(1.48275342024365*nu*prst**8/r**2.5 - 11.3175085791863*nu*prst**6/r**3.5 + 147.443752990146*nu*prst**4/r**4.5) + prst**4*(-6.0*nu2 + 8.0*nu)/r2             # <<<<<<<<<<<<<<
 * 
 *         cdef double Qq = QSalign2 + Qpm
 */
  __Pyx_TraceLine(241,0,__PYX_ERR(1, 241, __pyx_L1_error))
  __pyx_t_14 = __Pyx_SoftComplexToDouble(__Pyx_c_sum_double(__Pyx_c_sum_double(__pyx_t_double_complex_from_parts(((__pyx_v_flagQPN4 * (((((0.121954868780449 * __pyx_v_nu) * pow(__pyx_v_prst, 8.0)) / __pyx_v_r) + ((pow(__pyx_v_prst, 6.0) * (((6.0 * __pyx_v_nu3) - (5.4 * __pyx_v_nu2)) - (2.78300763695006 * __pyx_v_nu))) / __pyx_v_r2)) + ((pow(__pyx_v_prst, 4.0) * (((10.0 * __pyx_v_nu3) - (131.0 * __pyx_v_nu2)) + (92.7110442849544 * __pyx_v_nu))) / __pyx_v_r3))) + (__pyx_v_flagQPN5 * ((((pow(__pyx_v_prst, 8.0) * ((((-6.0 * __pyx_v_nu4) + (3.42857142857143 * __pyx_v_nu3)) + (3.33842023648322 * __pyx_v_nu2)) + (1.38977750996128 * __pyx_v_nu))) / __pyx_v_r2) + ((pow(__pyx_v_prst, 6.0) * ((((-14.0 * __pyx_v_nu4) + (188.0 * __pyx_v_nu3)) - (89.5298327361234 * __pyx_v_nu2)) - (33.9782122170436 * __pyx_v_nu))) / __pyx_v_r3)) + ((pow(__pyx_v_prst, 4.0) * (((602.318540416564 * __pyx_v_nu3) + (__pyx_v_nu2 * ((118.4 * __pyx_v_lr) - 1796.13660498019))) + (__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_lr))))) / __pyx_v_r4)))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_flagQPN55, 0), __Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_quot_double(__pyx_t_double_complex_from_parts(((1.48275342024365 * __pyx_v_nu) * pow(__pyx_v_prst, 8.0)), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(2.5, 0))), __Pyx_c_quot_double(__pyx_t_double_complex_from_parts(((11.3175085791863 * __pyx_v_nu) * pow(__pyx_v_prst, 6.0)), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(3.5, 0)))), __Pyx_c_quot_double(__pyx_t_double_complex_from_parts(((147.443752990146 * __pyx_v_nu) * pow(__pyx_v_prst, 4.0)), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(4.5, 0)))))), __pyx_t_double_complex_from_parts(((pow(__pyx_v_prst, 4.0) * ((-6.0 * __pyx_v_nu2) + (8.0 * __pyx_v_nu))) / __pyx_v_r2), 0)), 1); if (unlikely(__pyx_t_14 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 241, __pyx_L1_error)
  __pyx_v_Qpm = __pyx_t_14;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":243
 *         cdef double Qpm = flagQPN4*(0.121954868780449*nu*prst**8/r + prst**6*(6.0*nu3 - 5.4*nu2 - 2.78300763695006*nu)/r2 + prst**4*(10.0*nu3 - 131.0*nu2 + 92.7110442849544*nu)/r3) + flagQPN5*(prst**8*(-6.0*nu4 + 3.42857142857143*nu3 + 3.33842023648322*nu2 + 1.38977750996128*nu)/r2 + prst**6*(-14.0*nu4 + 188.0*nu3 - 89.5298327361234*nu2 - 33.9782122170436*nu)/r3 + prst**4*(602.318540416564*nu3 + nu2*(118.4*lr - 1796.13660498019) + nu*(452.542166996693 - 51.6952380952381*lr))/r4) + flagQPN55*(1.48275342024365*nu*prst**8/r**2.5 - 11.3175085791863*nu*prst**6/r**3.5 + 147.443752990146*nu*prst**4/r**4.5) + prst**4*(-6.0*nu2 + 8.0*nu)/r2
 * 
 *         cdef double Qq = QSalign2 + Qpm             # <<<<<<<<<<<<<<
 * 
 *         cdef double Bnpa = -r*(r + 2.0)/(ap2*r*(r + 2.0) + r4)
 */
  __Pyx_TraceLine(243,0,__PYX_ERR(1, 243, __pyx_L1_error))
  __pyx_v_Qq = (__pyx_v_QSalign2 + __pyx_v_Qpm);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":245
 *         cdef double Qq = QSalign2 + Qpm
 * 
 *         cdef double Bnpa = -r*(r + 2.0)/(ap2*r*(r + 2.0) + r4)             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSS = 1.00000000000000
 */
  __Pyx_TraceLine(245,0,__PYX_ERR(1, 245, __pyx_L1_error))
  __pyx_v_Bnpa = (((-__pyx_v_r) * (__pyx_v_r + 2.0)) / (((__pyx_v_ap2 * __pyx_v_r) * (__pyx_v_r + 2.0)) + __pyx_v_r4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":247
 *         cdef double Bnpa = -r*(r + 2.0)/(ap2*r*(r + 2.0) + r4)
 * 
 *         cdef double flagNLOSS = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double BnpSalign2 = flagNLOSS*(0.1875*am2*(4.0*nu - 1.0) + ap2*(3.0*nu + 2.8125) - 2.625*apamd)/r3 + flagNLOSS2*(0.015625*am2*(4.0*nu2 + 115.0*nu - 37.0) + 0.015625*ap2*(-1171.0*nu - 861.0) + 0.03125*apamd*(26.0*nu + 449.0))/r4
 */
  __Pyx_TraceLine(247,0,__PYX_ERR(1, 247, __pyx_L1_error))
  __pyx_v_flagNLOSS = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":249
 *         cdef double flagNLOSS = 1.00000000000000
 * 
 *         cdef double BnpSalign2 = flagNLOSS*(0.1875*am2*(4.0*nu - 1.0) + ap2*(3.0*nu + 2.8125) - 2.625*apamd)/r3 + flagNLOSS2*(0.015625*am2*(4.0*nu2 + 115.0*nu - 37.0) + 0.015625*ap2*(-1171.0*nu - 861.0) + 0.03125*apamd*(26.0*nu + 449.0))/r4             # <<<<<<<<<<<<<<
 * 
 *         cdef double Bnp = Apm*Dbpm + BnpSalign2 + ap2/r2 - 1.0
 */
  __Pyx_TraceLine(249,0,__PYX_ERR(1, 249, __pyx_L1_error))
  __pyx_v_BnpSalign2 = (((__pyx_v_flagNLOSS * ((((0.1875 * __pyx_v_am2) * ((4.0 * __pyx_v_nu) - 1.0)) + (__pyx_v_ap2 * ((3.0 * __pyx_v_nu) + 2.8125))) - (2.625 * __pyx_v_apamd))) / __pyx_v_r3) + ((__pyx_v_flagNLOSS2 * ((((0.015625 * __pyx_v_am2) * (((4.0 * __pyx_v_nu2) + (115.0 * __pyx_v_nu)) - 37.0)) + ((0.015625 * __pyx_v_ap2) * ((-1171.0 * __pyx_v_nu) - 861.0))) + ((0.03125 * __pyx_v_apamd) * ((26.0 * __pyx_v_nu) + 449.0)))) / __pyx_v_r4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":251
 *         cdef double BnpSalign2 = flagNLOSS*(0.1875*am2*(4.0*nu - 1.0) + ap2*(3.0*nu + 2.8125) - 2.625*apamd)/r3 + flagNLOSS2*(0.015625*am2*(4.0*nu2 + 115.0*nu - 37.0) + 0.015625*ap2*(-1171.0*nu - 861.0) + 0.03125*apamd*(26.0*nu + 449.0))/r4
 * 
 *         cdef double Bnp = Apm*Dbpm + BnpSalign2 + ap2/r2 - 1.0             # <<<<<<<<<<<<<<
 * 
 *         cdef double ASalignCal2 = 0.0
 */
  __Pyx_TraceLine(251,0,__PYX_ERR(1, 251, __pyx_L1_error))
  __pyx_v_Bnp = ((((__pyx_v_Apm * __pyx_v_Dbpm) + __pyx_v_BnpSalign2) + (__pyx_v_ap2 / __pyx_v_r2)) - 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":253
 *         cdef double Bnp = Apm*Dbpm + BnpSalign2 + ap2/r2 - 1.0
 * 
 *         cdef double ASalignCal2 = 0.0             # <<<<<<<<<<<<<<
 * 
 *         cdef double ASalign2 = flagNLOSS*(0.125*am2*(4.0*nu + 1.0) + 1.125*ap2 - 1.25*apamd)/r4 + flagNLOSS2*(0.046875*am2*(28.0*nu2 - 27.0*nu - 3.0) - 0.390625*ap2*(7.0*nu + 9.0) - 1.21875*apamd*(2.0*nu - 3.0))/r**5
 */
  __Pyx_TraceLine(253,0,__PYX_ERR(1, 253, __pyx_L1_error))
  __pyx_v_ASalignCal2 = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":255
 *         cdef double ASalignCal2 = 0.0
 * 
 *         cdef double ASalign2 = flagNLOSS*(0.125*am2*(4.0*nu + 1.0) + 1.125*ap2 - 1.25*apamd)/r4 + flagNLOSS2*(0.046875*am2*(28.0*nu2 - 27.0*nu - 3.0) - 0.390625*ap2*(7.0*nu + 9.0) - 1.21875*apamd*(2.0*nu - 3.0))/r**5             # <<<<<<<<<<<<<<
 * 
 *         cdef double A = (ASalign2 + ASalignCal2 + Apm + ap2/r2)/(ap2*(1.0 + 2.0/r)/r2 + 1.0)
 */
  __Pyx_TraceLine(255,0,__PYX_ERR(1, 255, __pyx_L1_error))
  __pyx_v_ASalign2 = (((__pyx_v_flagNLOSS * ((((0.125 * __pyx_v_am2) * ((4.0 * __pyx_v_nu) + 1.0)) + (1.125 * __pyx_v_ap2)) - (1.25 * __pyx_v_apamd))) / __pyx_v_r4) + ((__pyx_v_flagNLOSS2 * ((((0.046875 * __pyx_v_am2) * (((28.0 * __pyx_v_nu2) - (27.0 * __pyx_v_nu)) - 3.0)) - ((0.390625 * __pyx_v_ap2) * ((7.0 * __pyx_v_nu) + 9.0))) - ((1.21875 * __pyx_v_apamd) * ((2.0 * __pyx_v_nu) - 3.0)))) / pow(__pyx_v_r, 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":257
 *         cdef double ASalign2 = flagNLOSS*(0.125*am2*(4.0*nu + 1.0) + 1.125*ap2 - 1.25*apamd)/r4 + flagNLOSS2*(0.046875*am2*(28.0*nu2 - 27.0*nu - 3.0) - 0.390625*ap2*(7.0*nu + 9.0) - 1.21875*apamd*(2.0*nu - 3.0))/r**5
 * 
 *         cdef double A = (ASalign2 + ASalignCal2 + Apm + ap2/r2)/(ap2*(1.0 + 2.0/r)/r2 + 1.0)             # <<<<<<<<<<<<<<
 * 
 *         cdef double lap = ap
 */
  __Pyx_TraceLine(257,0,__PYX_ERR(1, 257, __pyx_L1_error))
  __pyx_v_A = ((((__pyx_v_ASalign2 + __pyx_v_ASalignCal2) + __pyx_v_Apm) + (__pyx_v_ap2 / __pyx_v_r2)) / (((__pyx_v_ap2 * (1.0 + (2.0 / __pyx_v_r))) / __pyx_v_r2) + 1.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":259
 *         cdef double A = (ASalign2 + ASalignCal2 + Apm + ap2/r2)/(ap2*(1.0 + 2.0/r)/r2 + 1.0)
 * 
 *         cdef double lap = ap             # <<<<<<<<<<<<<<
 * 
 *         cdef double Heven = sqrt(A*(Bnpa*L2*lap**2/r2 + L2/r2 + Qq + prst**2*(Bnp + 1.0)/xi**2 + 1.0))
 */
  __Pyx_TraceLine(259,0,__PYX_ERR(1, 259, __pyx_L1_error))
  __pyx_v_lap = __pyx_v_ap;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":261
 *         cdef double lap = ap
 * 
 *         cdef double Heven = sqrt(A*(Bnpa*L2*lap**2/r2 + L2/r2 + Qq + prst**2*(Bnp + 1.0)/xi**2 + 1.0))             # <<<<<<<<<<<<<<
 * 
 *         cdef double lam = am
 */
  __Pyx_TraceLine(261,0,__PYX_ERR(1, 261, __pyx_L1_error))
  __pyx_v_Heven = sqrt((__pyx_v_A * (((((((__pyx_v_Bnpa * __pyx_v_L2) * pow(__pyx_v_lap, 2.0)) / __pyx_v_r2) + (__pyx_v_L2 / __pyx_v_r2)) + __pyx_v_Qq) + ((pow(__pyx_v_prst, 2.0) * (__pyx_v_Bnp + 1.0)) / pow(__pyx_v_xi, 2.0))) + 1.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":263
 *         cdef double Heven = sqrt(A*(Bnpa*L2*lap**2/r2 + L2/r2 + Qq + prst**2*(Bnp + 1.0)/xi**2 + 1.0))
 * 
 *         cdef double lam = am             # <<<<<<<<<<<<<<
 * 
 *         cdef double Ga3 = 0.0416666666666667*L*ap2*delta*lam/r2 + L*lap*(-0.25*ap2 + 0.208333333333333*apamd)/r2
 */
  __Pyx_TraceLine(263,0,__PYX_ERR(1, 263, __pyx_L1_error))
  __pyx_v_lam = __pyx_v_am;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":265
 *         cdef double lam = am
 * 
 *         cdef double Ga3 = 0.0416666666666667*L*ap2*delta*lam/r2 + L*lap*(-0.25*ap2 + 0.208333333333333*apamd)/r2             # <<<<<<<<<<<<<<
 * 
 *         cdef double SOcalib = L*nu*dSO*lap/r3
 */
  __Pyx_TraceLine(265,0,__PYX_ERR(1, 265, __pyx_L1_error))
  __pyx_v_Ga3 = ((((((0.0416666666666667 * __pyx_v_L) * __pyx_v_ap2) * __pyx_v_delta) * __pyx_v_lam) / __pyx_v_r2) + (((__pyx_v_L * __pyx_v_lap) * ((-0.25 * __pyx_v_ap2) + (0.208333333333333 * __pyx_v_apamd))) / __pyx_v_r2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":267
 *         cdef double Ga3 = 0.0416666666666667*L*ap2*delta*lam/r2 + L*lap*(-0.25*ap2 + 0.208333333333333*apamd)/r2
 * 
 *         cdef double SOcalib = L*nu*dSO*lap/r3             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSO2 = 1.00000000000000
 */
  __Pyx_TraceLine(267,0,__PYX_ERR(1, 267, __pyx_L1_error))
  __pyx_v_SOcalib = ((((__pyx_v_L * __pyx_v_nu) * __pyx_v_dSO) * __pyx_v_lap) / __pyx_v_r3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":269
 *         cdef double SOcalib = L*nu*dSO*lap/r3
 * 
 *         cdef double flagNLOSO2 = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double flagNLOSO = 1.00000000000000
 */
  __Pyx_TraceLine(269,0,__PYX_ERR(1, 269, __pyx_L1_error))
  __pyx_v_flagNLOSO2 = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":271
 *         cdef double flagNLOSO2 = 1.00000000000000
 * 
 *         cdef double flagNLOSO = 1.00000000000000             # <<<<<<<<<<<<<<
 * 
 *         cdef double gam = flagNLOSO*(L2*(0.46875 - 0.28125*nu)/r2 + (0.34375*nu + 0.09375)/r) + flagNLOSO2*(L**4*(0.29296875*nu2 - 0.3515625*nu - 0.41015625)/r4 + L2*(-0.798177083333333*nu2 - 0.2734375*nu - 0.23046875)/r3 + (0.536458333333333*nu2 - 0.03125*nu + 0.078125)/r2) + 0.25
 */
  __Pyx_TraceLine(271,0,__PYX_ERR(1, 271, __pyx_L1_error))
  __pyx_v_flagNLOSO = 1.00000000000000;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":273
 *         cdef double flagNLOSO = 1.00000000000000
 * 
 *         cdef double gam = flagNLOSO*(L2*(0.46875 - 0.28125*nu)/r2 + (0.34375*nu + 0.09375)/r) + flagNLOSO2*(L**4*(0.29296875*nu2 - 0.3515625*nu - 0.41015625)/r4 + L2*(-0.798177083333333*nu2 - 0.2734375*nu - 0.23046875)/r3 + (0.536458333333333*nu2 - 0.03125*nu + 0.078125)/r2) + 0.25             # <<<<<<<<<<<<<<
 * 
 *         cdef double gap = flagNLOSO*(L2*(-1.40625*nu - 0.46875)/r2 + (0.71875*nu - 0.09375)/r) + flagNLOSO2*(L**4*(1.34765625*nu2 + 0.5859375*nu + 0.41015625)/r4 + L2*(-2.07161458333333*nu2 - 2.0859375*nu + 0.23046875)/r3 + (0.567708333333333*nu2 - 5.53125*nu - 0.078125)/r2) + 1.75
 */
  __Pyx_TraceLine(273,0,__PYX_ERR(1, 273, __pyx_L1_error))
  __pyx_v_gam = (((__pyx_v_flagNLOSO * (((__pyx_v_L2 * (0.46875 - (0.28125 * __pyx_v_nu))) / __pyx_v_r2) + (((0.34375 * __pyx_v_nu) + 0.09375) / __pyx_v_r))) + (__pyx_v_flagNLOSO2 * ((((pow(__pyx_v_L, 4.0) * (((0.29296875 * __pyx_v_nu2) - (0.3515625 * __pyx_v_nu)) - 0.41015625)) / __pyx_v_r4) + ((__pyx_v_L2 * (((-0.798177083333333 * __pyx_v_nu2) - (0.2734375 * __pyx_v_nu)) - 0.23046875)) / __pyx_v_r3)) + ((((0.536458333333333 * __pyx_v_nu2) - (0.03125 * __pyx_v_nu)) + 0.078125) / __pyx_v_r2)))) + 0.25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":275
 *         cdef double gam = flagNLOSO*(L2*(0.46875 - 0.28125*nu)/r2 + (0.34375*nu + 0.09375)/r) + flagNLOSO2*(L**4*(0.29296875*nu2 - 0.3515625*nu - 0.41015625)/r4 + L2*(-0.798177083333333*nu2 - 0.2734375*nu - 0.23046875)/r3 + (0.536458333333333*nu2 - 0.03125*nu + 0.078125)/r2) + 0.25
 * 
 *         cdef double gap = flagNLOSO*(L2*(-1.40625*nu - 0.46875)/r2 + (0.71875*nu - 0.09375)/r) + flagNLOSO2*(L**4*(1.34765625*nu2 + 0.5859375*nu + 0.41015625)/r4 + L2*(-2.07161458333333*nu2 - 2.0859375*nu + 0.23046875)/r3 + (0.567708333333333*nu2 - 5.53125*nu - 0.078125)/r2) + 1.75             # <<<<<<<<<<<<<<
 * 
 *         cdef double Hodd = (Ga3 + L*delta*gam*lam + L*gap*lap + SOcalib)/(2.0*ap2 + 2.0*r2 + r*(ap2 + r2 - 2.0*r))
 */
  __Pyx_TraceLine(275,0,__PYX_ERR(1, 275, __pyx_L1_error))
  __pyx_v_gap = (((__pyx_v_flagNLOSO * (((__pyx_v_L2 * ((-1.40625 * __pyx_v_nu) - 0.46875)) / __pyx_v_r2) + (((0.71875 * __pyx_v_nu) - 0.09375) / __pyx_v_r))) + (__pyx_v_flagNLOSO2 * ((((pow(__pyx_v_L, 4.0) * (((1.34765625 * __pyx_v_nu2) + (0.5859375 * __pyx_v_nu)) + 0.41015625)) / __pyx_v_r4) + ((__pyx_v_L2 * (((-2.07161458333333 * __pyx_v_nu2) - (2.0859375 * __pyx_v_nu)) + 0.23046875)) / __pyx_v_r3)) + ((((0.567708333333333 * __pyx_v_nu2) - (5.53125 * __pyx_v_nu)) - 0.078125) / __pyx_v_r2)))) + 1.75);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":277
 *         cdef double gap = flagNLOSO*(L2*(-1.40625*nu - 0.46875)/r2 + (0.71875*nu - 0.09375)/r) + flagNLOSO2*(L**4*(1.34765625*nu2 + 0.5859375*nu + 0.41015625)/r4 + L2*(-2.07161458333333*nu2 - 2.0859375*nu + 0.23046875)/r3 + (0.567708333333333*nu2 - 5.53125*nu - 0.078125)/r2) + 1.75
 * 
 *         cdef double Hodd = (Ga3 + L*delta*gam*lam + L*gap*lap + SOcalib)/(2.0*ap2 + 2.0*r2 + r*(ap2 + r2 - 2.0*r))             # <<<<<<<<<<<<<<
 * 
 *         cdef double Heff = Heven + Hodd
 */
  __Pyx_TraceLine(277,0,__PYX_ERR(1, 277, __pyx_L1_error))
  __pyx_v_Hodd = ((((__pyx_v_Ga3 + (((__pyx_v_L * __pyx_v_delta) * __pyx_v_gam) * __pyx_v_lam)) + ((__pyx_v_L * __pyx_v_gap) * __pyx_v_lap)) + __pyx_v_SOcalib) / (((2.0 * __pyx_v_ap2) + (2.0 * __pyx_v_r2)) + (__pyx_v_r * ((__pyx_v_ap2 + __pyx_v_r2) - (2.0 * __pyx_v_r)))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":279
 *         cdef double Hodd = (Ga3 + L*delta*gam*lam + L*gap*lap + SOcalib)/(2.0*ap2 + 2.0*r2 + r*(ap2 + r2 - 2.0*r))
 * 
 *         cdef double Heff = Heven + Hodd             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(279,0,__PYX_ERR(1, 279, __pyx_L1_error))
  __pyx_v_Heff = (__pyx_v_Heven + __pyx_v_Hodd);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":284
 * 
 *         # Evaluate H_real/nu
 *         cdef double H = M * sqrt(1+2*nu*(Heff-1)) / nu             # <<<<<<<<<<<<<<
 *         if not verbose:
 *             return H,xi
 */
  __Pyx_TraceLine(284,0,__PYX_ERR(1, 284, __pyx_L1_error))
  __pyx_v_H = ((__pyx_v_M * sqrt((1.0 + ((2.0 * __pyx_v_nu) * (__pyx_v_Heff - 1.0))))) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":285
 *         # Evaluate H_real/nu
 *         cdef double H = M * sqrt(1+2*nu*(Heff-1)) / nu
 *         if not verbose:             # <<<<<<<<<<<<<<
 *             return H,xi
 *         else:
 */
  __Pyx_TraceLine(285,0,__PYX_ERR(1, 285, __pyx_L1_error))
  __pyx_t_15 = (!__pyx_v_verbose);
  if (__pyx_t_15) {

    /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":286
 *         cdef double H = M * sqrt(1+2*nu*(Heff-1)) / nu
 *         if not verbose:
 *             return H,xi             # <<<<<<<<<<<<<<
 *         else:
 *             return H,xi,A,Bnp,Bnpa,Qq,Heven,Hodd
 */
    __Pyx_TraceLine(286,0,__PYX_ERR(1, 286, __pyx_L1_error))
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_H); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_xi); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_2);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":285
 *         # Evaluate H_real/nu
 *         cdef double H = M * sqrt(1+2*nu*(Heff-1)) / nu
 *         if not verbose:             # <<<<<<<<<<<<<<
 *             return H,xi
 *         else:
 */
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":288
 *             return H,xi
 *         else:
 *             return H,xi,A,Bnp,Bnpa,Qq,Heven,Hodd             # <<<<<<<<<<<<<<
 * 
 *     cpdef grad(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):
 */
  __Pyx_TraceLine(288,0,__PYX_ERR(1, 288, __pyx_L1_error))
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_10 = PyFloat_FromDouble(__pyx_v_H); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_xi); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_A); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = PyFloat_FromDouble(__pyx_v_Bnp); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = PyFloat_FromDouble(__pyx_v_Bnpa); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = PyFloat_FromDouble(__pyx_v_Qq); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyFloat_FromDouble(__pyx_v_Heven); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyFloat_FromDouble(__pyx_v_Hodd); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_New(8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 6, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 7, __pyx_t_5);
    __pyx_t_10 = 0;
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_9 = 0;
    __pyx_t_8 = 0;
    __pyx_t_7 = 0;
    __pyx_t_6 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":154
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C._call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_4_call, "\n        Evaluate the aligned-spin SEOBNRv5HM Hamiltonian as well as several potentials.\n        See Sec. 1B and 1C of\n        https://dcc.ligo.org/DocDB/0186/T2300060/001/SEOBNRv5_theory.pdf\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n          verbose (bint): Output additional potentials.\n\n        Returns:\n           (tuple)  H,xi, A, Bnp, Bnpa, Qq, Heven, Hodd\n\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call = {"_call", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_4_call};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  int __pyx_v_verbose;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_call (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,&__pyx_n_s_verbose,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_call", 0, 6, 7, 1); __PYX_ERR(1, 154, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_call", 0, 6, 7, 2); __PYX_ERR(1, 154, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_call", 0, 6, 7, 3); __PYX_ERR(1, 154, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_call", 0, 6, 7, 4); __PYX_ERR(1, 154, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_call", 0, 6, 7, 5); __PYX_ERR(1, 154, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_verbose);
          if (value) { values[6] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_call") < 0)) __PYX_ERR(1, 154, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 154, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 154, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
    if (values[6]) {
      __pyx_v_verbose = __Pyx_PyObject_IsTrue(values[6]); if (unlikely((__pyx_v_verbose == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 154, __pyx_L3_error)
    } else {
      __pyx_v_verbose = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_call", 0, 6, 7, __pyx_nargs); __PYX_ERR(1, 154, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C._call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_4_call(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_verbose);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_4_call(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_v_verbose) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__12)
  __Pyx_RefNannySetupContext("_call", 0);
  __Pyx_TraceCall("_call (wrapper)", __pyx_f[1], 154, 0, __PYX_ERR(1, 154, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 154, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 154, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.verbose = __pyx_v_verbose;
  __pyx_t_1 = __pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->_call(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C._call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call__pyx_wrap_1(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2, int __pyx_skip_dispatch) {
  return __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_skip_dispatch, NULL);
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":290
 *             return H,xi,A,Bnp,Bnpa,Qq,Heven,Hodd
 * 
 *     cpdef grad(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_grad(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  double __pyx_v_pphi;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_x0;
  double __pyx_v_x1;
  double __pyx_v_x2;
  double __pyx_v_x3;
  double __pyx_v_x4;
  double __pyx_v_x5;
  double __pyx_v_x6;
  double __pyx_v_x7;
  double __pyx_v_x8;
  double __pyx_v_x9;
  double __pyx_v_x10;
  double __pyx_v_x11;
  double __pyx_v_x12;
  double __pyx_v_x13;
  double __pyx_v_x14;
  double __pyx_v_x15;
  double __pyx_v_x16;
  double __pyx_v_x17;
  double __pyx_v_x18;
  double __pyx_v_x19;
  double __pyx_v_x20;
  double __pyx_v_x21;
  double __pyx_v_x22;
  double __pyx_v_x23;
  double __pyx_v_x24;
  double __pyx_v_x25;
  double __pyx_v_x26;
  double __pyx_v_x27;
  double __pyx_v_x28;
  double __pyx_v_x29;
  double __pyx_v_x30;
  double __pyx_v_x31;
  double __pyx_v_x32;
  double __pyx_v_x33;
  double __pyx_v_x34;
  double __pyx_v_x35;
  double __pyx_v_x36;
  double __pyx_v_x37;
  double __pyx_v_x38;
  double __pyx_v_x39;
  double __pyx_v_x40;
  double __pyx_v_x41;
  double __pyx_v_x42;
  double __pyx_v_x43;
  double __pyx_v_x44;
  double __pyx_v_x45;
  double __pyx_v_x46;
  double __pyx_v_x47;
  double __pyx_v_x48;
  double __pyx_v_x49;
  double __pyx_v_x50;
  double __pyx_v_x51;
  double __pyx_v_x52;
  double __pyx_v_x53;
  double __pyx_v_x54;
  double __pyx_v_x55;
  double __pyx_v_x56;
  double __pyx_v_x57;
  double __pyx_v_x58;
  double __pyx_v_x59;
  double __pyx_v_x60;
  double __pyx_v_x61;
  double __pyx_v_x62;
  double __pyx_v_x63;
  double __pyx_v_x64;
  double __pyx_v_x65;
  double __pyx_v_x66;
  double __pyx_v_x67;
  double __pyx_v_x68;
  double __pyx_v_x69;
  double __pyx_v_x70;
  double __pyx_v_x71;
  double __pyx_v_x72;
  double __pyx_v_x73;
  double __pyx_v_x74;
  double __pyx_v_x75;
  double __pyx_v_x76;
  double __pyx_v_x77;
  double __pyx_v_x78;
  double __pyx_v_x79;
  double __pyx_v_x80;
  double __pyx_v_x81;
  double __pyx_v_x82;
  double __pyx_v_x83;
  double __pyx_v_x84;
  double __pyx_v_x85;
  double __pyx_v_x86;
  double __pyx_v_x87;
  double __pyx_v_x88;
  double __pyx_v_x89;
  double __pyx_v_x90;
  double __pyx_v_x91;
  double __pyx_v_x92;
  double __pyx_v_x93;
  double __pyx_v_x94;
  double __pyx_v_x95;
  double __pyx_v_x96;
  double __pyx_v_x97;
  double __pyx_v_x98;
  double __pyx_v_x99;
  double __pyx_v_x100;
  double __pyx_v_x101;
  double __pyx_v_x102;
  double __pyx_v_x103;
  double __pyx_v_x104;
  double __pyx_v_x105;
  double __pyx_v_x106;
  double __pyx_v_x107;
  double __pyx_v_x108;
  double __pyx_v_x109;
  double __pyx_v_x110;
  double __pyx_v_x111;
  double __pyx_v_x112;
  double __pyx_v_x113;
  double __pyx_v_x114;
  double __pyx_v_x115;
  double __pyx_v_x116;
  double __pyx_v_x117;
  double __pyx_v_x118;
  double __pyx_v_x119;
  double __pyx_v_x120;
  double __pyx_v_x121;
  double __pyx_v_x122;
  double __pyx_v_x123;
  double __pyx_v_x124;
  double __pyx_v_x125;
  double __pyx_v_x126;
  double __pyx_v_x127;
  double __pyx_v_x128;
  double __pyx_v_x129;
  double __pyx_v_x130;
  double __pyx_v_x131;
  double __pyx_v_x132;
  double __pyx_v_x133;
  double __pyx_v_x134;
  double __pyx_v_x135;
  double __pyx_v_x136;
  double __pyx_v_x137;
  double __pyx_v_x138;
  double __pyx_v_x139;
  double __pyx_v_x140;
  double __pyx_v_x141;
  double __pyx_v_x142;
  double __pyx_v_x143;
  double __pyx_v_x144;
  double __pyx_v_x145;
  double __pyx_v_x146;
  double __pyx_v_x147;
  double __pyx_v_x148;
  double __pyx_v_x149;
  double __pyx_v_x150;
  double __pyx_v_x151;
  double __pyx_v_x152;
  double __pyx_v_x153;
  double __pyx_v_x154;
  double __pyx_v_x155;
  double __pyx_v_x156;
  double __pyx_v_x157;
  double __pyx_v_x158;
  double __pyx_v_x159;
  double __pyx_v_x160;
  double __pyx_v_x161;
  double __pyx_v_x162;
  double __pyx_v_x163;
  double __pyx_v_x164;
  double __pyx_v_x165;
  double __pyx_v_x166;
  double __pyx_v_x167;
  double __pyx_v_x168;
  double __pyx_v_x169;
  double __pyx_v_x170;
  double __pyx_v_x171;
  double __pyx_v_x172;
  double __pyx_v_x173;
  double __pyx_v_x174;
  double __pyx_v_x175;
  double __pyx_v_x176;
  double __pyx_v_x177;
  double __pyx_v_x178;
  double __pyx_v_x179;
  double __pyx_v_x180;
  double __pyx_v_x181;
  double __pyx_v_x182;
  double __pyx_v_x183;
  double __pyx_v_x184;
  double __pyx_v_x185;
  double __pyx_v_x186;
  double __pyx_v_x187;
  double __pyx_v_x188;
  double __pyx_v_x189;
  double __pyx_v_x190;
  double __pyx_v_x191;
  double __pyx_v_x192;
  double __pyx_v_x193;
  double __pyx_v_x194;
  double __pyx_v_x195;
  double __pyx_v_H;
  CYTHON_UNUSED double __pyx_v_xi;
  double __pyx_v_dHeffdr;
  double __pyx_v_dHeffdphi;
  double __pyx_v_dHeffdpr;
  double __pyx_v_dHeffdpphi;
  double __pyx_v_dHdr;
  double __pyx_v_dHdphi;
  double __pyx_v_dHdpr;
  double __pyx_v_dHdpphi;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  double __pyx_t_13;
  __pyx_ctuple_double__and_double __pyx_t_14;
  double __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__13)
  __Pyx_RefNannySetupContext("grad", 0);
  __Pyx_TraceCall("grad", __pyx_f[1], 290, 0, __PYX_ERR(1, 290, __pyx_L1_error));
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_grad); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #ifdef __Pyx_CyFunction_USED
      if (!__Pyx_IsCyOrPyCFunction(__pyx_t_1)
      #else
      if (!PyCFunction_Check(__pyx_t_1)
      #endif
              || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad)) {
        __Pyx_XDECREF(__pyx_r);
        if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 290, __pyx_L1_error) }
        __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_q, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 290, __pyx_L1_error) }
        __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_p, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyFloat_FromDouble(__pyx_v_chi_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyFloat_FromDouble(__pyx_v_chi_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyFloat_FromDouble(__pyx_v_m_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_m_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = __pyx_t_1; __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_11 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[7] = {__pyx_t_10, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 6+__pyx_t_11);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 290, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":310
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(310,0,__PYX_ERR(1, 310, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":311
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(311,0,__PYX_ERR(1, 311, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":313
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(313,0,__PYX_ERR(1, 313, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":314
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(314,0,__PYX_ERR(1, 314, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":316
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(316,0,__PYX_ERR(1, 316, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":318
 *         cdef double pphi = L
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']
 */
  __Pyx_TraceLine(318,0,__PYX_ERR(1, 318, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":319
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs['dSO']
 * 
 */
  __Pyx_TraceLine(319,0,__PYX_ERR(1, 319, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_a6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_a6 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":320
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(320,0,__PYX_ERR(1, 320, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_dSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 320, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_dSO = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":324
 * 
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M             # <<<<<<<<<<<<<<
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 */
  __Pyx_TraceLine(324,0,__PYX_ERR(1, 324, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->M;
  __pyx_v_M = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":325
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu             # <<<<<<<<<<<<<<
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 */
  __Pyx_TraceLine(325,0,__PYX_ERR(1, 325, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->nu;
  __pyx_v_nu = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":326
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1             # <<<<<<<<<<<<<<
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2
 */
  __Pyx_TraceLine(326,0,__PYX_ERR(1, 326, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_1;
  __pyx_v_X_1 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":327
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2             # <<<<<<<<<<<<<<
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1
 */
  __Pyx_TraceLine(327,0,__PYX_ERR(1, 327, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_2;
  __pyx_v_X_2 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":328
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2             # <<<<<<<<<<<<<<
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2
 */
  __Pyx_TraceLine(328,0,__PYX_ERR(1, 328, __pyx_L1_error))
  __pyx_v_x0 = pow(__pyx_v_r, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":329
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1             # <<<<<<<<<<<<<<
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2
 */
  __Pyx_TraceLine(329,0,__PYX_ERR(1, 329, __pyx_L1_error))
  __pyx_v_x1 = (__pyx_v_chi_1 * __pyx_v_X_1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":330
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2             # <<<<<<<<<<<<<<
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2
 */
  __Pyx_TraceLine(330,0,__PYX_ERR(1, 330, __pyx_L1_error))
  __pyx_v_x2 = (__pyx_v_chi_2 * __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":331
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2             # <<<<<<<<<<<<<<
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4
 */
  __Pyx_TraceLine(331,0,__PYX_ERR(1, 331, __pyx_L1_error))
  __pyx_v_x3 = (__pyx_v_x1 + __pyx_v_x2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":332
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2             # <<<<<<<<<<<<<<
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r
 */
  __Pyx_TraceLine(332,0,__PYX_ERR(1, 332, __pyx_L1_error))
  __pyx_v_x4 = pow(__pyx_v_x3, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":333
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4             # <<<<<<<<<<<<<<
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4
 */
  __Pyx_TraceLine(333,0,__PYX_ERR(1, 333, __pyx_L1_error))
  __pyx_v_x5 = (2.0 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":334
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r             # <<<<<<<<<<<<<<
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)
 */
  __Pyx_TraceLine(334,0,__PYX_ERR(1, 334, __pyx_L1_error))
  __pyx_v_x6 = (2.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":335
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4             # <<<<<<<<<<<<<<
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 */
  __Pyx_TraceLine(335,0,__PYX_ERR(1, 335, __pyx_L1_error))
  __pyx_v_x7 = (__pyx_v_x0 + __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":336
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)             # <<<<<<<<<<<<<<
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4
 */
  __Pyx_TraceLine(336,0,__PYX_ERR(1, 336, __pyx_L1_error))
  __pyx_v_x8 = (__pyx_v_r * ((-__pyx_v_x6) + __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":337
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x10 = r**4
 *         cdef double x11 = x10**(-1)
 */
  __Pyx_TraceLine(337,0,__PYX_ERR(1, 337, __pyx_L1_error))
  __pyx_v_x9 = pow((((2.0 * __pyx_v_x0) + __pyx_v_x5) + __pyx_v_x8), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":338
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4             # <<<<<<<<<<<<<<
 *         cdef double x11 = x10**(-1)
 *         cdef double x12 = 3.0*nu
 */
  __Pyx_TraceLine(338,0,__PYX_ERR(1, 338, __pyx_L1_error))
  __pyx_v_x10 = pow(__pyx_v_r, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":339
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4
 *         cdef double x11 = x10**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3
 */
  __Pyx_TraceLine(339,0,__PYX_ERR(1, 339, __pyx_L1_error))
  __pyx_v_x11 = pow(__pyx_v_x10, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":340
 *         cdef double x10 = r**4
 *         cdef double x11 = x10**(-1)
 *         cdef double x12 = 3.0*nu             # <<<<<<<<<<<<<<
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3
 */
  __Pyx_TraceLine(340,0,__PYX_ERR(1, 340, __pyx_L1_error))
  __pyx_v_x12 = (3.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":341
 *         cdef double x11 = x10**(-1)
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3             # <<<<<<<<<<<<<<
 *         cdef double x14 = r**3
 *         cdef double x15 = x14**(-1)
 */
  __Pyx_TraceLine(341,0,__PYX_ERR(1, 341, __pyx_L1_error))
  __pyx_v_x13 = (__pyx_v_pphi * __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":342
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3             # <<<<<<<<<<<<<<
 *         cdef double x15 = x14**(-1)
 *         cdef double x16 = x15*x4
 */
  __Pyx_TraceLine(342,0,__PYX_ERR(1, 342, __pyx_L1_error))
  __pyx_v_x14 = pow(__pyx_v_r, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":343
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3
 *         cdef double x15 = x14**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2
 */
  __Pyx_TraceLine(343,0,__PYX_ERR(1, 343, __pyx_L1_error))
  __pyx_v_x15 = pow(__pyx_v_x14, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":344
 *         cdef double x14 = r**3
 *         cdef double x15 = x14**(-1)
 *         cdef double x16 = x15*x4             # <<<<<<<<<<<<<<
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2
 */
  __Pyx_TraceLine(344,0,__PYX_ERR(1, 344, __pyx_L1_error))
  __pyx_v_x16 = (__pyx_v_x15 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":345
 *         cdef double x15 = x14**(-1)
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2             # <<<<<<<<<<<<<<
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18
 */
  __Pyx_TraceLine(345,0,__PYX_ERR(1, 345, __pyx_L1_error))
  __pyx_v_x17 = (__pyx_v_x1 - __pyx_v_x2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":346
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2             # <<<<<<<<<<<<<<
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19
 */
  __Pyx_TraceLine(346,0,__PYX_ERR(1, 346, __pyx_L1_error))
  __pyx_v_x18 = (__pyx_v_X_1 - __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":347
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18             # <<<<<<<<<<<<<<
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 */
  __Pyx_TraceLine(347,0,__PYX_ERR(1, 347, __pyx_L1_error))
  __pyx_v_x19 = (__pyx_v_x17 * __pyx_v_x18);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":348
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19             # <<<<<<<<<<<<<<
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3
 */
  __Pyx_TraceLine(348,0,__PYX_ERR(1, 348, __pyx_L1_error))
  __pyx_v_x20 = (__pyx_v_pphi * __pyx_v_x19);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":349
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 */
  __Pyx_TraceLine(349,0,__PYX_ERR(1, 349, __pyx_L1_error))
  __pyx_v_x21 = ((5.0 * __pyx_v_X_1) - (5.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":350
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3             # <<<<<<<<<<<<<<
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15
 */
  __Pyx_TraceLine(350,0,__PYX_ERR(1, 350, __pyx_L1_error))
  __pyx_v_x22 = (__pyx_v_x17 * __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":351
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4             # <<<<<<<<<<<<<<
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = x0**(-1)
 */
  __Pyx_TraceLine(351,0,__PYX_ERR(1, 351, __pyx_L1_error))
  __pyx_v_x23 = (((0.0416666666666667 * __pyx_v_x21) * __pyx_v_x22) - (0.25 * __pyx_v_x4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":352
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15             # <<<<<<<<<<<<<<
 *         cdef double x25 = x0**(-1)
 *         cdef double x26 = 0.71875*nu - 0.09375
 */
  __Pyx_TraceLine(352,0,__PYX_ERR(1, 352, __pyx_L1_error))
  __pyx_v_x24 = (2.0 * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":353
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = x0**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875
 */
  __Pyx_TraceLine(353,0,__PYX_ERR(1, 353, __pyx_L1_error))
  __pyx_v_x25 = pow(__pyx_v_x0, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":354
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = x0**(-1)
 *         cdef double x26 = 0.71875*nu - 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2
 */
  __Pyx_TraceLine(354,0,__PYX_ERR(1, 354, __pyx_L1_error))
  __pyx_v_x26 = ((0.71875 * __pyx_v_nu) - 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":355
 *         cdef double x25 = x0**(-1)
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875             # <<<<<<<<<<<<<<
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28
 */
  __Pyx_TraceLine(355,0,__PYX_ERR(1, 355, __pyx_L1_error))
  __pyx_v_x27 = ((-1.40625 * __pyx_v_nu) - 0.46875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":356
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2             # <<<<<<<<<<<<<<
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29
 */
  __Pyx_TraceLine(356,0,__PYX_ERR(1, 356, __pyx_L1_error))
  __pyx_v_x28 = pow(__pyx_v_pphi, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":357
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28             # <<<<<<<<<<<<<<
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2
 */
  __Pyx_TraceLine(357,0,__PYX_ERR(1, 357, __pyx_L1_error))
  __pyx_v_x29 = (__pyx_v_x15 * __pyx_v_x28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":358
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29             # <<<<<<<<<<<<<<
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 */
  __Pyx_TraceLine(358,0,__PYX_ERR(1, 358, __pyx_L1_error))
  __pyx_v_x30 = (2.0 * __pyx_v_x29);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":359
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2             # <<<<<<<<<<<<<<
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11
 */
  __Pyx_TraceLine(359,0,__PYX_ERR(1, 359, __pyx_L1_error))
  __pyx_v_x31 = pow(__pyx_v_nu, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":360
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33
 */
  __Pyx_TraceLine(360,0,__PYX_ERR(1, 360, __pyx_L1_error))
  __pyx_v_x32 = (((-2.0859375 * __pyx_v_nu) - (2.07161458333333 * __pyx_v_x31)) + 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":361
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11             # <<<<<<<<<<<<<<
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 */
  __Pyx_TraceLine(361,0,__PYX_ERR(1, 361, __pyx_L1_error))
  __pyx_v_x33 = (3.0 * __pyx_v_x11);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":362
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33             # <<<<<<<<<<<<<<
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4
 */
  __Pyx_TraceLine(362,0,__PYX_ERR(1, 362, __pyx_L1_error))
  __pyx_v_x34 = (__pyx_v_x28 * __pyx_v_x33);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":363
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5
 */
  __Pyx_TraceLine(363,0,__PYX_ERR(1, 363, __pyx_L1_error))
  __pyx_v_x35 = (((0.5859375 * __pyx_v_nu) + (1.34765625 * __pyx_v_x31)) + 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":364
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4             # <<<<<<<<<<<<<<
 *         cdef double x37 = r**5
 *         cdef double x38 = x37**(-1)
 */
  __Pyx_TraceLine(364,0,__PYX_ERR(1, 364, __pyx_L1_error))
  __pyx_v_x36 = pow(__pyx_v_pphi, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":365
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5             # <<<<<<<<<<<<<<
 *         cdef double x38 = x37**(-1)
 *         cdef double x39 = 4.0*x38
 */
  __Pyx_TraceLine(365,0,__PYX_ERR(1, 365, __pyx_L1_error))
  __pyx_v_x37 = pow(__pyx_v_r, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":366
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5
 *         cdef double x38 = x37**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39
 */
  __Pyx_TraceLine(366,0,__PYX_ERR(1, 366, __pyx_L1_error))
  __pyx_v_x38 = pow(__pyx_v_x37, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":367
 *         cdef double x37 = r**5
 *         cdef double x38 = x37**(-1)
 *         cdef double x39 = 4.0*x38             # <<<<<<<<<<<<<<
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375
 */
  __Pyx_TraceLine(367,0,__PYX_ERR(1, 367, __pyx_L1_error))
  __pyx_v_x39 = (4.0 * __pyx_v_x38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":368
 *         cdef double x38 = x37**(-1)
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39             # <<<<<<<<<<<<<<
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu
 */
  __Pyx_TraceLine(368,0,__PYX_ERR(1, 368, __pyx_L1_error))
  __pyx_v_x40 = (__pyx_v_x36 * __pyx_v_x39);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":369
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 */
  __Pyx_TraceLine(369,0,__PYX_ERR(1, 369, __pyx_L1_error))
  __pyx_v_x41 = ((0.34375 * __pyx_v_nu) + 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":370
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu             # <<<<<<<<<<<<<<
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 */
  __Pyx_TraceLine(370,0,__PYX_ERR(1, 370, __pyx_L1_error))
  __pyx_v_x42 = (0.46875 - (0.28125 * __pyx_v_nu));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":371
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15
 */
  __Pyx_TraceLine(371,0,__PYX_ERR(1, 371, __pyx_L1_error))
  __pyx_v_x43 = (((-0.2734375 * __pyx_v_nu) - (0.798177083333333 * __pyx_v_x31)) - 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":372
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4
 */
  __Pyx_TraceLine(372,0,__PYX_ERR(1, 372, __pyx_L1_error))
  __pyx_v_x44 = (((-0.3515625 * __pyx_v_nu) + (0.29296875 * __pyx_v_x31)) - 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":373
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15             # <<<<<<<<<<<<<<
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46
 */
  __Pyx_TraceLine(373,0,__PYX_ERR(1, 373, __pyx_L1_error))
  __pyx_v_x45 = ((__pyx_v_nu * __pyx_v_dSO) * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":374
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4             # <<<<<<<<<<<<<<
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25
 */
  __Pyx_TraceLine(374,0,__PYX_ERR(1, 374, __pyx_L1_error))
  __pyx_v_x46 = (__pyx_v_x25 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":375
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46             # <<<<<<<<<<<<<<
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)
 */
  __Pyx_TraceLine(375,0,__PYX_ERR(1, 375, __pyx_L1_error))
  __pyx_v_x47 = (0.0416666666666667 * __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":376
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25             # <<<<<<<<<<<<<<
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28
 */
  __Pyx_TraceLine(376,0,__PYX_ERR(1, 376, __pyx_L1_error))
  __pyx_v_x48 = (__pyx_v_x23 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":377
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36
 */
  __Pyx_TraceLine(377,0,__PYX_ERR(1, 377, __pyx_L1_error))
  __pyx_v_x49 = pow(__pyx_v_r, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":378
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28             # <<<<<<<<<<<<<<
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 */
  __Pyx_TraceLine(378,0,__PYX_ERR(1, 378, __pyx_L1_error))
  __pyx_v_x50 = (__pyx_v_x25 * __pyx_v_x28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":379
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36             # <<<<<<<<<<<<<<
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 */
  __Pyx_TraceLine(379,0,__PYX_ERR(1, 379, __pyx_L1_error))
  __pyx_v_x51 = (__pyx_v_x11 * __pyx_v_x36);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":380
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)             # <<<<<<<<<<<<<<
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4
 */
  __Pyx_TraceLine(380,0,__PYX_ERR(1, 380, __pyx_L1_error))
  __pyx_v_x52 = (__pyx_v_x3 * ((((((__pyx_v_x25 * (((-5.53125 * __pyx_v_nu) + (0.567708333333333 * __pyx_v_x31)) - 0.078125)) + (__pyx_v_x26 * __pyx_v_x49)) + (__pyx_v_x27 * __pyx_v_x50)) + (__pyx_v_x29 * __pyx_v_x32)) + (__pyx_v_x35 * __pyx_v_x51)) + 1.75));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":381
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)             # <<<<<<<<<<<<<<
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)
 */
  __Pyx_TraceLine(381,0,__PYX_ERR(1, 381, __pyx_L1_error))
  __pyx_v_x53 = (__pyx_v_x19 * ((((((__pyx_v_x25 * (((-0.03125 * __pyx_v_nu) + (0.536458333333333 * __pyx_v_x31)) + 0.078125)) + (__pyx_v_x29 * __pyx_v_x43)) + (__pyx_v_x41 * __pyx_v_x49)) + (__pyx_v_x42 * __pyx_v_x50)) + (__pyx_v_x44 * __pyx_v_x51)) + 0.25));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":382
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4             # <<<<<<<<<<<<<<
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55
 */
  __Pyx_TraceLine(382,0,__PYX_ERR(1, 382, __pyx_L1_error))
  __pyx_v_x54 = pow(__pyx_v_prst, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":383
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)             # <<<<<<<<<<<<<<
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6
 */
  __Pyx_TraceLine(383,0,__PYX_ERR(1, 383, __pyx_L1_error))
  __pyx_v_x55 = pow(__pyx_v_r, -4.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":384
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55             # <<<<<<<<<<<<<<
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)
 */
  __Pyx_TraceLine(384,0,__PYX_ERR(1, 384, __pyx_L1_error))
  __pyx_v_x56 = (__pyx_v_nu * __pyx_v_x55);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":385
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6             # <<<<<<<<<<<<<<
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58
 */
  __Pyx_TraceLine(385,0,__PYX_ERR(1, 385, __pyx_L1_error))
  __pyx_v_x57 = pow(__pyx_v_prst, 6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":386
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)             # <<<<<<<<<<<<<<
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)
 */
  __Pyx_TraceLine(386,0,__PYX_ERR(1, 386, __pyx_L1_error))
  __pyx_v_x58 = pow(__pyx_v_r, -3.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":387
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58             # <<<<<<<<<<<<<<
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8
 */
  __Pyx_TraceLine(387,0,__PYX_ERR(1, 387, __pyx_L1_error))
  __pyx_v_x59 = (__pyx_v_nu * __pyx_v_x58);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":388
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)             # <<<<<<<<<<<<<<
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61
 */
  __Pyx_TraceLine(388,0,__PYX_ERR(1, 388, __pyx_L1_error))
  __pyx_v_x60 = pow(__pyx_v_r, -2.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":389
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8             # <<<<<<<<<<<<<<
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49
 */
  __Pyx_TraceLine(389,0,__PYX_ERR(1, 389, __pyx_L1_error))
  __pyx_v_x61 = pow(__pyx_v_prst, 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":390
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61             # <<<<<<<<<<<<<<
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61
 */
  __Pyx_TraceLine(390,0,__PYX_ERR(1, 390, __pyx_L1_error))
  __pyx_v_x62 = (__pyx_v_nu * __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":391
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49             # <<<<<<<<<<<<<<
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31
 */
  __Pyx_TraceLine(391,0,__PYX_ERR(1, 391, __pyx_L1_error))
  __pyx_v_x63 = (__pyx_v_nu * __pyx_v_x49);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":392
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61             # <<<<<<<<<<<<<<
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65
 */
  __Pyx_TraceLine(392,0,__PYX_ERR(1, 392, __pyx_L1_error))
  __pyx_v_x64 = (0.121954868780449 * __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":393
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31             # <<<<<<<<<<<<<<
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3
 */
  __Pyx_TraceLine(393,0,__PYX_ERR(1, 393, __pyx_L1_error))
  __pyx_v_x65 = ((8.0 * __pyx_v_nu) - (6.0 * __pyx_v_x31));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":394
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65             # <<<<<<<<<<<<<<
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 */
  __Pyx_TraceLine(394,0,__PYX_ERR(1, 394, __pyx_L1_error))
  __pyx_v_x66 = (__pyx_v_x25 * __pyx_v_x65);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":395
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3             # <<<<<<<<<<<<<<
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54
 */
  __Pyx_TraceLine(395,0,__PYX_ERR(1, 395, __pyx_L1_error))
  __pyx_v_x67 = pow(__pyx_v_nu, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":396
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67             # <<<<<<<<<<<<<<
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 */
  __Pyx_TraceLine(396,0,__PYX_ERR(1, 396, __pyx_L1_error))
  __pyx_v_x68 = (((92.7110442849544 * __pyx_v_nu) - (131.0 * __pyx_v_x31)) + (10.0 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":397
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54             # <<<<<<<<<<<<<<
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70
 */
  __Pyx_TraceLine(397,0,__PYX_ERR(1, 397, __pyx_L1_error))
  __pyx_v_x69 = (__pyx_v_x15 * __pyx_v_x54);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":398
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67             # <<<<<<<<<<<<<<
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4
 */
  __Pyx_TraceLine(398,0,__PYX_ERR(1, 398, __pyx_L1_error))
  __pyx_v_x70 = (((-2.78300763695006 * __pyx_v_nu) - (5.4 * __pyx_v_x31)) + (6.0 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":399
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70             # <<<<<<<<<<<<<<
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 */
  __Pyx_TraceLine(399,0,__PYX_ERR(1, 399, __pyx_L1_error))
  __pyx_v_x71 = (__pyx_v_x25 * __pyx_v_x70);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":400
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4             # <<<<<<<<<<<<<<
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57
 */
  __Pyx_TraceLine(400,0,__PYX_ERR(1, 400, __pyx_L1_error))
  __pyx_v_x72 = pow(__pyx_v_nu, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":401
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72             # <<<<<<<<<<<<<<
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 */
  __Pyx_TraceLine(401,0,__PYX_ERR(1, 401, __pyx_L1_error))
  __pyx_v_x73 = ((((-33.9782122170436 * __pyx_v_nu) - (89.5298327361234 * __pyx_v_x31)) + (188.0 * __pyx_v_x67)) - (14.0 * __pyx_v_x72));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":402
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57             # <<<<<<<<<<<<<<
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75
 */
  __Pyx_TraceLine(402,0,__PYX_ERR(1, 402, __pyx_L1_error))
  __pyx_v_x74 = (__pyx_v_x15 * __pyx_v_x57);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":403
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72             # <<<<<<<<<<<<<<
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)
 */
  __Pyx_TraceLine(403,0,__PYX_ERR(1, 403, __pyx_L1_error))
  __pyx_v_x75 = ((((1.38977750996128 * __pyx_v_nu) + (3.33842023648322 * __pyx_v_x31)) + (3.42857142857143 * __pyx_v_x67)) - (6.0 * __pyx_v_x72));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":404
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75             # <<<<<<<<<<<<<<
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 */
  __Pyx_TraceLine(404,0,__PYX_ERR(1, 404, __pyx_L1_error))
  __pyx_v_x76 = (__pyx_v_x61 * __pyx_v_x75);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":405
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)             # <<<<<<<<<<<<<<
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54
 */
  __Pyx_TraceLine(405,0,__PYX_ERR(1, 405, __pyx_L1_error))
  __pyx_v_x77 = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":406
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67             # <<<<<<<<<<<<<<
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0
 */
  __Pyx_TraceLine(406,0,__PYX_ERR(1, 406, __pyx_L1_error))
  __pyx_v_x78 = (((__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_x77))) + (__pyx_v_x31 * ((118.4 * __pyx_v_x77) - 1796.13660498019))) + (602.318540416564 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":407
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54             # <<<<<<<<<<<<<<
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80
 */
  __Pyx_TraceLine(407,0,__PYX_ERR(1, 407, __pyx_L1_error))
  __pyx_v_x79 = (__pyx_v_x11 * __pyx_v_x54);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":408
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4
 */
  __Pyx_TraceLine(408,0,__PYX_ERR(1, 408, __pyx_L1_error))
  __pyx_v_x80 = (__pyx_v_r + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":409
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80             # <<<<<<<<<<<<<<
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82
 */
  __Pyx_TraceLine(409,0,__PYX_ERR(1, 409, __pyx_L1_error))
  __pyx_v_x81 = (__pyx_v_x4 * __pyx_v_x80);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":410
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4             # <<<<<<<<<<<<<<
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = x83**(-1)
 */
  __Pyx_TraceLine(410,0,__PYX_ERR(1, 410, __pyx_L1_error))
  __pyx_v_x82 = (__pyx_v_r * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":411
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82             # <<<<<<<<<<<<<<
 *         cdef double x84 = x83**(-1)
 *         cdef double x85 = x28*x49*x84
 */
  __Pyx_TraceLine(411,0,__PYX_ERR(1, 411, __pyx_L1_error))
  __pyx_v_x83 = (__pyx_v_x10 + (__pyx_v_x80 * __pyx_v_x82));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":412
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = x83**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)
 */
  __Pyx_TraceLine(412,0,__PYX_ERR(1, 412, __pyx_L1_error))
  __pyx_v_x84 = pow(__pyx_v_x83, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":413
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = x83**(-1)
 *         cdef double x85 = x28*x49*x84             # <<<<<<<<<<<<<<
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4
 */
  __Pyx_TraceLine(413,0,__PYX_ERR(1, 413, __pyx_L1_error))
  __pyx_v_x85 = ((__pyx_v_x28 * __pyx_v_x49) * __pyx_v_x84);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":414
 *         cdef double x84 = x83**(-1)
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)             # <<<<<<<<<<<<<<
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu
 */
  __Pyx_TraceLine(414,0,__PYX_ERR(1, 414, __pyx_L1_error))
  __pyx_v_x86 = pow(__pyx_v_r, -13.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":415
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4             # <<<<<<<<<<<<<<
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0
 */
  __Pyx_TraceLine(415,0,__PYX_ERR(1, 415, __pyx_L1_error))
  __pyx_v_x87 = pow(__pyx_v_x7, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":416
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu             # <<<<<<<<<<<<<<
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 */
  __Pyx_TraceLine(416,0,__PYX_ERR(1, 416, __pyx_L1_error))
  __pyx_v_x88 = (756.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":417
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0             # <<<<<<<<<<<<<<
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2
 */
  __Pyx_TraceLine(417,0,__PYX_ERR(1, 417, __pyx_L1_error))
  __pyx_v_x89 = (((336.0 * __pyx_v_r) + __pyx_v_x88) + 407.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":418
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0             # <<<<<<<<<<<<<<
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91
 */
  __Pyx_TraceLine(418,0,__PYX_ERR(1, 418, __pyx_L1_error))
  __pyx_v_x90 = (((((((2048.0 * __pyx_v_nu) * __pyx_v_x77) * __pyx_v_x89) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) - ((7.0 * __pyx_v_r) * (((938918.400156317 * __pyx_v_nu) - (185763.092693281 * __pyx_v_x31)) - 245760.0))) - (5416406.59541186 * __pyx_v_x31)) - 3440640.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":419
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2             # <<<<<<<<<<<<<<
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 */
  __Pyx_TraceLine(419,0,__PYX_ERR(1, 419, __pyx_L1_error))
  __pyx_v_x91 = pow(__pyx_v_x77, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":420
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91             # <<<<<<<<<<<<<<
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 */
  __Pyx_TraceLine(420,0,__PYX_ERR(1, 420, __pyx_L1_error))
  __pyx_v_x92 = (__pyx_v_x31 * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":421
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)             # <<<<<<<<<<<<<<
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0
 */
  __Pyx_TraceLine(421,0,__PYX_ERR(1, 421, __pyx_L1_error))
  __pyx_v_x93 = (__pyx_v_x67 * (((-163683964.822551 * __pyx_v_r) - (17833256.898555 * __pyx_v_x0)) - 1188987459.03162));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":422
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)             # <<<<<<<<<<<<<<
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0
 */
  __Pyx_TraceLine(422,0,__PYX_ERR(1, 422, __pyx_L1_error))
  __pyx_v_x94 = (__pyx_v_x31 * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (122635399361.987 * __pyx_v_r)) + (2064783811.32587 * __pyx_v_x0)) - (3089250703.76879 * __pyx_v_x10)) - (6178501407.53758 * __pyx_v_x14)) + (1426660551.8844 * __pyx_v_x37)) + 276057889687.011));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":423
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96
 */
  __Pyx_TraceLine(423,0,__PYX_ERR(1, 423, __pyx_L1_error))
  __pyx_v_x95 = ((588.0 * __pyx_v_nu) + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":424
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 */
  __Pyx_TraceLine(424,0,__PYX_ERR(1, 424, __pyx_L1_error))
  __pyx_v_x96 = (__pyx_v_x88 + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":425
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96             # <<<<<<<<<<<<<<
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77
 */
  __Pyx_TraceLine(425,0,__PYX_ERR(1, 425, __pyx_L1_error))
  __pyx_v_x97 = (__pyx_v_x14 * __pyx_v_x96);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":426
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0             # <<<<<<<<<<<<<<
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99
 */
  __Pyx_TraceLine(426,0,__PYX_ERR(1, 426, __pyx_L1_error))
  __pyx_v_x98 = ((((((((-38842241.4769507 * __pyx_v_nu) + ((240.0 * __pyx_v_r) * (((-7466.27061066206 * __pyx_v_nu) - (3024.0 * __pyx_v_x31)) + 17264.0))) + ((1920.0 * __pyx_v_x0) * __pyx_v_x95)) + ((480.0 * __pyx_v_x10) * __pyx_v_x96)) - (1882456.23663972 * __pyx_v_x31)) + (161280.0 * __pyx_v_x37)) + (960.0 * __pyx_v_x97)) + 13447680.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":427
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77             # <<<<<<<<<<<<<<
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r
 */
  __Pyx_TraceLine(427,0,__PYX_ERR(1, 427, __pyx_L1_error))
  __pyx_v_x99 = (__pyx_v_nu * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":428
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99             # <<<<<<<<<<<<<<
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 */
  __Pyx_TraceLine(428,0,__PYX_ERR(1, 428, __pyx_L1_error))
  __pyx_v_x100 = (__pyx_v_x98 * __pyx_v_x99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":429
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r             # <<<<<<<<<<<<<<
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6
 */
  __Pyx_TraceLine(429,0,__PYX_ERR(1, 429, __pyx_L1_error))
  __pyx_v_x101 = (8.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":430
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0             # <<<<<<<<<<<<<<
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r
 */
  __Pyx_TraceLine(430,0,__PYX_ERR(1, 430, __pyx_L1_error))
  __pyx_v_x102 = ((((4.0 * __pyx_v_x0) + __pyx_v_x101) + (2.0 * __pyx_v_x14)) + 16.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":431
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6             # <<<<<<<<<<<<<<
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r
 */
  __Pyx_TraceLine(431,0,__PYX_ERR(1, 431, __pyx_L1_error))
  __pyx_v_x103 = (7680.0 * __pyx_v_a6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":432
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r             # <<<<<<<<<<<<<<
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r
 */
  __Pyx_TraceLine(432,0,__PYX_ERR(1, 432, __pyx_L1_error))
  __pyx_v_x104 = (128.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":433
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r             # <<<<<<<<<<<<<<
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r
 */
  __Pyx_TraceLine(433,0,__PYX_ERR(1, 433, __pyx_L1_error))
  __pyx_v_x105 = (7704.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":434
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r             # <<<<<<<<<<<<<<
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 */
  __Pyx_TraceLine(434,0,__PYX_ERR(1, 434, __pyx_L1_error))
  __pyx_v_x106 = (148.04406601634 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":435
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r             # <<<<<<<<<<<<<<
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 */
  __Pyx_TraceLine(435,0,__PYX_ERR(1, 435, __pyx_L1_error))
  __pyx_v_x107 = (113485.217444961 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":436
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))             # <<<<<<<<<<<<<<
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90
 */
  __Pyx_TraceLine(436,0,__PYX_ERR(1, 436, __pyx_L1_error))
  __pyx_v_x108 = (__pyx_v_nu * ((((__pyx_v_x103 * (__pyx_v_x10 + __pyx_v_x102)) + (__pyx_v_x104 * (((((13218.7851094412 * __pyx_v_r) + (8529.39255472061 * __pyx_v_x0)) - (6852.34813868015 * __pyx_v_x10)) + (4264.6962773603 * __pyx_v_x14)) - 33722.4297811176))) + (__pyx_v_x106 * (((((3852.0 * __pyx_v_x0) + (349.0 * __pyx_v_x10)) + __pyx_v_x105) + (1926.0 * __pyx_v_x14)) + 36400.0))) + (__pyx_v_x107 * ((-__pyx_v_x10) + __pyx_v_x102))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":437
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 */
  __Pyx_TraceLine(437,0,__PYX_ERR(1, 437, __pyx_L1_error))
  __pyx_v_x109 = pow((((((((32768.0 * __pyx_v_x100) + (53760.0 * __pyx_v_x108)) + (13212057600.0 * __pyx_v_x37)) + (241555486248.807 * __pyx_v_x72)) + (67645734912.0 * __pyx_v_x92)) + (1120.0 * __pyx_v_x93)) + (7.0 * __pyx_v_x94)), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":438
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90             # <<<<<<<<<<<<<<
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)
 */
  __Pyx_TraceLine(438,0,__PYX_ERR(1, 438, __pyx_L1_error))
  __pyx_v_x110 = ((__pyx_v_x10 * __pyx_v_x109) * __pyx_v_x90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":439
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46             # <<<<<<<<<<<<<<
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91
 */
  __Pyx_TraceLine(439,0,__PYX_ERR(1, 439, __pyx_L1_error))
  __pyx_v_x111 = (__pyx_v_x110 + (0.000130208333333333 * __pyx_v_x46));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":440
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)             # <<<<<<<<<<<<<<
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 */
  __Pyx_TraceLine(440,0,__PYX_ERR(1, 440, __pyx_L1_error))
  __pyx_v_x112 = pow(__pyx_v_x111, -4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":441
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91             # <<<<<<<<<<<<<<
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114
 */
  __Pyx_TraceLine(441,0,__PYX_ERR(1, 441, __pyx_L1_error))
  __pyx_v_x113 = (__pyx_v_r * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":442
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913             # <<<<<<<<<<<<<<
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 */
  __Pyx_TraceLine(442,0,__PYX_ERR(1, 442, __pyx_L1_error))
  __pyx_v_x114 = (((-630116198.873299 * __pyx_v_nu) - (197773496.793534 * __pyx_v_x31)) + 5805304367.87913);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":443
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114             # <<<<<<<<<<<<<<
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14
 */
  __Pyx_TraceLine(443,0,__PYX_ERR(1, 443, __pyx_L1_error))
  __pyx_v_x115 = (__pyx_v_x0 * __pyx_v_x114);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":444
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329             # <<<<<<<<<<<<<<
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 */
  __Pyx_TraceLine(444,0,__PYX_ERR(1, 444, __pyx_L1_error))
  __pyx_v_x116 = (((-2675575.66847905 * __pyx_v_nu) - (138240.0 * __pyx_v_x31)) - 5278341.3229329);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":445
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14             # <<<<<<<<<<<<<<
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 */
  __Pyx_TraceLine(445,0,__PYX_ERR(1, 445, __pyx_L1_error))
  __pyx_v_x117 = (__pyx_v_x116 * __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":446
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)             # <<<<<<<<<<<<<<
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119
 */
  __Pyx_TraceLine(446,0,__PYX_ERR(1, 446, __pyx_L1_error))
  __pyx_v_x118 = (__pyx_v_nu * ((((-2510664218.28128 * __pyx_v_nu) - (42636451.6032331 * __pyx_v_x31)) + (14515200.0 * __pyx_v_x67)) + 1002013764.01019));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":447
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0             # <<<<<<<<<<<<<<
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0
 */
  __Pyx_TraceLine(447,0,__PYX_ERR(1, 447, __pyx_L1_error))
  __pyx_v_x119 = (((((43393301259014.8 * __pyx_v_nu) + (43133561885859.3 * __pyx_v_x31)) + (5927865218923.02 * __pyx_v_x67)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":448
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119             # <<<<<<<<<<<<<<
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121
 */
  __Pyx_TraceLine(448,0,__PYX_ERR(1, 448, __pyx_L1_error))
  __pyx_v_x120 = (__pyx_v_r * __pyx_v_x119);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":449
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0             # <<<<<<<<<<<<<<
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 */
  __Pyx_TraceLine(449,0,__PYX_ERR(1, 449, __pyx_L1_error))
  __pyx_v_x121 = ((14700.0 * __pyx_v_nu) + 42911.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":450
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121             # <<<<<<<<<<<<<<
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77
 */
  __Pyx_TraceLine(450,0,__PYX_ERR(1, 450, __pyx_L1_error))
  __pyx_v_x122 = (283115520.0 * __pyx_v_x121);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":451
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14             # <<<<<<<<<<<<<<
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 */
  __Pyx_TraceLine(451,0,__PYX_ERR(1, 451, __pyx_L1_error))
  __pyx_v_x123 = (((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + ((49152.0 * __pyx_v_r) * (((409207698.136075 * __pyx_v_nu) + (102574080.0 * __pyx_v_x31)) - 2119671837.36038))) + (__pyx_v_x0 * __pyx_v_x122)) + (879923036160.0 * __pyx_v_x14));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":452
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77             # <<<<<<<<<<<<<<
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r
 */
  __Pyx_TraceLine(452,0,__PYX_ERR(1, 452, __pyx_L1_error))
  __pyx_v_x124 = (__pyx_v_x123 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":453
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2             # <<<<<<<<<<<<<<
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0
 */
  __Pyx_TraceLine(453,0,__PYX_ERR(1, 453, __pyx_L1_error))
  __pyx_v_x125 = pow((((((__pyx_v_x113 - (1.59227685093395e-9 * __pyx_v_x115)) - (1.67189069348064e-7 * __pyx_v_x117)) + (9.55366110560367e-9 * __pyx_v_x118)) + (1.72773095804465e-13 * __pyx_v_x120)) + (1.72773095804465e-13 * __pyx_v_x124)), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":454
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r             # <<<<<<<<<<<<<<
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31
 */
  __Pyx_TraceLine(454,0,__PYX_ERR(1, 454, __pyx_L1_error))
  __pyx_v_x126 = (__pyx_v_nu * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":455
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0             # <<<<<<<<<<<<<<
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121
 */
  __Pyx_TraceLine(455,0,__PYX_ERR(1, 455, __pyx_L1_error))
  __pyx_v_x127 = (__pyx_v_nu * __pyx_v_x0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":456
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31             # <<<<<<<<<<<<<<
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31
 */
  __Pyx_TraceLine(456,0,__PYX_ERR(1, 456, __pyx_L1_error))
  __pyx_v_x128 = (__pyx_v_r * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":457
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121             # <<<<<<<<<<<<<<
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 */
  __Pyx_TraceLine(457,0,__PYX_ERR(1, 457, __pyx_L1_error))
  __pyx_v_x129 = (__pyx_v_r * __pyx_v_x121);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":458
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31             # <<<<<<<<<<<<<<
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 */
  __Pyx_TraceLine(458,0,__PYX_ERR(1, 458, __pyx_L1_error))
  __pyx_v_x130 = (__pyx_v_x0 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":459
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0             # <<<<<<<<<<<<<<
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77
 */
  __Pyx_TraceLine(459,0,__PYX_ERR(1, 459, __pyx_L1_error))
  __pyx_v_x131 = ((5041721180160.0 * __pyx_v_x31) - 104186110149937.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":460
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131             # <<<<<<<<<<<<<<
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 */
  __Pyx_TraceLine(460,0,__PYX_ERR(1, 460, __pyx_L1_error))
  __pyx_v_x132 = ((((-25392914995744.3 * __pyx_v_nu) - (__pyx_v_r * __pyx_v_x122)) - (879923036160.0 * __pyx_v_x0)) - __pyx_v_x131);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":461
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77             # <<<<<<<<<<<<<<
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)
 */
  __Pyx_TraceLine(461,0,__PYX_ERR(1, 461, __pyx_L1_error))
  __pyx_v_x133 = (__pyx_v_x132 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":462
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1             # <<<<<<<<<<<<<<
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31
 */
  __Pyx_TraceLine(462,0,__PYX_ERR(1, 462, __pyx_L1_error))
  __pyx_v_x134 = (((((((((((((-0.0438084424460039 * __pyx_v_nu) - (0.143521050466841 * __pyx_v_r)) + (0.0185696317637669 * __pyx_v_x0)) + (0.0385795738434214 * __pyx_v_x126)) + (0.00941289164152486 * __pyx_v_x127)) + (0.00662650629087394 * __pyx_v_x128)) - (1.18824456940711e-6 * __pyx_v_x129)) + (0.000486339502879429 * __pyx_v_x130)) - (3.63558293513537e-15 * __pyx_v_x133)) + (0.291062041428379 * __pyx_v_x31)) + (0.0244692826489756 * __pyx_v_x67)) + (0.0210425293255724 * __pyx_v_x91)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":463
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2
 */
  __Pyx_TraceLine(463,0,__PYX_ERR(1, 463, __pyx_L1_error))
  __pyx_v_x135 = pow(__pyx_v_x134, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":464
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31             # <<<<<<<<<<<<<<
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 */
  __Pyx_TraceLine(464,0,__PYX_ERR(1, 464, __pyx_L1_error))
  __pyx_v_x136 = (4.0 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":465
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2             # <<<<<<<<<<<<<<
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 */
  __Pyx_TraceLine(465,0,__PYX_ERR(1, 465, __pyx_L1_error))
  __pyx_v_x137 = pow(__pyx_v_x17, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":466
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)             # <<<<<<<<<<<<<<
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2
 */
  __Pyx_TraceLine(466,0,__PYX_ERR(1, 466, __pyx_L1_error))
  __pyx_v_x138 = ((((-0.46875 * __pyx_v_x137) * (((-5.0 * __pyx_v_nu) + __pyx_v_x136) + 1.0)) + ((((0.0625 * __pyx_v_x17) * __pyx_v_x21) * __pyx_v_x3) * ((18.0 * __pyx_v_nu) - 1.0))) - ((0.15625 * __pyx_v_x4) * (((-33.0 * __pyx_v_nu) + (32.0 * __pyx_v_x31)) - 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":467
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87             # <<<<<<<<<<<<<<
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2
 */
  __Pyx_TraceLine(467,0,__PYX_ERR(1, 467, __pyx_L1_error))
  __pyx_v_x139 = (((((__pyx_v_x112 * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x54) * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":468
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2             # <<<<<<<<<<<<<<
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)
 */
  __Pyx_TraceLine(468,0,__PYX_ERR(1, 468, __pyx_L1_error))
  __pyx_v_x140 = pow(__pyx_v_x7, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":469
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2             # <<<<<<<<<<<<<<
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31
 */
  __Pyx_TraceLine(469,0,__PYX_ERR(1, 469, __pyx_L1_error))
  __pyx_v_x141 = pow(__pyx_v_prst, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":470
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91
 */
  __Pyx_TraceLine(470,0,__PYX_ERR(1, 470, __pyx_L1_error))
  __pyx_v_x142 = pow(__pyx_v_x111, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":471
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31             # <<<<<<<<<<<<<<
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 */
  __Pyx_TraceLine(471,0,__PYX_ERR(1, 471, __pyx_L1_error))
  __pyx_v_x143 = (1822680546449.21 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":472
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91             # <<<<<<<<<<<<<<
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = x145**(-1)
 */
  __Pyx_TraceLine(472,0,__PYX_ERR(1, 472, __pyx_L1_error))
  __pyx_v_x144 = (5787938193408.0 * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":473
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0             # <<<<<<<<<<<<<<
 *         cdef double x146 = x145**(-1)
 *         cdef double x147 = 0.0625*x137
 */
  __Pyx_TraceLine(473,0,__PYX_ERR(1, 473, __pyx_L1_error))
  __pyx_v_x145 = (((((((((((((-12049908701745.2 * __pyx_v_nu) + (__pyx_v_r * __pyx_v_x143)) - (39476764256925.6 * __pyx_v_r)) + (5107745331375.71 * __pyx_v_x0)) + (10611661054566.2 * __pyx_v_x126)) + (2589101062873.81 * __pyx_v_x127)) - (326837426.241486 * __pyx_v_x129)) + (133772083200.0 * __pyx_v_x130)) - __pyx_v_x133) + __pyx_v_x144) + (80059249540278.2 * __pyx_v_x31)) + (6730497718123.02 * __pyx_v_x67)) + 275059053208689.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":474
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = x145**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22
 */
  __Pyx_TraceLine(474,0,__PYX_ERR(1, 474, __pyx_L1_error))
  __pyx_v_x146 = pow(__pyx_v_x145, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":475
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = x145**(-1)
 *         cdef double x147 = 0.0625*x137             # <<<<<<<<<<<<<<
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0
 */
  __Pyx_TraceLine(475,0,__PYX_ERR(1, 475, __pyx_L1_error))
  __pyx_v_x147 = (0.0625 * __pyx_v_x137);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":476
 *         cdef double x146 = x145**(-1)
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22             # <<<<<<<<<<<<<<
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4
 */
  __Pyx_TraceLine(476,0,__PYX_ERR(1, 476, __pyx_L1_error))
  __pyx_v_x148 = (0.125 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":477
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0             # <<<<<<<<<<<<<<
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 */
  __Pyx_TraceLine(477,0,__PYX_ERR(1, 477, __pyx_L1_error))
  __pyx_v_x149 = ((-1171.0 * __pyx_v_nu) - 861.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":478
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4             # <<<<<<<<<<<<<<
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22
 */
  __Pyx_TraceLine(478,0,__PYX_ERR(1, 478, __pyx_L1_error))
  __pyx_v_x150 = (0.015625 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":479
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)             # <<<<<<<<<<<<<<
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 */
  __Pyx_TraceLine(479,0,__PYX_ERR(1, 479, __pyx_L1_error))
  __pyx_v_x151 = (__pyx_v_x137 * (((115.0 * __pyx_v_nu) + __pyx_v_x136) - 37.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":480
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22             # <<<<<<<<<<<<<<
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 */
  __Pyx_TraceLine(480,0,__PYX_ERR(1, 480, __pyx_L1_error))
  __pyx_v_x152 = (0.03125 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":481
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)             # <<<<<<<<<<<<<<
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = x154**(-1)
 */
  __Pyx_TraceLine(481,0,__PYX_ERR(1, 481, __pyx_L1_error))
  __pyx_v_x153 = (__pyx_v_x18 * ((26.0 * __pyx_v_nu) + 449.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":482
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124             # <<<<<<<<<<<<<<
 *         cdef double x155 = x154**(-1)
 *         cdef double x156 = x145*x155*x37
 */
  __Pyx_TraceLine(482,0,__PYX_ERR(1, 482, __pyx_L1_error))
  __pyx_v_x154 = ((((((5787938193408.0 * __pyx_v_x113) - (9216.0 * __pyx_v_x115)) - (967680.0 * __pyx_v_x117)) + (55296.0 * __pyx_v_x118)) + __pyx_v_x120) + __pyx_v_x124);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":483
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = x154**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90
 */
  __Pyx_TraceLine(483,0,__PYX_ERR(1, 483, __pyx_L1_error))
  __pyx_v_x155 = pow(__pyx_v_x154, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":484
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = x154**(-1)
 *         cdef double x156 = x145*x155*x37             # <<<<<<<<<<<<<<
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 */
  __Pyx_TraceLine(484,0,__PYX_ERR(1, 484, __pyx_L1_error))
  __pyx_v_x156 = ((__pyx_v_x145 * __pyx_v_x155) * __pyx_v_x37);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":485
 *         cdef double x155 = x154**(-1)
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90             # <<<<<<<<<<<<<<
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 */
  __Pyx_TraceLine(485,0,__PYX_ERR(1, 485, __pyx_L1_error))
  __pyx_v_x157 = (__pyx_v_x109 * __pyx_v_x90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":486
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46             # <<<<<<<<<<<<<<
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 */
  __Pyx_TraceLine(486,0,__PYX_ERR(1, 486, __pyx_L1_error))
  __pyx_v_x158 = ((((__pyx_v_x11 * (((__pyx_v_x149 * __pyx_v_x150) + (0.015625 * __pyx_v_x151)) + (__pyx_v_x152 * __pyx_v_x153))) + (__pyx_v_x15 * (((__pyx_v_x147 * ((12.0 * __pyx_v_nu) - 3.0)) + (__pyx_v_x148 * ((-21.0 * __pyx_v_X_1) + (21.0 * __pyx_v_X_2)))) + (__pyx_v_x4 * (__pyx_v_x12 + 2.8125))))) + ((7680.0 * __pyx_v_x156) * __pyx_v_x157)) + __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":487
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158             # <<<<<<<<<<<<<<
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 */
  __Pyx_TraceLine(487,0,__PYX_ERR(1, 487, __pyx_L1_error))
  __pyx_v_x159 = (((((__pyx_v_x140 * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x158);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":488
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = x161**(-1)
 */
  __Pyx_TraceLine(488,0,__PYX_ERR(1, 488, __pyx_L1_error))
  __pyx_v_x160 = ((((((((((((((((1.27277314139085e-19 * __pyx_v_x139) * __pyx_v_x86) + ((1.69542100694444e-8 * __pyx_v_x159) * __pyx_v_x38)) + (__pyx_v_x25 * __pyx_v_x76)) + __pyx_v_x50) + ((147.443752990146 * __pyx_v_x54) * __pyx_v_x56)) + (__pyx_v_x54 * __pyx_v_x66)) - ((11.3175085791863 * __pyx_v_x57) * __pyx_v_x59)) + (__pyx_v_x57 * __pyx_v_x71)) + ((1.48275342024365 * __pyx_v_x60) * __pyx_v_x62)) + (__pyx_v_x63 * __pyx_v_x64)) + (__pyx_v_x68 * __pyx_v_x69)) + (__pyx_v_x73 * __pyx_v_x74)) + (__pyx_v_x78 * __pyx_v_x79)) - (__pyx_v_x81 * __pyx_v_x85)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":489
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x162 = x161**(-1)
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 */
  __Pyx_TraceLine(489,0,__PYX_ERR(1, 489, __pyx_L1_error))
  __pyx_v_x161 = ((__pyx_v_x46 * ((2.0 * __pyx_v_x49) + 1.0)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":490
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = x161**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22
 */
  __Pyx_TraceLine(490,0,__PYX_ERR(1, 490, __pyx_L1_error))
  __pyx_v_x162 = pow(__pyx_v_x161, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":491
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = x161**(-1)
 *         cdef double x163 = x137*(4.0*nu + 1.0)             # <<<<<<<<<<<<<<
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 */
  __Pyx_TraceLine(491,0,__PYX_ERR(1, 491, __pyx_L1_error))
  __pyx_v_x163 = (__pyx_v_x137 * ((4.0 * __pyx_v_nu) + 1.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":492
 *         cdef double x162 = x161**(-1)
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22             # <<<<<<<<<<<<<<
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 */
  __Pyx_TraceLine(492,0,__PYX_ERR(1, 492, __pyx_L1_error))
  __pyx_v_x164 = ((-__pyx_v_x21) * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":493
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)             # <<<<<<<<<<<<<<
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 */
  __Pyx_TraceLine(493,0,__PYX_ERR(1, 493, __pyx_L1_error))
  __pyx_v_x165 = (__pyx_v_x137 * (((-27.0 * __pyx_v_nu) + (28.0 * __pyx_v_x31)) - 3.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":494
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)             # <<<<<<<<<<<<<<
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167
 */
  __Pyx_TraceLine(494,0,__PYX_ERR(1, 494, __pyx_L1_error))
  __pyx_v_x166 = (__pyx_v_x152 * ((-39.0 * __pyx_v_X_1) + (39.0 * __pyx_v_X_2)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":495
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46             # <<<<<<<<<<<<<<
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)
 */
  __Pyx_TraceLine(495,0,__PYX_ERR(1, 495, __pyx_L1_error))
  __pyx_v_x167 = ((((__pyx_v_x11 * (((0.125 * __pyx_v_x163) + (0.25 * __pyx_v_x164)) + (1.125 * __pyx_v_x4))) + (7680.0 * __pyx_v_x110)) + (__pyx_v_x38 * ((((-__pyx_v_x150) * ((175.0 * __pyx_v_nu) + 225.0)) + (0.046875 * __pyx_v_x165)) + (__pyx_v_x166 * ((2.0 * __pyx_v_nu) - 3.0))))) + __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":496
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167             # <<<<<<<<<<<<<<
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0
 */
  __Pyx_TraceLine(496,0,__PYX_ERR(1, 496, __pyx_L1_error))
  __pyx_v_x168 = (__pyx_v_x162 * __pyx_v_x167);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":497
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)             # <<<<<<<<<<<<<<
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)
 */
  __Pyx_TraceLine(497,0,__PYX_ERR(1, 497, __pyx_L1_error))
  __pyx_v_x169 = pow((__pyx_v_x160 * __pyx_v_x168), -0.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":498
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5
 */
  __Pyx_TraceLine(498,0,__PYX_ERR(1, 498, __pyx_L1_error))
  __pyx_v_x170 = ((4.0 * __pyx_v_x49) + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":499
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)             # <<<<<<<<<<<<<<
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 */
  __Pyx_TraceLine(499,0,__PYX_ERR(1, 499, __pyx_L1_error))
  __pyx_v_x171 = pow(__pyx_v_r, -6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":500
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5             # <<<<<<<<<<<<<<
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49
 */
  __Pyx_TraceLine(500,0,__PYX_ERR(1, 500, __pyx_L1_error))
  __pyx_v_x172 = (__pyx_v_x15 * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":501
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0             # <<<<<<<<<<<<<<
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14
 */
  __Pyx_TraceLine(501,0,__PYX_ERR(1, 501, __pyx_L1_error))
  __pyx_v_x173 = (((((-6572428.80109422 * __pyx_v_nu) + (1300341.64885296 * __pyx_v_x31)) + ((2048.0 * __pyx_v_x63) * __pyx_v_x89)) + (688128.0 * __pyx_v_x99)) + 1720320.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":502
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49             # <<<<<<<<<<<<<<
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 */
  __Pyx_TraceLine(502,0,__PYX_ERR(1, 502, __pyx_L1_error))
  __pyx_v_x174 = (__pyx_v_x31 * __pyx_v_x49);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":503
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14             # <<<<<<<<<<<<<<
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 */
  __Pyx_TraceLine(503,0,__PYX_ERR(1, 503, __pyx_L1_error))
  __pyx_v_x175 = (4.0 * __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":504
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0             # <<<<<<<<<<<<<<
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 */
  __Pyx_TraceLine(504,0,__PYX_ERR(1, 504, __pyx_L1_error))
  __pyx_v_x176 = (((6.0 * __pyx_v_x0) + __pyx_v_x101) + 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":505
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2             # <<<<<<<<<<<<<<
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77
 */
  __Pyx_TraceLine(505,0,__PYX_ERR(1, 505, __pyx_L1_error))
  __pyx_v_x177 = (((1.31621673590926e-19 * __pyx_v_x90) * ((((((((53760.0 * __pyx_v_nu) * (((((((((3740417.71815805 * __pyx_v_r) + (2115968.85907902 * __pyx_v_x0)) - (938918.400156317 * __pyx_v_x10)) + (__pyx_v_x103 * (__pyx_v_x175 + __pyx_v_x176))) + (__pyx_v_x104 * ((((17058.7851094412 * __pyx_v_r) + (12794.0888320809 * __pyx_v_x0)) - (27409.3925547206 * __pyx_v_x14)) + 13218.7851094412))) + (__pyx_v_x106 * ((((5778.0 * __pyx_v_x0) + __pyx_v_x105) + (1396.0 * __pyx_v_x14)) + 7704.0))) + (__pyx_v_x107 * ((-__pyx_v_x175) + __pyx_v_x176))) + (1057984.42953951 * __pyx_v_x14)) + 2888096.47013111)) + (66060288000.0 * __pyx_v_x10)) + ((135291469824.0 * __pyx_v_x174) * __pyx_v_x77)) + ((7.0 * __pyx_v_x31) * ((((((-117964800.0 * __pyx_v_a6) + (4129567622.65173 * __pyx_v_r)) - (18535504222.6128 * __pyx_v_x0)) + (7133302759.42198 * __pyx_v_x10)) - (12357002815.0752 * __pyx_v_x14)) + 122635399361.987))) + ((32768.0 * __pyx_v_x63) * __pyx_v_x98)) + ((7.0 * __pyx_v_x67) * ((-5706642207.53758 * __pyx_v_r) - 26189434371.6082))) + ((32768.0 * __pyx_v_x99) * (((((((-1791904.9465589 * __pyx_v_nu) + ((3840.0 * __pyx_v_r) * __pyx_v_x95)) + ((2880.0 * __pyx_v_x0) * __pyx_v_x96)) + (806400.0 * __pyx_v_x10)) - (725760.0 * __pyx_v_x31)) + (1920.0 * __pyx_v_x97)) + 4143360.0)))) / pow((((((((1.35654132757922e-7 * __pyx_v_x100) + (2.22557561555966e-7 * __pyx_v_x108)) + (0.0546957463279941 * __pyx_v_x37)) + __pyx_v_x72) + (0.28004222119933 * __pyx_v_x92)) + (4.63661586574928e-9 * __pyx_v_x93)) + (2.8978849160933e-11 * __pyx_v_x94)), 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":506
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172             # <<<<<<<<<<<<<<
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 */
  __Pyx_TraceLine(506,0,__PYX_ERR(1, 506, __pyx_L1_error))
  __pyx_v_x178 = ((((((-7680.0 * __pyx_v_x10) * __pyx_v_x109) * __pyx_v_x173) + (__pyx_v_x10 * __pyx_v_x177)) - (((30720.0 * __pyx_v_x109) * __pyx_v_x14) * __pyx_v_x90)) + __pyx_v_x172);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":507
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77             # <<<<<<<<<<<<<<
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87
 */
  __Pyx_TraceLine(507,0,__PYX_ERR(1, 507, __pyx_L1_error))
  __pyx_v_x179 = (11575876386816.0 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":508
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1             # <<<<<<<<<<<<<<
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 */
  __Pyx_TraceLine(508,0,__PYX_ERR(1, 508, __pyx_L1_error))
  __pyx_v_x180 = (((((((((5807150888816.34 * __pyx_v_nu) + (10215490662751.4 * __pyx_v_r)) + (5178202125747.62 * __pyx_v_x126)) + (267544166400.0 * __pyx_v_x128)) - (__pyx_v_x132 * __pyx_v_x49)) + __pyx_v_x143) + (__pyx_v_x179 * __pyx_v_x49)) + (__pyx_v_x77 * (((4161798144000.0 * __pyx_v_nu) + (1759846072320.0 * __pyx_v_r)) + 12148770078720.0))) - 53501685054374.1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":509
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87             # <<<<<<<<<<<<<<
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158
 */
  __Pyx_TraceLine(509,0,__PYX_ERR(1, 509, __pyx_L1_error))
  __pyx_v_x181 = ((((__pyx_v_x125 * __pyx_v_x138) * __pyx_v_x54) * __pyx_v_x86) * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":510
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)             # <<<<<<<<<<<<<<
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178
 */
  __Pyx_TraceLine(510,0,__PYX_ERR(1, 510, __pyx_L1_error))
  __pyx_v_x182 = ((((((((-18432.0 * __pyx_v_r) * __pyx_v_x114) - ((2903040.0 * __pyx_v_x0) * __pyx_v_x116)) + __pyx_v_x119) + (__pyx_v_x123 * __pyx_v_x49)) + __pyx_v_x144) + __pyx_v_x179) + (__pyx_v_x77 * ((((20113376778784.3 * __pyx_v_nu) + (2639769108480.0 * __pyx_v_x0)) + (566231040.0 * __pyx_v_x129)) + __pyx_v_x131)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":511
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158             # <<<<<<<<<<<<<<
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38
 */
  __Pyx_TraceLine(511,0,__PYX_ERR(1, 511, __pyx_L1_error))
  __pyx_v_x183 = (__pyx_v_x141 * __pyx_v_x158);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":512
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178             # <<<<<<<<<<<<<<
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3
 */
  __Pyx_TraceLine(512,0,__PYX_ERR(1, 512, __pyx_L1_error))
  __pyx_v_x184 = (-__pyx_v_x178);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":513
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38             # <<<<<<<<<<<<<<
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5
 */
  __Pyx_TraceLine(513,0,__PYX_ERR(1, 513, __pyx_L1_error))
  __pyx_v_x185 = (__pyx_v_x154 * __pyx_v_x38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":514
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3             # <<<<<<<<<<<<<<
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7
 */
  __Pyx_TraceLine(514,0,__PYX_ERR(1, 514, __pyx_L1_error))
  __pyx_v_x186 = pow(__pyx_v_prst, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":515
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5             # <<<<<<<<<<<<<<
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186
 */
  __Pyx_TraceLine(515,0,__PYX_ERR(1, 515, __pyx_L1_error))
  __pyx_v_x187 = pow(__pyx_v_prst, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":516
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7             # <<<<<<<<<<<<<<
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187
 */
  __Pyx_TraceLine(516,0,__PYX_ERR(1, 516, __pyx_L1_error))
  __pyx_v_x188 = pow(__pyx_v_prst, 7.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":517
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186             # <<<<<<<<<<<<<<
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 */
  __Pyx_TraceLine(517,0,__PYX_ERR(1, 517, __pyx_L1_error))
  __pyx_v_x189 = (4.0 * __pyx_v_x186);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":518
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187             # <<<<<<<<<<<<<<
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi
 */
  __Pyx_TraceLine(518,0,__PYX_ERR(1, 518, __pyx_L1_error))
  __pyx_v_x190 = (6.0 * __pyx_v_x187);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":519
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)             # <<<<<<<<<<<<<<
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25
 */
  __Pyx_TraceLine(519,0,__PYX_ERR(1, 519, __pyx_L1_error))
  __pyx_v_x191 = ((__pyx_v_x167 * __pyx_v_x169) / ((__pyx_v_x170 * __pyx_v_x46) + 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":520
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi             # <<<<<<<<<<<<<<
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192
 */
  __Pyx_TraceLine(520,0,__PYX_ERR(1, 520, __pyx_L1_error))
  __pyx_v_x192 = (2.0 * __pyx_v_pphi);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":521
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25             # <<<<<<<<<<<<<<
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11
 */
  __Pyx_TraceLine(521,0,__PYX_ERR(1, 521, __pyx_L1_error))
  __pyx_v_x193 = (__pyx_v_x192 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":522
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192             # <<<<<<<<<<<<<<
 *         cdef double x195 = 4.0*pphi**3*x11
 * 
 */
  __Pyx_TraceLine(522,0,__PYX_ERR(1, 522, __pyx_L1_error))
  __pyx_v_x194 = (__pyx_v_x15 * __pyx_v_x192);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":523
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(523,0,__PYX_ERR(1, 523, __pyx_L1_error))
  __pyx_v_x195 = ((4.0 * pow(__pyx_v_pphi, 3.0)) * __pyx_v_x11);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":528
 *         # Evaluate Hamiltonian
 *         cdef double H,xi
 *         H,xi =  evaluate_H(q,p,chi_1,chi_2,m_1,m_2,M,nu,X_1,X_2,a6,dSO)             # <<<<<<<<<<<<<<
 * 
 *         # Heff Jacobian expressions
 */
  __Pyx_TraceLine(528,0,__PYX_ERR(1, 528, __pyx_L1_error))
  __pyx_t_14 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_M, __pyx_v_nu, __pyx_v_X_1, __pyx_v_X_2, __pyx_v_a6, __pyx_v_dSO, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 528, __pyx_L1_error)
  __pyx_t_13 = __pyx_t_14.f0;
  __pyx_t_15 = __pyx_t_14.f1;
  __pyx_v_H = __pyx_t_13;
  __pyx_v_xi = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":531
 * 
 *         # Heff Jacobian expressions
 *         cdef double dHeffdr = 0.5*x169*(x160*x162*(-x171*(-x150*(875.0*nu + 1125.0) + 0.234375*x165 + x166*(10.0*nu - 15.0)) - x178 - x38*(0.5*x163 + x164 + 4.5*x4)) - x160*x167*(-x11*x5 - x16*x170)/x161**2 + x168*(-663.496888455656*nu*r**(-5.5)*x54 - nu*x25*x64 + 39.6112800271521*nu*x55*x57 + 6.78168402777778e-8*x11*x141*x142*x146*x154*x158*x7 + x11*x54*(118.4*x174 - 51.6952380952381*x63) + 7.59859378406358e-45*x112*x135*x138*x154*x182*x54*x86*x87 - 9.25454462627843e-34*x112*x180*x181/x134**3 - 2.24091649004576e-37*x135*x140*x142*x154*x180*x183*x38 + 1.69542100694444e-8*x140*x141*x142*x146*x154*x38*(38400.0*x10*x109*x145*x155*x90 + 7680.0*x109*x145*x155*x173*x37 + 7680.0*x109*x155*x180*x37*x90 - x11*(x147*(36.0*nu - 9.0) + x148*(-63.0*X_1 + 63.0*X_2) + x4*(9.0*nu + 8.4375)) - x156*x177 - x172 - x38*(x148*x153 + 0.0625*x149*x4 + 0.0625*x151) - 2.29252167428035e-22*x145*x157*x182*x37/x125) + 1.69542100694444e-8*x140*x141*x142*x146*x158*x182*x38 - 8.47710503472222e-8*x159*x171 - x24*x76 + x25*x28*x4*x80*x84 + x28*x4*x49*x80*(x175 + x81 + x82)/x83**2 - x30 - x33*x57*x73 - x39*x54*x78 - x4*x85 - 3.70688355060912*x58*x62 - 2.0*x65*x69 - 3.0*x68*x79 - 2.0*x70*x74 - 4.41515887225116e-12*x140*x146*x183*x184*x185/x111**3 - 6.62902677807736e-23*x135*x181*x184/x111**5 + 1.01821851311268e-18*x112*x125*x135*x138*x54*x7**3/r**12 - 1.65460508380811e-18*x139/r**14)) + x9*(-dSO*x11*x12*x13 + pphi*x17*x18*(-x15*(-0.0625*nu + 1.07291666666667*x31 + 0.15625) - x25*x41 - x30*x42 - x34*x43 - x40*x44) + pphi*x3*(-x15*(-11.0625*nu + 1.13541666666667*x31 - 0.15625) - x25*x26 - x27*x30 - x32*x34 - x35*x40) - x13*x23*x24 - 0.0833333333333333*x16*x20) - 0.25*(r*(x6 - 2.0) + x6 + x7)*(pphi*x52 + pphi*x53 + x13*x45 + x13*x48 + x20*x47)/(x7 + 0.5*x8)**2             # <<<<<<<<<<<<<<
 * 
 *         cdef double dHeffdphi = 0
 */
  __Pyx_TraceLine(531,0,__PYX_ERR(1, 531, __pyx_L1_error))
  __pyx_t_15 = __Pyx_SoftComplexToDouble(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((0.5 * __pyx_v_x169), 0), __Pyx_c_sum_double(__pyx_t_double_complex_from_parts((((__pyx_v_x160 * __pyx_v_x162) * ((((-__pyx_v_x171) * ((((-__pyx_v_x150) * ((875.0 * __pyx_v_nu) + 1125.0)) + (0.234375 * __pyx_v_x165)) + (__pyx_v_x166 * ((10.0 * __pyx_v_nu) - 15.0)))) - __pyx_v_x178) - (__pyx_v_x38 * (((0.5 * __pyx_v_x163) + __pyx_v_x164) + (4.5 * __pyx_v_x4))))) - (((__pyx_v_x160 * __pyx_v_x167) * (((-__pyx_v_x11) * __pyx_v_x5) - (__pyx_v_x16 * __pyx_v_x170))) / pow(__pyx_v_x161, 2.0))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_x168, 0), __Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((-663.496888455656 * __pyx_v_nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-5.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_x54, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_nu * __pyx_v_x25) * __pyx_v_x64), 0)), __pyx_t_double_complex_from_parts((((39.6112800271521 * __pyx_v_nu) * __pyx_v_x55) * __pyx_v_x57), 0)), __pyx_t_double_complex_from_parts((((((((6.78168402777778e-8 * __pyx_v_x11) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x158) * __pyx_v_x7), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x11 * __pyx_v_x54) * ((118.4 * __pyx_v_x174) - (51.6952380952381 * __pyx_v_x63))), 0)), __pyx_t_double_complex_from_parts(((((((((7.59859378406358e-45 * __pyx_v_x112) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x154) * __pyx_v_x182) * __pyx_v_x54) * __pyx_v_x86) * __pyx_v_x87), 0)), __pyx_t_double_complex_from_parts(((((9.25454462627843e-34 * __pyx_v_x112) * __pyx_v_x180) * __pyx_v_x181) / pow(__pyx_v_x134, 3.0)), 0)), __pyx_t_double_complex_from_parts((((((((2.24091649004576e-37 * __pyx_v_x135) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x154) * __pyx_v_x180) * __pyx_v_x183) * __pyx_v_x38), 0)), __pyx_t_double_complex_from_parts((((((((1.69542100694444e-8 * __pyx_v_x140) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x38) * ((((((((((((38400.0 * __pyx_v_x10) * __pyx_v_x109) * __pyx_v_x145) * __pyx_v_x155) * __pyx_v_x90) + (((((7680.0 * __pyx_v_x109) * __pyx_v_x145) * __pyx_v_x155) * __pyx_v_x173) * __pyx_v_x37)) + (((((7680.0 * __pyx_v_x109) * __pyx_v_x155) * __pyx_v_x180) * __pyx_v_x37) * __pyx_v_x90)) - (__pyx_v_x11 * (((__pyx_v_x147 * ((36.0 * __pyx_v_nu) - 9.0)) + (__pyx_v_x148 * ((-63.0 * __pyx_v_X_1) + (63.0 * __pyx_v_X_2)))) + (__pyx_v_x4 * ((9.0 * __pyx_v_nu) + 8.4375))))) - (__pyx_v_x156 * __pyx_v_x177)) - __pyx_v_x172) - (__pyx_v_x38 * (((__pyx_v_x148 * __pyx_v_x153) + ((0.0625 * __pyx_v_x149) * __pyx_v_x4)) + (0.0625 * __pyx_v_x151)))) - (((((2.29252167428035e-22 * __pyx_v_x145) * __pyx_v_x157) * __pyx_v_x182) * __pyx_v_x37) / __pyx_v_x125))), 0)), __pyx_t_double_complex_from_parts((((((((1.69542100694444e-8 * __pyx_v_x140) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x158) * __pyx_v_x182) * __pyx_v_x38), 0)), __pyx_t_double_complex_from_parts(((8.47710503472222e-8 * __pyx_v_x159) * __pyx_v_x171), 0)), __pyx_t_double_complex_from_parts((__pyx_v_x24 * __pyx_v_x76), 0)), __pyx_t_double_complex_from_parts(((((__pyx_v_x25 * __pyx_v_x28) * __pyx_v_x4) * __pyx_v_x80) * __pyx_v_x84), 0)), __pyx_t_double_complex_from_parts((((((__pyx_v_x28 * __pyx_v_x4) * __pyx_v_x49) * __pyx_v_x80) * ((__pyx_v_x175 + __pyx_v_x81) + __pyx_v_x82)) / pow(__pyx_v_x83, 2.0)), 0)), __pyx_t_double_complex_from_parts(__pyx_v_x30, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x33 * __pyx_v_x57) * __pyx_v_x73), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x39 * __pyx_v_x54) * __pyx_v_x78), 0)), __pyx_t_double_complex_from_parts((__pyx_v_x4 * __pyx_v_x85), 0)), __pyx_t_double_complex_from_parts(((3.70688355060912 * __pyx_v_x58) * __pyx_v_x62), 0)), __pyx_t_double_complex_from_parts(((2.0 * __pyx_v_x65) * __pyx_v_x69), 0)), __pyx_t_double_complex_from_parts(((3.0 * __pyx_v_x68) * __pyx_v_x79), 0)), __pyx_t_double_complex_from_parts(((2.0 * __pyx_v_x70) * __pyx_v_x74), 0)), __pyx_t_double_complex_from_parts(((((((4.41515887225116e-12 * __pyx_v_x140) * __pyx_v_x146) * __pyx_v_x183) * __pyx_v_x184) * __pyx_v_x185) / pow(__pyx_v_x111, 3.0)), 0)), __pyx_t_double_complex_from_parts(((((6.62902677807736e-23 * __pyx_v_x135) * __pyx_v_x181) * __pyx_v_x184) / pow(__pyx_v_x111, 5.0)), 0)), __pyx_t_double_complex_from_parts((((((((1.01821851311268e-18 * __pyx_v_x112) * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x54) * pow(__pyx_v_x7, 3.0)) / pow(__pyx_v_r, 12.0)), 0)), __pyx_t_double_complex_from_parts(((1.65460508380811e-18 * __pyx_v_x139) / pow(__pyx_v_r, 14.0)), 0))))), __pyx_t_double_complex_from_parts((__pyx_v_x9 * ((((((((-__pyx_v_dSO) * __pyx_v_x11) * __pyx_v_x12) * __pyx_v_x13) + (((__pyx_v_pphi * __pyx_v_x17) * __pyx_v_x18) * ((((((-__pyx_v_x15) * (((-0.0625 * __pyx_v_nu) + (1.07291666666667 * __pyx_v_x31)) + 0.15625)) - (__pyx_v_x25 * __pyx_v_x41)) - (__pyx_v_x30 * __pyx_v_x42)) - (__pyx_v_x34 * __pyx_v_x43)) - (__pyx_v_x40 * __pyx_v_x44)))) + ((__pyx_v_pphi * __pyx_v_x3) * ((((((-__pyx_v_x15) * (((-11.0625 * __pyx_v_nu) + (1.13541666666667 * __pyx_v_x31)) - 0.15625)) - (__pyx_v_x25 * __pyx_v_x26)) - (__pyx_v_x27 * __pyx_v_x30)) - (__pyx_v_x32 * __pyx_v_x34)) - (__pyx_v_x35 * __pyx_v_x40)))) - ((__pyx_v_x13 * __pyx_v_x23) * __pyx_v_x24)) - ((0.0833333333333333 * __pyx_v_x16) * __pyx_v_x20))), 0)), __pyx_t_double_complex_from_parts((((0.25 * (((__pyx_v_r * (__pyx_v_x6 - 2.0)) + __pyx_v_x6) + __pyx_v_x7)) * (((((__pyx_v_pphi * __pyx_v_x52) + (__pyx_v_pphi * __pyx_v_x53)) + (__pyx_v_x13 * __pyx_v_x45)) + (__pyx_v_x13 * __pyx_v_x48)) + (__pyx_v_x20 * __pyx_v_x47))) / pow((__pyx_v_x7 + (0.5 * __pyx_v_x8)), 2.0)), 0)), 1); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 531, __pyx_L1_error)
  __pyx_v_dHeffdr = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":533
 *         cdef double dHeffdr = 0.5*x169*(x160*x162*(-x171*(-x150*(875.0*nu + 1125.0) + 0.234375*x165 + x166*(10.0*nu - 15.0)) - x178 - x38*(0.5*x163 + x164 + 4.5*x4)) - x160*x167*(-x11*x5 - x16*x170)/x161**2 + x168*(-663.496888455656*nu*r**(-5.5)*x54 - nu*x25*x64 + 39.6112800271521*nu*x55*x57 + 6.78168402777778e-8*x11*x141*x142*x146*x154*x158*x7 + x11*x54*(118.4*x174 - 51.6952380952381*x63) + 7.59859378406358e-45*x112*x135*x138*x154*x182*x54*x86*x87 - 9.25454462627843e-34*x112*x180*x181/x134**3 - 2.24091649004576e-37*x135*x140*x142*x154*x180*x183*x38 + 1.69542100694444e-8*x140*x141*x142*x146*x154*x38*(38400.0*x10*x109*x145*x155*x90 + 7680.0*x109*x145*x155*x173*x37 + 7680.0*x109*x155*x180*x37*x90 - x11*(x147*(36.0*nu - 9.0) + x148*(-63.0*X_1 + 63.0*X_2) + x4*(9.0*nu + 8.4375)) - x156*x177 - x172 - x38*(x148*x153 + 0.0625*x149*x4 + 0.0625*x151) - 2.29252167428035e-22*x145*x157*x182*x37/x125) + 1.69542100694444e-8*x140*x141*x142*x146*x158*x182*x38 - 8.47710503472222e-8*x159*x171 - x24*x76 + x25*x28*x4*x80*x84 + x28*x4*x49*x80*(x175 + x81 + x82)/x83**2 - x30 - x33*x57*x73 - x39*x54*x78 - x4*x85 - 3.70688355060912*x58*x62 - 2.0*x65*x69 - 3.0*x68*x79 - 2.0*x70*x74 - 4.41515887225116e-12*x140*x146*x183*x184*x185/x111**3 - 6.62902677807736e-23*x135*x181*x184/x111**5 + 1.01821851311268e-18*x112*x125*x135*x138*x54*x7**3/r**12 - 1.65460508380811e-18*x139/r**14)) + x9*(-dSO*x11*x12*x13 + pphi*x17*x18*(-x15*(-0.0625*nu + 1.07291666666667*x31 + 0.15625) - x25*x41 - x30*x42 - x34*x43 - x40*x44) + pphi*x3*(-x15*(-11.0625*nu + 1.13541666666667*x31 - 0.15625) - x25*x26 - x27*x30 - x32*x34 - x35*x40) - x13*x23*x24 - 0.0833333333333333*x16*x20) - 0.25*(r*(x6 - 2.0) + x6 + x7)*(pphi*x52 + pphi*x53 + x13*x45 + x13*x48 + x20*x47)/(x7 + 0.5*x8)**2
 * 
 *         cdef double dHeffdphi = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)
 */
  __Pyx_TraceLine(533,0,__PYX_ERR(1, 533, __pyx_L1_error))
  __pyx_v_dHeffdphi = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":535
 *         cdef double dHeffdphi = 0
 * 
 *         cdef double dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)             # <<<<<<<<<<<<<<
 * 
 *         cdef double dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)
 */
  __Pyx_TraceLine(535,0,__PYX_ERR(1, 535, __pyx_L1_error))
  __pyx_v_dHeffdpr = (__pyx_v_x191 * ((((((((((((((11.8620273619492 * __pyx_v_nu) * __pyx_v_x188) * __pyx_v_x60) + ((((((3.39084201388889e-8 * __pyx_v_prst) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x158) * __pyx_v_x185)) + ((__pyx_v_x11 * __pyx_v_x189) * __pyx_v_x78)) + (((((((5.09109256556341e-19 * __pyx_v_x112) * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x186) * __pyx_v_x86) * __pyx_v_x87)) + ((__pyx_v_x15 * __pyx_v_x189) * __pyx_v_x68)) + ((__pyx_v_x15 * __pyx_v_x190) * __pyx_v_x73)) + ((589.775011960583 * __pyx_v_x186) * __pyx_v_x56)) - ((67.9050514751178 * __pyx_v_x187) * __pyx_v_x59)) + (((8.0 * __pyx_v_x188) * __pyx_v_x25) * __pyx_v_x75)) + ((0.975638950243592 * __pyx_v_x188) * __pyx_v_x63)) + (__pyx_v_x189 * __pyx_v_x66)) + (__pyx_v_x190 * __pyx_v_x71)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":537
 *         cdef double dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)
 * 
 *         cdef double dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)             # <<<<<<<<<<<<<<
 * 
 *         # Compute H Jacobian
 */
  __Pyx_TraceLine(537,0,__PYX_ERR(1, 537, __pyx_L1_error))
  __pyx_v_dHeffdpphi = ((__pyx_v_x191 * (((2.0 * __pyx_v_pphi) * __pyx_v_x25) - ((((__pyx_v_pphi * __pyx_v_x49) * __pyx_v_x5) * __pyx_v_x80) * __pyx_v_x84))) + (__pyx_v_x9 * (((((((__pyx_v_x13 * (((__pyx_v_x193 * __pyx_v_x27) + (__pyx_v_x194 * __pyx_v_x32)) + (__pyx_v_x195 * __pyx_v_x35))) + (__pyx_v_x19 * __pyx_v_x47)) + (__pyx_v_x20 * (((__pyx_v_x193 * __pyx_v_x42) + (__pyx_v_x194 * __pyx_v_x43)) + (__pyx_v_x195 * __pyx_v_x44)))) + (__pyx_v_x3 * __pyx_v_x45)) + (__pyx_v_x3 * __pyx_v_x48)) + __pyx_v_x52) + __pyx_v_x53)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":540
 * 
 *         # Compute H Jacobian
 *         cdef double dHdr = M * M * dHeffdr / (nu*H)             # <<<<<<<<<<<<<<
 *         cdef double dHdphi = M * M * dHeffdphi / (nu*H)
 *         cdef double dHdpr = M * M * dHeffdpr / (nu*H)
 */
  __Pyx_TraceLine(540,0,__PYX_ERR(1, 540, __pyx_L1_error))
  __pyx_v_dHdr = (((__pyx_v_M * __pyx_v_M) * __pyx_v_dHeffdr) / (__pyx_v_nu * __pyx_v_H));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":541
 *         # Compute H Jacobian
 *         cdef double dHdr = M * M * dHeffdr / (nu*H)
 *         cdef double dHdphi = M * M * dHeffdphi / (nu*H)             # <<<<<<<<<<<<<<
 *         cdef double dHdpr = M * M * dHeffdpr / (nu*H)
 *         cdef double dHdpphi = M * M * dHeffdpphi / (nu*H)
 */
  __Pyx_TraceLine(541,0,__PYX_ERR(1, 541, __pyx_L1_error))
  __pyx_v_dHdphi = (((__pyx_v_M * __pyx_v_M) * __pyx_v_dHeffdphi) / (__pyx_v_nu * __pyx_v_H));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":542
 *         cdef double dHdr = M * M * dHeffdr / (nu*H)
 *         cdef double dHdphi = M * M * dHeffdphi / (nu*H)
 *         cdef double dHdpr = M * M * dHeffdpr / (nu*H)             # <<<<<<<<<<<<<<
 *         cdef double dHdpphi = M * M * dHeffdpphi / (nu*H)
 * 
 */
  __Pyx_TraceLine(542,0,__PYX_ERR(1, 542, __pyx_L1_error))
  __pyx_v_dHdpr = (((__pyx_v_M * __pyx_v_M) * __pyx_v_dHeffdpr) / (__pyx_v_nu * __pyx_v_H));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":543
 *         cdef double dHdphi = M * M * dHeffdphi / (nu*H)
 *         cdef double dHdpr = M * M * dHeffdpr / (nu*H)
 *         cdef double dHdpphi = M * M * dHeffdpphi / (nu*H)             # <<<<<<<<<<<<<<
 * 
 *         return dHdr, dHdphi, dHdpr, dHdpphi
 */
  __Pyx_TraceLine(543,0,__PYX_ERR(1, 543, __pyx_L1_error))
  __pyx_v_dHdpphi = (((__pyx_v_M * __pyx_v_M) * __pyx_v_dHeffdpphi) / (__pyx_v_nu * __pyx_v_H));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":545
 *         cdef double dHdpphi = M * M * dHeffdpphi / (nu*H)
 * 
 *         return dHdr, dHdphi, dHdpr, dHdpphi             # <<<<<<<<<<<<<<
 * 
 *     cpdef hessian(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):
 */
  __Pyx_TraceLine(545,0,__PYX_ERR(1, 545, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_dHdr); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_dHdphi); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyFloat_FromDouble(__pyx_v_dHdpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = PyFloat_FromDouble(__pyx_v_dHdpphi); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_t_8);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_9 = 0;
  __pyx_t_8 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":290
 *             return H,xi,A,Bnp,Bnpa,Qq,Heven,Hodd
 * 
 *     cpdef grad(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.grad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_6grad, "\n        Compute the gradient of the Hamiltonian in polar coordinates.\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n\n        Returns:\n           (tuple) dHdr, dHdphi, dHdpr, dHdpphi\n\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad = {"grad", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_6grad};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("grad (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("grad", 1, 6, 6, 1); __PYX_ERR(1, 290, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("grad", 1, 6, 6, 2); __PYX_ERR(1, 290, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("grad", 1, 6, 6, 3); __PYX_ERR(1, 290, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("grad", 1, 6, 6, 4); __PYX_ERR(1, 290, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("grad", 1, 6, 6, 5); __PYX_ERR(1, 290, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "grad") < 0)) __PYX_ERR(1, 290, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 290, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 290, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 290, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("grad", 1, 6, 6, __pyx_nargs); __PYX_ERR(1, 290, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.grad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_6grad(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_6grad(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__13)
  __Pyx_RefNannySetupContext("grad", 0);
  __Pyx_TraceCall("grad (wrapper)", __pyx_f[1], 290, 0, __PYX_ERR(1, 290, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 290, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 290, __pyx_L1_error) }
  __pyx_t_1 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_grad(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.grad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":547
 *         return dHdr, dHdphi, dHdpr, dHdpphi
 * 
 *     cpdef hessian(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_hessian(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  double __pyx_v_pphi;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_x0;
  double __pyx_v_x1;
  double __pyx_v_x2;
  double __pyx_v_x3;
  double __pyx_v_x4;
  double __pyx_v_x5;
  double __pyx_v_x6;
  double __pyx_v_x7;
  double __pyx_v_x8;
  double __pyx_v_x9;
  double __pyx_v_x10;
  double __pyx_v_x11;
  double __pyx_v_x12;
  double __pyx_v_x13;
  double __pyx_v_x14;
  double __pyx_v_x15;
  double __pyx_v_x16;
  double __pyx_v_x17;
  double __pyx_v_x18;
  double __pyx_v_x19;
  double __pyx_v_x20;
  double __pyx_v_x21;
  double __pyx_v_x22;
  double __pyx_v_x23;
  double __pyx_v_x24;
  double __pyx_v_x25;
  double __pyx_v_x26;
  double __pyx_v_x27;
  double __pyx_v_x28;
  double __pyx_v_x29;
  double __pyx_v_x30;
  double __pyx_v_x31;
  double __pyx_v_x32;
  double __pyx_v_x33;
  double __pyx_v_x34;
  double __pyx_v_x35;
  double __pyx_v_x36;
  double __pyx_v_x37;
  double __pyx_v_x38;
  double __pyx_v_x39;
  double __pyx_v_x40;
  double __pyx_v_x41;
  double __pyx_v_x42;
  double __pyx_v_x43;
  double __pyx_v_x44;
  double __pyx_v_x45;
  double __pyx_v_x46;
  double __pyx_v_x47;
  double __pyx_v_x48;
  double __pyx_v_x49;
  double __pyx_v_x50;
  double __pyx_v_x51;
  double __pyx_v_x52;
  double __pyx_v_x53;
  double __pyx_v_x54;
  double __pyx_v_x55;
  double __pyx_v_x56;
  double __pyx_v_x57;
  double __pyx_v_x58;
  double __pyx_v_x59;
  double __pyx_v_x60;
  double __pyx_v_x61;
  double __pyx_v_x62;
  double __pyx_v_x63;
  double __pyx_v_x64;
  double __pyx_v_x65;
  double __pyx_v_x66;
  double __pyx_v_x67;
  double __pyx_v_x68;
  double __pyx_v_x69;
  double __pyx_v_x70;
  double __pyx_v_x71;
  double __pyx_v_x72;
  double __pyx_v_x73;
  double __pyx_v_x74;
  double __pyx_v_x75;
  double __pyx_v_x76;
  double __pyx_v_x77;
  double __pyx_v_x78;
  double __pyx_v_x79;
  double __pyx_v_x80;
  double __pyx_v_x81;
  double __pyx_v_x82;
  double __pyx_v_x83;
  double __pyx_v_x84;
  double __pyx_v_x85;
  double __pyx_v_x86;
  double __pyx_v_x87;
  double __pyx_v_x88;
  double __pyx_v_x89;
  double __pyx_v_x90;
  double __pyx_v_x91;
  double __pyx_v_x92;
  double __pyx_v_x93;
  double __pyx_v_x94;
  double __pyx_v_x95;
  double __pyx_v_x96;
  double __pyx_v_x97;
  double __pyx_v_x98;
  double __pyx_v_x99;
  double __pyx_v_x100;
  double __pyx_v_x101;
  double __pyx_v_x102;
  double __pyx_v_x103;
  double __pyx_v_x104;
  double __pyx_v_x105;
  double __pyx_v_x106;
  double __pyx_v_x107;
  double __pyx_v_x108;
  double __pyx_v_x109;
  double __pyx_v_x110;
  double __pyx_v_x111;
  double __pyx_v_x112;
  double __pyx_v_x113;
  double __pyx_v_x114;
  double __pyx_v_x115;
  double __pyx_v_x116;
  double __pyx_v_x117;
  double __pyx_v_x118;
  double __pyx_v_x119;
  double __pyx_v_x120;
  double __pyx_v_x121;
  double __pyx_v_x122;
  double __pyx_v_x123;
  double __pyx_v_x124;
  double __pyx_v_x125;
  double __pyx_v_x126;
  double __pyx_v_x127;
  double __pyx_v_x128;
  double __pyx_v_x129;
  double __pyx_v_x130;
  double __pyx_v_x131;
  double __pyx_v_x132;
  double __pyx_v_x133;
  double __pyx_v_x134;
  double __pyx_v_x135;
  double __pyx_v_x136;
  double __pyx_v_x137;
  double __pyx_v_x138;
  double __pyx_v_x139;
  double __pyx_v_x140;
  double __pyx_v_x141;
  double __pyx_v_x142;
  double __pyx_v_x143;
  double __pyx_v_x144;
  double __pyx_v_x145;
  double __pyx_v_x146;
  double __pyx_v_x147;
  double __pyx_v_x148;
  double __pyx_v_x149;
  double __pyx_v_x150;
  double __pyx_v_x151;
  double __pyx_v_x152;
  double __pyx_v_x153;
  double __pyx_v_x154;
  double __pyx_v_x155;
  double __pyx_v_x156;
  double __pyx_v_x157;
  double __pyx_v_x158;
  double __pyx_v_x159;
  double __pyx_v_x160;
  double __pyx_v_x161;
  double __pyx_v_x162;
  double __pyx_v_x163;
  double __pyx_v_x164;
  double __pyx_v_x165;
  double __pyx_v_x166;
  double __pyx_v_x167;
  double __pyx_v_x168;
  double __pyx_v_x169;
  double __pyx_v_x170;
  double __pyx_v_x171;
  double __pyx_v_x172;
  double __pyx_v_x173;
  double __pyx_v_x174;
  double __pyx_v_x175;
  double __pyx_v_x176;
  double __pyx_v_x177;
  double __pyx_v_x178;
  double __pyx_v_x179;
  double __pyx_v_x180;
  double __pyx_v_x181;
  double __pyx_v_x182;
  double __pyx_v_x183;
  double __pyx_v_x184;
  double __pyx_v_x185;
  double __pyx_v_x186;
  double __pyx_v_x187;
  double __pyx_v_x188;
  double __pyx_v_x189;
  double __pyx_v_x190;
  double __pyx_v_x191;
  double __pyx_v_x192;
  double __pyx_v_x193;
  double __pyx_v_x194;
  double __pyx_v_x195;
  double __pyx_v_y0;
  double __pyx_v_y1;
  double __pyx_v_y2;
  double __pyx_v_y3;
  double __pyx_v_y4;
  double __pyx_v_y5;
  double __pyx_v_y6;
  double __pyx_v_y7;
  double __pyx_v_y8;
  double __pyx_v_y9;
  double __pyx_v_y10;
  double __pyx_v_y11;
  double __pyx_v_y12;
  double __pyx_v_y13;
  double __pyx_v_y14;
  double __pyx_v_y15;
  double __pyx_v_y16;
  double __pyx_v_y17;
  double __pyx_v_y18;
  double __pyx_v_y19;
  double __pyx_v_y20;
  double __pyx_v_y21;
  double __pyx_v_y22;
  double __pyx_v_y23;
  double __pyx_v_y24;
  double __pyx_v_y25;
  double __pyx_v_y26;
  double __pyx_v_y27;
  double __pyx_v_y28;
  double __pyx_v_y29;
  double __pyx_v_y30;
  double __pyx_v_y31;
  double __pyx_v_y32;
  double __pyx_v_y33;
  double __pyx_v_y34;
  double __pyx_v_y35;
  double __pyx_v_y36;
  double __pyx_v_y37;
  double __pyx_v_y38;
  double __pyx_v_y39;
  double __pyx_v_y40;
  double __pyx_v_y41;
  double __pyx_v_y42;
  double __pyx_v_y43;
  double __pyx_v_y44;
  double __pyx_v_y45;
  double __pyx_v_y46;
  double __pyx_v_y47;
  double __pyx_v_y48;
  double __pyx_v_y49;
  double __pyx_v_y50;
  double __pyx_v_y51;
  double __pyx_v_y52;
  double __pyx_v_y53;
  double __pyx_v_y54;
  double __pyx_v_y55;
  double __pyx_v_y56;
  double __pyx_v_y57;
  double __pyx_v_y58;
  double __pyx_v_y59;
  double __pyx_v_y60;
  double __pyx_v_y61;
  double __pyx_v_y62;
  double __pyx_v_y63;
  double __pyx_v_y64;
  double __pyx_v_y65;
  double __pyx_v_y66;
  double __pyx_v_y67;
  double __pyx_v_y68;
  double __pyx_v_y69;
  double __pyx_v_y70;
  double __pyx_v_y71;
  double __pyx_v_y72;
  double __pyx_v_y73;
  double __pyx_v_y74;
  double __pyx_v_y75;
  double __pyx_v_y76;
  double __pyx_v_y77;
  double __pyx_v_y78;
  double __pyx_v_y79;
  double __pyx_v_y80;
  double __pyx_v_y81;
  double __pyx_v_y82;
  double __pyx_v_y83;
  double __pyx_v_y84;
  double __pyx_v_y85;
  double __pyx_v_y86;
  double __pyx_v_y87;
  double __pyx_v_y88;
  double __pyx_v_y89;
  double __pyx_v_y90;
  double __pyx_v_y91;
  double __pyx_v_y92;
  double __pyx_v_y93;
  double __pyx_v_y94;
  double __pyx_v_y95;
  double __pyx_v_y96;
  double __pyx_v_y97;
  double __pyx_v_y98;
  double __pyx_v_y99;
  double __pyx_v_y100;
  double __pyx_v_y101;
  double __pyx_v_y102;
  double __pyx_v_y103;
  double __pyx_v_y104;
  double __pyx_v_y105;
  double __pyx_v_y106;
  double __pyx_v_y107;
  double __pyx_v_y108;
  double __pyx_v_y109;
  double __pyx_v_y110;
  double __pyx_v_y111;
  double __pyx_v_y112;
  double __pyx_v_y113;
  double __pyx_v_y114;
  double __pyx_v_y115;
  double __pyx_v_y116;
  double __pyx_v_y117;
  double __pyx_v_y118;
  double __pyx_v_y119;
  double __pyx_v_y120;
  double __pyx_v_y121;
  double __pyx_v_y122;
  double __pyx_v_y123;
  double __pyx_v_y124;
  double __pyx_v_y125;
  double __pyx_v_y126;
  double __pyx_v_y127;
  double __pyx_v_y128;
  double __pyx_v_y129;
  double __pyx_v_y130;
  double __pyx_v_y131;
  double __pyx_v_y132;
  double __pyx_v_y133;
  double __pyx_v_y134;
  double __pyx_v_y135;
  double __pyx_v_y136;
  double __pyx_v_y137;
  double __pyx_v_y138;
  double __pyx_v_y139;
  double __pyx_v_y140;
  double __pyx_v_y141;
  double __pyx_v_y142;
  double __pyx_v_y143;
  double __pyx_v_y144;
  double __pyx_v_y145;
  double __pyx_v_y146;
  double __pyx_v_y147;
  double __pyx_v_y148;
  double __pyx_v_y149;
  double __pyx_v_y150;
  double __pyx_v_y151;
  double __pyx_v_y152;
  double __pyx_v_y153;
  double __pyx_v_y154;
  double __pyx_v_y155;
  double __pyx_v_y156;
  double __pyx_v_y157;
  double __pyx_v_y158;
  double __pyx_v_y159;
  double __pyx_v_y160;
  double __pyx_v_y161;
  double __pyx_v_y162;
  double __pyx_v_y163;
  double __pyx_v_y164;
  double __pyx_v_y165;
  double __pyx_v_y166;
  double __pyx_v_y167;
  double __pyx_v_y168;
  double __pyx_v_y169;
  double __pyx_v_y170;
  double __pyx_v_y171;
  double __pyx_v_y172;
  double __pyx_v_y173;
  double __pyx_v_y174;
  double __pyx_v_y175;
  double __pyx_v_y176;
  double __pyx_v_y177;
  double __pyx_v_y178;
  double __pyx_v_y179;
  double __pyx_v_y180;
  double __pyx_v_y181;
  double __pyx_v_y182;
  double __pyx_v_y183;
  double __pyx_v_y184;
  double __pyx_v_y185;
  double __pyx_v_y186;
  double __pyx_v_y187;
  double __pyx_v_y188;
  double __pyx_v_y189;
  double __pyx_v_y190;
  double __pyx_v_y191;
  double __pyx_v_y192;
  double __pyx_v_y193;
  double __pyx_v_y194;
  double __pyx_v_y195;
  double __pyx_v_y196;
  double __pyx_v_y197;
  double __pyx_v_y198;
  double __pyx_v_y199;
  double __pyx_v_y200;
  double __pyx_v_y201;
  double __pyx_v_y202;
  double __pyx_v_y203;
  double __pyx_v_y204;
  double __pyx_v_y205;
  double __pyx_v_y206;
  double __pyx_v_y207;
  double __pyx_v_y208;
  double __pyx_v_y209;
  double __pyx_v_y210;
  double __pyx_v_y211;
  double __pyx_v_y212;
  double __pyx_v_y213;
  double __pyx_v_y214;
  double __pyx_v_y215;
  double __pyx_v_y216;
  double __pyx_v_y217;
  double __pyx_v_y218;
  double __pyx_v_y219;
  double __pyx_v_y220;
  double __pyx_v_y221;
  double __pyx_v_y222;
  double __pyx_v_y223;
  double __pyx_v_y224;
  double __pyx_v_y225;
  double __pyx_v_y226;
  double __pyx_v_y227;
  double __pyx_v_y228;
  double __pyx_v_y229;
  double __pyx_v_y230;
  double __pyx_v_y231;
  double __pyx_v_y232;
  double __pyx_v_y233;
  double __pyx_v_y234;
  double __pyx_v_y235;
  double __pyx_v_y236;
  double __pyx_v_y237;
  double __pyx_v_y238;
  double __pyx_v_y239;
  double __pyx_v_y240;
  double __pyx_v_y241;
  double __pyx_v_y242;
  double __pyx_v_y243;
  double __pyx_v_y244;
  double __pyx_v_y245;
  double __pyx_v_y246;
  double __pyx_v_y247;
  double __pyx_v_y248;
  double __pyx_v_y249;
  double __pyx_v_y250;
  double __pyx_v_y251;
  double __pyx_v_y252;
  double __pyx_v_y253;
  double __pyx_v_y254;
  double __pyx_v_y255;
  double __pyx_v_y256;
  double __pyx_v_y257;
  double __pyx_v_y258;
  double __pyx_v_y259;
  double __pyx_v_y260;
  double __pyx_v_y261;
  double __pyx_v_y262;
  double __pyx_v_y263;
  double __pyx_v_y264;
  double __pyx_v_y265;
  double __pyx_v_y266;
  double __pyx_v_y267;
  double __pyx_v_y268;
  double __pyx_v_y269;
  double __pyx_v_y270;
  double __pyx_v_y271;
  double __pyx_v_y272;
  double __pyx_v_y273;
  double __pyx_v_y274;
  double __pyx_v_y275;
  double __pyx_v_y276;
  double __pyx_v_y277;
  double __pyx_v_y278;
  double __pyx_v_y279;
  double __pyx_v_y280;
  double __pyx_v_y281;
  double __pyx_v_y282;
  double __pyx_v_y283;
  double __pyx_v_y284;
  double __pyx_v_y285;
  double __pyx_v_y286;
  double __pyx_v_y287;
  double __pyx_v_y288;
  double __pyx_v_y289;
  double __pyx_v_y290;
  double __pyx_v_y291;
  double __pyx_v_y292;
  double __pyx_v_y293;
  double __pyx_v_y294;
  double __pyx_v_y295;
  double __pyx_v_y296;
  double __pyx_v_y297;
  double __pyx_v_y298;
  double __pyx_v_y299;
  double __pyx_v_y300;
  double __pyx_v_y301;
  double __pyx_v_y302;
  double __pyx_v_y303;
  double __pyx_v_y304;
  double __pyx_v_y305;
  double __pyx_v_y306;
  double __pyx_v_y307;
  double __pyx_v_y308;
  double __pyx_v_y309;
  double __pyx_v_y310;
  double __pyx_v_y311;
  double __pyx_v_y312;
  double __pyx_v_y313;
  double __pyx_v_y314;
  double __pyx_v_y315;
  double __pyx_v_y316;
  double __pyx_v_y317;
  double __pyx_v_y318;
  double __pyx_v_y319;
  double __pyx_v_y320;
  double __pyx_v_y321;
  double __pyx_v_y322;
  double __pyx_v_y323;
  double __pyx_v_y324;
  double __pyx_v_y325;
  double __pyx_v_y326;
  double __pyx_v_y327;
  double __pyx_v_y328;
  double __pyx_v_y329;
  double __pyx_v_y330;
  double __pyx_v_y331;
  double __pyx_v_y332;
  double __pyx_v_y333;
  double __pyx_v_y334;
  double __pyx_v_y335;
  double __pyx_v_y336;
  double __pyx_v_y337;
  double __pyx_v_y338;
  double __pyx_v_y339;
  double __pyx_v_y340;
  double __pyx_v_y341;
  double __pyx_v_y342;
  double __pyx_v_y343;
  double __pyx_v_y344;
  double __pyx_v_y345;
  double __pyx_v_y346;
  double __pyx_v_y347;
  double __pyx_v_y348;
  double __pyx_v_y349;
  double __pyx_v_y350;
  double __pyx_v_y351;
  double __pyx_v_y352;
  double __pyx_v_y353;
  double __pyx_v_y354;
  double __pyx_v_y355;
  double __pyx_v_y356;
  double __pyx_v_y357;
  double __pyx_v_y358;
  double __pyx_v_y359;
  double __pyx_v_y360;
  double __pyx_v_y361;
  double __pyx_v_y362;
  double __pyx_v_y363;
  double __pyx_v_y364;
  double __pyx_v_y365;
  double __pyx_v_y366;
  double __pyx_v_y367;
  double __pyx_v_y368;
  double __pyx_v_y369;
  double __pyx_v_y370;
  double __pyx_v_y371;
  double __pyx_v_y372;
  double __pyx_v_y373;
  double __pyx_v_y374;
  double __pyx_v_y375;
  double __pyx_v_y376;
  double __pyx_v_y377;
  double __pyx_v_y378;
  double __pyx_v_y379;
  double __pyx_v_y380;
  double __pyx_v_y381;
  double __pyx_v_y382;
  double __pyx_v_y383;
  double __pyx_v_y384;
  double __pyx_v_y385;
  double __pyx_v_y386;
  double __pyx_v_y387;
  double __pyx_v_y388;
  double __pyx_v_y389;
  double __pyx_v_y390;
  double __pyx_v_y391;
  double __pyx_v_y392;
  double __pyx_v_y393;
  double __pyx_v_y394;
  double __pyx_v_y395;
  double __pyx_v_y396;
  double __pyx_v_y397;
  double __pyx_v_y398;
  double __pyx_v_y399;
  double __pyx_v_y400;
  double __pyx_v_y401;
  double __pyx_v_y402;
  double __pyx_v_y403;
  double __pyx_v_y404;
  double __pyx_v_y405;
  double __pyx_v_y406;
  double __pyx_v_y407;
  double __pyx_v_y408;
  double __pyx_v_y409;
  double __pyx_v_y410;
  double __pyx_v_y411;
  double __pyx_v_y412;
  double __pyx_v_y413;
  double __pyx_v_y414;
  double __pyx_v_y415;
  double __pyx_v_H;
  CYTHON_UNUSED double __pyx_v_xi;
  double __pyx_v_dHeffdr;
  double __pyx_v_dHeffdphi;
  double __pyx_v_dHeffdpr;
  double __pyx_v_dHeffdpphi;
  double __pyx_v_d2Heffdr2;
  double __pyx_v_d2Heffdphi2;
  double __pyx_v_d2Heffdpr2;
  double __pyx_v_d2Heffdpphi2;
  double __pyx_v_d2Heffdrdphi;
  double __pyx_v_d2Heffdrdpr;
  double __pyx_v_d2Heffdrdpphi;
  double __pyx_v_d2Heffdphidpr;
  double __pyx_v_d2Heffdphidpphi;
  double __pyx_v_d2Heffdprdpphi;
  double __pyx_v_d2Hdr2;
  double __pyx_v_d2Hdphi2;
  double __pyx_v_d2Hdpr2;
  double __pyx_v_d2Hdpphi2;
  double __pyx_v_d2Hdrdphi;
  double __pyx_v_d2Hdrdpr;
  double __pyx_v_d2Hdrdpphi;
  double __pyx_v_d2Hdphidpr;
  double __pyx_v_d2Hdphidpphi;
  double __pyx_v_d2Hdprdpphi;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  double __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  double __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__14)
  __Pyx_RefNannySetupContext("hessian", 0);
  __Pyx_TraceCall("hessian", __pyx_f[1], 547, 0, __PYX_ERR(1, 547, __pyx_L1_error));
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_hessian); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 547, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #ifdef __Pyx_CyFunction_USED
      if (!__Pyx_IsCyOrPyCFunction(__pyx_t_1)
      #else
      if (!PyCFunction_Check(__pyx_t_1)
      #endif
              || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian)) {
        __Pyx_XDECREF(__pyx_r);
        if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 547, __pyx_L1_error) }
        __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_q, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 547, __pyx_L1_error) }
        __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_p, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyFloat_FromDouble(__pyx_v_chi_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyFloat_FromDouble(__pyx_v_chi_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyFloat_FromDouble(__pyx_v_m_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_m_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = __pyx_t_1; __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_11 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[7] = {__pyx_t_10, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 6+__pyx_t_11);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 547, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":567
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(567,0,__PYX_ERR(1, 567, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":568
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(568,0,__PYX_ERR(1, 568, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":570
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(570,0,__PYX_ERR(1, 570, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":571
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(571,0,__PYX_ERR(1, 571, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":573
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(573,0,__PYX_ERR(1, 573, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":575
 *         cdef double pphi = L
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']
 */
  __Pyx_TraceLine(575,0,__PYX_ERR(1, 575, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":576
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs['dSO']
 * 
 */
  __Pyx_TraceLine(576,0,__PYX_ERR(1, 576, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_a6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_a6 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":577
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(577,0,__PYX_ERR(1, 577, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_dSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_dSO = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":581
 * 
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M             # <<<<<<<<<<<<<<
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 */
  __Pyx_TraceLine(581,0,__PYX_ERR(1, 581, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->M;
  __pyx_v_M = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":582
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu             # <<<<<<<<<<<<<<
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 */
  __Pyx_TraceLine(582,0,__PYX_ERR(1, 582, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->nu;
  __pyx_v_nu = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":583
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1             # <<<<<<<<<<<<<<
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2
 */
  __Pyx_TraceLine(583,0,__PYX_ERR(1, 583, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_1;
  __pyx_v_X_1 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":584
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2             # <<<<<<<<<<<<<<
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1
 */
  __Pyx_TraceLine(584,0,__PYX_ERR(1, 584, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_2;
  __pyx_v_X_2 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":585
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2             # <<<<<<<<<<<<<<
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2
 */
  __Pyx_TraceLine(585,0,__PYX_ERR(1, 585, __pyx_L1_error))
  __pyx_v_x0 = pow(__pyx_v_r, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":586
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1             # <<<<<<<<<<<<<<
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2
 */
  __Pyx_TraceLine(586,0,__PYX_ERR(1, 586, __pyx_L1_error))
  __pyx_v_x1 = (__pyx_v_chi_1 * __pyx_v_X_1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":587
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2             # <<<<<<<<<<<<<<
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2
 */
  __Pyx_TraceLine(587,0,__PYX_ERR(1, 587, __pyx_L1_error))
  __pyx_v_x2 = (__pyx_v_chi_2 * __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":588
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2             # <<<<<<<<<<<<<<
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4
 */
  __Pyx_TraceLine(588,0,__PYX_ERR(1, 588, __pyx_L1_error))
  __pyx_v_x3 = (__pyx_v_x1 + __pyx_v_x2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":589
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2             # <<<<<<<<<<<<<<
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r
 */
  __Pyx_TraceLine(589,0,__PYX_ERR(1, 589, __pyx_L1_error))
  __pyx_v_x4 = pow(__pyx_v_x3, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":590
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4             # <<<<<<<<<<<<<<
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4
 */
  __Pyx_TraceLine(590,0,__PYX_ERR(1, 590, __pyx_L1_error))
  __pyx_v_x5 = (2.0 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":591
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r             # <<<<<<<<<<<<<<
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)
 */
  __Pyx_TraceLine(591,0,__PYX_ERR(1, 591, __pyx_L1_error))
  __pyx_v_x6 = (2.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":592
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4             # <<<<<<<<<<<<<<
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 */
  __Pyx_TraceLine(592,0,__PYX_ERR(1, 592, __pyx_L1_error))
  __pyx_v_x7 = (__pyx_v_x0 + __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":593
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)             # <<<<<<<<<<<<<<
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4
 */
  __Pyx_TraceLine(593,0,__PYX_ERR(1, 593, __pyx_L1_error))
  __pyx_v_x8 = (__pyx_v_r * ((-__pyx_v_x6) + __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":594
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x10 = r**4
 *         cdef double x11 = x10**(-1)
 */
  __Pyx_TraceLine(594,0,__PYX_ERR(1, 594, __pyx_L1_error))
  __pyx_v_x9 = pow((((2.0 * __pyx_v_x0) + __pyx_v_x5) + __pyx_v_x8), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":595
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4             # <<<<<<<<<<<<<<
 *         cdef double x11 = x10**(-1)
 *         cdef double x12 = 3.0*nu
 */
  __Pyx_TraceLine(595,0,__PYX_ERR(1, 595, __pyx_L1_error))
  __pyx_v_x10 = pow(__pyx_v_r, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":596
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4
 *         cdef double x11 = x10**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3
 */
  __Pyx_TraceLine(596,0,__PYX_ERR(1, 596, __pyx_L1_error))
  __pyx_v_x11 = pow(__pyx_v_x10, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":597
 *         cdef double x10 = r**4
 *         cdef double x11 = x10**(-1)
 *         cdef double x12 = 3.0*nu             # <<<<<<<<<<<<<<
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3
 */
  __Pyx_TraceLine(597,0,__PYX_ERR(1, 597, __pyx_L1_error))
  __pyx_v_x12 = (3.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":598
 *         cdef double x11 = x10**(-1)
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3             # <<<<<<<<<<<<<<
 *         cdef double x14 = r**3
 *         cdef double x15 = x14**(-1)
 */
  __Pyx_TraceLine(598,0,__PYX_ERR(1, 598, __pyx_L1_error))
  __pyx_v_x13 = (__pyx_v_pphi * __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":599
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3             # <<<<<<<<<<<<<<
 *         cdef double x15 = x14**(-1)
 *         cdef double x16 = x15*x4
 */
  __Pyx_TraceLine(599,0,__PYX_ERR(1, 599, __pyx_L1_error))
  __pyx_v_x14 = pow(__pyx_v_r, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":600
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3
 *         cdef double x15 = x14**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2
 */
  __Pyx_TraceLine(600,0,__PYX_ERR(1, 600, __pyx_L1_error))
  __pyx_v_x15 = pow(__pyx_v_x14, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":601
 *         cdef double x14 = r**3
 *         cdef double x15 = x14**(-1)
 *         cdef double x16 = x15*x4             # <<<<<<<<<<<<<<
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2
 */
  __Pyx_TraceLine(601,0,__PYX_ERR(1, 601, __pyx_L1_error))
  __pyx_v_x16 = (__pyx_v_x15 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":602
 *         cdef double x15 = x14**(-1)
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2             # <<<<<<<<<<<<<<
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18
 */
  __Pyx_TraceLine(602,0,__PYX_ERR(1, 602, __pyx_L1_error))
  __pyx_v_x17 = (__pyx_v_x1 - __pyx_v_x2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":603
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2             # <<<<<<<<<<<<<<
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19
 */
  __Pyx_TraceLine(603,0,__PYX_ERR(1, 603, __pyx_L1_error))
  __pyx_v_x18 = (__pyx_v_X_1 - __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":604
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18             # <<<<<<<<<<<<<<
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 */
  __Pyx_TraceLine(604,0,__PYX_ERR(1, 604, __pyx_L1_error))
  __pyx_v_x19 = (__pyx_v_x17 * __pyx_v_x18);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":605
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19             # <<<<<<<<<<<<<<
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3
 */
  __Pyx_TraceLine(605,0,__PYX_ERR(1, 605, __pyx_L1_error))
  __pyx_v_x20 = (__pyx_v_pphi * __pyx_v_x19);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":606
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 */
  __Pyx_TraceLine(606,0,__PYX_ERR(1, 606, __pyx_L1_error))
  __pyx_v_x21 = ((5.0 * __pyx_v_X_1) - (5.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":607
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3             # <<<<<<<<<<<<<<
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15
 */
  __Pyx_TraceLine(607,0,__PYX_ERR(1, 607, __pyx_L1_error))
  __pyx_v_x22 = (__pyx_v_x17 * __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":608
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4             # <<<<<<<<<<<<<<
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = x0**(-1)
 */
  __Pyx_TraceLine(608,0,__PYX_ERR(1, 608, __pyx_L1_error))
  __pyx_v_x23 = (((0.0416666666666667 * __pyx_v_x21) * __pyx_v_x22) - (0.25 * __pyx_v_x4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":609
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15             # <<<<<<<<<<<<<<
 *         cdef double x25 = x0**(-1)
 *         cdef double x26 = 0.71875*nu - 0.09375
 */
  __Pyx_TraceLine(609,0,__PYX_ERR(1, 609, __pyx_L1_error))
  __pyx_v_x24 = (2.0 * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":610
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = x0**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875
 */
  __Pyx_TraceLine(610,0,__PYX_ERR(1, 610, __pyx_L1_error))
  __pyx_v_x25 = pow(__pyx_v_x0, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":611
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = x0**(-1)
 *         cdef double x26 = 0.71875*nu - 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2
 */
  __Pyx_TraceLine(611,0,__PYX_ERR(1, 611, __pyx_L1_error))
  __pyx_v_x26 = ((0.71875 * __pyx_v_nu) - 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":612
 *         cdef double x25 = x0**(-1)
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875             # <<<<<<<<<<<<<<
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28
 */
  __Pyx_TraceLine(612,0,__PYX_ERR(1, 612, __pyx_L1_error))
  __pyx_v_x27 = ((-1.40625 * __pyx_v_nu) - 0.46875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":613
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2             # <<<<<<<<<<<<<<
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29
 */
  __Pyx_TraceLine(613,0,__PYX_ERR(1, 613, __pyx_L1_error))
  __pyx_v_x28 = pow(__pyx_v_pphi, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":614
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28             # <<<<<<<<<<<<<<
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2
 */
  __Pyx_TraceLine(614,0,__PYX_ERR(1, 614, __pyx_L1_error))
  __pyx_v_x29 = (__pyx_v_x15 * __pyx_v_x28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":615
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29             # <<<<<<<<<<<<<<
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 */
  __Pyx_TraceLine(615,0,__PYX_ERR(1, 615, __pyx_L1_error))
  __pyx_v_x30 = (2.0 * __pyx_v_x29);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":616
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2             # <<<<<<<<<<<<<<
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11
 */
  __Pyx_TraceLine(616,0,__PYX_ERR(1, 616, __pyx_L1_error))
  __pyx_v_x31 = pow(__pyx_v_nu, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":617
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33
 */
  __Pyx_TraceLine(617,0,__PYX_ERR(1, 617, __pyx_L1_error))
  __pyx_v_x32 = (((-2.0859375 * __pyx_v_nu) - (2.07161458333333 * __pyx_v_x31)) + 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":618
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11             # <<<<<<<<<<<<<<
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 */
  __Pyx_TraceLine(618,0,__PYX_ERR(1, 618, __pyx_L1_error))
  __pyx_v_x33 = (3.0 * __pyx_v_x11);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":619
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33             # <<<<<<<<<<<<<<
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4
 */
  __Pyx_TraceLine(619,0,__PYX_ERR(1, 619, __pyx_L1_error))
  __pyx_v_x34 = (__pyx_v_x28 * __pyx_v_x33);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":620
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5
 */
  __Pyx_TraceLine(620,0,__PYX_ERR(1, 620, __pyx_L1_error))
  __pyx_v_x35 = (((0.5859375 * __pyx_v_nu) + (1.34765625 * __pyx_v_x31)) + 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":621
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4             # <<<<<<<<<<<<<<
 *         cdef double x37 = r**5
 *         cdef double x38 = x37**(-1)
 */
  __Pyx_TraceLine(621,0,__PYX_ERR(1, 621, __pyx_L1_error))
  __pyx_v_x36 = pow(__pyx_v_pphi, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":622
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5             # <<<<<<<<<<<<<<
 *         cdef double x38 = x37**(-1)
 *         cdef double x39 = 4.0*x38
 */
  __Pyx_TraceLine(622,0,__PYX_ERR(1, 622, __pyx_L1_error))
  __pyx_v_x37 = pow(__pyx_v_r, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":623
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5
 *         cdef double x38 = x37**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39
 */
  __Pyx_TraceLine(623,0,__PYX_ERR(1, 623, __pyx_L1_error))
  __pyx_v_x38 = pow(__pyx_v_x37, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":624
 *         cdef double x37 = r**5
 *         cdef double x38 = x37**(-1)
 *         cdef double x39 = 4.0*x38             # <<<<<<<<<<<<<<
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375
 */
  __Pyx_TraceLine(624,0,__PYX_ERR(1, 624, __pyx_L1_error))
  __pyx_v_x39 = (4.0 * __pyx_v_x38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":625
 *         cdef double x38 = x37**(-1)
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39             # <<<<<<<<<<<<<<
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu
 */
  __Pyx_TraceLine(625,0,__PYX_ERR(1, 625, __pyx_L1_error))
  __pyx_v_x40 = (__pyx_v_x36 * __pyx_v_x39);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":626
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 */
  __Pyx_TraceLine(626,0,__PYX_ERR(1, 626, __pyx_L1_error))
  __pyx_v_x41 = ((0.34375 * __pyx_v_nu) + 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":627
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu             # <<<<<<<<<<<<<<
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 */
  __Pyx_TraceLine(627,0,__PYX_ERR(1, 627, __pyx_L1_error))
  __pyx_v_x42 = (0.46875 - (0.28125 * __pyx_v_nu));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":628
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15
 */
  __Pyx_TraceLine(628,0,__PYX_ERR(1, 628, __pyx_L1_error))
  __pyx_v_x43 = (((-0.2734375 * __pyx_v_nu) - (0.798177083333333 * __pyx_v_x31)) - 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":629
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4
 */
  __Pyx_TraceLine(629,0,__PYX_ERR(1, 629, __pyx_L1_error))
  __pyx_v_x44 = (((-0.3515625 * __pyx_v_nu) + (0.29296875 * __pyx_v_x31)) - 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":630
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15             # <<<<<<<<<<<<<<
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46
 */
  __Pyx_TraceLine(630,0,__PYX_ERR(1, 630, __pyx_L1_error))
  __pyx_v_x45 = ((__pyx_v_nu * __pyx_v_dSO) * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":631
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4             # <<<<<<<<<<<<<<
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25
 */
  __Pyx_TraceLine(631,0,__PYX_ERR(1, 631, __pyx_L1_error))
  __pyx_v_x46 = (__pyx_v_x25 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":632
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46             # <<<<<<<<<<<<<<
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)
 */
  __Pyx_TraceLine(632,0,__PYX_ERR(1, 632, __pyx_L1_error))
  __pyx_v_x47 = (0.0416666666666667 * __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":633
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25             # <<<<<<<<<<<<<<
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28
 */
  __Pyx_TraceLine(633,0,__PYX_ERR(1, 633, __pyx_L1_error))
  __pyx_v_x48 = (__pyx_v_x23 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":634
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36
 */
  __Pyx_TraceLine(634,0,__PYX_ERR(1, 634, __pyx_L1_error))
  __pyx_v_x49 = pow(__pyx_v_r, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":635
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28             # <<<<<<<<<<<<<<
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 */
  __Pyx_TraceLine(635,0,__PYX_ERR(1, 635, __pyx_L1_error))
  __pyx_v_x50 = (__pyx_v_x25 * __pyx_v_x28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":636
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36             # <<<<<<<<<<<<<<
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 */
  __Pyx_TraceLine(636,0,__PYX_ERR(1, 636, __pyx_L1_error))
  __pyx_v_x51 = (__pyx_v_x11 * __pyx_v_x36);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":637
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)             # <<<<<<<<<<<<<<
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4
 */
  __Pyx_TraceLine(637,0,__PYX_ERR(1, 637, __pyx_L1_error))
  __pyx_v_x52 = (__pyx_v_x3 * ((((((__pyx_v_x25 * (((-5.53125 * __pyx_v_nu) + (0.567708333333333 * __pyx_v_x31)) - 0.078125)) + (__pyx_v_x26 * __pyx_v_x49)) + (__pyx_v_x27 * __pyx_v_x50)) + (__pyx_v_x29 * __pyx_v_x32)) + (__pyx_v_x35 * __pyx_v_x51)) + 1.75));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":638
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)             # <<<<<<<<<<<<<<
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)
 */
  __Pyx_TraceLine(638,0,__PYX_ERR(1, 638, __pyx_L1_error))
  __pyx_v_x53 = (__pyx_v_x19 * ((((((__pyx_v_x25 * (((-0.03125 * __pyx_v_nu) + (0.536458333333333 * __pyx_v_x31)) + 0.078125)) + (__pyx_v_x29 * __pyx_v_x43)) + (__pyx_v_x41 * __pyx_v_x49)) + (__pyx_v_x42 * __pyx_v_x50)) + (__pyx_v_x44 * __pyx_v_x51)) + 0.25));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":639
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4             # <<<<<<<<<<<<<<
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55
 */
  __Pyx_TraceLine(639,0,__PYX_ERR(1, 639, __pyx_L1_error))
  __pyx_v_x54 = pow(__pyx_v_prst, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":640
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)             # <<<<<<<<<<<<<<
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6
 */
  __Pyx_TraceLine(640,0,__PYX_ERR(1, 640, __pyx_L1_error))
  __pyx_v_x55 = pow(__pyx_v_r, -4.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":641
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55             # <<<<<<<<<<<<<<
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)
 */
  __Pyx_TraceLine(641,0,__PYX_ERR(1, 641, __pyx_L1_error))
  __pyx_v_x56 = (__pyx_v_nu * __pyx_v_x55);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":642
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6             # <<<<<<<<<<<<<<
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58
 */
  __Pyx_TraceLine(642,0,__PYX_ERR(1, 642, __pyx_L1_error))
  __pyx_v_x57 = pow(__pyx_v_prst, 6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":643
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)             # <<<<<<<<<<<<<<
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)
 */
  __Pyx_TraceLine(643,0,__PYX_ERR(1, 643, __pyx_L1_error))
  __pyx_v_x58 = pow(__pyx_v_r, -3.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":644
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58             # <<<<<<<<<<<<<<
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8
 */
  __Pyx_TraceLine(644,0,__PYX_ERR(1, 644, __pyx_L1_error))
  __pyx_v_x59 = (__pyx_v_nu * __pyx_v_x58);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":645
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)             # <<<<<<<<<<<<<<
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61
 */
  __Pyx_TraceLine(645,0,__PYX_ERR(1, 645, __pyx_L1_error))
  __pyx_v_x60 = pow(__pyx_v_r, -2.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":646
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8             # <<<<<<<<<<<<<<
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49
 */
  __Pyx_TraceLine(646,0,__PYX_ERR(1, 646, __pyx_L1_error))
  __pyx_v_x61 = pow(__pyx_v_prst, 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":647
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61             # <<<<<<<<<<<<<<
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61
 */
  __Pyx_TraceLine(647,0,__PYX_ERR(1, 647, __pyx_L1_error))
  __pyx_v_x62 = (__pyx_v_nu * __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":648
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49             # <<<<<<<<<<<<<<
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31
 */
  __Pyx_TraceLine(648,0,__PYX_ERR(1, 648, __pyx_L1_error))
  __pyx_v_x63 = (__pyx_v_nu * __pyx_v_x49);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":649
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61             # <<<<<<<<<<<<<<
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65
 */
  __Pyx_TraceLine(649,0,__PYX_ERR(1, 649, __pyx_L1_error))
  __pyx_v_x64 = (0.121954868780449 * __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":650
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31             # <<<<<<<<<<<<<<
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3
 */
  __Pyx_TraceLine(650,0,__PYX_ERR(1, 650, __pyx_L1_error))
  __pyx_v_x65 = ((8.0 * __pyx_v_nu) - (6.0 * __pyx_v_x31));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":651
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65             # <<<<<<<<<<<<<<
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 */
  __Pyx_TraceLine(651,0,__PYX_ERR(1, 651, __pyx_L1_error))
  __pyx_v_x66 = (__pyx_v_x25 * __pyx_v_x65);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":652
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3             # <<<<<<<<<<<<<<
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54
 */
  __Pyx_TraceLine(652,0,__PYX_ERR(1, 652, __pyx_L1_error))
  __pyx_v_x67 = pow(__pyx_v_nu, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":653
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67             # <<<<<<<<<<<<<<
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 */
  __Pyx_TraceLine(653,0,__PYX_ERR(1, 653, __pyx_L1_error))
  __pyx_v_x68 = (((92.7110442849544 * __pyx_v_nu) - (131.0 * __pyx_v_x31)) + (10.0 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":654
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54             # <<<<<<<<<<<<<<
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70
 */
  __Pyx_TraceLine(654,0,__PYX_ERR(1, 654, __pyx_L1_error))
  __pyx_v_x69 = (__pyx_v_x15 * __pyx_v_x54);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":655
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67             # <<<<<<<<<<<<<<
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4
 */
  __Pyx_TraceLine(655,0,__PYX_ERR(1, 655, __pyx_L1_error))
  __pyx_v_x70 = (((-2.78300763695006 * __pyx_v_nu) - (5.4 * __pyx_v_x31)) + (6.0 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":656
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70             # <<<<<<<<<<<<<<
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 */
  __Pyx_TraceLine(656,0,__PYX_ERR(1, 656, __pyx_L1_error))
  __pyx_v_x71 = (__pyx_v_x25 * __pyx_v_x70);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":657
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4             # <<<<<<<<<<<<<<
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57
 */
  __Pyx_TraceLine(657,0,__PYX_ERR(1, 657, __pyx_L1_error))
  __pyx_v_x72 = pow(__pyx_v_nu, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":658
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72             # <<<<<<<<<<<<<<
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 */
  __Pyx_TraceLine(658,0,__PYX_ERR(1, 658, __pyx_L1_error))
  __pyx_v_x73 = ((((-33.9782122170436 * __pyx_v_nu) - (89.5298327361234 * __pyx_v_x31)) + (188.0 * __pyx_v_x67)) - (14.0 * __pyx_v_x72));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":659
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57             # <<<<<<<<<<<<<<
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75
 */
  __Pyx_TraceLine(659,0,__PYX_ERR(1, 659, __pyx_L1_error))
  __pyx_v_x74 = (__pyx_v_x15 * __pyx_v_x57);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":660
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72             # <<<<<<<<<<<<<<
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)
 */
  __Pyx_TraceLine(660,0,__PYX_ERR(1, 660, __pyx_L1_error))
  __pyx_v_x75 = ((((1.38977750996128 * __pyx_v_nu) + (3.33842023648322 * __pyx_v_x31)) + (3.42857142857143 * __pyx_v_x67)) - (6.0 * __pyx_v_x72));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":661
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75             # <<<<<<<<<<<<<<
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 */
  __Pyx_TraceLine(661,0,__PYX_ERR(1, 661, __pyx_L1_error))
  __pyx_v_x76 = (__pyx_v_x61 * __pyx_v_x75);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":662
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)             # <<<<<<<<<<<<<<
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54
 */
  __Pyx_TraceLine(662,0,__PYX_ERR(1, 662, __pyx_L1_error))
  __pyx_v_x77 = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":663
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67             # <<<<<<<<<<<<<<
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0
 */
  __Pyx_TraceLine(663,0,__PYX_ERR(1, 663, __pyx_L1_error))
  __pyx_v_x78 = (((__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_x77))) + (__pyx_v_x31 * ((118.4 * __pyx_v_x77) - 1796.13660498019))) + (602.318540416564 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":664
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54             # <<<<<<<<<<<<<<
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80
 */
  __Pyx_TraceLine(664,0,__PYX_ERR(1, 664, __pyx_L1_error))
  __pyx_v_x79 = (__pyx_v_x11 * __pyx_v_x54);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":665
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4
 */
  __Pyx_TraceLine(665,0,__PYX_ERR(1, 665, __pyx_L1_error))
  __pyx_v_x80 = (__pyx_v_r + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":666
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80             # <<<<<<<<<<<<<<
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82
 */
  __Pyx_TraceLine(666,0,__PYX_ERR(1, 666, __pyx_L1_error))
  __pyx_v_x81 = (__pyx_v_x4 * __pyx_v_x80);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":667
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4             # <<<<<<<<<<<<<<
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = x83**(-1)
 */
  __Pyx_TraceLine(667,0,__PYX_ERR(1, 667, __pyx_L1_error))
  __pyx_v_x82 = (__pyx_v_r * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":668
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82             # <<<<<<<<<<<<<<
 *         cdef double x84 = x83**(-1)
 *         cdef double x85 = x28*x49*x84
 */
  __Pyx_TraceLine(668,0,__PYX_ERR(1, 668, __pyx_L1_error))
  __pyx_v_x83 = (__pyx_v_x10 + (__pyx_v_x80 * __pyx_v_x82));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":669
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = x83**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)
 */
  __Pyx_TraceLine(669,0,__PYX_ERR(1, 669, __pyx_L1_error))
  __pyx_v_x84 = pow(__pyx_v_x83, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":670
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = x83**(-1)
 *         cdef double x85 = x28*x49*x84             # <<<<<<<<<<<<<<
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4
 */
  __Pyx_TraceLine(670,0,__PYX_ERR(1, 670, __pyx_L1_error))
  __pyx_v_x85 = ((__pyx_v_x28 * __pyx_v_x49) * __pyx_v_x84);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":671
 *         cdef double x84 = x83**(-1)
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)             # <<<<<<<<<<<<<<
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu
 */
  __Pyx_TraceLine(671,0,__PYX_ERR(1, 671, __pyx_L1_error))
  __pyx_v_x86 = pow(__pyx_v_r, -13.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":672
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4             # <<<<<<<<<<<<<<
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0
 */
  __Pyx_TraceLine(672,0,__PYX_ERR(1, 672, __pyx_L1_error))
  __pyx_v_x87 = pow(__pyx_v_x7, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":673
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu             # <<<<<<<<<<<<<<
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 */
  __Pyx_TraceLine(673,0,__PYX_ERR(1, 673, __pyx_L1_error))
  __pyx_v_x88 = (756.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":674
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0             # <<<<<<<<<<<<<<
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2
 */
  __Pyx_TraceLine(674,0,__PYX_ERR(1, 674, __pyx_L1_error))
  __pyx_v_x89 = (((336.0 * __pyx_v_r) + __pyx_v_x88) + 407.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":675
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0             # <<<<<<<<<<<<<<
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91
 */
  __Pyx_TraceLine(675,0,__PYX_ERR(1, 675, __pyx_L1_error))
  __pyx_v_x90 = (((((((2048.0 * __pyx_v_nu) * __pyx_v_x77) * __pyx_v_x89) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) - ((7.0 * __pyx_v_r) * (((938918.400156317 * __pyx_v_nu) - (185763.092693281 * __pyx_v_x31)) - 245760.0))) - (5416406.59541186 * __pyx_v_x31)) - 3440640.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":676
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2             # <<<<<<<<<<<<<<
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 */
  __Pyx_TraceLine(676,0,__PYX_ERR(1, 676, __pyx_L1_error))
  __pyx_v_x91 = pow(__pyx_v_x77, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":677
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91             # <<<<<<<<<<<<<<
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 */
  __Pyx_TraceLine(677,0,__PYX_ERR(1, 677, __pyx_L1_error))
  __pyx_v_x92 = (__pyx_v_x31 * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":678
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)             # <<<<<<<<<<<<<<
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0
 */
  __Pyx_TraceLine(678,0,__PYX_ERR(1, 678, __pyx_L1_error))
  __pyx_v_x93 = (__pyx_v_x67 * (((-163683964.822551 * __pyx_v_r) - (17833256.898555 * __pyx_v_x0)) - 1188987459.03162));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":679
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)             # <<<<<<<<<<<<<<
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0
 */
  __Pyx_TraceLine(679,0,__PYX_ERR(1, 679, __pyx_L1_error))
  __pyx_v_x94 = (__pyx_v_x31 * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (122635399361.987 * __pyx_v_r)) + (2064783811.32587 * __pyx_v_x0)) - (3089250703.76879 * __pyx_v_x10)) - (6178501407.53758 * __pyx_v_x14)) + (1426660551.8844 * __pyx_v_x37)) + 276057889687.011));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":680
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96
 */
  __Pyx_TraceLine(680,0,__PYX_ERR(1, 680, __pyx_L1_error))
  __pyx_v_x95 = ((588.0 * __pyx_v_nu) + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":681
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 */
  __Pyx_TraceLine(681,0,__PYX_ERR(1, 681, __pyx_L1_error))
  __pyx_v_x96 = (__pyx_v_x88 + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":682
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96             # <<<<<<<<<<<<<<
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77
 */
  __Pyx_TraceLine(682,0,__PYX_ERR(1, 682, __pyx_L1_error))
  __pyx_v_x97 = (__pyx_v_x14 * __pyx_v_x96);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":683
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0             # <<<<<<<<<<<<<<
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99
 */
  __Pyx_TraceLine(683,0,__PYX_ERR(1, 683, __pyx_L1_error))
  __pyx_v_x98 = ((((((((-38842241.4769507 * __pyx_v_nu) + ((240.0 * __pyx_v_r) * (((-7466.27061066206 * __pyx_v_nu) - (3024.0 * __pyx_v_x31)) + 17264.0))) + ((1920.0 * __pyx_v_x0) * __pyx_v_x95)) + ((480.0 * __pyx_v_x10) * __pyx_v_x96)) - (1882456.23663972 * __pyx_v_x31)) + (161280.0 * __pyx_v_x37)) + (960.0 * __pyx_v_x97)) + 13447680.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":684
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77             # <<<<<<<<<<<<<<
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r
 */
  __Pyx_TraceLine(684,0,__PYX_ERR(1, 684, __pyx_L1_error))
  __pyx_v_x99 = (__pyx_v_nu * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":685
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99             # <<<<<<<<<<<<<<
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 */
  __Pyx_TraceLine(685,0,__PYX_ERR(1, 685, __pyx_L1_error))
  __pyx_v_x100 = (__pyx_v_x98 * __pyx_v_x99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":686
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r             # <<<<<<<<<<<<<<
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6
 */
  __Pyx_TraceLine(686,0,__PYX_ERR(1, 686, __pyx_L1_error))
  __pyx_v_x101 = (8.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":687
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0             # <<<<<<<<<<<<<<
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r
 */
  __Pyx_TraceLine(687,0,__PYX_ERR(1, 687, __pyx_L1_error))
  __pyx_v_x102 = ((((4.0 * __pyx_v_x0) + __pyx_v_x101) + (2.0 * __pyx_v_x14)) + 16.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":688
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6             # <<<<<<<<<<<<<<
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r
 */
  __Pyx_TraceLine(688,0,__PYX_ERR(1, 688, __pyx_L1_error))
  __pyx_v_x103 = (7680.0 * __pyx_v_a6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":689
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r             # <<<<<<<<<<<<<<
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r
 */
  __Pyx_TraceLine(689,0,__PYX_ERR(1, 689, __pyx_L1_error))
  __pyx_v_x104 = (128.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":690
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r             # <<<<<<<<<<<<<<
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r
 */
  __Pyx_TraceLine(690,0,__PYX_ERR(1, 690, __pyx_L1_error))
  __pyx_v_x105 = (7704.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":691
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r             # <<<<<<<<<<<<<<
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 */
  __Pyx_TraceLine(691,0,__PYX_ERR(1, 691, __pyx_L1_error))
  __pyx_v_x106 = (148.04406601634 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":692
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r             # <<<<<<<<<<<<<<
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 */
  __Pyx_TraceLine(692,0,__PYX_ERR(1, 692, __pyx_L1_error))
  __pyx_v_x107 = (113485.217444961 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":693
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))             # <<<<<<<<<<<<<<
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90
 */
  __Pyx_TraceLine(693,0,__PYX_ERR(1, 693, __pyx_L1_error))
  __pyx_v_x108 = (__pyx_v_nu * ((((__pyx_v_x103 * (__pyx_v_x10 + __pyx_v_x102)) + (__pyx_v_x104 * (((((13218.7851094412 * __pyx_v_r) + (8529.39255472061 * __pyx_v_x0)) - (6852.34813868015 * __pyx_v_x10)) + (4264.6962773603 * __pyx_v_x14)) - 33722.4297811176))) + (__pyx_v_x106 * (((((3852.0 * __pyx_v_x0) + (349.0 * __pyx_v_x10)) + __pyx_v_x105) + (1926.0 * __pyx_v_x14)) + 36400.0))) + (__pyx_v_x107 * ((-__pyx_v_x10) + __pyx_v_x102))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":694
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 */
  __Pyx_TraceLine(694,0,__PYX_ERR(1, 694, __pyx_L1_error))
  __pyx_v_x109 = pow((((((((32768.0 * __pyx_v_x100) + (53760.0 * __pyx_v_x108)) + (13212057600.0 * __pyx_v_x37)) + (241555486248.807 * __pyx_v_x72)) + (67645734912.0 * __pyx_v_x92)) + (1120.0 * __pyx_v_x93)) + (7.0 * __pyx_v_x94)), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":695
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90             # <<<<<<<<<<<<<<
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)
 */
  __Pyx_TraceLine(695,0,__PYX_ERR(1, 695, __pyx_L1_error))
  __pyx_v_x110 = ((__pyx_v_x10 * __pyx_v_x109) * __pyx_v_x90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":696
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46             # <<<<<<<<<<<<<<
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91
 */
  __Pyx_TraceLine(696,0,__PYX_ERR(1, 696, __pyx_L1_error))
  __pyx_v_x111 = (__pyx_v_x110 + (0.000130208333333333 * __pyx_v_x46));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":697
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)             # <<<<<<<<<<<<<<
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 */
  __Pyx_TraceLine(697,0,__PYX_ERR(1, 697, __pyx_L1_error))
  __pyx_v_x112 = pow(__pyx_v_x111, -4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":698
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91             # <<<<<<<<<<<<<<
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114
 */
  __Pyx_TraceLine(698,0,__PYX_ERR(1, 698, __pyx_L1_error))
  __pyx_v_x113 = (__pyx_v_r * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":699
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913             # <<<<<<<<<<<<<<
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 */
  __Pyx_TraceLine(699,0,__PYX_ERR(1, 699, __pyx_L1_error))
  __pyx_v_x114 = (((-630116198.873299 * __pyx_v_nu) - (197773496.793534 * __pyx_v_x31)) + 5805304367.87913);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":700
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114             # <<<<<<<<<<<<<<
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14
 */
  __Pyx_TraceLine(700,0,__PYX_ERR(1, 700, __pyx_L1_error))
  __pyx_v_x115 = (__pyx_v_x0 * __pyx_v_x114);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":701
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329             # <<<<<<<<<<<<<<
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 */
  __Pyx_TraceLine(701,0,__PYX_ERR(1, 701, __pyx_L1_error))
  __pyx_v_x116 = (((-2675575.66847905 * __pyx_v_nu) - (138240.0 * __pyx_v_x31)) - 5278341.3229329);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":702
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14             # <<<<<<<<<<<<<<
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 */
  __Pyx_TraceLine(702,0,__PYX_ERR(1, 702, __pyx_L1_error))
  __pyx_v_x117 = (__pyx_v_x116 * __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":703
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)             # <<<<<<<<<<<<<<
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119
 */
  __Pyx_TraceLine(703,0,__PYX_ERR(1, 703, __pyx_L1_error))
  __pyx_v_x118 = (__pyx_v_nu * ((((-2510664218.28128 * __pyx_v_nu) - (42636451.6032331 * __pyx_v_x31)) + (14515200.0 * __pyx_v_x67)) + 1002013764.01019));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":704
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0             # <<<<<<<<<<<<<<
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0
 */
  __Pyx_TraceLine(704,0,__PYX_ERR(1, 704, __pyx_L1_error))
  __pyx_v_x119 = (((((43393301259014.8 * __pyx_v_nu) + (43133561885859.3 * __pyx_v_x31)) + (5927865218923.02 * __pyx_v_x67)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":705
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119             # <<<<<<<<<<<<<<
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121
 */
  __Pyx_TraceLine(705,0,__PYX_ERR(1, 705, __pyx_L1_error))
  __pyx_v_x120 = (__pyx_v_r * __pyx_v_x119);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":706
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0             # <<<<<<<<<<<<<<
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 */
  __Pyx_TraceLine(706,0,__PYX_ERR(1, 706, __pyx_L1_error))
  __pyx_v_x121 = ((14700.0 * __pyx_v_nu) + 42911.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":707
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121             # <<<<<<<<<<<<<<
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77
 */
  __Pyx_TraceLine(707,0,__PYX_ERR(1, 707, __pyx_L1_error))
  __pyx_v_x122 = (283115520.0 * __pyx_v_x121);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":708
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14             # <<<<<<<<<<<<<<
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 */
  __Pyx_TraceLine(708,0,__PYX_ERR(1, 708, __pyx_L1_error))
  __pyx_v_x123 = (((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + ((49152.0 * __pyx_v_r) * (((409207698.136075 * __pyx_v_nu) + (102574080.0 * __pyx_v_x31)) - 2119671837.36038))) + (__pyx_v_x0 * __pyx_v_x122)) + (879923036160.0 * __pyx_v_x14));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":709
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77             # <<<<<<<<<<<<<<
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r
 */
  __Pyx_TraceLine(709,0,__PYX_ERR(1, 709, __pyx_L1_error))
  __pyx_v_x124 = (__pyx_v_x123 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":710
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2             # <<<<<<<<<<<<<<
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0
 */
  __Pyx_TraceLine(710,0,__PYX_ERR(1, 710, __pyx_L1_error))
  __pyx_v_x125 = pow((((((__pyx_v_x113 - (1.59227685093395e-9 * __pyx_v_x115)) - (1.67189069348064e-7 * __pyx_v_x117)) + (9.55366110560367e-9 * __pyx_v_x118)) + (1.72773095804465e-13 * __pyx_v_x120)) + (1.72773095804465e-13 * __pyx_v_x124)), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":711
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r             # <<<<<<<<<<<<<<
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31
 */
  __Pyx_TraceLine(711,0,__PYX_ERR(1, 711, __pyx_L1_error))
  __pyx_v_x126 = (__pyx_v_nu * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":712
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0             # <<<<<<<<<<<<<<
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121
 */
  __Pyx_TraceLine(712,0,__PYX_ERR(1, 712, __pyx_L1_error))
  __pyx_v_x127 = (__pyx_v_nu * __pyx_v_x0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":713
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31             # <<<<<<<<<<<<<<
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31
 */
  __Pyx_TraceLine(713,0,__PYX_ERR(1, 713, __pyx_L1_error))
  __pyx_v_x128 = (__pyx_v_r * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":714
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121             # <<<<<<<<<<<<<<
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 */
  __Pyx_TraceLine(714,0,__PYX_ERR(1, 714, __pyx_L1_error))
  __pyx_v_x129 = (__pyx_v_r * __pyx_v_x121);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":715
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31             # <<<<<<<<<<<<<<
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 */
  __Pyx_TraceLine(715,0,__PYX_ERR(1, 715, __pyx_L1_error))
  __pyx_v_x130 = (__pyx_v_x0 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":716
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0             # <<<<<<<<<<<<<<
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77
 */
  __Pyx_TraceLine(716,0,__PYX_ERR(1, 716, __pyx_L1_error))
  __pyx_v_x131 = ((5041721180160.0 * __pyx_v_x31) - 104186110149937.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":717
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131             # <<<<<<<<<<<<<<
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 */
  __Pyx_TraceLine(717,0,__PYX_ERR(1, 717, __pyx_L1_error))
  __pyx_v_x132 = ((((-25392914995744.3 * __pyx_v_nu) - (__pyx_v_r * __pyx_v_x122)) - (879923036160.0 * __pyx_v_x0)) - __pyx_v_x131);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":718
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77             # <<<<<<<<<<<<<<
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)
 */
  __Pyx_TraceLine(718,0,__PYX_ERR(1, 718, __pyx_L1_error))
  __pyx_v_x133 = (__pyx_v_x132 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":719
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1             # <<<<<<<<<<<<<<
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31
 */
  __Pyx_TraceLine(719,0,__PYX_ERR(1, 719, __pyx_L1_error))
  __pyx_v_x134 = (((((((((((((-0.0438084424460039 * __pyx_v_nu) - (0.143521050466841 * __pyx_v_r)) + (0.0185696317637669 * __pyx_v_x0)) + (0.0385795738434214 * __pyx_v_x126)) + (0.00941289164152486 * __pyx_v_x127)) + (0.00662650629087394 * __pyx_v_x128)) - (1.18824456940711e-6 * __pyx_v_x129)) + (0.000486339502879429 * __pyx_v_x130)) - (3.63558293513537e-15 * __pyx_v_x133)) + (0.291062041428379 * __pyx_v_x31)) + (0.0244692826489756 * __pyx_v_x67)) + (0.0210425293255724 * __pyx_v_x91)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":720
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2
 */
  __Pyx_TraceLine(720,0,__PYX_ERR(1, 720, __pyx_L1_error))
  __pyx_v_x135 = pow(__pyx_v_x134, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":721
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31             # <<<<<<<<<<<<<<
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 */
  __Pyx_TraceLine(721,0,__PYX_ERR(1, 721, __pyx_L1_error))
  __pyx_v_x136 = (4.0 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":722
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2             # <<<<<<<<<<<<<<
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 */
  __Pyx_TraceLine(722,0,__PYX_ERR(1, 722, __pyx_L1_error))
  __pyx_v_x137 = pow(__pyx_v_x17, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":723
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)             # <<<<<<<<<<<<<<
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2
 */
  __Pyx_TraceLine(723,0,__PYX_ERR(1, 723, __pyx_L1_error))
  __pyx_v_x138 = ((((-0.46875 * __pyx_v_x137) * (((-5.0 * __pyx_v_nu) + __pyx_v_x136) + 1.0)) + ((((0.0625 * __pyx_v_x17) * __pyx_v_x21) * __pyx_v_x3) * ((18.0 * __pyx_v_nu) - 1.0))) - ((0.15625 * __pyx_v_x4) * (((-33.0 * __pyx_v_nu) + (32.0 * __pyx_v_x31)) - 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":724
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87             # <<<<<<<<<<<<<<
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2
 */
  __Pyx_TraceLine(724,0,__PYX_ERR(1, 724, __pyx_L1_error))
  __pyx_v_x139 = (((((__pyx_v_x112 * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x54) * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":725
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2             # <<<<<<<<<<<<<<
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)
 */
  __Pyx_TraceLine(725,0,__PYX_ERR(1, 725, __pyx_L1_error))
  __pyx_v_x140 = pow(__pyx_v_x7, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":726
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2             # <<<<<<<<<<<<<<
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31
 */
  __Pyx_TraceLine(726,0,__PYX_ERR(1, 726, __pyx_L1_error))
  __pyx_v_x141 = pow(__pyx_v_prst, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":727
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91
 */
  __Pyx_TraceLine(727,0,__PYX_ERR(1, 727, __pyx_L1_error))
  __pyx_v_x142 = pow(__pyx_v_x111, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":728
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31             # <<<<<<<<<<<<<<
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 */
  __Pyx_TraceLine(728,0,__PYX_ERR(1, 728, __pyx_L1_error))
  __pyx_v_x143 = (1822680546449.21 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":729
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91             # <<<<<<<<<<<<<<
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = x145**(-1)
 */
  __Pyx_TraceLine(729,0,__PYX_ERR(1, 729, __pyx_L1_error))
  __pyx_v_x144 = (5787938193408.0 * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":730
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0             # <<<<<<<<<<<<<<
 *         cdef double x146 = x145**(-1)
 *         cdef double x147 = 0.0625*x137
 */
  __Pyx_TraceLine(730,0,__PYX_ERR(1, 730, __pyx_L1_error))
  __pyx_v_x145 = (((((((((((((-12049908701745.2 * __pyx_v_nu) + (__pyx_v_r * __pyx_v_x143)) - (39476764256925.6 * __pyx_v_r)) + (5107745331375.71 * __pyx_v_x0)) + (10611661054566.2 * __pyx_v_x126)) + (2589101062873.81 * __pyx_v_x127)) - (326837426.241486 * __pyx_v_x129)) + (133772083200.0 * __pyx_v_x130)) - __pyx_v_x133) + __pyx_v_x144) + (80059249540278.2 * __pyx_v_x31)) + (6730497718123.02 * __pyx_v_x67)) + 275059053208689.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":731
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = x145**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22
 */
  __Pyx_TraceLine(731,0,__PYX_ERR(1, 731, __pyx_L1_error))
  __pyx_v_x146 = pow(__pyx_v_x145, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":732
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = x145**(-1)
 *         cdef double x147 = 0.0625*x137             # <<<<<<<<<<<<<<
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0
 */
  __Pyx_TraceLine(732,0,__PYX_ERR(1, 732, __pyx_L1_error))
  __pyx_v_x147 = (0.0625 * __pyx_v_x137);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":733
 *         cdef double x146 = x145**(-1)
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22             # <<<<<<<<<<<<<<
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4
 */
  __Pyx_TraceLine(733,0,__PYX_ERR(1, 733, __pyx_L1_error))
  __pyx_v_x148 = (0.125 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":734
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0             # <<<<<<<<<<<<<<
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 */
  __Pyx_TraceLine(734,0,__PYX_ERR(1, 734, __pyx_L1_error))
  __pyx_v_x149 = ((-1171.0 * __pyx_v_nu) - 861.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":735
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4             # <<<<<<<<<<<<<<
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22
 */
  __Pyx_TraceLine(735,0,__PYX_ERR(1, 735, __pyx_L1_error))
  __pyx_v_x150 = (0.015625 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":736
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)             # <<<<<<<<<<<<<<
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 */
  __Pyx_TraceLine(736,0,__PYX_ERR(1, 736, __pyx_L1_error))
  __pyx_v_x151 = (__pyx_v_x137 * (((115.0 * __pyx_v_nu) + __pyx_v_x136) - 37.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":737
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22             # <<<<<<<<<<<<<<
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 */
  __Pyx_TraceLine(737,0,__PYX_ERR(1, 737, __pyx_L1_error))
  __pyx_v_x152 = (0.03125 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":738
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)             # <<<<<<<<<<<<<<
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = x154**(-1)
 */
  __Pyx_TraceLine(738,0,__PYX_ERR(1, 738, __pyx_L1_error))
  __pyx_v_x153 = (__pyx_v_x18 * ((26.0 * __pyx_v_nu) + 449.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":739
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124             # <<<<<<<<<<<<<<
 *         cdef double x155 = x154**(-1)
 *         cdef double x156 = x145*x155*x37
 */
  __Pyx_TraceLine(739,0,__PYX_ERR(1, 739, __pyx_L1_error))
  __pyx_v_x154 = ((((((5787938193408.0 * __pyx_v_x113) - (9216.0 * __pyx_v_x115)) - (967680.0 * __pyx_v_x117)) + (55296.0 * __pyx_v_x118)) + __pyx_v_x120) + __pyx_v_x124);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":740
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = x154**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90
 */
  __Pyx_TraceLine(740,0,__PYX_ERR(1, 740, __pyx_L1_error))
  __pyx_v_x155 = pow(__pyx_v_x154, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":741
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = x154**(-1)
 *         cdef double x156 = x145*x155*x37             # <<<<<<<<<<<<<<
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 */
  __Pyx_TraceLine(741,0,__PYX_ERR(1, 741, __pyx_L1_error))
  __pyx_v_x156 = ((__pyx_v_x145 * __pyx_v_x155) * __pyx_v_x37);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":742
 *         cdef double x155 = x154**(-1)
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90             # <<<<<<<<<<<<<<
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 */
  __Pyx_TraceLine(742,0,__PYX_ERR(1, 742, __pyx_L1_error))
  __pyx_v_x157 = (__pyx_v_x109 * __pyx_v_x90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":743
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46             # <<<<<<<<<<<<<<
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 */
  __Pyx_TraceLine(743,0,__PYX_ERR(1, 743, __pyx_L1_error))
  __pyx_v_x158 = ((((__pyx_v_x11 * (((__pyx_v_x149 * __pyx_v_x150) + (0.015625 * __pyx_v_x151)) + (__pyx_v_x152 * __pyx_v_x153))) + (__pyx_v_x15 * (((__pyx_v_x147 * ((12.0 * __pyx_v_nu) - 3.0)) + (__pyx_v_x148 * ((-21.0 * __pyx_v_X_1) + (21.0 * __pyx_v_X_2)))) + (__pyx_v_x4 * (__pyx_v_x12 + 2.8125))))) + ((7680.0 * __pyx_v_x156) * __pyx_v_x157)) + __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":744
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158             # <<<<<<<<<<<<<<
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 */
  __Pyx_TraceLine(744,0,__PYX_ERR(1, 744, __pyx_L1_error))
  __pyx_v_x159 = (((((__pyx_v_x140 * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x158);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":745
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = x161**(-1)
 */
  __Pyx_TraceLine(745,0,__PYX_ERR(1, 745, __pyx_L1_error))
  __pyx_v_x160 = ((((((((((((((((1.27277314139085e-19 * __pyx_v_x139) * __pyx_v_x86) + ((1.69542100694444e-8 * __pyx_v_x159) * __pyx_v_x38)) + (__pyx_v_x25 * __pyx_v_x76)) + __pyx_v_x50) + ((147.443752990146 * __pyx_v_x54) * __pyx_v_x56)) + (__pyx_v_x54 * __pyx_v_x66)) - ((11.3175085791863 * __pyx_v_x57) * __pyx_v_x59)) + (__pyx_v_x57 * __pyx_v_x71)) + ((1.48275342024365 * __pyx_v_x60) * __pyx_v_x62)) + (__pyx_v_x63 * __pyx_v_x64)) + (__pyx_v_x68 * __pyx_v_x69)) + (__pyx_v_x73 * __pyx_v_x74)) + (__pyx_v_x78 * __pyx_v_x79)) - (__pyx_v_x81 * __pyx_v_x85)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":746
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x162 = x161**(-1)
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 */
  __Pyx_TraceLine(746,0,__PYX_ERR(1, 746, __pyx_L1_error))
  __pyx_v_x161 = ((__pyx_v_x46 * ((2.0 * __pyx_v_x49) + 1.0)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":747
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = x161**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22
 */
  __Pyx_TraceLine(747,0,__PYX_ERR(1, 747, __pyx_L1_error))
  __pyx_v_x162 = pow(__pyx_v_x161, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":748
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = x161**(-1)
 *         cdef double x163 = x137*(4.0*nu + 1.0)             # <<<<<<<<<<<<<<
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 */
  __Pyx_TraceLine(748,0,__PYX_ERR(1, 748, __pyx_L1_error))
  __pyx_v_x163 = (__pyx_v_x137 * ((4.0 * __pyx_v_nu) + 1.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":749
 *         cdef double x162 = x161**(-1)
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22             # <<<<<<<<<<<<<<
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 */
  __Pyx_TraceLine(749,0,__PYX_ERR(1, 749, __pyx_L1_error))
  __pyx_v_x164 = ((-__pyx_v_x21) * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":750
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)             # <<<<<<<<<<<<<<
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 */
  __Pyx_TraceLine(750,0,__PYX_ERR(1, 750, __pyx_L1_error))
  __pyx_v_x165 = (__pyx_v_x137 * (((-27.0 * __pyx_v_nu) + (28.0 * __pyx_v_x31)) - 3.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":751
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)             # <<<<<<<<<<<<<<
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167
 */
  __Pyx_TraceLine(751,0,__PYX_ERR(1, 751, __pyx_L1_error))
  __pyx_v_x166 = (__pyx_v_x152 * ((-39.0 * __pyx_v_X_1) + (39.0 * __pyx_v_X_2)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":752
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46             # <<<<<<<<<<<<<<
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)
 */
  __Pyx_TraceLine(752,0,__PYX_ERR(1, 752, __pyx_L1_error))
  __pyx_v_x167 = ((((__pyx_v_x11 * (((0.125 * __pyx_v_x163) + (0.25 * __pyx_v_x164)) + (1.125 * __pyx_v_x4))) + (7680.0 * __pyx_v_x110)) + (__pyx_v_x38 * ((((-__pyx_v_x150) * ((175.0 * __pyx_v_nu) + 225.0)) + (0.046875 * __pyx_v_x165)) + (__pyx_v_x166 * ((2.0 * __pyx_v_nu) - 3.0))))) + __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":753
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167             # <<<<<<<<<<<<<<
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0
 */
  __Pyx_TraceLine(753,0,__PYX_ERR(1, 753, __pyx_L1_error))
  __pyx_v_x168 = (__pyx_v_x162 * __pyx_v_x167);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":754
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)             # <<<<<<<<<<<<<<
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)
 */
  __Pyx_TraceLine(754,0,__PYX_ERR(1, 754, __pyx_L1_error))
  __pyx_v_x169 = pow((__pyx_v_x160 * __pyx_v_x168), -0.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":755
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5
 */
  __Pyx_TraceLine(755,0,__PYX_ERR(1, 755, __pyx_L1_error))
  __pyx_v_x170 = ((4.0 * __pyx_v_x49) + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":756
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)             # <<<<<<<<<<<<<<
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 */
  __Pyx_TraceLine(756,0,__PYX_ERR(1, 756, __pyx_L1_error))
  __pyx_v_x171 = pow(__pyx_v_r, -6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":757
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5             # <<<<<<<<<<<<<<
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49
 */
  __Pyx_TraceLine(757,0,__PYX_ERR(1, 757, __pyx_L1_error))
  __pyx_v_x172 = (__pyx_v_x15 * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":758
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0             # <<<<<<<<<<<<<<
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14
 */
  __Pyx_TraceLine(758,0,__PYX_ERR(1, 758, __pyx_L1_error))
  __pyx_v_x173 = (((((-6572428.80109422 * __pyx_v_nu) + (1300341.64885296 * __pyx_v_x31)) + ((2048.0 * __pyx_v_x63) * __pyx_v_x89)) + (688128.0 * __pyx_v_x99)) + 1720320.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":759
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49             # <<<<<<<<<<<<<<
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 */
  __Pyx_TraceLine(759,0,__PYX_ERR(1, 759, __pyx_L1_error))
  __pyx_v_x174 = (__pyx_v_x31 * __pyx_v_x49);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":760
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14             # <<<<<<<<<<<<<<
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 */
  __Pyx_TraceLine(760,0,__PYX_ERR(1, 760, __pyx_L1_error))
  __pyx_v_x175 = (4.0 * __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":761
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0             # <<<<<<<<<<<<<<
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 */
  __Pyx_TraceLine(761,0,__PYX_ERR(1, 761, __pyx_L1_error))
  __pyx_v_x176 = (((6.0 * __pyx_v_x0) + __pyx_v_x101) + 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":762
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2             # <<<<<<<<<<<<<<
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77
 */
  __Pyx_TraceLine(762,0,__PYX_ERR(1, 762, __pyx_L1_error))
  __pyx_v_x177 = (((1.31621673590926e-19 * __pyx_v_x90) * ((((((((53760.0 * __pyx_v_nu) * (((((((((3740417.71815805 * __pyx_v_r) + (2115968.85907902 * __pyx_v_x0)) - (938918.400156317 * __pyx_v_x10)) + (__pyx_v_x103 * (__pyx_v_x175 + __pyx_v_x176))) + (__pyx_v_x104 * ((((17058.7851094412 * __pyx_v_r) + (12794.0888320809 * __pyx_v_x0)) - (27409.3925547206 * __pyx_v_x14)) + 13218.7851094412))) + (__pyx_v_x106 * ((((5778.0 * __pyx_v_x0) + __pyx_v_x105) + (1396.0 * __pyx_v_x14)) + 7704.0))) + (__pyx_v_x107 * ((-__pyx_v_x175) + __pyx_v_x176))) + (1057984.42953951 * __pyx_v_x14)) + 2888096.47013111)) + (66060288000.0 * __pyx_v_x10)) + ((135291469824.0 * __pyx_v_x174) * __pyx_v_x77)) + ((7.0 * __pyx_v_x31) * ((((((-117964800.0 * __pyx_v_a6) + (4129567622.65173 * __pyx_v_r)) - (18535504222.6128 * __pyx_v_x0)) + (7133302759.42198 * __pyx_v_x10)) - (12357002815.0752 * __pyx_v_x14)) + 122635399361.987))) + ((32768.0 * __pyx_v_x63) * __pyx_v_x98)) + ((7.0 * __pyx_v_x67) * ((-5706642207.53758 * __pyx_v_r) - 26189434371.6082))) + ((32768.0 * __pyx_v_x99) * (((((((-1791904.9465589 * __pyx_v_nu) + ((3840.0 * __pyx_v_r) * __pyx_v_x95)) + ((2880.0 * __pyx_v_x0) * __pyx_v_x96)) + (806400.0 * __pyx_v_x10)) - (725760.0 * __pyx_v_x31)) + (1920.0 * __pyx_v_x97)) + 4143360.0)))) / pow((((((((1.35654132757922e-7 * __pyx_v_x100) + (2.22557561555966e-7 * __pyx_v_x108)) + (0.0546957463279941 * __pyx_v_x37)) + __pyx_v_x72) + (0.28004222119933 * __pyx_v_x92)) + (4.63661586574928e-9 * __pyx_v_x93)) + (2.8978849160933e-11 * __pyx_v_x94)), 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":763
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172             # <<<<<<<<<<<<<<
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 */
  __Pyx_TraceLine(763,0,__PYX_ERR(1, 763, __pyx_L1_error))
  __pyx_v_x178 = ((((((-7680.0 * __pyx_v_x10) * __pyx_v_x109) * __pyx_v_x173) + (__pyx_v_x10 * __pyx_v_x177)) - (((30720.0 * __pyx_v_x109) * __pyx_v_x14) * __pyx_v_x90)) + __pyx_v_x172);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":764
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77             # <<<<<<<<<<<<<<
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87
 */
  __Pyx_TraceLine(764,0,__PYX_ERR(1, 764, __pyx_L1_error))
  __pyx_v_x179 = (11575876386816.0 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":765
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1             # <<<<<<<<<<<<<<
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 */
  __Pyx_TraceLine(765,0,__PYX_ERR(1, 765, __pyx_L1_error))
  __pyx_v_x180 = (((((((((5807150888816.34 * __pyx_v_nu) + (10215490662751.4 * __pyx_v_r)) + (5178202125747.62 * __pyx_v_x126)) + (267544166400.0 * __pyx_v_x128)) - (__pyx_v_x132 * __pyx_v_x49)) + __pyx_v_x143) + (__pyx_v_x179 * __pyx_v_x49)) + (__pyx_v_x77 * (((4161798144000.0 * __pyx_v_nu) + (1759846072320.0 * __pyx_v_r)) + 12148770078720.0))) - 53501685054374.1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":766
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87             # <<<<<<<<<<<<<<
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158
 */
  __Pyx_TraceLine(766,0,__PYX_ERR(1, 766, __pyx_L1_error))
  __pyx_v_x181 = ((((__pyx_v_x125 * __pyx_v_x138) * __pyx_v_x54) * __pyx_v_x86) * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":767
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)             # <<<<<<<<<<<<<<
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178
 */
  __Pyx_TraceLine(767,0,__PYX_ERR(1, 767, __pyx_L1_error))
  __pyx_v_x182 = ((((((((-18432.0 * __pyx_v_r) * __pyx_v_x114) - ((2903040.0 * __pyx_v_x0) * __pyx_v_x116)) + __pyx_v_x119) + (__pyx_v_x123 * __pyx_v_x49)) + __pyx_v_x144) + __pyx_v_x179) + (__pyx_v_x77 * ((((20113376778784.3 * __pyx_v_nu) + (2639769108480.0 * __pyx_v_x0)) + (566231040.0 * __pyx_v_x129)) + __pyx_v_x131)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":768
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158             # <<<<<<<<<<<<<<
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38
 */
  __Pyx_TraceLine(768,0,__PYX_ERR(1, 768, __pyx_L1_error))
  __pyx_v_x183 = (__pyx_v_x141 * __pyx_v_x158);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":769
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178             # <<<<<<<<<<<<<<
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3
 */
  __Pyx_TraceLine(769,0,__PYX_ERR(1, 769, __pyx_L1_error))
  __pyx_v_x184 = (-__pyx_v_x178);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":770
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38             # <<<<<<<<<<<<<<
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5
 */
  __Pyx_TraceLine(770,0,__PYX_ERR(1, 770, __pyx_L1_error))
  __pyx_v_x185 = (__pyx_v_x154 * __pyx_v_x38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":771
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3             # <<<<<<<<<<<<<<
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7
 */
  __Pyx_TraceLine(771,0,__PYX_ERR(1, 771, __pyx_L1_error))
  __pyx_v_x186 = pow(__pyx_v_prst, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":772
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5             # <<<<<<<<<<<<<<
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186
 */
  __Pyx_TraceLine(772,0,__PYX_ERR(1, 772, __pyx_L1_error))
  __pyx_v_x187 = pow(__pyx_v_prst, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":773
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7             # <<<<<<<<<<<<<<
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187
 */
  __Pyx_TraceLine(773,0,__PYX_ERR(1, 773, __pyx_L1_error))
  __pyx_v_x188 = pow(__pyx_v_prst, 7.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":774
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186             # <<<<<<<<<<<<<<
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 */
  __Pyx_TraceLine(774,0,__PYX_ERR(1, 774, __pyx_L1_error))
  __pyx_v_x189 = (4.0 * __pyx_v_x186);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":775
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187             # <<<<<<<<<<<<<<
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi
 */
  __Pyx_TraceLine(775,0,__PYX_ERR(1, 775, __pyx_L1_error))
  __pyx_v_x190 = (6.0 * __pyx_v_x187);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":776
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)             # <<<<<<<<<<<<<<
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25
 */
  __Pyx_TraceLine(776,0,__PYX_ERR(1, 776, __pyx_L1_error))
  __pyx_v_x191 = ((__pyx_v_x167 * __pyx_v_x169) / ((__pyx_v_x170 * __pyx_v_x46) + 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":777
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi             # <<<<<<<<<<<<<<
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192
 */
  __Pyx_TraceLine(777,0,__PYX_ERR(1, 777, __pyx_L1_error))
  __pyx_v_x192 = (2.0 * __pyx_v_pphi);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":778
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25             # <<<<<<<<<<<<<<
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11
 */
  __Pyx_TraceLine(778,0,__PYX_ERR(1, 778, __pyx_L1_error))
  __pyx_v_x193 = (__pyx_v_x192 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":779
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192             # <<<<<<<<<<<<<<
 *         cdef double x195 = 4.0*pphi**3*x11
 *         cdef double y0 = 2.0*r
 */
  __Pyx_TraceLine(779,0,__PYX_ERR(1, 779, __pyx_L1_error))
  __pyx_v_x194 = (__pyx_v_x15 * __pyx_v_x192);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":780
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11             # <<<<<<<<<<<<<<
 *         cdef double y0 = 2.0*r
 *         cdef double y1 = r**2
 */
  __Pyx_TraceLine(780,0,__PYX_ERR(1, 780, __pyx_L1_error))
  __pyx_v_x195 = ((4.0 * pow(__pyx_v_pphi, 3.0)) * __pyx_v_x11);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":781
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11
 *         cdef double y0 = 2.0*r             # <<<<<<<<<<<<<<
 *         cdef double y1 = r**2
 *         cdef double y2 = chi_1*X_1
 */
  __Pyx_TraceLine(781,0,__PYX_ERR(1, 781, __pyx_L1_error))
  __pyx_v_y0 = (2.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":782
 *         cdef double x195 = 4.0*pphi**3*x11
 *         cdef double y0 = 2.0*r
 *         cdef double y1 = r**2             # <<<<<<<<<<<<<<
 *         cdef double y2 = chi_1*X_1
 *         cdef double y3 = chi_2*X_2
 */
  __Pyx_TraceLine(782,0,__PYX_ERR(1, 782, __pyx_L1_error))
  __pyx_v_y1 = pow(__pyx_v_r, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":783
 *         cdef double y0 = 2.0*r
 *         cdef double y1 = r**2
 *         cdef double y2 = chi_1*X_1             # <<<<<<<<<<<<<<
 *         cdef double y3 = chi_2*X_2
 *         cdef double y4 = y2 + y3
 */
  __Pyx_TraceLine(783,0,__PYX_ERR(1, 783, __pyx_L1_error))
  __pyx_v_y2 = (__pyx_v_chi_1 * __pyx_v_X_1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":784
 *         cdef double y1 = r**2
 *         cdef double y2 = chi_1*X_1
 *         cdef double y3 = chi_2*X_2             # <<<<<<<<<<<<<<
 *         cdef double y4 = y2 + y3
 *         cdef double y5 = y4**2
 */
  __Pyx_TraceLine(784,0,__PYX_ERR(1, 784, __pyx_L1_error))
  __pyx_v_y3 = (__pyx_v_chi_2 * __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":785
 *         cdef double y2 = chi_1*X_1
 *         cdef double y3 = chi_2*X_2
 *         cdef double y4 = y2 + y3             # <<<<<<<<<<<<<<
 *         cdef double y5 = y4**2
 *         cdef double y6 = y1 + y5
 */
  __Pyx_TraceLine(785,0,__PYX_ERR(1, 785, __pyx_L1_error))
  __pyx_v_y4 = (__pyx_v_y2 + __pyx_v_y3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":786
 *         cdef double y3 = chi_2*X_2
 *         cdef double y4 = y2 + y3
 *         cdef double y5 = y4**2             # <<<<<<<<<<<<<<
 *         cdef double y6 = y1 + y5
 *         cdef double y7 = r*(-y0 + y6)
 */
  __Pyx_TraceLine(786,0,__PYX_ERR(1, 786, __pyx_L1_error))
  __pyx_v_y5 = pow(__pyx_v_y4, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":787
 *         cdef double y4 = y2 + y3
 *         cdef double y5 = y4**2
 *         cdef double y6 = y1 + y5             # <<<<<<<<<<<<<<
 *         cdef double y7 = r*(-y0 + y6)
 *         cdef double y8 = 2.0*y5
 */
  __Pyx_TraceLine(787,0,__PYX_ERR(1, 787, __pyx_L1_error))
  __pyx_v_y6 = (__pyx_v_y1 + __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":788
 *         cdef double y5 = y4**2
 *         cdef double y6 = y1 + y5
 *         cdef double y7 = r*(-y0 + y6)             # <<<<<<<<<<<<<<
 *         cdef double y8 = 2.0*y5
 *         cdef double y9 = 2.0*y1 + y8
 */
  __Pyx_TraceLine(788,0,__PYX_ERR(1, 788, __pyx_L1_error))
  __pyx_v_y7 = (__pyx_v_r * ((-__pyx_v_y0) + __pyx_v_y6));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":789
 *         cdef double y6 = y1 + y5
 *         cdef double y7 = r*(-y0 + y6)
 *         cdef double y8 = 2.0*y5             # <<<<<<<<<<<<<<
 *         cdef double y9 = 2.0*y1 + y8
 *         cdef double y10 = (y7 + y9)**(-1)
 */
  __Pyx_TraceLine(789,0,__PYX_ERR(1, 789, __pyx_L1_error))
  __pyx_v_y8 = (2.0 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":790
 *         cdef double y7 = r*(-y0 + y6)
 *         cdef double y8 = 2.0*y5
 *         cdef double y9 = 2.0*y1 + y8             # <<<<<<<<<<<<<<
 *         cdef double y10 = (y7 + y9)**(-1)
 *         cdef double y11 = r**5
 */
  __Pyx_TraceLine(790,0,__PYX_ERR(1, 790, __pyx_L1_error))
  __pyx_v_y9 = ((2.0 * __pyx_v_y1) + __pyx_v_y8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":791
 *         cdef double y8 = 2.0*y5
 *         cdef double y9 = 2.0*y1 + y8
 *         cdef double y10 = (y7 + y9)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y11 = r**5
 *         cdef double y12 = y11**(-1)
 */
  __Pyx_TraceLine(791,0,__PYX_ERR(1, 791, __pyx_L1_error))
  __pyx_v_y10 = pow((__pyx_v_y7 + __pyx_v_y9), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":792
 *         cdef double y9 = 2.0*y1 + y8
 *         cdef double y10 = (y7 + y9)**(-1)
 *         cdef double y11 = r**5             # <<<<<<<<<<<<<<
 *         cdef double y12 = y11**(-1)
 *         cdef double y13 = 12.0*nu
 */
  __Pyx_TraceLine(792,0,__PYX_ERR(1, 792, __pyx_L1_error))
  __pyx_v_y11 = pow(__pyx_v_r, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":793
 *         cdef double y10 = (y7 + y9)**(-1)
 *         cdef double y11 = r**5
 *         cdef double y12 = y11**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y13 = 12.0*nu
 *         cdef double y14 = pphi*y4
 */
  __Pyx_TraceLine(793,0,__PYX_ERR(1, 793, __pyx_L1_error))
  __pyx_v_y12 = pow(__pyx_v_y11, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":794
 *         cdef double y11 = r**5
 *         cdef double y12 = y11**(-1)
 *         cdef double y13 = 12.0*nu             # <<<<<<<<<<<<<<
 *         cdef double y14 = pphi*y4
 *         cdef double y15 = dSO*y14
 */
  __Pyx_TraceLine(794,0,__PYX_ERR(1, 794, __pyx_L1_error))
  __pyx_v_y13 = (12.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":795
 *         cdef double y12 = y11**(-1)
 *         cdef double y13 = 12.0*nu
 *         cdef double y14 = pphi*y4             # <<<<<<<<<<<<<<
 *         cdef double y15 = dSO*y14
 *         cdef double y16 = r**4
 */
  __Pyx_TraceLine(795,0,__PYX_ERR(1, 795, __pyx_L1_error))
  __pyx_v_y14 = (__pyx_v_pphi * __pyx_v_y4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":796
 *         cdef double y13 = 12.0*nu
 *         cdef double y14 = pphi*y4
 *         cdef double y15 = dSO*y14             # <<<<<<<<<<<<<<
 *         cdef double y16 = r**4
 *         cdef double y17 = y16**(-1)
 */
  __Pyx_TraceLine(796,0,__PYX_ERR(1, 796, __pyx_L1_error))
  __pyx_v_y15 = (__pyx_v_dSO * __pyx_v_y14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":797
 *         cdef double y14 = pphi*y4
 *         cdef double y15 = dSO*y14
 *         cdef double y16 = r**4             # <<<<<<<<<<<<<<
 *         cdef double y17 = y16**(-1)
 *         cdef double y18 = 0.25*y5
 */
  __Pyx_TraceLine(797,0,__PYX_ERR(1, 797, __pyx_L1_error))
  __pyx_v_y16 = pow(__pyx_v_r, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":798
 *         cdef double y15 = dSO*y14
 *         cdef double y16 = r**4
 *         cdef double y17 = y16**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y18 = 0.25*y5
 *         cdef double y19 = y2 - y3
 */
  __Pyx_TraceLine(798,0,__PYX_ERR(1, 798, __pyx_L1_error))
  __pyx_v_y17 = pow(__pyx_v_y16, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":799
 *         cdef double y16 = r**4
 *         cdef double y17 = y16**(-1)
 *         cdef double y18 = 0.25*y5             # <<<<<<<<<<<<<<
 *         cdef double y19 = y2 - y3
 *         cdef double y20 = X_1 - X_2
 */
  __Pyx_TraceLine(799,0,__PYX_ERR(1, 799, __pyx_L1_error))
  __pyx_v_y18 = (0.25 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":800
 *         cdef double y17 = y16**(-1)
 *         cdef double y18 = 0.25*y5
 *         cdef double y19 = y2 - y3             # <<<<<<<<<<<<<<
 *         cdef double y20 = X_1 - X_2
 *         cdef double y21 = y19*y20
 */
  __Pyx_TraceLine(800,0,__PYX_ERR(1, 800, __pyx_L1_error))
  __pyx_v_y19 = (__pyx_v_y2 - __pyx_v_y3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":801
 *         cdef double y18 = 0.25*y5
 *         cdef double y19 = y2 - y3
 *         cdef double y20 = X_1 - X_2             # <<<<<<<<<<<<<<
 *         cdef double y21 = y19*y20
 *         cdef double y22 = pphi*y21
 */
  __Pyx_TraceLine(801,0,__PYX_ERR(1, 801, __pyx_L1_error))
  __pyx_v_y20 = (__pyx_v_X_1 - __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":802
 *         cdef double y19 = y2 - y3
 *         cdef double y20 = X_1 - X_2
 *         cdef double y21 = y19*y20             # <<<<<<<<<<<<<<
 *         cdef double y22 = pphi*y21
 *         cdef double y23 = 5.0*X_1 - 5.0*X_2
 */
  __Pyx_TraceLine(802,0,__PYX_ERR(1, 802, __pyx_L1_error))
  __pyx_v_y21 = (__pyx_v_y19 * __pyx_v_y20);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":803
 *         cdef double y20 = X_1 - X_2
 *         cdef double y21 = y19*y20
 *         cdef double y22 = pphi*y21             # <<<<<<<<<<<<<<
 *         cdef double y23 = 5.0*X_1 - 5.0*X_2
 *         cdef double y24 = y19*y4
 */
  __Pyx_TraceLine(803,0,__PYX_ERR(1, 803, __pyx_L1_error))
  __pyx_v_y22 = (__pyx_v_pphi * __pyx_v_y21);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":804
 *         cdef double y21 = y19*y20
 *         cdef double y22 = pphi*y21
 *         cdef double y23 = 5.0*X_1 - 5.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double y24 = y19*y4
 *         cdef double y25 = -y18 + 0.0416666666666667*y23*y24
 */
  __Pyx_TraceLine(804,0,__PYX_ERR(1, 804, __pyx_L1_error))
  __pyx_v_y23 = ((5.0 * __pyx_v_X_1) - (5.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":805
 *         cdef double y22 = pphi*y21
 *         cdef double y23 = 5.0*X_1 - 5.0*X_2
 *         cdef double y24 = y19*y4             # <<<<<<<<<<<<<<
 *         cdef double y25 = -y18 + 0.0416666666666667*y23*y24
 *         cdef double y26 = 6.0*y17
 */
  __Pyx_TraceLine(805,0,__PYX_ERR(1, 805, __pyx_L1_error))
  __pyx_v_y24 = (__pyx_v_y19 * __pyx_v_y4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":806
 *         cdef double y23 = 5.0*X_1 - 5.0*X_2
 *         cdef double y24 = y19*y4
 *         cdef double y25 = -y18 + 0.0416666666666667*y23*y24             # <<<<<<<<<<<<<<
 *         cdef double y26 = 6.0*y17
 *         cdef double y27 = r**3
 */
  __Pyx_TraceLine(806,0,__PYX_ERR(1, 806, __pyx_L1_error))
  __pyx_v_y25 = ((-__pyx_v_y18) + ((0.0416666666666667 * __pyx_v_y23) * __pyx_v_y24));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":807
 *         cdef double y24 = y19*y4
 *         cdef double y25 = -y18 + 0.0416666666666667*y23*y24
 *         cdef double y26 = 6.0*y17             # <<<<<<<<<<<<<<
 *         cdef double y27 = r**3
 *         cdef double y28 = y27**(-1)
 */
  __Pyx_TraceLine(807,0,__PYX_ERR(1, 807, __pyx_L1_error))
  __pyx_v_y26 = (6.0 * __pyx_v_y17);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":808
 *         cdef double y25 = -y18 + 0.0416666666666667*y23*y24
 *         cdef double y26 = 6.0*y17
 *         cdef double y27 = r**3             # <<<<<<<<<<<<<<
 *         cdef double y28 = y27**(-1)
 *         cdef double y29 = -1.40625*nu - 0.46875
 */
  __Pyx_TraceLine(808,0,__PYX_ERR(1, 808, __pyx_L1_error))
  __pyx_v_y27 = pow(__pyx_v_r, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":809
 *         cdef double y26 = 6.0*y17
 *         cdef double y27 = r**3
 *         cdef double y28 = y27**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y29 = -1.40625*nu - 0.46875
 *         cdef double y30 = pphi**2
 */
  __Pyx_TraceLine(809,0,__PYX_ERR(1, 809, __pyx_L1_error))
  __pyx_v_y28 = pow(__pyx_v_y27, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":810
 *         cdef double y27 = r**3
 *         cdef double y28 = y27**(-1)
 *         cdef double y29 = -1.40625*nu - 0.46875             # <<<<<<<<<<<<<<
 *         cdef double y30 = pphi**2
 *         cdef double y31 = y26*y30
 */
  __Pyx_TraceLine(810,0,__PYX_ERR(1, 810, __pyx_L1_error))
  __pyx_v_y29 = ((-1.40625 * __pyx_v_nu) - 0.46875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":811
 *         cdef double y28 = y27**(-1)
 *         cdef double y29 = -1.40625*nu - 0.46875
 *         cdef double y30 = pphi**2             # <<<<<<<<<<<<<<
 *         cdef double y31 = y26*y30
 *         cdef double y32 = nu**2
 */
  __Pyx_TraceLine(811,0,__PYX_ERR(1, 811, __pyx_L1_error))
  __pyx_v_y30 = pow(__pyx_v_pphi, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":812
 *         cdef double y29 = -1.40625*nu - 0.46875
 *         cdef double y30 = pphi**2
 *         cdef double y31 = y26*y30             # <<<<<<<<<<<<<<
 *         cdef double y32 = nu**2
 *         cdef double y33 = -2.0859375*nu - 2.07161458333333*y32 + 0.23046875
 */
  __Pyx_TraceLine(812,0,__PYX_ERR(1, 812, __pyx_L1_error))
  __pyx_v_y31 = (__pyx_v_y26 * __pyx_v_y30);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":813
 *         cdef double y30 = pphi**2
 *         cdef double y31 = y26*y30
 *         cdef double y32 = nu**2             # <<<<<<<<<<<<<<
 *         cdef double y33 = -2.0859375*nu - 2.07161458333333*y32 + 0.23046875
 *         cdef double y34 = 12.0*y12
 */
  __Pyx_TraceLine(813,0,__PYX_ERR(1, 813, __pyx_L1_error))
  __pyx_v_y32 = pow(__pyx_v_nu, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":814
 *         cdef double y31 = y26*y30
 *         cdef double y32 = nu**2
 *         cdef double y33 = -2.0859375*nu - 2.07161458333333*y32 + 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double y34 = 12.0*y12
 *         cdef double y35 = y30*y34
 */
  __Pyx_TraceLine(814,0,__PYX_ERR(1, 814, __pyx_L1_error))
  __pyx_v_y33 = (((-2.0859375 * __pyx_v_nu) - (2.07161458333333 * __pyx_v_y32)) + 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":815
 *         cdef double y32 = nu**2
 *         cdef double y33 = -2.0859375*nu - 2.07161458333333*y32 + 0.23046875
 *         cdef double y34 = 12.0*y12             # <<<<<<<<<<<<<<
 *         cdef double y35 = y30*y34
 *         cdef double y36 = r**(-6)
 */
  __Pyx_TraceLine(815,0,__PYX_ERR(1, 815, __pyx_L1_error))
  __pyx_v_y34 = (12.0 * __pyx_v_y12);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":816
 *         cdef double y33 = -2.0859375*nu - 2.07161458333333*y32 + 0.23046875
 *         cdef double y34 = 12.0*y12
 *         cdef double y35 = y30*y34             # <<<<<<<<<<<<<<
 *         cdef double y36 = r**(-6)
 *         cdef double y37 = 20.0*y36
 */
  __Pyx_TraceLine(816,0,__PYX_ERR(1, 816, __pyx_L1_error))
  __pyx_v_y35 = (__pyx_v_y30 * __pyx_v_y34);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":817
 *         cdef double y34 = 12.0*y12
 *         cdef double y35 = y30*y34
 *         cdef double y36 = r**(-6)             # <<<<<<<<<<<<<<
 *         cdef double y37 = 20.0*y36
 *         cdef double y38 = pphi**4
 */
  __Pyx_TraceLine(817,0,__PYX_ERR(1, 817, __pyx_L1_error))
  __pyx_v_y36 = pow(__pyx_v_r, -6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":818
 *         cdef double y35 = y30*y34
 *         cdef double y36 = r**(-6)
 *         cdef double y37 = 20.0*y36             # <<<<<<<<<<<<<<
 *         cdef double y38 = pphi**4
 *         cdef double y39 = 0.5859375*nu + 1.34765625*y32 + 0.41015625
 */
  __Pyx_TraceLine(818,0,__PYX_ERR(1, 818, __pyx_L1_error))
  __pyx_v_y37 = (20.0 * __pyx_v_y36);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":819
 *         cdef double y36 = r**(-6)
 *         cdef double y37 = 20.0*y36
 *         cdef double y38 = pphi**4             # <<<<<<<<<<<<<<
 *         cdef double y39 = 0.5859375*nu + 1.34765625*y32 + 0.41015625
 *         cdef double y40 = y38*y39
 */
  __Pyx_TraceLine(819,0,__PYX_ERR(1, 819, __pyx_L1_error))
  __pyx_v_y38 = pow(__pyx_v_pphi, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":820
 *         cdef double y37 = 20.0*y36
 *         cdef double y38 = pphi**4
 *         cdef double y39 = 0.5859375*nu + 1.34765625*y32 + 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double y40 = y38*y39
 *         cdef double y41 = 0.46875 - 0.28125*nu
 */
  __Pyx_TraceLine(820,0,__PYX_ERR(1, 820, __pyx_L1_error))
  __pyx_v_y39 = (((0.5859375 * __pyx_v_nu) + (1.34765625 * __pyx_v_y32)) + 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":821
 *         cdef double y38 = pphi**4
 *         cdef double y39 = 0.5859375*nu + 1.34765625*y32 + 0.41015625
 *         cdef double y40 = y38*y39             # <<<<<<<<<<<<<<
 *         cdef double y41 = 0.46875 - 0.28125*nu
 *         cdef double y42 = -0.2734375*nu - 0.798177083333333*y32 - 0.23046875
 */
  __Pyx_TraceLine(821,0,__PYX_ERR(1, 821, __pyx_L1_error))
  __pyx_v_y40 = (__pyx_v_y38 * __pyx_v_y39);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":822
 *         cdef double y39 = 0.5859375*nu + 1.34765625*y32 + 0.41015625
 *         cdef double y40 = y38*y39
 *         cdef double y41 = 0.46875 - 0.28125*nu             # <<<<<<<<<<<<<<
 *         cdef double y42 = -0.2734375*nu - 0.798177083333333*y32 - 0.23046875
 *         cdef double y43 = -0.3515625*nu + 0.29296875*y32 - 0.41015625
 */
  __Pyx_TraceLine(822,0,__PYX_ERR(1, 822, __pyx_L1_error))
  __pyx_v_y41 = (0.46875 - (0.28125 * __pyx_v_nu));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":823
 *         cdef double y40 = y38*y39
 *         cdef double y41 = 0.46875 - 0.28125*nu
 *         cdef double y42 = -0.2734375*nu - 0.798177083333333*y32 - 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double y43 = -0.3515625*nu + 0.29296875*y32 - 0.41015625
 *         cdef double y44 = y38*y43
 */
  __Pyx_TraceLine(823,0,__PYX_ERR(1, 823, __pyx_L1_error))
  __pyx_v_y42 = (((-0.2734375 * __pyx_v_nu) - (0.798177083333333 * __pyx_v_y32)) - 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":824
 *         cdef double y41 = 0.46875 - 0.28125*nu
 *         cdef double y42 = -0.2734375*nu - 0.798177083333333*y32 - 0.23046875
 *         cdef double y43 = -0.3515625*nu + 0.29296875*y32 - 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double y44 = y38*y43
 *         cdef double y45 = y0 - 2.0
 */
  __Pyx_TraceLine(824,0,__PYX_ERR(1, 824, __pyx_L1_error))
  __pyx_v_y43 = (((-0.3515625 * __pyx_v_nu) + (0.29296875 * __pyx_v_y32)) - 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":825
 *         cdef double y42 = -0.2734375*nu - 0.798177083333333*y32 - 0.23046875
 *         cdef double y43 = -0.3515625*nu + 0.29296875*y32 - 0.41015625
 *         cdef double y44 = y38*y43             # <<<<<<<<<<<<<<
 *         cdef double y45 = y0 - 2.0
 *         cdef double y46 = 3.0*nu
 */
  __Pyx_TraceLine(825,0,__PYX_ERR(1, 825, __pyx_L1_error))
  __pyx_v_y44 = (__pyx_v_y38 * __pyx_v_y43);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":826
 *         cdef double y43 = -0.3515625*nu + 0.29296875*y32 - 0.41015625
 *         cdef double y44 = y38*y43
 *         cdef double y45 = y0 - 2.0             # <<<<<<<<<<<<<<
 *         cdef double y46 = 3.0*nu
 *         cdef double y47 = y17*y46
 */
  __Pyx_TraceLine(826,0,__PYX_ERR(1, 826, __pyx_L1_error))
  __pyx_v_y45 = (__pyx_v_y0 - 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":827
 *         cdef double y44 = y38*y43
 *         cdef double y45 = y0 - 2.0
 *         cdef double y46 = 3.0*nu             # <<<<<<<<<<<<<<
 *         cdef double y47 = y17*y46
 *         cdef double y48 = y28*y5
 */
  __Pyx_TraceLine(827,0,__PYX_ERR(1, 827, __pyx_L1_error))
  __pyx_v_y46 = (3.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":828
 *         cdef double y45 = y0 - 2.0
 *         cdef double y46 = 3.0*nu
 *         cdef double y47 = y17*y46             # <<<<<<<<<<<<<<
 *         cdef double y48 = y28*y5
 *         cdef double y49 = 0.0833333333333333*y48
 */
  __Pyx_TraceLine(828,0,__PYX_ERR(1, 828, __pyx_L1_error))
  __pyx_v_y47 = (__pyx_v_y17 * __pyx_v_y46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":829
 *         cdef double y46 = 3.0*nu
 *         cdef double y47 = y17*y46
 *         cdef double y48 = y28*y5             # <<<<<<<<<<<<<<
 *         cdef double y49 = 0.0833333333333333*y48
 *         cdef double y50 = y25*y28
 */
  __Pyx_TraceLine(829,0,__PYX_ERR(1, 829, __pyx_L1_error))
  __pyx_v_y48 = (__pyx_v_y28 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":830
 *         cdef double y47 = y17*y46
 *         cdef double y48 = y28*y5
 *         cdef double y49 = 0.0833333333333333*y48             # <<<<<<<<<<<<<<
 *         cdef double y50 = y25*y28
 *         cdef double y51 = y1**(-1)
 */
  __Pyx_TraceLine(830,0,__PYX_ERR(1, 830, __pyx_L1_error))
  __pyx_v_y49 = (0.0833333333333333 * __pyx_v_y48);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":831
 *         cdef double y48 = y28*y5
 *         cdef double y49 = 0.0833333333333333*y48
 *         cdef double y50 = y25*y28             # <<<<<<<<<<<<<<
 *         cdef double y51 = y1**(-1)
 *         cdef double y52 = 0.71875*nu - 0.09375
 */
  __Pyx_TraceLine(831,0,__PYX_ERR(1, 831, __pyx_L1_error))
  __pyx_v_y50 = (__pyx_v_y25 * __pyx_v_y28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":832
 *         cdef double y49 = 0.0833333333333333*y48
 *         cdef double y50 = y25*y28
 *         cdef double y51 = y1**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y52 = 0.71875*nu - 0.09375
 *         cdef double y53 = y28*y30
 */
  __Pyx_TraceLine(832,0,__PYX_ERR(1, 832, __pyx_L1_error))
  __pyx_v_y51 = pow(__pyx_v_y1, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":833
 *         cdef double y50 = y25*y28
 *         cdef double y51 = y1**(-1)
 *         cdef double y52 = 0.71875*nu - 0.09375             # <<<<<<<<<<<<<<
 *         cdef double y53 = y28*y30
 *         cdef double y54 = 2.0*y53
 */
  __Pyx_TraceLine(833,0,__PYX_ERR(1, 833, __pyx_L1_error))
  __pyx_v_y52 = ((0.71875 * __pyx_v_nu) - 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":834
 *         cdef double y51 = y1**(-1)
 *         cdef double y52 = 0.71875*nu - 0.09375
 *         cdef double y53 = y28*y30             # <<<<<<<<<<<<<<
 *         cdef double y54 = 2.0*y53
 *         cdef double y55 = 3.0*y17
 */
  __Pyx_TraceLine(834,0,__PYX_ERR(1, 834, __pyx_L1_error))
  __pyx_v_y53 = (__pyx_v_y28 * __pyx_v_y30);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":835
 *         cdef double y52 = 0.71875*nu - 0.09375
 *         cdef double y53 = y28*y30
 *         cdef double y54 = 2.0*y53             # <<<<<<<<<<<<<<
 *         cdef double y55 = 3.0*y17
 *         cdef double y56 = y30*y55
 */
  __Pyx_TraceLine(835,0,__PYX_ERR(1, 835, __pyx_L1_error))
  __pyx_v_y54 = (2.0 * __pyx_v_y53);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":836
 *         cdef double y53 = y28*y30
 *         cdef double y54 = 2.0*y53
 *         cdef double y55 = 3.0*y17             # <<<<<<<<<<<<<<
 *         cdef double y56 = y30*y55
 *         cdef double y57 = 4.0*y12
 */
  __Pyx_TraceLine(836,0,__PYX_ERR(1, 836, __pyx_L1_error))
  __pyx_v_y55 = (3.0 * __pyx_v_y17);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":837
 *         cdef double y54 = 2.0*y53
 *         cdef double y55 = 3.0*y17
 *         cdef double y56 = y30*y55             # <<<<<<<<<<<<<<
 *         cdef double y57 = 4.0*y12
 *         cdef double y58 = -y28*(-11.0625*nu + 1.13541666666667*y32 - 0.15625) - y29*y54 - y33*y56 - y40*y57 - y51*y52
 */
  __Pyx_TraceLine(837,0,__PYX_ERR(1, 837, __pyx_L1_error))
  __pyx_v_y56 = (__pyx_v_y30 * __pyx_v_y55);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":838
 *         cdef double y55 = 3.0*y17
 *         cdef double y56 = y30*y55
 *         cdef double y57 = 4.0*y12             # <<<<<<<<<<<<<<
 *         cdef double y58 = -y28*(-11.0625*nu + 1.13541666666667*y32 - 0.15625) - y29*y54 - y33*y56 - y40*y57 - y51*y52
 *         cdef double y59 = 0.34375*nu + 0.09375
 */
  __Pyx_TraceLine(838,0,__PYX_ERR(1, 838, __pyx_L1_error))
  __pyx_v_y57 = (4.0 * __pyx_v_y12);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":839
 *         cdef double y56 = y30*y55
 *         cdef double y57 = 4.0*y12
 *         cdef double y58 = -y28*(-11.0625*nu + 1.13541666666667*y32 - 0.15625) - y29*y54 - y33*y56 - y40*y57 - y51*y52             # <<<<<<<<<<<<<<
 *         cdef double y59 = 0.34375*nu + 0.09375
 *         cdef double y60 = -y28*(-0.0625*nu + 1.07291666666667*y32 + 0.15625) - y41*y54 - y42*y56 - y44*y57 - y51*y59
 */
  __Pyx_TraceLine(839,0,__PYX_ERR(1, 839, __pyx_L1_error))
  __pyx_v_y58 = ((((((-__pyx_v_y28) * (((-11.0625 * __pyx_v_nu) + (1.13541666666667 * __pyx_v_y32)) - 0.15625)) - (__pyx_v_y29 * __pyx_v_y54)) - (__pyx_v_y33 * __pyx_v_y56)) - (__pyx_v_y40 * __pyx_v_y57)) - (__pyx_v_y51 * __pyx_v_y52));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":840
 *         cdef double y57 = 4.0*y12
 *         cdef double y58 = -y28*(-11.0625*nu + 1.13541666666667*y32 - 0.15625) - y29*y54 - y33*y56 - y40*y57 - y51*y52
 *         cdef double y59 = 0.34375*nu + 0.09375             # <<<<<<<<<<<<<<
 *         cdef double y60 = -y28*(-0.0625*nu + 1.07291666666667*y32 + 0.15625) - y41*y54 - y42*y56 - y44*y57 - y51*y59
 *         cdef double y61 = y6 + 0.5*y7
 */
  __Pyx_TraceLine(840,0,__PYX_ERR(1, 840, __pyx_L1_error))
  __pyx_v_y59 = ((0.34375 * __pyx_v_nu) + 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":841
 *         cdef double y58 = -y28*(-11.0625*nu + 1.13541666666667*y32 - 0.15625) - y29*y54 - y33*y56 - y40*y57 - y51*y52
 *         cdef double y59 = 0.34375*nu + 0.09375
 *         cdef double y60 = -y28*(-0.0625*nu + 1.07291666666667*y32 + 0.15625) - y41*y54 - y42*y56 - y44*y57 - y51*y59             # <<<<<<<<<<<<<<
 *         cdef double y61 = y6 + 0.5*y7
 *         cdef double y62 = y61**(-2)
 */
  __Pyx_TraceLine(841,0,__PYX_ERR(1, 841, __pyx_L1_error))
  __pyx_v_y60 = ((((((-__pyx_v_y28) * (((-0.0625 * __pyx_v_nu) + (1.07291666666667 * __pyx_v_y32)) + 0.15625)) - (__pyx_v_y41 * __pyx_v_y54)) - (__pyx_v_y42 * __pyx_v_y56)) - (__pyx_v_y44 * __pyx_v_y57)) - (__pyx_v_y51 * __pyx_v_y59));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":842
 *         cdef double y59 = 0.34375*nu + 0.09375
 *         cdef double y60 = -y28*(-0.0625*nu + 1.07291666666667*y32 + 0.15625) - y41*y54 - y42*y56 - y44*y57 - y51*y59
 *         cdef double y61 = y6 + 0.5*y7             # <<<<<<<<<<<<<<
 *         cdef double y62 = y61**(-2)
 *         cdef double y63 = 0.25*y62
 */
  __Pyx_TraceLine(842,0,__PYX_ERR(1, 842, __pyx_L1_error))
  __pyx_v_y61 = (__pyx_v_y6 + (0.5 * __pyx_v_y7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":843
 *         cdef double y60 = -y28*(-0.0625*nu + 1.07291666666667*y32 + 0.15625) - y41*y54 - y42*y56 - y44*y57 - y51*y59
 *         cdef double y61 = y6 + 0.5*y7
 *         cdef double y62 = y61**(-2)             # <<<<<<<<<<<<<<
 *         cdef double y63 = 0.25*y62
 *         cdef double y64 = r*y45
 */
  __Pyx_TraceLine(843,0,__PYX_ERR(1, 843, __pyx_L1_error))
  __pyx_v_y62 = pow(__pyx_v_y61, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":844
 *         cdef double y61 = y6 + 0.5*y7
 *         cdef double y62 = y61**(-2)
 *         cdef double y63 = 0.25*y62             # <<<<<<<<<<<<<<
 *         cdef double y64 = r*y45
 *         cdef double y65 = 0.5*y5
 */
  __Pyx_TraceLine(844,0,__PYX_ERR(1, 844, __pyx_L1_error))
  __pyx_v_y63 = (0.25 * __pyx_v_y62);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":845
 *         cdef double y62 = y61**(-2)
 *         cdef double y63 = 0.25*y62
 *         cdef double y64 = r*y45             # <<<<<<<<<<<<<<
 *         cdef double y65 = 0.5*y5
 *         cdef double y66 = nu*y28
 */
  __Pyx_TraceLine(845,0,__PYX_ERR(1, 845, __pyx_L1_error))
  __pyx_v_y64 = (__pyx_v_r * __pyx_v_y45);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":846
 *         cdef double y63 = 0.25*y62
 *         cdef double y64 = r*y45
 *         cdef double y65 = 0.5*y5             # <<<<<<<<<<<<<<
 *         cdef double y66 = nu*y28
 *         cdef double y67 = y5*y51
 */
  __Pyx_TraceLine(846,0,__PYX_ERR(1, 846, __pyx_L1_error))
  __pyx_v_y65 = (0.5 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":847
 *         cdef double y64 = r*y45
 *         cdef double y65 = 0.5*y5
 *         cdef double y66 = nu*y28             # <<<<<<<<<<<<<<
 *         cdef double y67 = y5*y51
 *         cdef double y68 = 0.0416666666666667*y67
 */
  __Pyx_TraceLine(847,0,__PYX_ERR(1, 847, __pyx_L1_error))
  __pyx_v_y66 = (__pyx_v_nu * __pyx_v_y28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":848
 *         cdef double y65 = 0.5*y5
 *         cdef double y66 = nu*y28
 *         cdef double y67 = y5*y51             # <<<<<<<<<<<<<<
 *         cdef double y68 = 0.0416666666666667*y67
 *         cdef double y69 = pphi*y51
 */
  __Pyx_TraceLine(848,0,__PYX_ERR(1, 848, __pyx_L1_error))
  __pyx_v_y67 = (__pyx_v_y5 * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":849
 *         cdef double y66 = nu*y28
 *         cdef double y67 = y5*y51
 *         cdef double y68 = 0.0416666666666667*y67             # <<<<<<<<<<<<<<
 *         cdef double y69 = pphi*y51
 *         cdef double y70 = y25*y4
 */
  __Pyx_TraceLine(849,0,__PYX_ERR(1, 849, __pyx_L1_error))
  __pyx_v_y68 = (0.0416666666666667 * __pyx_v_y67);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":850
 *         cdef double y67 = y5*y51
 *         cdef double y68 = 0.0416666666666667*y67
 *         cdef double y69 = pphi*y51             # <<<<<<<<<<<<<<
 *         cdef double y70 = y25*y4
 *         cdef double y71 = r**(-1)
 */
  __Pyx_TraceLine(850,0,__PYX_ERR(1, 850, __pyx_L1_error))
  __pyx_v_y69 = (__pyx_v_pphi * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":851
 *         cdef double y68 = 0.0416666666666667*y67
 *         cdef double y69 = pphi*y51
 *         cdef double y70 = y25*y4             # <<<<<<<<<<<<<<
 *         cdef double y71 = r**(-1)
 *         cdef double y72 = y30*y51
 */
  __Pyx_TraceLine(851,0,__PYX_ERR(1, 851, __pyx_L1_error))
  __pyx_v_y70 = (__pyx_v_y25 * __pyx_v_y4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":852
 *         cdef double y69 = pphi*y51
 *         cdef double y70 = y25*y4
 *         cdef double y71 = r**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y72 = y30*y51
 *         cdef double y73 = y17*y38
 */
  __Pyx_TraceLine(852,0,__PYX_ERR(1, 852, __pyx_L1_error))
  __pyx_v_y71 = pow(__pyx_v_r, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":853
 *         cdef double y70 = y25*y4
 *         cdef double y71 = r**(-1)
 *         cdef double y72 = y30*y51             # <<<<<<<<<<<<<<
 *         cdef double y73 = y17*y38
 *         cdef double y74 = y4*(y29*y72 + y33*y53 + y39*y73 + y51*(-5.53125*nu + 0.567708333333333*y32 - 0.078125) + y52*y71 + 1.75)
 */
  __Pyx_TraceLine(853,0,__PYX_ERR(1, 853, __pyx_L1_error))
  __pyx_v_y72 = (__pyx_v_y30 * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":854
 *         cdef double y71 = r**(-1)
 *         cdef double y72 = y30*y51
 *         cdef double y73 = y17*y38             # <<<<<<<<<<<<<<
 *         cdef double y74 = y4*(y29*y72 + y33*y53 + y39*y73 + y51*(-5.53125*nu + 0.567708333333333*y32 - 0.078125) + y52*y71 + 1.75)
 *         cdef double y75 = y21*(y41*y72 + y42*y53 + y43*y73 + y51*(-0.03125*nu + 0.536458333333333*y32 + 0.078125) + y59*y71 + 0.25)
 */
  __Pyx_TraceLine(854,0,__PYX_ERR(1, 854, __pyx_L1_error))
  __pyx_v_y73 = (__pyx_v_y17 * __pyx_v_y38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":855
 *         cdef double y72 = y30*y51
 *         cdef double y73 = y17*y38
 *         cdef double y74 = y4*(y29*y72 + y33*y53 + y39*y73 + y51*(-5.53125*nu + 0.567708333333333*y32 - 0.078125) + y52*y71 + 1.75)             # <<<<<<<<<<<<<<
 *         cdef double y75 = y21*(y41*y72 + y42*y53 + y43*y73 + y51*(-0.03125*nu + 0.536458333333333*y32 + 0.078125) + y59*y71 + 0.25)
 *         cdef double y76 = prst**4
 */
  __Pyx_TraceLine(855,0,__PYX_ERR(1, 855, __pyx_L1_error))
  __pyx_v_y74 = (__pyx_v_y4 * ((((((__pyx_v_y29 * __pyx_v_y72) + (__pyx_v_y33 * __pyx_v_y53)) + (__pyx_v_y39 * __pyx_v_y73)) + (__pyx_v_y51 * (((-5.53125 * __pyx_v_nu) + (0.567708333333333 * __pyx_v_y32)) - 0.078125))) + (__pyx_v_y52 * __pyx_v_y71)) + 1.75));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":856
 *         cdef double y73 = y17*y38
 *         cdef double y74 = y4*(y29*y72 + y33*y53 + y39*y73 + y51*(-5.53125*nu + 0.567708333333333*y32 - 0.078125) + y52*y71 + 1.75)
 *         cdef double y75 = y21*(y41*y72 + y42*y53 + y43*y73 + y51*(-0.03125*nu + 0.536458333333333*y32 + 0.078125) + y59*y71 + 0.25)             # <<<<<<<<<<<<<<
 *         cdef double y76 = prst**4
 *         cdef double y77 = r**(-4.5)
 */
  __Pyx_TraceLine(856,0,__PYX_ERR(1, 856, __pyx_L1_error))
  __pyx_v_y75 = (__pyx_v_y21 * ((((((__pyx_v_y41 * __pyx_v_y72) + (__pyx_v_y42 * __pyx_v_y53)) + (__pyx_v_y43 * __pyx_v_y73)) + (__pyx_v_y51 * (((-0.03125 * __pyx_v_nu) + (0.536458333333333 * __pyx_v_y32)) + 0.078125))) + (__pyx_v_y59 * __pyx_v_y71)) + 0.25));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":857
 *         cdef double y74 = y4*(y29*y72 + y33*y53 + y39*y73 + y51*(-5.53125*nu + 0.567708333333333*y32 - 0.078125) + y52*y71 + 1.75)
 *         cdef double y75 = y21*(y41*y72 + y42*y53 + y43*y73 + y51*(-0.03125*nu + 0.536458333333333*y32 + 0.078125) + y59*y71 + 0.25)
 *         cdef double y76 = prst**4             # <<<<<<<<<<<<<<
 *         cdef double y77 = r**(-4.5)
 *         cdef double y78 = nu*y77
 */
  __Pyx_TraceLine(857,0,__PYX_ERR(1, 857, __pyx_L1_error))
  __pyx_v_y76 = pow(__pyx_v_prst, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":858
 *         cdef double y75 = y21*(y41*y72 + y42*y53 + y43*y73 + y51*(-0.03125*nu + 0.536458333333333*y32 + 0.078125) + y59*y71 + 0.25)
 *         cdef double y76 = prst**4
 *         cdef double y77 = r**(-4.5)             # <<<<<<<<<<<<<<
 *         cdef double y78 = nu*y77
 *         cdef double y79 = r**(-3.5)
 */
  __Pyx_TraceLine(858,0,__PYX_ERR(1, 858, __pyx_L1_error))
  __pyx_v_y77 = pow(__pyx_v_r, -4.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":859
 *         cdef double y76 = prst**4
 *         cdef double y77 = r**(-4.5)
 *         cdef double y78 = nu*y77             # <<<<<<<<<<<<<<
 *         cdef double y79 = r**(-3.5)
 *         cdef double y80 = prst**6
 */
  __Pyx_TraceLine(859,0,__PYX_ERR(1, 859, __pyx_L1_error))
  __pyx_v_y78 = (__pyx_v_nu * __pyx_v_y77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":860
 *         cdef double y77 = r**(-4.5)
 *         cdef double y78 = nu*y77
 *         cdef double y79 = r**(-3.5)             # <<<<<<<<<<<<<<
 *         cdef double y80 = prst**6
 *         cdef double y81 = nu*y80
 */
  __Pyx_TraceLine(860,0,__PYX_ERR(1, 860, __pyx_L1_error))
  __pyx_v_y79 = pow(__pyx_v_r, -3.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":861
 *         cdef double y78 = nu*y77
 *         cdef double y79 = r**(-3.5)
 *         cdef double y80 = prst**6             # <<<<<<<<<<<<<<
 *         cdef double y81 = nu*y80
 *         cdef double y82 = r**(-2.5)
 */
  __Pyx_TraceLine(861,0,__PYX_ERR(1, 861, __pyx_L1_error))
  __pyx_v_y80 = pow(__pyx_v_prst, 6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":862
 *         cdef double y79 = r**(-3.5)
 *         cdef double y80 = prst**6
 *         cdef double y81 = nu*y80             # <<<<<<<<<<<<<<
 *         cdef double y82 = r**(-2.5)
 *         cdef double y83 = prst**8
 */
  __Pyx_TraceLine(862,0,__PYX_ERR(1, 862, __pyx_L1_error))
  __pyx_v_y81 = (__pyx_v_nu * __pyx_v_y80);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":863
 *         cdef double y80 = prst**6
 *         cdef double y81 = nu*y80
 *         cdef double y82 = r**(-2.5)             # <<<<<<<<<<<<<<
 *         cdef double y83 = prst**8
 *         cdef double y84 = nu*y83
 */
  __Pyx_TraceLine(863,0,__PYX_ERR(1, 863, __pyx_L1_error))
  __pyx_v_y82 = pow(__pyx_v_r, -2.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":864
 *         cdef double y81 = nu*y80
 *         cdef double y82 = r**(-2.5)
 *         cdef double y83 = prst**8             # <<<<<<<<<<<<<<
 *         cdef double y84 = nu*y83
 *         cdef double y85 = nu*y71
 */
  __Pyx_TraceLine(864,0,__PYX_ERR(1, 864, __pyx_L1_error))
  __pyx_v_y83 = pow(__pyx_v_prst, 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":865
 *         cdef double y82 = r**(-2.5)
 *         cdef double y83 = prst**8
 *         cdef double y84 = nu*y83             # <<<<<<<<<<<<<<
 *         cdef double y85 = nu*y71
 *         cdef double y86 = 0.121954868780449*y83
 */
  __Pyx_TraceLine(865,0,__PYX_ERR(1, 865, __pyx_L1_error))
  __pyx_v_y84 = (__pyx_v_nu * __pyx_v_y83);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":866
 *         cdef double y83 = prst**8
 *         cdef double y84 = nu*y83
 *         cdef double y85 = nu*y71             # <<<<<<<<<<<<<<
 *         cdef double y86 = 0.121954868780449*y83
 *         cdef double y87 = 8.0*nu - 6.0*y32
 */
  __Pyx_TraceLine(866,0,__PYX_ERR(1, 866, __pyx_L1_error))
  __pyx_v_y85 = (__pyx_v_nu * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":867
 *         cdef double y84 = nu*y83
 *         cdef double y85 = nu*y71
 *         cdef double y86 = 0.121954868780449*y83             # <<<<<<<<<<<<<<
 *         cdef double y87 = 8.0*nu - 6.0*y32
 *         cdef double y88 = y76*y87
 */
  __Pyx_TraceLine(867,0,__PYX_ERR(1, 867, __pyx_L1_error))
  __pyx_v_y86 = (0.121954868780449 * __pyx_v_y83);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":868
 *         cdef double y85 = nu*y71
 *         cdef double y86 = 0.121954868780449*y83
 *         cdef double y87 = 8.0*nu - 6.0*y32             # <<<<<<<<<<<<<<
 *         cdef double y88 = y76*y87
 *         cdef double y89 = nu**3
 */
  __Pyx_TraceLine(868,0,__PYX_ERR(1, 868, __pyx_L1_error))
  __pyx_v_y87 = ((8.0 * __pyx_v_nu) - (6.0 * __pyx_v_y32));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":869
 *         cdef double y86 = 0.121954868780449*y83
 *         cdef double y87 = 8.0*nu - 6.0*y32
 *         cdef double y88 = y76*y87             # <<<<<<<<<<<<<<
 *         cdef double y89 = nu**3
 *         cdef double y90 = 92.7110442849544*nu - 131.0*y32 + 10.0*y89
 */
  __Pyx_TraceLine(869,0,__PYX_ERR(1, 869, __pyx_L1_error))
  __pyx_v_y88 = (__pyx_v_y76 * __pyx_v_y87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":870
 *         cdef double y87 = 8.0*nu - 6.0*y32
 *         cdef double y88 = y76*y87
 *         cdef double y89 = nu**3             # <<<<<<<<<<<<<<
 *         cdef double y90 = 92.7110442849544*nu - 131.0*y32 + 10.0*y89
 *         cdef double y91 = y76*y90
 */
  __Pyx_TraceLine(870,0,__PYX_ERR(1, 870, __pyx_L1_error))
  __pyx_v_y89 = pow(__pyx_v_nu, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":871
 *         cdef double y88 = y76*y87
 *         cdef double y89 = nu**3
 *         cdef double y90 = 92.7110442849544*nu - 131.0*y32 + 10.0*y89             # <<<<<<<<<<<<<<
 *         cdef double y91 = y76*y90
 *         cdef double y92 = -2.78300763695006*nu - 5.4*y32 + 6.0*y89
 */
  __Pyx_TraceLine(871,0,__PYX_ERR(1, 871, __pyx_L1_error))
  __pyx_v_y90 = (((92.7110442849544 * __pyx_v_nu) - (131.0 * __pyx_v_y32)) + (10.0 * __pyx_v_y89));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":872
 *         cdef double y89 = nu**3
 *         cdef double y90 = 92.7110442849544*nu - 131.0*y32 + 10.0*y89
 *         cdef double y91 = y76*y90             # <<<<<<<<<<<<<<
 *         cdef double y92 = -2.78300763695006*nu - 5.4*y32 + 6.0*y89
 *         cdef double y93 = y80*y92
 */
  __Pyx_TraceLine(872,0,__PYX_ERR(1, 872, __pyx_L1_error))
  __pyx_v_y91 = (__pyx_v_y76 * __pyx_v_y90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":873
 *         cdef double y90 = 92.7110442849544*nu - 131.0*y32 + 10.0*y89
 *         cdef double y91 = y76*y90
 *         cdef double y92 = -2.78300763695006*nu - 5.4*y32 + 6.0*y89             # <<<<<<<<<<<<<<
 *         cdef double y93 = y80*y92
 *         cdef double y94 = nu**4
 */
  __Pyx_TraceLine(873,0,__PYX_ERR(1, 873, __pyx_L1_error))
  __pyx_v_y92 = (((-2.78300763695006 * __pyx_v_nu) - (5.4 * __pyx_v_y32)) + (6.0 * __pyx_v_y89));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":874
 *         cdef double y91 = y76*y90
 *         cdef double y92 = -2.78300763695006*nu - 5.4*y32 + 6.0*y89
 *         cdef double y93 = y80*y92             # <<<<<<<<<<<<<<
 *         cdef double y94 = nu**4
 *         cdef double y95 = -33.9782122170436*nu - 89.5298327361234*y32 + 188.0*y89 - 14.0*y94
 */
  __Pyx_TraceLine(874,0,__PYX_ERR(1, 874, __pyx_L1_error))
  __pyx_v_y93 = (__pyx_v_y80 * __pyx_v_y92);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":875
 *         cdef double y92 = -2.78300763695006*nu - 5.4*y32 + 6.0*y89
 *         cdef double y93 = y80*y92
 *         cdef double y94 = nu**4             # <<<<<<<<<<<<<<
 *         cdef double y95 = -33.9782122170436*nu - 89.5298327361234*y32 + 188.0*y89 - 14.0*y94
 *         cdef double y96 = y80*y95
 */
  __Pyx_TraceLine(875,0,__PYX_ERR(1, 875, __pyx_L1_error))
  __pyx_v_y94 = pow(__pyx_v_nu, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":876
 *         cdef double y93 = y80*y92
 *         cdef double y94 = nu**4
 *         cdef double y95 = -33.9782122170436*nu - 89.5298327361234*y32 + 188.0*y89 - 14.0*y94             # <<<<<<<<<<<<<<
 *         cdef double y96 = y80*y95
 *         cdef double y97 = 1.38977750996128*nu + 3.33842023648322*y32 + 3.42857142857143*y89 - 6.0*y94
 */
  __Pyx_TraceLine(876,0,__PYX_ERR(1, 876, __pyx_L1_error))
  __pyx_v_y95 = ((((-33.9782122170436 * __pyx_v_nu) - (89.5298327361234 * __pyx_v_y32)) + (188.0 * __pyx_v_y89)) - (14.0 * __pyx_v_y94));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":877
 *         cdef double y94 = nu**4
 *         cdef double y95 = -33.9782122170436*nu - 89.5298327361234*y32 + 188.0*y89 - 14.0*y94
 *         cdef double y96 = y80*y95             # <<<<<<<<<<<<<<
 *         cdef double y97 = 1.38977750996128*nu + 3.33842023648322*y32 + 3.42857142857143*y89 - 6.0*y94
 *         cdef double y98 = y83*y97
 */
  __Pyx_TraceLine(877,0,__PYX_ERR(1, 877, __pyx_L1_error))
  __pyx_v_y96 = (__pyx_v_y80 * __pyx_v_y95);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":878
 *         cdef double y95 = -33.9782122170436*nu - 89.5298327361234*y32 + 188.0*y89 - 14.0*y94
 *         cdef double y96 = y80*y95
 *         cdef double y97 = 1.38977750996128*nu + 3.33842023648322*y32 + 3.42857142857143*y89 - 6.0*y94             # <<<<<<<<<<<<<<
 *         cdef double y98 = y83*y97
 *         cdef double y99 = log(r)
 */
  __Pyx_TraceLine(878,0,__PYX_ERR(1, 878, __pyx_L1_error))
  __pyx_v_y97 = ((((1.38977750996128 * __pyx_v_nu) + (3.33842023648322 * __pyx_v_y32)) + (3.42857142857143 * __pyx_v_y89)) - (6.0 * __pyx_v_y94));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":879
 *         cdef double y96 = y80*y95
 *         cdef double y97 = 1.38977750996128*nu + 3.33842023648322*y32 + 3.42857142857143*y89 - 6.0*y94
 *         cdef double y98 = y83*y97             # <<<<<<<<<<<<<<
 *         cdef double y99 = log(r)
 *         cdef double y100 = nu*(452.542166996693 - 51.6952380952381*y99) + y32*(118.4*y99 - 1796.13660498019) + 602.318540416564*y89
 */
  __Pyx_TraceLine(879,0,__PYX_ERR(1, 879, __pyx_L1_error))
  __pyx_v_y98 = (__pyx_v_y83 * __pyx_v_y97);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":880
 *         cdef double y97 = 1.38977750996128*nu + 3.33842023648322*y32 + 3.42857142857143*y89 - 6.0*y94
 *         cdef double y98 = y83*y97
 *         cdef double y99 = log(r)             # <<<<<<<<<<<<<<
 *         cdef double y100 = nu*(452.542166996693 - 51.6952380952381*y99) + y32*(118.4*y99 - 1796.13660498019) + 602.318540416564*y89
 *         cdef double y101 = y17*y76
 */
  __Pyx_TraceLine(880,0,__PYX_ERR(1, 880, __pyx_L1_error))
  __pyx_v_y99 = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":881
 *         cdef double y98 = y83*y97
 *         cdef double y99 = log(r)
 *         cdef double y100 = nu*(452.542166996693 - 51.6952380952381*y99) + y32*(118.4*y99 - 1796.13660498019) + 602.318540416564*y89             # <<<<<<<<<<<<<<
 *         cdef double y101 = y17*y76
 *         cdef double y102 = r + 2.0
 */
  __Pyx_TraceLine(881,0,__PYX_ERR(1, 881, __pyx_L1_error))
  __pyx_v_y100 = (((__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_y99))) + (__pyx_v_y32 * ((118.4 * __pyx_v_y99) - 1796.13660498019))) + (602.318540416564 * __pyx_v_y89));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":882
 *         cdef double y99 = log(r)
 *         cdef double y100 = nu*(452.542166996693 - 51.6952380952381*y99) + y32*(118.4*y99 - 1796.13660498019) + 602.318540416564*y89
 *         cdef double y101 = y17*y76             # <<<<<<<<<<<<<<
 *         cdef double y102 = r + 2.0
 *         cdef double y103 = r*y5
 */
  __Pyx_TraceLine(882,0,__PYX_ERR(1, 882, __pyx_L1_error))
  __pyx_v_y101 = (__pyx_v_y17 * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":883
 *         cdef double y100 = nu*(452.542166996693 - 51.6952380952381*y99) + y32*(118.4*y99 - 1796.13660498019) + 602.318540416564*y89
 *         cdef double y101 = y17*y76
 *         cdef double y102 = r + 2.0             # <<<<<<<<<<<<<<
 *         cdef double y103 = r*y5
 *         cdef double y104 = y102*y103 + y16
 */
  __Pyx_TraceLine(883,0,__PYX_ERR(1, 883, __pyx_L1_error))
  __pyx_v_y102 = (__pyx_v_r + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":884
 *         cdef double y101 = y17*y76
 *         cdef double y102 = r + 2.0
 *         cdef double y103 = r*y5             # <<<<<<<<<<<<<<
 *         cdef double y104 = y102*y103 + y16
 *         cdef double y105 = y104**(-1)
 */
  __Pyx_TraceLine(884,0,__PYX_ERR(1, 884, __pyx_L1_error))
  __pyx_v_y103 = (__pyx_v_r * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":885
 *         cdef double y102 = r + 2.0
 *         cdef double y103 = r*y5
 *         cdef double y104 = y102*y103 + y16             # <<<<<<<<<<<<<<
 *         cdef double y105 = y104**(-1)
 *         cdef double y106 = y105*y30
 */
  __Pyx_TraceLine(885,0,__PYX_ERR(1, 885, __pyx_L1_error))
  __pyx_v_y104 = ((__pyx_v_y102 * __pyx_v_y103) + __pyx_v_y16);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":886
 *         cdef double y103 = r*y5
 *         cdef double y104 = y102*y103 + y16
 *         cdef double y105 = y104**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y106 = y105*y30
 *         cdef double y107 = y102*y5
 */
  __Pyx_TraceLine(886,0,__PYX_ERR(1, 886, __pyx_L1_error))
  __pyx_v_y105 = pow(__pyx_v_y104, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":887
 *         cdef double y104 = y102*y103 + y16
 *         cdef double y105 = y104**(-1)
 *         cdef double y106 = y105*y30             # <<<<<<<<<<<<<<
 *         cdef double y107 = y102*y5
 *         cdef double y108 = y107*y71
 */
  __Pyx_TraceLine(887,0,__PYX_ERR(1, 887, __pyx_L1_error))
  __pyx_v_y106 = (__pyx_v_y105 * __pyx_v_y30);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":888
 *         cdef double y105 = y104**(-1)
 *         cdef double y106 = y105*y30
 *         cdef double y107 = y102*y5             # <<<<<<<<<<<<<<
 *         cdef double y108 = y107*y71
 *         cdef double y109 = y99**2
 */
  __Pyx_TraceLine(888,0,__PYX_ERR(1, 888, __pyx_L1_error))
  __pyx_v_y107 = (__pyx_v_y102 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":889
 *         cdef double y106 = y105*y30
 *         cdef double y107 = y102*y5
 *         cdef double y108 = y107*y71             # <<<<<<<<<<<<<<
 *         cdef double y109 = y99**2
 *         cdef double y110 = y109*y32
 */
  __Pyx_TraceLine(889,0,__PYX_ERR(1, 889, __pyx_L1_error))
  __pyx_v_y108 = (__pyx_v_y107 * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":890
 *         cdef double y107 = y102*y5
 *         cdef double y108 = y107*y71
 *         cdef double y109 = y99**2             # <<<<<<<<<<<<<<
 *         cdef double y110 = y109*y32
 *         cdef double y111 = y89*(-163683964.822551*r - 17833256.898555*y1 - 1188987459.03162)
 */
  __Pyx_TraceLine(890,0,__PYX_ERR(1, 890, __pyx_L1_error))
  __pyx_v_y109 = pow(__pyx_v_y99, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":891
 *         cdef double y108 = y107*y71
 *         cdef double y109 = y99**2
 *         cdef double y110 = y109*y32             # <<<<<<<<<<<<<<
 *         cdef double y111 = y89*(-163683964.822551*r - 17833256.898555*y1 - 1188987459.03162)
 *         cdef double y112 = y32*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*y1 + 1426660551.8844*y11 - 3089250703.76879*y16 - 6178501407.53758*y27 + 276057889687.011)
 */
  __Pyx_TraceLine(891,0,__PYX_ERR(1, 891, __pyx_L1_error))
  __pyx_v_y110 = (__pyx_v_y109 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":892
 *         cdef double y109 = y99**2
 *         cdef double y110 = y109*y32
 *         cdef double y111 = y89*(-163683964.822551*r - 17833256.898555*y1 - 1188987459.03162)             # <<<<<<<<<<<<<<
 *         cdef double y112 = y32*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*y1 + 1426660551.8844*y11 - 3089250703.76879*y16 - 6178501407.53758*y27 + 276057889687.011)
 *         cdef double y113 = 588.0*nu + 1079.0
 */
  __Pyx_TraceLine(892,0,__PYX_ERR(1, 892, __pyx_L1_error))
  __pyx_v_y111 = (__pyx_v_y89 * (((-163683964.822551 * __pyx_v_r) - (17833256.898555 * __pyx_v_y1)) - 1188987459.03162));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":893
 *         cdef double y110 = y109*y32
 *         cdef double y111 = y89*(-163683964.822551*r - 17833256.898555*y1 - 1188987459.03162)
 *         cdef double y112 = y32*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*y1 + 1426660551.8844*y11 - 3089250703.76879*y16 - 6178501407.53758*y27 + 276057889687.011)             # <<<<<<<<<<<<<<
 *         cdef double y113 = 588.0*nu + 1079.0
 *         cdef double y114 = 756.0*nu
 */
  __Pyx_TraceLine(893,0,__PYX_ERR(1, 893, __pyx_L1_error))
  __pyx_v_y112 = (__pyx_v_y32 * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (122635399361.987 * __pyx_v_r)) + (2064783811.32587 * __pyx_v_y1)) + (1426660551.8844 * __pyx_v_y11)) - (3089250703.76879 * __pyx_v_y16)) - (6178501407.53758 * __pyx_v_y27)) + 276057889687.011));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":894
 *         cdef double y111 = y89*(-163683964.822551*r - 17833256.898555*y1 - 1188987459.03162)
 *         cdef double y112 = y32*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*y1 + 1426660551.8844*y11 - 3089250703.76879*y16 - 6178501407.53758*y27 + 276057889687.011)
 *         cdef double y113 = 588.0*nu + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double y114 = 756.0*nu
 *         cdef double y115 = y114 + 1079.0
 */
  __Pyx_TraceLine(894,0,__PYX_ERR(1, 894, __pyx_L1_error))
  __pyx_v_y113 = ((588.0 * __pyx_v_nu) + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":895
 *         cdef double y112 = y32*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*y1 + 1426660551.8844*y11 - 3089250703.76879*y16 - 6178501407.53758*y27 + 276057889687.011)
 *         cdef double y113 = 588.0*nu + 1079.0
 *         cdef double y114 = 756.0*nu             # <<<<<<<<<<<<<<
 *         cdef double y115 = y114 + 1079.0
 *         cdef double y116 = y115*y27
 */
  __Pyx_TraceLine(895,0,__PYX_ERR(1, 895, __pyx_L1_error))
  __pyx_v_y114 = (756.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":896
 *         cdef double y113 = 588.0*nu + 1079.0
 *         cdef double y114 = 756.0*nu
 *         cdef double y115 = y114 + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double y116 = y115*y27
 *         cdef double y117 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*y32 + 17264.0) + 1920.0*y1*y113 + 161280.0*y11 + 480.0*y115*y16 + 960.0*y116 - 1882456.23663972*y32 + 13447680.0
 */
  __Pyx_TraceLine(896,0,__PYX_ERR(1, 896, __pyx_L1_error))
  __pyx_v_y115 = (__pyx_v_y114 + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":897
 *         cdef double y114 = 756.0*nu
 *         cdef double y115 = y114 + 1079.0
 *         cdef double y116 = y115*y27             # <<<<<<<<<<<<<<
 *         cdef double y117 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*y32 + 17264.0) + 1920.0*y1*y113 + 161280.0*y11 + 480.0*y115*y16 + 960.0*y116 - 1882456.23663972*y32 + 13447680.0
 *         cdef double y118 = nu*y99
 */
  __Pyx_TraceLine(897,0,__PYX_ERR(1, 897, __pyx_L1_error))
  __pyx_v_y116 = (__pyx_v_y115 * __pyx_v_y27);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":898
 *         cdef double y115 = y114 + 1079.0
 *         cdef double y116 = y115*y27
 *         cdef double y117 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*y32 + 17264.0) + 1920.0*y1*y113 + 161280.0*y11 + 480.0*y115*y16 + 960.0*y116 - 1882456.23663972*y32 + 13447680.0             # <<<<<<<<<<<<<<
 *         cdef double y118 = nu*y99
 *         cdef double y119 = y117*y118
 */
  __Pyx_TraceLine(898,0,__PYX_ERR(1, 898, __pyx_L1_error))
  __pyx_v_y117 = ((((((((-38842241.4769507 * __pyx_v_nu) + ((240.0 * __pyx_v_r) * (((-7466.27061066206 * __pyx_v_nu) - (3024.0 * __pyx_v_y32)) + 17264.0))) + ((1920.0 * __pyx_v_y1) * __pyx_v_y113)) + (161280.0 * __pyx_v_y11)) + ((480.0 * __pyx_v_y115) * __pyx_v_y16)) + (960.0 * __pyx_v_y116)) - (1882456.23663972 * __pyx_v_y32)) + 13447680.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":899
 *         cdef double y116 = y115*y27
 *         cdef double y117 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*y32 + 17264.0) + 1920.0*y1*y113 + 161280.0*y11 + 480.0*y115*y16 + 960.0*y116 - 1882456.23663972*y32 + 13447680.0
 *         cdef double y118 = nu*y99             # <<<<<<<<<<<<<<
 *         cdef double y119 = y117*y118
 *         cdef double y120 = 8.0*r
 */
  __Pyx_TraceLine(899,0,__PYX_ERR(1, 899, __pyx_L1_error))
  __pyx_v_y118 = (__pyx_v_nu * __pyx_v_y99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":900
 *         cdef double y117 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*y32 + 17264.0) + 1920.0*y1*y113 + 161280.0*y11 + 480.0*y115*y16 + 960.0*y116 - 1882456.23663972*y32 + 13447680.0
 *         cdef double y118 = nu*y99
 *         cdef double y119 = y117*y118             # <<<<<<<<<<<<<<
 *         cdef double y120 = 8.0*r
 *         cdef double y121 = 4.0*y1 + y120 + 2.0*y27 + 16.0
 */
  __Pyx_TraceLine(900,0,__PYX_ERR(1, 900, __pyx_L1_error))
  __pyx_v_y119 = (__pyx_v_y117 * __pyx_v_y118);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":901
 *         cdef double y118 = nu*y99
 *         cdef double y119 = y117*y118
 *         cdef double y120 = 8.0*r             # <<<<<<<<<<<<<<
 *         cdef double y121 = 4.0*y1 + y120 + 2.0*y27 + 16.0
 *         cdef double y122 = 7680.0*a6
 */
  __Pyx_TraceLine(901,0,__PYX_ERR(1, 901, __pyx_L1_error))
  __pyx_v_y120 = (8.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":902
 *         cdef double y119 = y117*y118
 *         cdef double y120 = 8.0*r
 *         cdef double y121 = 4.0*y1 + y120 + 2.0*y27 + 16.0             # <<<<<<<<<<<<<<
 *         cdef double y122 = 7680.0*a6
 *         cdef double y123 = 128.0*r
 */
  __Pyx_TraceLine(902,0,__PYX_ERR(1, 902, __pyx_L1_error))
  __pyx_v_y121 = ((((4.0 * __pyx_v_y1) + __pyx_v_y120) + (2.0 * __pyx_v_y27)) + 16.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":903
 *         cdef double y120 = 8.0*r
 *         cdef double y121 = 4.0*y1 + y120 + 2.0*y27 + 16.0
 *         cdef double y122 = 7680.0*a6             # <<<<<<<<<<<<<<
 *         cdef double y123 = 128.0*r
 *         cdef double y124 = 7704.0*r
 */
  __Pyx_TraceLine(903,0,__PYX_ERR(1, 903, __pyx_L1_error))
  __pyx_v_y122 = (7680.0 * __pyx_v_a6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":904
 *         cdef double y121 = 4.0*y1 + y120 + 2.0*y27 + 16.0
 *         cdef double y122 = 7680.0*a6
 *         cdef double y123 = 128.0*r             # <<<<<<<<<<<<<<
 *         cdef double y124 = 7704.0*r
 *         cdef double y125 = 148.04406601634*r
 */
  __Pyx_TraceLine(904,0,__PYX_ERR(1, 904, __pyx_L1_error))
  __pyx_v_y123 = (128.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":905
 *         cdef double y122 = 7680.0*a6
 *         cdef double y123 = 128.0*r
 *         cdef double y124 = 7704.0*r             # <<<<<<<<<<<<<<
 *         cdef double y125 = 148.04406601634*r
 *         cdef double y126 = 113485.217444961*r
 */
  __Pyx_TraceLine(905,0,__PYX_ERR(1, 905, __pyx_L1_error))
  __pyx_v_y124 = (7704.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":906
 *         cdef double y123 = 128.0*r
 *         cdef double y124 = 7704.0*r
 *         cdef double y125 = 148.04406601634*r             # <<<<<<<<<<<<<<
 *         cdef double y126 = 113485.217444961*r
 *         cdef double y127 = nu*(y122*(y121 + y16) + y123*(13218.7851094412*r + 8529.39255472061*y1 - 6852.34813868015*y16 + 4264.6962773603*y27 - 33722.4297811176) + y125*(3852.0*y1 + y124 + 349.0*y16 + 1926.0*y27 + 36400.0) + y126*(y121 - y16))
 */
  __Pyx_TraceLine(906,0,__PYX_ERR(1, 906, __pyx_L1_error))
  __pyx_v_y125 = (148.04406601634 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":907
 *         cdef double y124 = 7704.0*r
 *         cdef double y125 = 148.04406601634*r
 *         cdef double y126 = 113485.217444961*r             # <<<<<<<<<<<<<<
 *         cdef double y127 = nu*(y122*(y121 + y16) + y123*(13218.7851094412*r + 8529.39255472061*y1 - 6852.34813868015*y16 + 4264.6962773603*y27 - 33722.4297811176) + y125*(3852.0*y1 + y124 + 349.0*y16 + 1926.0*y27 + 36400.0) + y126*(y121 - y16))
 *         cdef double y128 = (13212057600.0*y11 + 67645734912.0*y110 + 1120.0*y111 + 7.0*y112 + 32768.0*y119 + 53760.0*y127 + 241555486248.807*y94)**(-1)
 */
  __Pyx_TraceLine(907,0,__PYX_ERR(1, 907, __pyx_L1_error))
  __pyx_v_y126 = (113485.217444961 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":908
 *         cdef double y125 = 148.04406601634*r
 *         cdef double y126 = 113485.217444961*r
 *         cdef double y127 = nu*(y122*(y121 + y16) + y123*(13218.7851094412*r + 8529.39255472061*y1 - 6852.34813868015*y16 + 4264.6962773603*y27 - 33722.4297811176) + y125*(3852.0*y1 + y124 + 349.0*y16 + 1926.0*y27 + 36400.0) + y126*(y121 - y16))             # <<<<<<<<<<<<<<
 *         cdef double y128 = (13212057600.0*y11 + 67645734912.0*y110 + 1120.0*y111 + 7.0*y112 + 32768.0*y119 + 53760.0*y127 + 241555486248.807*y94)**(-1)
 *         cdef double y129 = 336.0*r + y114 + 407.0
 */
  __Pyx_TraceLine(908,0,__PYX_ERR(1, 908, __pyx_L1_error))
  __pyx_v_y127 = (__pyx_v_nu * ((((__pyx_v_y122 * (__pyx_v_y121 + __pyx_v_y16)) + (__pyx_v_y123 * (((((13218.7851094412 * __pyx_v_r) + (8529.39255472061 * __pyx_v_y1)) - (6852.34813868015 * __pyx_v_y16)) + (4264.6962773603 * __pyx_v_y27)) - 33722.4297811176))) + (__pyx_v_y125 * (((((3852.0 * __pyx_v_y1) + __pyx_v_y124) + (349.0 * __pyx_v_y16)) + (1926.0 * __pyx_v_y27)) + 36400.0))) + (__pyx_v_y126 * (__pyx_v_y121 - __pyx_v_y16))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":909
 *         cdef double y126 = 113485.217444961*r
 *         cdef double y127 = nu*(y122*(y121 + y16) + y123*(13218.7851094412*r + 8529.39255472061*y1 - 6852.34813868015*y16 + 4264.6962773603*y27 - 33722.4297811176) + y125*(3852.0*y1 + y124 + 349.0*y16 + 1926.0*y27 + 36400.0) + y126*(y121 - y16))
 *         cdef double y128 = (13212057600.0*y11 + 67645734912.0*y110 + 1120.0*y111 + 7.0*y112 + 32768.0*y119 + 53760.0*y127 + 241555486248.807*y94)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y129 = 336.0*r + y114 + 407.0
 *         cdef double y130 = 2048.0*nu*y129*y99 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*y32 - 245760.0) - 5416406.59541186*y32 - 3440640.0
 */
  __Pyx_TraceLine(909,0,__PYX_ERR(1, 909, __pyx_L1_error))
  __pyx_v_y128 = pow((((((((13212057600.0 * __pyx_v_y11) + (67645734912.0 * __pyx_v_y110)) + (1120.0 * __pyx_v_y111)) + (7.0 * __pyx_v_y112)) + (32768.0 * __pyx_v_y119)) + (53760.0 * __pyx_v_y127)) + (241555486248.807 * __pyx_v_y94)), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":910
 *         cdef double y127 = nu*(y122*(y121 + y16) + y123*(13218.7851094412*r + 8529.39255472061*y1 - 6852.34813868015*y16 + 4264.6962773603*y27 - 33722.4297811176) + y125*(3852.0*y1 + y124 + 349.0*y16 + 1926.0*y27 + 36400.0) + y126*(y121 - y16))
 *         cdef double y128 = (13212057600.0*y11 + 67645734912.0*y110 + 1120.0*y111 + 7.0*y112 + 32768.0*y119 + 53760.0*y127 + 241555486248.807*y94)**(-1)
 *         cdef double y129 = 336.0*r + y114 + 407.0             # <<<<<<<<<<<<<<
 *         cdef double y130 = 2048.0*nu*y129*y99 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*y32 - 245760.0) - 5416406.59541186*y32 - 3440640.0
 *         cdef double y131 = y128*y130
 */
  __Pyx_TraceLine(910,0,__PYX_ERR(1, 910, __pyx_L1_error))
  __pyx_v_y129 = (((336.0 * __pyx_v_r) + __pyx_v_y114) + 407.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":911
 *         cdef double y128 = (13212057600.0*y11 + 67645734912.0*y110 + 1120.0*y111 + 7.0*y112 + 32768.0*y119 + 53760.0*y127 + 241555486248.807*y94)**(-1)
 *         cdef double y129 = 336.0*r + y114 + 407.0
 *         cdef double y130 = 2048.0*nu*y129*y99 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*y32 - 245760.0) - 5416406.59541186*y32 - 3440640.0             # <<<<<<<<<<<<<<
 *         cdef double y131 = y128*y130
 *         cdef double y132 = y131*y16
 */
  __Pyx_TraceLine(911,0,__PYX_ERR(1, 911, __pyx_L1_error))
  __pyx_v_y130 = (((((((2048.0 * __pyx_v_nu) * __pyx_v_y129) * __pyx_v_y99) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) - ((7.0 * __pyx_v_r) * (((938918.400156317 * __pyx_v_nu) - (185763.092693281 * __pyx_v_y32)) - 245760.0))) - (5416406.59541186 * __pyx_v_y32)) - 3440640.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":912
 *         cdef double y129 = 336.0*r + y114 + 407.0
 *         cdef double y130 = 2048.0*nu*y129*y99 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*y32 - 245760.0) - 5416406.59541186*y32 - 3440640.0
 *         cdef double y131 = y128*y130             # <<<<<<<<<<<<<<
 *         cdef double y132 = y131*y16
 *         cdef double y133 = y132 + 0.000130208333333333*y67
 */
  __Pyx_TraceLine(912,0,__PYX_ERR(1, 912, __pyx_L1_error))
  __pyx_v_y131 = (__pyx_v_y128 * __pyx_v_y130);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":913
 *         cdef double y130 = 2048.0*nu*y129*y99 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*y32 - 245760.0) - 5416406.59541186*y32 - 3440640.0
 *         cdef double y131 = y128*y130
 *         cdef double y132 = y131*y16             # <<<<<<<<<<<<<<
 *         cdef double y133 = y132 + 0.000130208333333333*y67
 *         cdef double y134 = y133**(-4)
 */
  __Pyx_TraceLine(913,0,__PYX_ERR(1, 913, __pyx_L1_error))
  __pyx_v_y132 = (__pyx_v_y131 * __pyx_v_y16);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":914
 *         cdef double y131 = y128*y130
 *         cdef double y132 = y131*y16
 *         cdef double y133 = y132 + 0.000130208333333333*y67             # <<<<<<<<<<<<<<
 *         cdef double y134 = y133**(-4)
 *         cdef double y135 = r*y109
 */
  __Pyx_TraceLine(914,0,__PYX_ERR(1, 914, __pyx_L1_error))
  __pyx_v_y133 = (__pyx_v_y132 + (0.000130208333333333 * __pyx_v_y67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":915
 *         cdef double y132 = y131*y16
 *         cdef double y133 = y132 + 0.000130208333333333*y67
 *         cdef double y134 = y133**(-4)             # <<<<<<<<<<<<<<
 *         cdef double y135 = r*y109
 *         cdef double y136 = -630116198.873299*nu - 197773496.793534*y32 + 5805304367.87913
 */
  __Pyx_TraceLine(915,0,__PYX_ERR(1, 915, __pyx_L1_error))
  __pyx_v_y134 = pow(__pyx_v_y133, -4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":916
 *         cdef double y133 = y132 + 0.000130208333333333*y67
 *         cdef double y134 = y133**(-4)
 *         cdef double y135 = r*y109             # <<<<<<<<<<<<<<
 *         cdef double y136 = -630116198.873299*nu - 197773496.793534*y32 + 5805304367.87913
 *         cdef double y137 = y1*y136
 */
  __Pyx_TraceLine(916,0,__PYX_ERR(1, 916, __pyx_L1_error))
  __pyx_v_y135 = (__pyx_v_r * __pyx_v_y109);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":917
 *         cdef double y134 = y133**(-4)
 *         cdef double y135 = r*y109
 *         cdef double y136 = -630116198.873299*nu - 197773496.793534*y32 + 5805304367.87913             # <<<<<<<<<<<<<<
 *         cdef double y137 = y1*y136
 *         cdef double y138 = -2675575.66847905*nu - 138240.0*y32 - 5278341.3229329
 */
  __Pyx_TraceLine(917,0,__PYX_ERR(1, 917, __pyx_L1_error))
  __pyx_v_y136 = (((-630116198.873299 * __pyx_v_nu) - (197773496.793534 * __pyx_v_y32)) + 5805304367.87913);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":918
 *         cdef double y135 = r*y109
 *         cdef double y136 = -630116198.873299*nu - 197773496.793534*y32 + 5805304367.87913
 *         cdef double y137 = y1*y136             # <<<<<<<<<<<<<<
 *         cdef double y138 = -2675575.66847905*nu - 138240.0*y32 - 5278341.3229329
 *         cdef double y139 = y138*y27
 */
  __Pyx_TraceLine(918,0,__PYX_ERR(1, 918, __pyx_L1_error))
  __pyx_v_y137 = (__pyx_v_y1 * __pyx_v_y136);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":919
 *         cdef double y136 = -630116198.873299*nu - 197773496.793534*y32 + 5805304367.87913
 *         cdef double y137 = y1*y136
 *         cdef double y138 = -2675575.66847905*nu - 138240.0*y32 - 5278341.3229329             # <<<<<<<<<<<<<<
 *         cdef double y139 = y138*y27
 *         cdef double y140 = nu*(-2510664218.28128*nu - 42636451.6032331*y32 + 14515200.0*y89 + 1002013764.01019)
 */
  __Pyx_TraceLine(919,0,__PYX_ERR(1, 919, __pyx_L1_error))
  __pyx_v_y138 = (((-2675575.66847905 * __pyx_v_nu) - (138240.0 * __pyx_v_y32)) - 5278341.3229329);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":920
 *         cdef double y137 = y1*y136
 *         cdef double y138 = -2675575.66847905*nu - 138240.0*y32 - 5278341.3229329
 *         cdef double y139 = y138*y27             # <<<<<<<<<<<<<<
 *         cdef double y140 = nu*(-2510664218.28128*nu - 42636451.6032331*y32 + 14515200.0*y89 + 1002013764.01019)
 *         cdef double y141 = (1 - 0.496948781616935*nu)**2
 */
  __Pyx_TraceLine(920,0,__PYX_ERR(1, 920, __pyx_L1_error))
  __pyx_v_y139 = (__pyx_v_y138 * __pyx_v_y27);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":921
 *         cdef double y138 = -2675575.66847905*nu - 138240.0*y32 - 5278341.3229329
 *         cdef double y139 = y138*y27
 *         cdef double y140 = nu*(-2510664218.28128*nu - 42636451.6032331*y32 + 14515200.0*y89 + 1002013764.01019)             # <<<<<<<<<<<<<<
 *         cdef double y141 = (1 - 0.496948781616935*nu)**2
 *         cdef double y142 = 43393301259014.8*nu + 86618264430493.3*y141 + 43133561885859.3*y32 + 5927865218923.02*y89 + 188440788778196.0
 */
  __Pyx_TraceLine(921,0,__PYX_ERR(1, 921, __pyx_L1_error))
  __pyx_v_y140 = (__pyx_v_nu * ((((-2510664218.28128 * __pyx_v_nu) - (42636451.6032331 * __pyx_v_y32)) + (14515200.0 * __pyx_v_y89)) + 1002013764.01019));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":922
 *         cdef double y139 = y138*y27
 *         cdef double y140 = nu*(-2510664218.28128*nu - 42636451.6032331*y32 + 14515200.0*y89 + 1002013764.01019)
 *         cdef double y141 = (1 - 0.496948781616935*nu)**2             # <<<<<<<<<<<<<<
 *         cdef double y142 = 43393301259014.8*nu + 86618264430493.3*y141 + 43133561885859.3*y32 + 5927865218923.02*y89 + 188440788778196.0
 *         cdef double y143 = r*y142
 */
  __Pyx_TraceLine(922,0,__PYX_ERR(1, 922, __pyx_L1_error))
  __pyx_v_y141 = pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":923
 *         cdef double y140 = nu*(-2510664218.28128*nu - 42636451.6032331*y32 + 14515200.0*y89 + 1002013764.01019)
 *         cdef double y141 = (1 - 0.496948781616935*nu)**2
 *         cdef double y142 = 43393301259014.8*nu + 86618264430493.3*y141 + 43133561885859.3*y32 + 5927865218923.02*y89 + 188440788778196.0             # <<<<<<<<<<<<<<
 *         cdef double y143 = r*y142
 *         cdef double y144 = 14700.0*nu + 42911.0
 */
  __Pyx_TraceLine(923,0,__PYX_ERR(1, 923, __pyx_L1_error))
  __pyx_v_y142 = (((((43393301259014.8 * __pyx_v_nu) + (86618264430493.3 * __pyx_v_y141)) + (43133561885859.3 * __pyx_v_y32)) + (5927865218923.02 * __pyx_v_y89)) + 188440788778196.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":924
 *         cdef double y141 = (1 - 0.496948781616935*nu)**2
 *         cdef double y142 = 43393301259014.8*nu + 86618264430493.3*y141 + 43133561885859.3*y32 + 5927865218923.02*y89 + 188440788778196.0
 *         cdef double y143 = r*y142             # <<<<<<<<<<<<<<
 *         cdef double y144 = 14700.0*nu + 42911.0
 *         cdef double y145 = 283115520.0*y144
 */
  __Pyx_TraceLine(924,0,__PYX_ERR(1, 924, __pyx_L1_error))
  __pyx_v_y143 = (__pyx_v_r * __pyx_v_y142);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":925
 *         cdef double y142 = 43393301259014.8*nu + 86618264430493.3*y141 + 43133561885859.3*y32 + 5927865218923.02*y89 + 188440788778196.0
 *         cdef double y143 = r*y142
 *         cdef double y144 = 14700.0*nu + 42911.0             # <<<<<<<<<<<<<<
 *         cdef double y145 = 283115520.0*y144
 *         cdef double y146 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*y32 - 2119671837.36038) + y1*y145 + 879923036160.0*y27
 */
  __Pyx_TraceLine(925,0,__PYX_ERR(1, 925, __pyx_L1_error))
  __pyx_v_y144 = ((14700.0 * __pyx_v_nu) + 42911.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":926
 *         cdef double y143 = r*y142
 *         cdef double y144 = 14700.0*nu + 42911.0
 *         cdef double y145 = 283115520.0*y144             # <<<<<<<<<<<<<<
 *         cdef double y146 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*y32 - 2119671837.36038) + y1*y145 + 879923036160.0*y27
 *         cdef double y147 = y146*y99
 */
  __Pyx_TraceLine(926,0,__PYX_ERR(1, 926, __pyx_L1_error))
  __pyx_v_y145 = (283115520.0 * __pyx_v_y144);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":927
 *         cdef double y144 = 14700.0*nu + 42911.0
 *         cdef double y145 = 283115520.0*y144
 *         cdef double y146 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*y32 - 2119671837.36038) + y1*y145 + 879923036160.0*y27             # <<<<<<<<<<<<<<
 *         cdef double y147 = y146*y99
 *         cdef double y148 = y135 - 1.59227685093395e-9*y137 - 1.67189069348064e-7*y139 + 9.55366110560367e-9*y140 + 1.72773095804465e-13*y143 + 1.72773095804465e-13*y147
 */
  __Pyx_TraceLine(927,0,__PYX_ERR(1, 927, __pyx_L1_error))
  __pyx_v_y146 = (((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + ((49152.0 * __pyx_v_r) * (((409207698.136075 * __pyx_v_nu) + (102574080.0 * __pyx_v_y32)) - 2119671837.36038))) + (__pyx_v_y1 * __pyx_v_y145)) + (879923036160.0 * __pyx_v_y27));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":928
 *         cdef double y145 = 283115520.0*y144
 *         cdef double y146 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*y32 - 2119671837.36038) + y1*y145 + 879923036160.0*y27
 *         cdef double y147 = y146*y99             # <<<<<<<<<<<<<<
 *         cdef double y148 = y135 - 1.59227685093395e-9*y137 - 1.67189069348064e-7*y139 + 9.55366110560367e-9*y140 + 1.72773095804465e-13*y143 + 1.72773095804465e-13*y147
 *         cdef double y149 = y148**2
 */
  __Pyx_TraceLine(928,0,__PYX_ERR(1, 928, __pyx_L1_error))
  __pyx_v_y147 = (__pyx_v_y146 * __pyx_v_y99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":929
 *         cdef double y146 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*y32 - 2119671837.36038) + y1*y145 + 879923036160.0*y27
 *         cdef double y147 = y146*y99
 *         cdef double y148 = y135 - 1.59227685093395e-9*y137 - 1.67189069348064e-7*y139 + 9.55366110560367e-9*y140 + 1.72773095804465e-13*y143 + 1.72773095804465e-13*y147             # <<<<<<<<<<<<<<
 *         cdef double y149 = y148**2
 *         cdef double y150 = nu*r
 */
  __Pyx_TraceLine(929,0,__PYX_ERR(1, 929, __pyx_L1_error))
  __pyx_v_y148 = (((((__pyx_v_y135 - (1.59227685093395e-9 * __pyx_v_y137)) - (1.67189069348064e-7 * __pyx_v_y139)) + (9.55366110560367e-9 * __pyx_v_y140)) + (1.72773095804465e-13 * __pyx_v_y143)) + (1.72773095804465e-13 * __pyx_v_y147));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":930
 *         cdef double y147 = y146*y99
 *         cdef double y148 = y135 - 1.59227685093395e-9*y137 - 1.67189069348064e-7*y139 + 9.55366110560367e-9*y140 + 1.72773095804465e-13*y143 + 1.72773095804465e-13*y147
 *         cdef double y149 = y148**2             # <<<<<<<<<<<<<<
 *         cdef double y150 = nu*r
 *         cdef double y151 = nu*y1
 */
  __Pyx_TraceLine(930,0,__PYX_ERR(1, 930, __pyx_L1_error))
  __pyx_v_y149 = pow(__pyx_v_y148, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":931
 *         cdef double y148 = y135 - 1.59227685093395e-9*y137 - 1.67189069348064e-7*y139 + 9.55366110560367e-9*y140 + 1.72773095804465e-13*y143 + 1.72773095804465e-13*y147
 *         cdef double y149 = y148**2
 *         cdef double y150 = nu*r             # <<<<<<<<<<<<<<
 *         cdef double y151 = nu*y1
 *         cdef double y152 = r*y32
 */
  __Pyx_TraceLine(931,0,__PYX_ERR(1, 931, __pyx_L1_error))
  __pyx_v_y150 = (__pyx_v_nu * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":932
 *         cdef double y149 = y148**2
 *         cdef double y150 = nu*r
 *         cdef double y151 = nu*y1             # <<<<<<<<<<<<<<
 *         cdef double y152 = r*y32
 *         cdef double y153 = r*y144
 */
  __Pyx_TraceLine(932,0,__PYX_ERR(1, 932, __pyx_L1_error))
  __pyx_v_y151 = (__pyx_v_nu * __pyx_v_y1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":933
 *         cdef double y150 = nu*r
 *         cdef double y151 = nu*y1
 *         cdef double y152 = r*y32             # <<<<<<<<<<<<<<
 *         cdef double y153 = r*y144
 *         cdef double y154 = y1*y32
 */
  __Pyx_TraceLine(933,0,__PYX_ERR(1, 933, __pyx_L1_error))
  __pyx_v_y152 = (__pyx_v_r * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":934
 *         cdef double y151 = nu*y1
 *         cdef double y152 = r*y32
 *         cdef double y153 = r*y144             # <<<<<<<<<<<<<<
 *         cdef double y154 = y1*y32
 *         cdef double y155 = 5041721180160.0*y32 - 104186110149937.0
 */
  __Pyx_TraceLine(934,0,__PYX_ERR(1, 934, __pyx_L1_error))
  __pyx_v_y153 = (__pyx_v_r * __pyx_v_y144);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":935
 *         cdef double y152 = r*y32
 *         cdef double y153 = r*y144
 *         cdef double y154 = y1*y32             # <<<<<<<<<<<<<<
 *         cdef double y155 = 5041721180160.0*y32 - 104186110149937.0
 *         cdef double y156 = -25392914995744.3*nu - r*y145 - 879923036160.0*y1 - y155
 */
  __Pyx_TraceLine(935,0,__PYX_ERR(1, 935, __pyx_L1_error))
  __pyx_v_y154 = (__pyx_v_y1 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":936
 *         cdef double y153 = r*y144
 *         cdef double y154 = y1*y32
 *         cdef double y155 = 5041721180160.0*y32 - 104186110149937.0             # <<<<<<<<<<<<<<
 *         cdef double y156 = -25392914995744.3*nu - r*y145 - 879923036160.0*y1 - y155
 *         cdef double y157 = y156*y99
 */
  __Pyx_TraceLine(936,0,__PYX_ERR(1, 936, __pyx_L1_error))
  __pyx_v_y155 = ((5041721180160.0 * __pyx_v_y32) - 104186110149937.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":937
 *         cdef double y154 = y1*y32
 *         cdef double y155 = 5041721180160.0*y32 - 104186110149937.0
 *         cdef double y156 = -25392914995744.3*nu - r*y145 - 879923036160.0*y1 - y155             # <<<<<<<<<<<<<<
 *         cdef double y157 = y156*y99
 *         cdef double y158 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*y1 + 0.0210425293255724*y109 + 0.0385795738434214*y150 + 0.00941289164152486*y151 + 0.00662650629087394*y152 - 1.18824456940711e-6*y153 + 0.000486339502879429*y154 - 3.63558293513537e-15*y157 + 0.291062041428379*y32 + 0.0244692826489756*y89 + 1
 */
  __Pyx_TraceLine(937,0,__PYX_ERR(1, 937, __pyx_L1_error))
  __pyx_v_y156 = ((((-25392914995744.3 * __pyx_v_nu) - (__pyx_v_r * __pyx_v_y145)) - (879923036160.0 * __pyx_v_y1)) - __pyx_v_y155);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":938
 *         cdef double y155 = 5041721180160.0*y32 - 104186110149937.0
 *         cdef double y156 = -25392914995744.3*nu - r*y145 - 879923036160.0*y1 - y155
 *         cdef double y157 = y156*y99             # <<<<<<<<<<<<<<
 *         cdef double y158 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*y1 + 0.0210425293255724*y109 + 0.0385795738434214*y150 + 0.00941289164152486*y151 + 0.00662650629087394*y152 - 1.18824456940711e-6*y153 + 0.000486339502879429*y154 - 3.63558293513537e-15*y157 + 0.291062041428379*y32 + 0.0244692826489756*y89 + 1
 *         cdef double y159 = y158**(-2)
 */
  __Pyx_TraceLine(938,0,__PYX_ERR(1, 938, __pyx_L1_error))
  __pyx_v_y157 = (__pyx_v_y156 * __pyx_v_y99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":939
 *         cdef double y156 = -25392914995744.3*nu - r*y145 - 879923036160.0*y1 - y155
 *         cdef double y157 = y156*y99
 *         cdef double y158 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*y1 + 0.0210425293255724*y109 + 0.0385795738434214*y150 + 0.00941289164152486*y151 + 0.00662650629087394*y152 - 1.18824456940711e-6*y153 + 0.000486339502879429*y154 - 3.63558293513537e-15*y157 + 0.291062041428379*y32 + 0.0244692826489756*y89 + 1             # <<<<<<<<<<<<<<
 *         cdef double y159 = y158**(-2)
 *         cdef double y160 = 4.0*y32
 */
  __Pyx_TraceLine(939,0,__PYX_ERR(1, 939, __pyx_L1_error))
  __pyx_v_y158 = (((((((((((((-0.0438084424460039 * __pyx_v_nu) - (0.143521050466841 * __pyx_v_r)) + (0.0185696317637669 * __pyx_v_y1)) + (0.0210425293255724 * __pyx_v_y109)) + (0.0385795738434214 * __pyx_v_y150)) + (0.00941289164152486 * __pyx_v_y151)) + (0.00662650629087394 * __pyx_v_y152)) - (1.18824456940711e-6 * __pyx_v_y153)) + (0.000486339502879429 * __pyx_v_y154)) - (3.63558293513537e-15 * __pyx_v_y157)) + (0.291062041428379 * __pyx_v_y32)) + (0.0244692826489756 * __pyx_v_y89)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":940
 *         cdef double y157 = y156*y99
 *         cdef double y158 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*y1 + 0.0210425293255724*y109 + 0.0385795738434214*y150 + 0.00941289164152486*y151 + 0.00662650629087394*y152 - 1.18824456940711e-6*y153 + 0.000486339502879429*y154 - 3.63558293513537e-15*y157 + 0.291062041428379*y32 + 0.0244692826489756*y89 + 1
 *         cdef double y159 = y158**(-2)             # <<<<<<<<<<<<<<
 *         cdef double y160 = 4.0*y32
 *         cdef double y161 = y19**2
 */
  __Pyx_TraceLine(940,0,__PYX_ERR(1, 940, __pyx_L1_error))
  __pyx_v_y159 = pow(__pyx_v_y158, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":941
 *         cdef double y158 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*y1 + 0.0210425293255724*y109 + 0.0385795738434214*y150 + 0.00941289164152486*y151 + 0.00662650629087394*y152 - 1.18824456940711e-6*y153 + 0.000486339502879429*y154 - 3.63558293513537e-15*y157 + 0.291062041428379*y32 + 0.0244692826489756*y89 + 1
 *         cdef double y159 = y158**(-2)
 *         cdef double y160 = 4.0*y32             # <<<<<<<<<<<<<<
 *         cdef double y161 = y19**2
 *         cdef double y162 = -0.46875*y161*(-5.0*nu + y160 + 1.0) + 0.0625*y19*y23*y4*(18.0*nu - 1.0) - 0.15625*y5*(-33.0*nu + 32.0*y32 - 5.0)
 */
  __Pyx_TraceLine(941,0,__PYX_ERR(1, 941, __pyx_L1_error))
  __pyx_v_y160 = (4.0 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":942
 *         cdef double y159 = y158**(-2)
 *         cdef double y160 = 4.0*y32
 *         cdef double y161 = y19**2             # <<<<<<<<<<<<<<
 *         cdef double y162 = -0.46875*y161*(-5.0*nu + y160 + 1.0) + 0.0625*y19*y23*y4*(18.0*nu - 1.0) - 0.15625*y5*(-33.0*nu + 32.0*y32 - 5.0)
 *         cdef double y163 = y134*y149*y159*y162
 */
  __Pyx_TraceLine(942,0,__PYX_ERR(1, 942, __pyx_L1_error))
  __pyx_v_y161 = pow(__pyx_v_y19, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":943
 *         cdef double y160 = 4.0*y32
 *         cdef double y161 = y19**2
 *         cdef double y162 = -0.46875*y161*(-5.0*nu + y160 + 1.0) + 0.0625*y19*y23*y4*(18.0*nu - 1.0) - 0.15625*y5*(-33.0*nu + 32.0*y32 - 5.0)             # <<<<<<<<<<<<<<
 *         cdef double y163 = y134*y149*y159*y162
 *         cdef double y164 = y163*y76
 */
  __Pyx_TraceLine(943,0,__PYX_ERR(1, 943, __pyx_L1_error))
  __pyx_v_y162 = ((((-0.46875 * __pyx_v_y161) * (((-5.0 * __pyx_v_nu) + __pyx_v_y160) + 1.0)) + ((((0.0625 * __pyx_v_y19) * __pyx_v_y23) * __pyx_v_y4) * ((18.0 * __pyx_v_nu) - 1.0))) - ((0.15625 * __pyx_v_y5) * (((-33.0 * __pyx_v_nu) + (32.0 * __pyx_v_y32)) - 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":944
 *         cdef double y161 = y19**2
 *         cdef double y162 = -0.46875*y161*(-5.0*nu + y160 + 1.0) + 0.0625*y19*y23*y4*(18.0*nu - 1.0) - 0.15625*y5*(-33.0*nu + 32.0*y32 - 5.0)
 *         cdef double y163 = y134*y149*y159*y162             # <<<<<<<<<<<<<<
 *         cdef double y164 = y163*y76
 *         cdef double y165 = r**(-13)
 */
  __Pyx_TraceLine(944,0,__PYX_ERR(1, 944, __pyx_L1_error))
  __pyx_v_y163 = (((__pyx_v_y134 * __pyx_v_y149) * __pyx_v_y159) * __pyx_v_y162);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":945
 *         cdef double y162 = -0.46875*y161*(-5.0*nu + y160 + 1.0) + 0.0625*y19*y23*y4*(18.0*nu - 1.0) - 0.15625*y5*(-33.0*nu + 32.0*y32 - 5.0)
 *         cdef double y163 = y134*y149*y159*y162
 *         cdef double y164 = y163*y76             # <<<<<<<<<<<<<<
 *         cdef double y165 = r**(-13)
 *         cdef double y166 = y6**4
 */
  __Pyx_TraceLine(945,0,__PYX_ERR(1, 945, __pyx_L1_error))
  __pyx_v_y164 = (__pyx_v_y163 * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":946
 *         cdef double y163 = y134*y149*y159*y162
 *         cdef double y164 = y163*y76
 *         cdef double y165 = r**(-13)             # <<<<<<<<<<<<<<
 *         cdef double y166 = y6**4
 *         cdef double y167 = y165*y166
 */
  __Pyx_TraceLine(946,0,__PYX_ERR(1, 946, __pyx_L1_error))
  __pyx_v_y165 = pow(__pyx_v_r, -13.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":947
 *         cdef double y164 = y163*y76
 *         cdef double y165 = r**(-13)
 *         cdef double y166 = y6**4             # <<<<<<<<<<<<<<
 *         cdef double y167 = y165*y166
 *         cdef double y168 = prst**2
 */
  __Pyx_TraceLine(947,0,__PYX_ERR(1, 947, __pyx_L1_error))
  __pyx_v_y166 = pow(__pyx_v_y6, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":948
 *         cdef double y165 = r**(-13)
 *         cdef double y166 = y6**4
 *         cdef double y167 = y165*y166             # <<<<<<<<<<<<<<
 *         cdef double y168 = prst**2
 *         cdef double y169 = y133**(-2)
 */
  __Pyx_TraceLine(948,0,__PYX_ERR(1, 948, __pyx_L1_error))
  __pyx_v_y167 = (__pyx_v_y165 * __pyx_v_y166);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":949
 *         cdef double y166 = y6**4
 *         cdef double y167 = y165*y166
 *         cdef double y168 = prst**2             # <<<<<<<<<<<<<<
 *         cdef double y169 = y133**(-2)
 *         cdef double y170 = 1822680546449.21*y32
 */
  __Pyx_TraceLine(949,0,__PYX_ERR(1, 949, __pyx_L1_error))
  __pyx_v_y168 = pow(__pyx_v_prst, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":950
 *         cdef double y167 = y165*y166
 *         cdef double y168 = prst**2
 *         cdef double y169 = y133**(-2)             # <<<<<<<<<<<<<<
 *         cdef double y170 = 1822680546449.21*y32
 *         cdef double y171 = 5787938193408.0*y109
 */
  __Pyx_TraceLine(950,0,__PYX_ERR(1, 950, __pyx_L1_error))
  __pyx_v_y169 = pow(__pyx_v_y133, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":951
 *         cdef double y168 = prst**2
 *         cdef double y169 = y133**(-2)
 *         cdef double y170 = 1822680546449.21*y32             # <<<<<<<<<<<<<<
 *         cdef double y171 = 5787938193408.0*y109
 *         cdef double y172 = -12049908701745.2*nu + r*y170 - 39476764256925.6*r + 5107745331375.71*y1 + 10611661054566.2*y150 + 2589101062873.81*y151 - 326837426.241486*y153 + 133772083200.0*y154 - y157 + y171 + 80059249540278.2*y32 + 6730497718123.02*y89 + 275059053208689.0
 */
  __Pyx_TraceLine(951,0,__PYX_ERR(1, 951, __pyx_L1_error))
  __pyx_v_y170 = (1822680546449.21 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":952
 *         cdef double y169 = y133**(-2)
 *         cdef double y170 = 1822680546449.21*y32
 *         cdef double y171 = 5787938193408.0*y109             # <<<<<<<<<<<<<<
 *         cdef double y172 = -12049908701745.2*nu + r*y170 - 39476764256925.6*r + 5107745331375.71*y1 + 10611661054566.2*y150 + 2589101062873.81*y151 - 326837426.241486*y153 + 133772083200.0*y154 - y157 + y171 + 80059249540278.2*y32 + 6730497718123.02*y89 + 275059053208689.0
 *         cdef double y173 = y172**(-1)
 */
  __Pyx_TraceLine(952,0,__PYX_ERR(1, 952, __pyx_L1_error))
  __pyx_v_y171 = (5787938193408.0 * __pyx_v_y109);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":953
 *         cdef double y170 = 1822680546449.21*y32
 *         cdef double y171 = 5787938193408.0*y109
 *         cdef double y172 = -12049908701745.2*nu + r*y170 - 39476764256925.6*r + 5107745331375.71*y1 + 10611661054566.2*y150 + 2589101062873.81*y151 - 326837426.241486*y153 + 133772083200.0*y154 - y157 + y171 + 80059249540278.2*y32 + 6730497718123.02*y89 + 275059053208689.0             # <<<<<<<<<<<<<<
 *         cdef double y173 = y172**(-1)
 *         cdef double y174 = y168*y169*y173
 */
  __Pyx_TraceLine(953,0,__PYX_ERR(1, 953, __pyx_L1_error))
  __pyx_v_y172 = (((((((((((((-12049908701745.2 * __pyx_v_nu) + (__pyx_v_r * __pyx_v_y170)) - (39476764256925.6 * __pyx_v_r)) + (5107745331375.71 * __pyx_v_y1)) + (10611661054566.2 * __pyx_v_y150)) + (2589101062873.81 * __pyx_v_y151)) - (326837426.241486 * __pyx_v_y153)) + (133772083200.0 * __pyx_v_y154)) - __pyx_v_y157) + __pyx_v_y171) + (80059249540278.2 * __pyx_v_y32)) + (6730497718123.02 * __pyx_v_y89)) + 275059053208689.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":954
 *         cdef double y171 = 5787938193408.0*y109
 *         cdef double y172 = -12049908701745.2*nu + r*y170 - 39476764256925.6*r + 5107745331375.71*y1 + 10611661054566.2*y150 + 2589101062873.81*y151 - 326837426.241486*y153 + 133772083200.0*y154 - y157 + y171 + 80059249540278.2*y32 + 6730497718123.02*y89 + 275059053208689.0
 *         cdef double y173 = y172**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y174 = y168*y169*y173
 *         cdef double y175 = 0.0625*y161
 */
  __Pyx_TraceLine(954,0,__PYX_ERR(1, 954, __pyx_L1_error))
  __pyx_v_y173 = pow(__pyx_v_y172, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":955
 *         cdef double y172 = -12049908701745.2*nu + r*y170 - 39476764256925.6*r + 5107745331375.71*y1 + 10611661054566.2*y150 + 2589101062873.81*y151 - 326837426.241486*y153 + 133772083200.0*y154 - y157 + y171 + 80059249540278.2*y32 + 6730497718123.02*y89 + 275059053208689.0
 *         cdef double y173 = y172**(-1)
 *         cdef double y174 = y168*y169*y173             # <<<<<<<<<<<<<<
 *         cdef double y175 = 0.0625*y161
 *         cdef double y176 = 0.125*y24
 */
  __Pyx_TraceLine(955,0,__PYX_ERR(1, 955, __pyx_L1_error))
  __pyx_v_y174 = ((__pyx_v_y168 * __pyx_v_y169) * __pyx_v_y173);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":956
 *         cdef double y173 = y172**(-1)
 *         cdef double y174 = y168*y169*y173
 *         cdef double y175 = 0.0625*y161             # <<<<<<<<<<<<<<
 *         cdef double y176 = 0.125*y24
 *         cdef double y177 = -1171.0*nu - 861.0
 */
  __Pyx_TraceLine(956,0,__PYX_ERR(1, 956, __pyx_L1_error))
  __pyx_v_y175 = (0.0625 * __pyx_v_y161);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":957
 *         cdef double y174 = y168*y169*y173
 *         cdef double y175 = 0.0625*y161
 *         cdef double y176 = 0.125*y24             # <<<<<<<<<<<<<<
 *         cdef double y177 = -1171.0*nu - 861.0
 *         cdef double y178 = 0.015625*y5
 */
  __Pyx_TraceLine(957,0,__PYX_ERR(1, 957, __pyx_L1_error))
  __pyx_v_y176 = (0.125 * __pyx_v_y24);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":958
 *         cdef double y175 = 0.0625*y161
 *         cdef double y176 = 0.125*y24
 *         cdef double y177 = -1171.0*nu - 861.0             # <<<<<<<<<<<<<<
 *         cdef double y178 = 0.015625*y5
 *         cdef double y179 = y161*(115.0*nu + y160 - 37.0)
 */
  __Pyx_TraceLine(958,0,__PYX_ERR(1, 958, __pyx_L1_error))
  __pyx_v_y177 = ((-1171.0 * __pyx_v_nu) - 861.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":959
 *         cdef double y176 = 0.125*y24
 *         cdef double y177 = -1171.0*nu - 861.0
 *         cdef double y178 = 0.015625*y5             # <<<<<<<<<<<<<<
 *         cdef double y179 = y161*(115.0*nu + y160 - 37.0)
 *         cdef double y180 = 0.03125*y24
 */
  __Pyx_TraceLine(959,0,__PYX_ERR(1, 959, __pyx_L1_error))
  __pyx_v_y178 = (0.015625 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":960
 *         cdef double y177 = -1171.0*nu - 861.0
 *         cdef double y178 = 0.015625*y5
 *         cdef double y179 = y161*(115.0*nu + y160 - 37.0)             # <<<<<<<<<<<<<<
 *         cdef double y180 = 0.03125*y24
 *         cdef double y181 = y20*(26.0*nu + 449.0)
 */
  __Pyx_TraceLine(960,0,__PYX_ERR(1, 960, __pyx_L1_error))
  __pyx_v_y179 = (__pyx_v_y161 * (((115.0 * __pyx_v_nu) + __pyx_v_y160) - 37.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":961
 *         cdef double y178 = 0.015625*y5
 *         cdef double y179 = y161*(115.0*nu + y160 - 37.0)
 *         cdef double y180 = 0.03125*y24             # <<<<<<<<<<<<<<
 *         cdef double y181 = y20*(26.0*nu + 449.0)
 *         cdef double y182 = 5787938193408.0*y135 - 9216.0*y137 - 967680.0*y139 + 55296.0*y140 + y143 + y147
 */
  __Pyx_TraceLine(961,0,__PYX_ERR(1, 961, __pyx_L1_error))
  __pyx_v_y180 = (0.03125 * __pyx_v_y24);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":962
 *         cdef double y179 = y161*(115.0*nu + y160 - 37.0)
 *         cdef double y180 = 0.03125*y24
 *         cdef double y181 = y20*(26.0*nu + 449.0)             # <<<<<<<<<<<<<<
 *         cdef double y182 = 5787938193408.0*y135 - 9216.0*y137 - 967680.0*y139 + 55296.0*y140 + y143 + y147
 *         cdef double y183 = y182**(-1)
 */
  __Pyx_TraceLine(962,0,__PYX_ERR(1, 962, __pyx_L1_error))
  __pyx_v_y181 = (__pyx_v_y20 * ((26.0 * __pyx_v_nu) + 449.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":963
 *         cdef double y180 = 0.03125*y24
 *         cdef double y181 = y20*(26.0*nu + 449.0)
 *         cdef double y182 = 5787938193408.0*y135 - 9216.0*y137 - 967680.0*y139 + 55296.0*y140 + y143 + y147             # <<<<<<<<<<<<<<
 *         cdef double y183 = y182**(-1)
 *         cdef double y184 = y11*y183
 */
  __Pyx_TraceLine(963,0,__PYX_ERR(1, 963, __pyx_L1_error))
  __pyx_v_y182 = ((((((5787938193408.0 * __pyx_v_y135) - (9216.0 * __pyx_v_y137)) - (967680.0 * __pyx_v_y139)) + (55296.0 * __pyx_v_y140)) + __pyx_v_y143) + __pyx_v_y147);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":964
 *         cdef double y181 = y20*(26.0*nu + 449.0)
 *         cdef double y182 = 5787938193408.0*y135 - 9216.0*y137 - 967680.0*y139 + 55296.0*y140 + y143 + y147
 *         cdef double y183 = y182**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y184 = y11*y183
 *         cdef double y185 = y172*y184
 */
  __Pyx_TraceLine(964,0,__PYX_ERR(1, 964, __pyx_L1_error))
  __pyx_v_y183 = pow(__pyx_v_y182, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":965
 *         cdef double y182 = 5787938193408.0*y135 - 9216.0*y137 - 967680.0*y139 + 55296.0*y140 + y143 + y147
 *         cdef double y183 = y182**(-1)
 *         cdef double y184 = y11*y183             # <<<<<<<<<<<<<<
 *         cdef double y185 = y172*y184
 *         cdef double y186 = 7680.0*y131
 */
  __Pyx_TraceLine(965,0,__PYX_ERR(1, 965, __pyx_L1_error))
  __pyx_v_y184 = (__pyx_v_y11 * __pyx_v_y183);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":966
 *         cdef double y183 = y182**(-1)
 *         cdef double y184 = y11*y183
 *         cdef double y185 = y172*y184             # <<<<<<<<<<<<<<
 *         cdef double y186 = 7680.0*y131
 *         cdef double y187 = y17*(y177*y178 + 0.015625*y179 + y180*y181) + y185*y186 + y28*(y175*(y13 - 3.0) + y176*(-21.0*X_1 + 21.0*X_2) + y5*(y46 + 2.8125)) + y67
 */
  __Pyx_TraceLine(966,0,__PYX_ERR(1, 966, __pyx_L1_error))
  __pyx_v_y185 = (__pyx_v_y172 * __pyx_v_y184);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":967
 *         cdef double y184 = y11*y183
 *         cdef double y185 = y172*y184
 *         cdef double y186 = 7680.0*y131             # <<<<<<<<<<<<<<
 *         cdef double y187 = y17*(y177*y178 + 0.015625*y179 + y180*y181) + y185*y186 + y28*(y175*(y13 - 3.0) + y176*(-21.0*X_1 + 21.0*X_2) + y5*(y46 + 2.8125)) + y67
 *         cdef double y188 = y182*y187
 */
  __Pyx_TraceLine(967,0,__PYX_ERR(1, 967, __pyx_L1_error))
  __pyx_v_y186 = (7680.0 * __pyx_v_y131);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":968
 *         cdef double y185 = y172*y184
 *         cdef double y186 = 7680.0*y131
 *         cdef double y187 = y17*(y177*y178 + 0.015625*y179 + y180*y181) + y185*y186 + y28*(y175*(y13 - 3.0) + y176*(-21.0*X_1 + 21.0*X_2) + y5*(y46 + 2.8125)) + y67             # <<<<<<<<<<<<<<
 *         cdef double y188 = y182*y187
 *         cdef double y189 = y174*y188
 */
  __Pyx_TraceLine(968,0,__PYX_ERR(1, 968, __pyx_L1_error))
  __pyx_v_y187 = ((((__pyx_v_y17 * (((__pyx_v_y177 * __pyx_v_y178) + (0.015625 * __pyx_v_y179)) + (__pyx_v_y180 * __pyx_v_y181))) + (__pyx_v_y185 * __pyx_v_y186)) + (__pyx_v_y28 * (((__pyx_v_y175 * (__pyx_v_y13 - 3.0)) + (__pyx_v_y176 * ((-21.0 * __pyx_v_X_1) + (21.0 * __pyx_v_X_2)))) + (__pyx_v_y5 * (__pyx_v_y46 + 2.8125))))) + __pyx_v_y67);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":969
 *         cdef double y186 = 7680.0*y131
 *         cdef double y187 = y17*(y177*y178 + 0.015625*y179 + y180*y181) + y185*y186 + y28*(y175*(y13 - 3.0) + y176*(-21.0*X_1 + 21.0*X_2) + y5*(y46 + 2.8125)) + y67
 *         cdef double y188 = y182*y187             # <<<<<<<<<<<<<<
 *         cdef double y189 = y174*y188
 *         cdef double y190 = y6**2
 */
  __Pyx_TraceLine(969,0,__PYX_ERR(1, 969, __pyx_L1_error))
  __pyx_v_y188 = (__pyx_v_y182 * __pyx_v_y187);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":970
 *         cdef double y187 = y17*(y177*y178 + 0.015625*y179 + y180*y181) + y185*y186 + y28*(y175*(y13 - 3.0) + y176*(-21.0*X_1 + 21.0*X_2) + y5*(y46 + 2.8125)) + y67
 *         cdef double y188 = y182*y187
 *         cdef double y189 = y174*y188             # <<<<<<<<<<<<<<
 *         cdef double y190 = y6**2
 *         cdef double y191 = y12*y190
 */
  __Pyx_TraceLine(970,0,__PYX_ERR(1, 970, __pyx_L1_error))
  __pyx_v_y189 = (__pyx_v_y174 * __pyx_v_y188);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":971
 *         cdef double y188 = y182*y187
 *         cdef double y189 = y174*y188
 *         cdef double y190 = y6**2             # <<<<<<<<<<<<<<
 *         cdef double y191 = y12*y190
 *         cdef double y192 = 1.69542100694444e-8*y191
 */
  __Pyx_TraceLine(971,0,__PYX_ERR(1, 971, __pyx_L1_error))
  __pyx_v_y190 = pow(__pyx_v_y6, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":972
 *         cdef double y189 = y174*y188
 *         cdef double y190 = y6**2
 *         cdef double y191 = y12*y190             # <<<<<<<<<<<<<<
 *         cdef double y192 = 1.69542100694444e-8*y191
 *         cdef double y193 = y100*y101 - y106*y108 + 1.27277314139085e-19*y164*y167 + y189*y192 + y28*y91 + y28*y96 + y51*y88 + y51*y93 + y51*y98 + y72 + 147.443752990146*y76*y78 - 11.3175085791863*y79*y81 + 1.48275342024365*y82*y84 + y85*y86 + 1.0
 */
  __Pyx_TraceLine(972,0,__PYX_ERR(1, 972, __pyx_L1_error))
  __pyx_v_y191 = (__pyx_v_y12 * __pyx_v_y190);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":973
 *         cdef double y190 = y6**2
 *         cdef double y191 = y12*y190
 *         cdef double y192 = 1.69542100694444e-8*y191             # <<<<<<<<<<<<<<
 *         cdef double y193 = y100*y101 - y106*y108 + 1.27277314139085e-19*y164*y167 + y189*y192 + y28*y91 + y28*y96 + y51*y88 + y51*y93 + y51*y98 + y72 + 147.443752990146*y76*y78 - 11.3175085791863*y79*y81 + 1.48275342024365*y82*y84 + y85*y86 + 1.0
 *         cdef double y194 = y67*(2.0*y71 + 1.0) + 1.0
 */
  __Pyx_TraceLine(973,0,__PYX_ERR(1, 973, __pyx_L1_error))
  __pyx_v_y192 = (1.69542100694444e-8 * __pyx_v_y191);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":974
 *         cdef double y191 = y12*y190
 *         cdef double y192 = 1.69542100694444e-8*y191
 *         cdef double y193 = y100*y101 - y106*y108 + 1.27277314139085e-19*y164*y167 + y189*y192 + y28*y91 + y28*y96 + y51*y88 + y51*y93 + y51*y98 + y72 + 147.443752990146*y76*y78 - 11.3175085791863*y79*y81 + 1.48275342024365*y82*y84 + y85*y86 + 1.0             # <<<<<<<<<<<<<<
 *         cdef double y194 = y67*(2.0*y71 + 1.0) + 1.0
 *         cdef double y195 = y194**(-1)
 */
  __Pyx_TraceLine(974,0,__PYX_ERR(1, 974, __pyx_L1_error))
  __pyx_v_y193 = (((((((((((((((__pyx_v_y100 * __pyx_v_y101) - (__pyx_v_y106 * __pyx_v_y108)) + ((1.27277314139085e-19 * __pyx_v_y164) * __pyx_v_y167)) + (__pyx_v_y189 * __pyx_v_y192)) + (__pyx_v_y28 * __pyx_v_y91)) + (__pyx_v_y28 * __pyx_v_y96)) + (__pyx_v_y51 * __pyx_v_y88)) + (__pyx_v_y51 * __pyx_v_y93)) + (__pyx_v_y51 * __pyx_v_y98)) + __pyx_v_y72) + ((147.443752990146 * __pyx_v_y76) * __pyx_v_y78)) - ((11.3175085791863 * __pyx_v_y79) * __pyx_v_y81)) + ((1.48275342024365 * __pyx_v_y82) * __pyx_v_y84)) + (__pyx_v_y85 * __pyx_v_y86)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":975
 *         cdef double y192 = 1.69542100694444e-8*y191
 *         cdef double y193 = y100*y101 - y106*y108 + 1.27277314139085e-19*y164*y167 + y189*y192 + y28*y91 + y28*y96 + y51*y88 + y51*y93 + y51*y98 + y72 + 147.443752990146*y76*y78 - 11.3175085791863*y79*y81 + 1.48275342024365*y82*y84 + y85*y86 + 1.0
 *         cdef double y194 = y67*(2.0*y71 + 1.0) + 1.0             # <<<<<<<<<<<<<<
 *         cdef double y195 = y194**(-1)
 *         cdef double y196 = y161*(4.0*nu + 1.0)
 */
  __Pyx_TraceLine(975,0,__PYX_ERR(1, 975, __pyx_L1_error))
  __pyx_v_y194 = ((__pyx_v_y67 * ((2.0 * __pyx_v_y71) + 1.0)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":976
 *         cdef double y193 = y100*y101 - y106*y108 + 1.27277314139085e-19*y164*y167 + y189*y192 + y28*y91 + y28*y96 + y51*y88 + y51*y93 + y51*y98 + y72 + 147.443752990146*y76*y78 - 11.3175085791863*y79*y81 + 1.48275342024365*y82*y84 + y85*y86 + 1.0
 *         cdef double y194 = y67*(2.0*y71 + 1.0) + 1.0
 *         cdef double y195 = y194**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y196 = y161*(4.0*nu + 1.0)
 *         cdef double y197 = -y23*y24
 */
  __Pyx_TraceLine(976,0,__PYX_ERR(1, 976, __pyx_L1_error))
  __pyx_v_y195 = pow(__pyx_v_y194, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":977
 *         cdef double y194 = y67*(2.0*y71 + 1.0) + 1.0
 *         cdef double y195 = y194**(-1)
 *         cdef double y196 = y161*(4.0*nu + 1.0)             # <<<<<<<<<<<<<<
 *         cdef double y197 = -y23*y24
 *         cdef double y198 = y17*(0.125*y196 + 0.25*y197 + 1.125*y5)
 */
  __Pyx_TraceLine(977,0,__PYX_ERR(1, 977, __pyx_L1_error))
  __pyx_v_y196 = (__pyx_v_y161 * ((4.0 * __pyx_v_nu) + 1.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":978
 *         cdef double y195 = y194**(-1)
 *         cdef double y196 = y161*(4.0*nu + 1.0)
 *         cdef double y197 = -y23*y24             # <<<<<<<<<<<<<<
 *         cdef double y198 = y17*(0.125*y196 + 0.25*y197 + 1.125*y5)
 *         cdef double y199 = y161*(-27.0*nu + 28.0*y32 - 3.0)
 */
  __Pyx_TraceLine(978,0,__PYX_ERR(1, 978, __pyx_L1_error))
  __pyx_v_y197 = ((-__pyx_v_y23) * __pyx_v_y24);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":979
 *         cdef double y196 = y161*(4.0*nu + 1.0)
 *         cdef double y197 = -y23*y24
 *         cdef double y198 = y17*(0.125*y196 + 0.25*y197 + 1.125*y5)             # <<<<<<<<<<<<<<
 *         cdef double y199 = y161*(-27.0*nu + 28.0*y32 - 3.0)
 *         cdef double y200 = -39.0*X_1 + 39.0*X_2
 */
  __Pyx_TraceLine(979,0,__PYX_ERR(1, 979, __pyx_L1_error))
  __pyx_v_y198 = (__pyx_v_y17 * (((0.125 * __pyx_v_y196) + (0.25 * __pyx_v_y197)) + (1.125 * __pyx_v_y5)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":980
 *         cdef double y197 = -y23*y24
 *         cdef double y198 = y17*(0.125*y196 + 0.25*y197 + 1.125*y5)
 *         cdef double y199 = y161*(-27.0*nu + 28.0*y32 - 3.0)             # <<<<<<<<<<<<<<
 *         cdef double y200 = -39.0*X_1 + 39.0*X_2
 *         cdef double y201 = y180*y200
 */
  __Pyx_TraceLine(980,0,__PYX_ERR(1, 980, __pyx_L1_error))
  __pyx_v_y199 = (__pyx_v_y161 * (((-27.0 * __pyx_v_nu) + (28.0 * __pyx_v_y32)) - 3.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":981
 *         cdef double y198 = y17*(0.125*y196 + 0.25*y197 + 1.125*y5)
 *         cdef double y199 = y161*(-27.0*nu + 28.0*y32 - 3.0)
 *         cdef double y200 = -39.0*X_1 + 39.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double y201 = y180*y200
 *         cdef double y202 = y12*(-y178*(175.0*nu + 225.0) + 0.046875*y199 + y201*(2.0*nu - 3.0))
 */
  __Pyx_TraceLine(981,0,__PYX_ERR(1, 981, __pyx_L1_error))
  __pyx_v_y200 = ((-39.0 * __pyx_v_X_1) + (39.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":982
 *         cdef double y199 = y161*(-27.0*nu + 28.0*y32 - 3.0)
 *         cdef double y200 = -39.0*X_1 + 39.0*X_2
 *         cdef double y201 = y180*y200             # <<<<<<<<<<<<<<
 *         cdef double y202 = y12*(-y178*(175.0*nu + 225.0) + 0.046875*y199 + y201*(2.0*nu - 3.0))
 *         cdef double y203 = 7680.0*y132 + y198 + y202 + y67
 */
  __Pyx_TraceLine(982,0,__PYX_ERR(1, 982, __pyx_L1_error))
  __pyx_v_y201 = (__pyx_v_y180 * __pyx_v_y200);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":983
 *         cdef double y200 = -39.0*X_1 + 39.0*X_2
 *         cdef double y201 = y180*y200
 *         cdef double y202 = y12*(-y178*(175.0*nu + 225.0) + 0.046875*y199 + y201*(2.0*nu - 3.0))             # <<<<<<<<<<<<<<
 *         cdef double y203 = 7680.0*y132 + y198 + y202 + y67
 *         cdef double y204 = y195*y203
 */
  __Pyx_TraceLine(983,0,__PYX_ERR(1, 983, __pyx_L1_error))
  __pyx_v_y202 = (__pyx_v_y12 * ((((-__pyx_v_y178) * ((175.0 * __pyx_v_nu) + 225.0)) + (0.046875 * __pyx_v_y199)) + (__pyx_v_y201 * ((2.0 * __pyx_v_nu) - 3.0))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":984
 *         cdef double y201 = y180*y200
 *         cdef double y202 = y12*(-y178*(175.0*nu + 225.0) + 0.046875*y199 + y201*(2.0*nu - 3.0))
 *         cdef double y203 = 7680.0*y132 + y198 + y202 + y67             # <<<<<<<<<<<<<<
 *         cdef double y204 = y195*y203
 *         cdef double y205 = y193*y204
 */
  __Pyx_TraceLine(984,0,__PYX_ERR(1, 984, __pyx_L1_error))
  __pyx_v_y203 = ((((7680.0 * __pyx_v_y132) + __pyx_v_y198) + __pyx_v_y202) + __pyx_v_y67);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":985
 *         cdef double y202 = y12*(-y178*(175.0*nu + 225.0) + 0.046875*y199 + y201*(2.0*nu - 3.0))
 *         cdef double y203 = 7680.0*y132 + y198 + y202 + y67
 *         cdef double y204 = y195*y203             # <<<<<<<<<<<<<<
 *         cdef double y205 = y193*y204
 *         cdef double y206 = y205**(-1.5)
 */
  __Pyx_TraceLine(985,0,__PYX_ERR(1, 985, __pyx_L1_error))
  __pyx_v_y204 = (__pyx_v_y195 * __pyx_v_y203);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":986
 *         cdef double y203 = 7680.0*y132 + y198 + y202 + y67
 *         cdef double y204 = y195*y203
 *         cdef double y205 = y193*y204             # <<<<<<<<<<<<<<
 *         cdef double y206 = y205**(-1.5)
 *         cdef double y207 = 4.0*y71 + 2.0
 */
  __Pyx_TraceLine(986,0,__PYX_ERR(1, 986, __pyx_L1_error))
  __pyx_v_y205 = (__pyx_v_y193 * __pyx_v_y204);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":987
 *         cdef double y204 = y195*y203
 *         cdef double y205 = y193*y204
 *         cdef double y206 = y205**(-1.5)             # <<<<<<<<<<<<<<
 *         cdef double y207 = 4.0*y71 + 2.0
 *         cdef double y208 = -y207
 */
  __Pyx_TraceLine(987,0,__PYX_ERR(1, 987, __pyx_L1_error))
  __pyx_v_y206 = pow(__pyx_v_y205, -1.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":988
 *         cdef double y205 = y193*y204
 *         cdef double y206 = y205**(-1.5)
 *         cdef double y207 = 4.0*y71 + 2.0             # <<<<<<<<<<<<<<
 *         cdef double y208 = -y207
 *         cdef double y209 = -y17*y8 + y208*y48
 */
  __Pyx_TraceLine(988,0,__PYX_ERR(1, 988, __pyx_L1_error))
  __pyx_v_y207 = ((4.0 * __pyx_v_y71) + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":989
 *         cdef double y206 = y205**(-1.5)
 *         cdef double y207 = 4.0*y71 + 2.0
 *         cdef double y208 = -y207             # <<<<<<<<<<<<<<
 *         cdef double y209 = -y17*y8 + y208*y48
 *         cdef double y210 = y194**(-2)
 */
  __Pyx_TraceLine(989,0,__PYX_ERR(1, 989, __pyx_L1_error))
  __pyx_v_y208 = (-__pyx_v_y207);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":990
 *         cdef double y207 = 4.0*y71 + 2.0
 *         cdef double y208 = -y207
 *         cdef double y209 = -y17*y8 + y208*y48             # <<<<<<<<<<<<<<
 *         cdef double y210 = y194**(-2)
 *         cdef double y211 = y203*y210
 */
  __Pyx_TraceLine(990,0,__PYX_ERR(1, 990, __pyx_L1_error))
  __pyx_v_y209 = (((-__pyx_v_y17) * __pyx_v_y8) + (__pyx_v_y208 * __pyx_v_y48));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":991
 *         cdef double y208 = -y207
 *         cdef double y209 = -y17*y8 + y208*y48
 *         cdef double y210 = y194**(-2)             # <<<<<<<<<<<<<<
 *         cdef double y211 = y203*y210
 *         cdef double y212 = y193*y211
 */
  __Pyx_TraceLine(991,0,__PYX_ERR(1, 991, __pyx_L1_error))
  __pyx_v_y210 = pow(__pyx_v_y194, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":992
 *         cdef double y209 = -y17*y8 + y208*y48
 *         cdef double y210 = y194**(-2)
 *         cdef double y211 = y203*y210             # <<<<<<<<<<<<<<
 *         cdef double y212 = y193*y211
 *         cdef double y213 = 875.0*nu + 1125.0
 */
  __Pyx_TraceLine(992,0,__PYX_ERR(1, 992, __pyx_L1_error))
  __pyx_v_y211 = (__pyx_v_y203 * __pyx_v_y210);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":993
 *         cdef double y210 = y194**(-2)
 *         cdef double y211 = y203*y210
 *         cdef double y212 = y193*y211             # <<<<<<<<<<<<<<
 *         cdef double y213 = 875.0*nu + 1125.0
 *         cdef double y214 = 10.0*nu - 15.0
 */
  __Pyx_TraceLine(993,0,__PYX_ERR(1, 993, __pyx_L1_error))
  __pyx_v_y212 = (__pyx_v_y193 * __pyx_v_y211);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":994
 *         cdef double y211 = y203*y210
 *         cdef double y212 = y193*y211
 *         cdef double y213 = 875.0*nu + 1125.0             # <<<<<<<<<<<<<<
 *         cdef double y214 = 10.0*nu - 15.0
 *         cdef double y215 = y28*y8
 */
  __Pyx_TraceLine(994,0,__PYX_ERR(1, 994, __pyx_L1_error))
  __pyx_v_y213 = ((875.0 * __pyx_v_nu) + 1125.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":995
 *         cdef double y212 = y193*y211
 *         cdef double y213 = 875.0*nu + 1125.0
 *         cdef double y214 = 10.0*nu - 15.0             # <<<<<<<<<<<<<<
 *         cdef double y215 = y28*y8
 *         cdef double y216 = 2048.0*y129
 */
  __Pyx_TraceLine(995,0,__PYX_ERR(1, 995, __pyx_L1_error))
  __pyx_v_y214 = ((10.0 * __pyx_v_nu) - 15.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":996
 *         cdef double y213 = 875.0*nu + 1125.0
 *         cdef double y214 = 10.0*nu - 15.0
 *         cdef double y215 = y28*y8             # <<<<<<<<<<<<<<
 *         cdef double y216 = 2048.0*y129
 *         cdef double y217 = -6572428.80109422*nu + 688128.0*y118 + y216*y85 + 1300341.64885296*y32 + 1720320.0
 */
  __Pyx_TraceLine(996,0,__PYX_ERR(1, 996, __pyx_L1_error))
  __pyx_v_y215 = (__pyx_v_y28 * __pyx_v_y8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":997
 *         cdef double y214 = 10.0*nu - 15.0
 *         cdef double y215 = y28*y8
 *         cdef double y216 = 2048.0*y129             # <<<<<<<<<<<<<<
 *         cdef double y217 = -6572428.80109422*nu + 688128.0*y118 + y216*y85 + 1300341.64885296*y32 + 1720320.0
 *         cdef double y218 = y130*y16
 */
  __Pyx_TraceLine(997,0,__PYX_ERR(1, 997, __pyx_L1_error))
  __pyx_v_y216 = (2048.0 * __pyx_v_y129);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":998
 *         cdef double y215 = y28*y8
 *         cdef double y216 = 2048.0*y129
 *         cdef double y217 = -6572428.80109422*nu + 688128.0*y118 + y216*y85 + 1300341.64885296*y32 + 1720320.0             # <<<<<<<<<<<<<<
 *         cdef double y218 = y130*y16
 *         cdef double y219 = 0.0546957463279941*y11 + 0.28004222119933*y110 + 4.63661586574928e-9*y111 + 2.8978849160933e-11*y112 + 1.35654132757922e-7*y119 + 2.22557561555966e-7*y127 + y94
 */
  __Pyx_TraceLine(998,0,__PYX_ERR(1, 998, __pyx_L1_error))
  __pyx_v_y217 = (((((-6572428.80109422 * __pyx_v_nu) + (688128.0 * __pyx_v_y118)) + (__pyx_v_y216 * __pyx_v_y85)) + (1300341.64885296 * __pyx_v_y32)) + 1720320.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":999
 *         cdef double y216 = 2048.0*y129
 *         cdef double y217 = -6572428.80109422*nu + 688128.0*y118 + y216*y85 + 1300341.64885296*y32 + 1720320.0
 *         cdef double y218 = y130*y16             # <<<<<<<<<<<<<<
 *         cdef double y219 = 0.0546957463279941*y11 + 0.28004222119933*y110 + 4.63661586574928e-9*y111 + 2.8978849160933e-11*y112 + 1.35654132757922e-7*y119 + 2.22557561555966e-7*y127 + y94
 *         cdef double y220 = y219**(-2)
 */
  __Pyx_TraceLine(999,0,__PYX_ERR(1, 999, __pyx_L1_error))
  __pyx_v_y218 = (__pyx_v_y130 * __pyx_v_y16);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1000
 *         cdef double y217 = -6572428.80109422*nu + 688128.0*y118 + y216*y85 + 1300341.64885296*y32 + 1720320.0
 *         cdef double y218 = y130*y16
 *         cdef double y219 = 0.0546957463279941*y11 + 0.28004222119933*y110 + 4.63661586574928e-9*y111 + 2.8978849160933e-11*y112 + 1.35654132757922e-7*y119 + 2.22557561555966e-7*y127 + y94             # <<<<<<<<<<<<<<
 *         cdef double y220 = y219**(-2)
 *         cdef double y221 = y89*(-5706642207.53758*r - 26189434371.6082)
 */
  __Pyx_TraceLine(1000,0,__PYX_ERR(1, 1000, __pyx_L1_error))
  __pyx_v_y219 = (((((((0.0546957463279941 * __pyx_v_y11) + (0.28004222119933 * __pyx_v_y110)) + (4.63661586574928e-9 * __pyx_v_y111)) + (2.8978849160933e-11 * __pyx_v_y112)) + (1.35654132757922e-7 * __pyx_v_y119)) + (2.22557561555966e-7 * __pyx_v_y127)) + __pyx_v_y94);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1001
 *         cdef double y218 = y130*y16
 *         cdef double y219 = 0.0546957463279941*y11 + 0.28004222119933*y110 + 4.63661586574928e-9*y111 + 2.8978849160933e-11*y112 + 1.35654132757922e-7*y119 + 2.22557561555966e-7*y127 + y94
 *         cdef double y220 = y219**(-2)             # <<<<<<<<<<<<<<
 *         cdef double y221 = y89*(-5706642207.53758*r - 26189434371.6082)
 *         cdef double y222 = y71*y99
 */
  __Pyx_TraceLine(1001,0,__PYX_ERR(1, 1001, __pyx_L1_error))
  __pyx_v_y220 = pow(__pyx_v_y219, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1002
 *         cdef double y219 = 0.0546957463279941*y11 + 0.28004222119933*y110 + 4.63661586574928e-9*y111 + 2.8978849160933e-11*y112 + 1.35654132757922e-7*y119 + 2.22557561555966e-7*y127 + y94
 *         cdef double y220 = y219**(-2)
 *         cdef double y221 = y89*(-5706642207.53758*r - 26189434371.6082)             # <<<<<<<<<<<<<<
 *         cdef double y222 = y71*y99
 *         cdef double y223 = y222*y32
 */
  __Pyx_TraceLine(1002,0,__PYX_ERR(1, 1002, __pyx_L1_error))
  __pyx_v_y221 = (__pyx_v_y89 * ((-5706642207.53758 * __pyx_v_r) - 26189434371.6082));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1003
 *         cdef double y220 = y219**(-2)
 *         cdef double y221 = y89*(-5706642207.53758*r - 26189434371.6082)
 *         cdef double y222 = y71*y99             # <<<<<<<<<<<<<<
 *         cdef double y223 = y222*y32
 *         cdef double y224 = y32*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*y1 + 7133302759.42198*y16 - 12357002815.0752*y27 + 122635399361.987)
 */
  __Pyx_TraceLine(1003,0,__PYX_ERR(1, 1003, __pyx_L1_error))
  __pyx_v_y222 = (__pyx_v_y71 * __pyx_v_y99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1004
 *         cdef double y221 = y89*(-5706642207.53758*r - 26189434371.6082)
 *         cdef double y222 = y71*y99
 *         cdef double y223 = y222*y32             # <<<<<<<<<<<<<<
 *         cdef double y224 = y32*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*y1 + 7133302759.42198*y16 - 12357002815.0752*y27 + 122635399361.987)
 *         cdef double y225 = y1*y115
 */
  __Pyx_TraceLine(1004,0,__PYX_ERR(1, 1004, __pyx_L1_error))
  __pyx_v_y223 = (__pyx_v_y222 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1005
 *         cdef double y222 = y71*y99
 *         cdef double y223 = y222*y32
 *         cdef double y224 = y32*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*y1 + 7133302759.42198*y16 - 12357002815.0752*y27 + 122635399361.987)             # <<<<<<<<<<<<<<
 *         cdef double y225 = y1*y115
 *         cdef double y226 = -1791904.9465589*nu + 3840.0*r*y113 + 1920.0*y116 + 806400.0*y16 + 2880.0*y225 - 725760.0*y32 + 4143360.0
 */
  __Pyx_TraceLine(1005,0,__PYX_ERR(1, 1005, __pyx_L1_error))
  __pyx_v_y224 = (__pyx_v_y32 * ((((((-117964800.0 * __pyx_v_a6) + (4129567622.65173 * __pyx_v_r)) - (18535504222.6128 * __pyx_v_y1)) + (7133302759.42198 * __pyx_v_y16)) - (12357002815.0752 * __pyx_v_y27)) + 122635399361.987));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1006
 *         cdef double y223 = y222*y32
 *         cdef double y224 = y32*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*y1 + 7133302759.42198*y16 - 12357002815.0752*y27 + 122635399361.987)
 *         cdef double y225 = y1*y115             # <<<<<<<<<<<<<<
 *         cdef double y226 = -1791904.9465589*nu + 3840.0*r*y113 + 1920.0*y116 + 806400.0*y16 + 2880.0*y225 - 725760.0*y32 + 4143360.0
 *         cdef double y227 = y118*y226
 */
  __Pyx_TraceLine(1006,0,__PYX_ERR(1, 1006, __pyx_L1_error))
  __pyx_v_y225 = (__pyx_v_y1 * __pyx_v_y115);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1007
 *         cdef double y224 = y32*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*y1 + 7133302759.42198*y16 - 12357002815.0752*y27 + 122635399361.987)
 *         cdef double y225 = y1*y115
 *         cdef double y226 = -1791904.9465589*nu + 3840.0*r*y113 + 1920.0*y116 + 806400.0*y16 + 2880.0*y225 - 725760.0*y32 + 4143360.0             # <<<<<<<<<<<<<<
 *         cdef double y227 = y118*y226
 *         cdef double y228 = y117*y85
 */
  __Pyx_TraceLine(1007,0,__PYX_ERR(1, 1007, __pyx_L1_error))
  __pyx_v_y226 = (((((((-1791904.9465589 * __pyx_v_nu) + ((3840.0 * __pyx_v_r) * __pyx_v_y113)) + (1920.0 * __pyx_v_y116)) + (806400.0 * __pyx_v_y16)) + (2880.0 * __pyx_v_y225)) - (725760.0 * __pyx_v_y32)) + 4143360.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1008
 *         cdef double y225 = y1*y115
 *         cdef double y226 = -1791904.9465589*nu + 3840.0*r*y113 + 1920.0*y116 + 806400.0*y16 + 2880.0*y225 - 725760.0*y32 + 4143360.0
 *         cdef double y227 = y118*y226             # <<<<<<<<<<<<<<
 *         cdef double y228 = y117*y85
 *         cdef double y229 = 4.0*y27
 */
  __Pyx_TraceLine(1008,0,__PYX_ERR(1, 1008, __pyx_L1_error))
  __pyx_v_y227 = (__pyx_v_y118 * __pyx_v_y226);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1009
 *         cdef double y226 = -1791904.9465589*nu + 3840.0*r*y113 + 1920.0*y116 + 806400.0*y16 + 2880.0*y225 - 725760.0*y32 + 4143360.0
 *         cdef double y227 = y118*y226
 *         cdef double y228 = y117*y85             # <<<<<<<<<<<<<<
 *         cdef double y229 = 4.0*y27
 *         cdef double y230 = 6.0*y1 + y120 + 8.0
 */
  __Pyx_TraceLine(1009,0,__PYX_ERR(1, 1009, __pyx_L1_error))
  __pyx_v_y228 = (__pyx_v_y117 * __pyx_v_y85);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1010
 *         cdef double y227 = y118*y226
 *         cdef double y228 = y117*y85
 *         cdef double y229 = 4.0*y27             # <<<<<<<<<<<<<<
 *         cdef double y230 = 6.0*y1 + y120 + 8.0
 *         cdef double y231 = nu*(3740417.71815805*r + 2115968.85907902*y1 + y122*(y229 + y230) + y123*(17058.7851094412*r + 12794.0888320809*y1 - 27409.3925547206*y27 + 13218.7851094412) + y125*(5778.0*y1 + y124 + 1396.0*y27 + 7704.0) + y126*(-y229 + y230) - 938918.400156317*y16 + 1057984.42953951*y27 + 2888096.47013111)
 */
  __Pyx_TraceLine(1010,0,__PYX_ERR(1, 1010, __pyx_L1_error))
  __pyx_v_y229 = (4.0 * __pyx_v_y27);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1011
 *         cdef double y228 = y117*y85
 *         cdef double y229 = 4.0*y27
 *         cdef double y230 = 6.0*y1 + y120 + 8.0             # <<<<<<<<<<<<<<
 *         cdef double y231 = nu*(3740417.71815805*r + 2115968.85907902*y1 + y122*(y229 + y230) + y123*(17058.7851094412*r + 12794.0888320809*y1 - 27409.3925547206*y27 + 13218.7851094412) + y125*(5778.0*y1 + y124 + 1396.0*y27 + 7704.0) + y126*(-y229 + y230) - 938918.400156317*y16 + 1057984.42953951*y27 + 2888096.47013111)
 *         cdef double y232 = y220*(66060288000.0*y16 + 7.0*y221 + 135291469824.0*y223 + 7.0*y224 + 32768.0*y227 + 32768.0*y228 + 53760.0*y231)
 */
  __Pyx_TraceLine(1011,0,__PYX_ERR(1, 1011, __pyx_L1_error))
  __pyx_v_y230 = (((6.0 * __pyx_v_y1) + __pyx_v_y120) + 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1012
 *         cdef double y229 = 4.0*y27
 *         cdef double y230 = 6.0*y1 + y120 + 8.0
 *         cdef double y231 = nu*(3740417.71815805*r + 2115968.85907902*y1 + y122*(y229 + y230) + y123*(17058.7851094412*r + 12794.0888320809*y1 - 27409.3925547206*y27 + 13218.7851094412) + y125*(5778.0*y1 + y124 + 1396.0*y27 + 7704.0) + y126*(-y229 + y230) - 938918.400156317*y16 + 1057984.42953951*y27 + 2888096.47013111)             # <<<<<<<<<<<<<<
 *         cdef double y232 = y220*(66060288000.0*y16 + 7.0*y221 + 135291469824.0*y223 + 7.0*y224 + 32768.0*y227 + 32768.0*y228 + 53760.0*y231)
 *         cdef double y233 = y218*y232
 */
  __Pyx_TraceLine(1012,0,__PYX_ERR(1, 1012, __pyx_L1_error))
  __pyx_v_y231 = (__pyx_v_nu * (((((((((3740417.71815805 * __pyx_v_r) + (2115968.85907902 * __pyx_v_y1)) + (__pyx_v_y122 * (__pyx_v_y229 + __pyx_v_y230))) + (__pyx_v_y123 * ((((17058.7851094412 * __pyx_v_r) + (12794.0888320809 * __pyx_v_y1)) - (27409.3925547206 * __pyx_v_y27)) + 13218.7851094412))) + (__pyx_v_y125 * ((((5778.0 * __pyx_v_y1) + __pyx_v_y124) + (1396.0 * __pyx_v_y27)) + 7704.0))) + (__pyx_v_y126 * ((-__pyx_v_y229) + __pyx_v_y230))) - (938918.400156317 * __pyx_v_y16)) + (1057984.42953951 * __pyx_v_y27)) + 2888096.47013111));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1013
 *         cdef double y230 = 6.0*y1 + y120 + 8.0
 *         cdef double y231 = nu*(3740417.71815805*r + 2115968.85907902*y1 + y122*(y229 + y230) + y123*(17058.7851094412*r + 12794.0888320809*y1 - 27409.3925547206*y27 + 13218.7851094412) + y125*(5778.0*y1 + y124 + 1396.0*y27 + 7704.0) + y126*(-y229 + y230) - 938918.400156317*y16 + 1057984.42953951*y27 + 2888096.47013111)
 *         cdef double y232 = y220*(66060288000.0*y16 + 7.0*y221 + 135291469824.0*y223 + 7.0*y224 + 32768.0*y227 + 32768.0*y228 + 53760.0*y231)             # <<<<<<<<<<<<<<
 *         cdef double y233 = y218*y232
 *         cdef double y234 = -30720.0*y128*y130*y27 - 7680.0*y128*y16*y217 + y215 + 1.31621673590926e-19*y233
 */
  __Pyx_TraceLine(1013,0,__PYX_ERR(1, 1013, __pyx_L1_error))
  __pyx_v_y232 = (__pyx_v_y220 * (((((((66060288000.0 * __pyx_v_y16) + (7.0 * __pyx_v_y221)) + (135291469824.0 * __pyx_v_y223)) + (7.0 * __pyx_v_y224)) + (32768.0 * __pyx_v_y227)) + (32768.0 * __pyx_v_y228)) + (53760.0 * __pyx_v_y231)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1014
 *         cdef double y231 = nu*(3740417.71815805*r + 2115968.85907902*y1 + y122*(y229 + y230) + y123*(17058.7851094412*r + 12794.0888320809*y1 - 27409.3925547206*y27 + 13218.7851094412) + y125*(5778.0*y1 + y124 + 1396.0*y27 + 7704.0) + y126*(-y229 + y230) - 938918.400156317*y16 + 1057984.42953951*y27 + 2888096.47013111)
 *         cdef double y232 = y220*(66060288000.0*y16 + 7.0*y221 + 135291469824.0*y223 + 7.0*y224 + 32768.0*y227 + 32768.0*y228 + 53760.0*y231)
 *         cdef double y233 = y218*y232             # <<<<<<<<<<<<<<
 *         cdef double y234 = -30720.0*y128*y130*y27 - 7680.0*y128*y16*y217 + y215 + 1.31621673590926e-19*y233
 *         cdef double y235 = -y12*(0.5*y196 + y197 + 4.5*y5) - y234 - y36*(-y178*y213 + 0.234375*y199 + y201*y214)
 */
  __Pyx_TraceLine(1014,0,__PYX_ERR(1, 1014, __pyx_L1_error))
  __pyx_v_y233 = (__pyx_v_y218 * __pyx_v_y232);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1015
 *         cdef double y232 = y220*(66060288000.0*y16 + 7.0*y221 + 135291469824.0*y223 + 7.0*y224 + 32768.0*y227 + 32768.0*y228 + 53760.0*y231)
 *         cdef double y233 = y218*y232
 *         cdef double y234 = -30720.0*y128*y130*y27 - 7680.0*y128*y16*y217 + y215 + 1.31621673590926e-19*y233             # <<<<<<<<<<<<<<
 *         cdef double y235 = -y12*(0.5*y196 + y197 + 4.5*y5) - y234 - y36*(-y178*y213 + 0.234375*y199 + y201*y214)
 *         cdef double y236 = y193*y195
 */
  __Pyx_TraceLine(1015,0,__PYX_ERR(1, 1015, __pyx_L1_error))
  __pyx_v_y234 = ((((((-30720.0 * __pyx_v_y128) * __pyx_v_y130) * __pyx_v_y27) - (((7680.0 * __pyx_v_y128) * __pyx_v_y16) * __pyx_v_y217)) + __pyx_v_y215) + (1.31621673590926e-19 * __pyx_v_y233));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1016
 *         cdef double y233 = y218*y232
 *         cdef double y234 = -30720.0*y128*y130*y27 - 7680.0*y128*y16*y217 + y215 + 1.31621673590926e-19*y233
 *         cdef double y235 = -y12*(0.5*y196 + y197 + 4.5*y5) - y234 - y36*(-y178*y213 + 0.234375*y199 + y201*y214)             # <<<<<<<<<<<<<<
 *         cdef double y236 = y193*y195
 *         cdef double y237 = r**(-5.5)
 */
  __Pyx_TraceLine(1016,0,__PYX_ERR(1, 1016, __pyx_L1_error))
  __pyx_v_y235 = ((((-__pyx_v_y12) * (((0.5 * __pyx_v_y196) + __pyx_v_y197) + (4.5 * __pyx_v_y5))) - __pyx_v_y234) - (__pyx_v_y36 * ((((-__pyx_v_y178) * __pyx_v_y213) + (0.234375 * __pyx_v_y199)) + (__pyx_v_y201 * __pyx_v_y214))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1017
 *         cdef double y234 = -30720.0*y128*y130*y27 - 7680.0*y128*y16*y217 + y215 + 1.31621673590926e-19*y233
 *         cdef double y235 = -y12*(0.5*y196 + y197 + 4.5*y5) - y234 - y36*(-y178*y213 + 0.234375*y199 + y201*y214)
 *         cdef double y236 = y193*y195             # <<<<<<<<<<<<<<
 *         cdef double y237 = r**(-5.5)
 *         cdef double y238 = nu*y76
 */
  __Pyx_TraceLine(1017,0,__PYX_ERR(1, 1017, __pyx_L1_error))
  __pyx_v_y236 = (__pyx_v_y193 * __pyx_v_y195);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1018
 *         cdef double y235 = -y12*(0.5*y196 + y197 + 4.5*y5) - y234 - y36*(-y178*y213 + 0.234375*y199 + y201*y214)
 *         cdef double y236 = y193*y195
 *         cdef double y237 = r**(-5.5)             # <<<<<<<<<<<<<<
 *         cdef double y238 = nu*y76
 *         cdef double y239 = nu*y51
 */
  __Pyx_TraceLine(1018,0,__PYX_ERR(1, 1018, __pyx_L1_error))
  __pyx_v_y237 = pow(__pyx_v_r, -5.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1019
 *         cdef double y236 = y193*y195
 *         cdef double y237 = r**(-5.5)
 *         cdef double y238 = nu*y76             # <<<<<<<<<<<<<<
 *         cdef double y239 = nu*y51
 *         cdef double y240 = 2.0*y28
 */
  __Pyx_TraceLine(1019,0,__PYX_ERR(1, 1019, __pyx_L1_error))
  __pyx_v_y238 = (__pyx_v_nu * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1020
 *         cdef double y237 = r**(-5.5)
 *         cdef double y238 = nu*y76
 *         cdef double y239 = nu*y51             # <<<<<<<<<<<<<<
 *         cdef double y240 = 2.0*y28
 *         cdef double y241 = 118.4*y32
 */
  __Pyx_TraceLine(1020,0,__PYX_ERR(1, 1020, __pyx_L1_error))
  __pyx_v_y239 = (__pyx_v_nu * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1021
 *         cdef double y238 = nu*y76
 *         cdef double y239 = nu*y51
 *         cdef double y240 = 2.0*y28             # <<<<<<<<<<<<<<
 *         cdef double y241 = 118.4*y32
 *         cdef double y242 = -51.6952380952381*nu*y71 + y241*y71
 */
  __Pyx_TraceLine(1021,0,__PYX_ERR(1, 1021, __pyx_L1_error))
  __pyx_v_y240 = (2.0 * __pyx_v_y28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1022
 *         cdef double y239 = nu*y51
 *         cdef double y240 = 2.0*y28
 *         cdef double y241 = 118.4*y32             # <<<<<<<<<<<<<<
 *         cdef double y242 = -51.6952380952381*nu*y71 + y241*y71
 *         cdef double y243 = y100*y76
 */
  __Pyx_TraceLine(1022,0,__PYX_ERR(1, 1022, __pyx_L1_error))
  __pyx_v_y241 = (118.4 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1023
 *         cdef double y240 = 2.0*y28
 *         cdef double y241 = 118.4*y32
 *         cdef double y242 = -51.6952380952381*nu*y71 + y241*y71             # <<<<<<<<<<<<<<
 *         cdef double y243 = y100*y76
 *         cdef double y244 = y5*y71
 */
  __Pyx_TraceLine(1023,0,__PYX_ERR(1, 1023, __pyx_L1_error))
  __pyx_v_y242 = (((-51.6952380952381 * __pyx_v_nu) * __pyx_v_y71) + (__pyx_v_y241 * __pyx_v_y71));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1024
 *         cdef double y241 = 118.4*y32
 *         cdef double y242 = -51.6952380952381*nu*y71 + y241*y71
 *         cdef double y243 = y100*y76             # <<<<<<<<<<<<<<
 *         cdef double y244 = y5*y71
 *         cdef double y245 = y104**(-2)
 */
  __Pyx_TraceLine(1024,0,__PYX_ERR(1, 1024, __pyx_L1_error))
  __pyx_v_y243 = (__pyx_v_y100 * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1025
 *         cdef double y242 = -51.6952380952381*nu*y71 + y241*y71
 *         cdef double y243 = y100*y76
 *         cdef double y244 = y5*y71             # <<<<<<<<<<<<<<
 *         cdef double y245 = y104**(-2)
 *         cdef double y246 = y103 + y107 + y229
 */
  __Pyx_TraceLine(1025,0,__PYX_ERR(1, 1025, __pyx_L1_error))
  __pyx_v_y244 = (__pyx_v_y5 * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1026
 *         cdef double y243 = y100*y76
 *         cdef double y244 = y5*y71
 *         cdef double y245 = y104**(-2)             # <<<<<<<<<<<<<<
 *         cdef double y246 = y103 + y107 + y229
 *         cdef double y247 = r**(-14)
 */
  __Pyx_TraceLine(1026,0,__PYX_ERR(1, 1026, __pyx_L1_error))
  __pyx_v_y245 = pow(__pyx_v_y104, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1027
 *         cdef double y244 = y5*y71
 *         cdef double y245 = y104**(-2)
 *         cdef double y246 = y103 + y107 + y229             # <<<<<<<<<<<<<<
 *         cdef double y247 = r**(-14)
 *         cdef double y248 = y164*y166
 */
  __Pyx_TraceLine(1027,0,__PYX_ERR(1, 1027, __pyx_L1_error))
  __pyx_v_y246 = ((__pyx_v_y103 + __pyx_v_y107) + __pyx_v_y229);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1028
 *         cdef double y245 = y104**(-2)
 *         cdef double y246 = y103 + y107 + y229
 *         cdef double y247 = r**(-14)             # <<<<<<<<<<<<<<
 *         cdef double y248 = y164*y166
 *         cdef double y249 = r**(-12)
 */
  __Pyx_TraceLine(1028,0,__PYX_ERR(1, 1028, __pyx_L1_error))
  __pyx_v_y247 = pow(__pyx_v_r, -14.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1029
 *         cdef double y246 = y103 + y107 + y229
 *         cdef double y247 = r**(-14)
 *         cdef double y248 = y164*y166             # <<<<<<<<<<<<<<
 *         cdef double y249 = r**(-12)
 *         cdef double y250 = y6**3
 */
  __Pyx_TraceLine(1029,0,__PYX_ERR(1, 1029, __pyx_L1_error))
  __pyx_v_y248 = (__pyx_v_y164 * __pyx_v_y166);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1030
 *         cdef double y247 = r**(-14)
 *         cdef double y248 = y164*y166
 *         cdef double y249 = r**(-12)             # <<<<<<<<<<<<<<
 *         cdef double y250 = y6**3
 *         cdef double y251 = 5178202125747.62*nu
 */
  __Pyx_TraceLine(1030,0,__PYX_ERR(1, 1030, __pyx_L1_error))
  __pyx_v_y249 = pow(__pyx_v_r, -12.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1031
 *         cdef double y248 = y164*y166
 *         cdef double y249 = r**(-12)
 *         cdef double y250 = y6**3             # <<<<<<<<<<<<<<
 *         cdef double y251 = 5178202125747.62*nu
 *         cdef double y252 = 267544166400.0*y32
 */
  __Pyx_TraceLine(1031,0,__PYX_ERR(1, 1031, __pyx_L1_error))
  __pyx_v_y250 = pow(__pyx_v_y6, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1032
 *         cdef double y249 = r**(-12)
 *         cdef double y250 = y6**3
 *         cdef double y251 = 5178202125747.62*nu             # <<<<<<<<<<<<<<
 *         cdef double y252 = 267544166400.0*y32
 *         cdef double y253 = 11575876386816.0*y71
 */
  __Pyx_TraceLine(1032,0,__PYX_ERR(1, 1032, __pyx_L1_error))
  __pyx_v_y251 = (5178202125747.62 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1033
 *         cdef double y250 = y6**3
 *         cdef double y251 = 5178202125747.62*nu
 *         cdef double y252 = 267544166400.0*y32             # <<<<<<<<<<<<<<
 *         cdef double y253 = 11575876386816.0*y71
 *         cdef double y254 = y253*y99
 */
  __Pyx_TraceLine(1033,0,__PYX_ERR(1, 1033, __pyx_L1_error))
  __pyx_v_y252 = (267544166400.0 * __pyx_v_y32);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1034
 *         cdef double y251 = 5178202125747.62*nu
 *         cdef double y252 = 267544166400.0*y32
 *         cdef double y253 = 11575876386816.0*y71             # <<<<<<<<<<<<<<
 *         cdef double y254 = y253*y99
 *         cdef double y255 = y99*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0)
 */
  __Pyx_TraceLine(1034,0,__PYX_ERR(1, 1034, __pyx_L1_error))
  __pyx_v_y253 = (11575876386816.0 * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1035
 *         cdef double y252 = 267544166400.0*y32
 *         cdef double y253 = 11575876386816.0*y71
 *         cdef double y254 = y253*y99             # <<<<<<<<<<<<<<
 *         cdef double y255 = y99*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0)
 *         cdef double y256 = y156*y71
 */
  __Pyx_TraceLine(1035,0,__PYX_ERR(1, 1035, __pyx_L1_error))
  __pyx_v_y254 = (__pyx_v_y253 * __pyx_v_y99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1036
 *         cdef double y253 = 11575876386816.0*y71
 *         cdef double y254 = y253*y99
 *         cdef double y255 = y99*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0)             # <<<<<<<<<<<<<<
 *         cdef double y256 = y156*y71
 *         cdef double y257 = 5807150888816.34*nu + r*y251 + r*y252 + 10215490662751.4*r + y170 + y254 + y255 - y256 - 53501685054374.1
 */
  __Pyx_TraceLine(1036,0,__PYX_ERR(1, 1036, __pyx_L1_error))
  __pyx_v_y255 = (__pyx_v_y99 * (((4161798144000.0 * __pyx_v_nu) + (1759846072320.0 * __pyx_v_r)) + 12148770078720.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1037
 *         cdef double y254 = y253*y99
 *         cdef double y255 = y99*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0)
 *         cdef double y256 = y156*y71             # <<<<<<<<<<<<<<
 *         cdef double y257 = 5807150888816.34*nu + r*y251 + r*y252 + 10215490662751.4*r + y170 + y254 + y255 - y256 - 53501685054374.1
 *         cdef double y258 = y158**(-3)
 */
  __Pyx_TraceLine(1037,0,__PYX_ERR(1, 1037, __pyx_L1_error))
  __pyx_v_y256 = (__pyx_v_y156 * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1038
 *         cdef double y255 = y99*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0)
 *         cdef double y256 = y156*y71
 *         cdef double y257 = 5807150888816.34*nu + r*y251 + r*y252 + 10215490662751.4*r + y170 + y254 + y255 - y256 - 53501685054374.1             # <<<<<<<<<<<<<<
 *         cdef double y258 = y158**(-3)
 *         cdef double y259 = y257*y258
 */
  __Pyx_TraceLine(1038,0,__PYX_ERR(1, 1038, __pyx_L1_error))
  __pyx_v_y257 = (((((((((5807150888816.34 * __pyx_v_nu) + (__pyx_v_r * __pyx_v_y251)) + (__pyx_v_r * __pyx_v_y252)) + (10215490662751.4 * __pyx_v_r)) + __pyx_v_y170) + __pyx_v_y254) + __pyx_v_y255) - __pyx_v_y256) - 53501685054374.1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1039
 *         cdef double y256 = y156*y71
 *         cdef double y257 = 5807150888816.34*nu + r*y251 + r*y252 + 10215490662751.4*r + y170 + y254 + y255 - y256 - 53501685054374.1
 *         cdef double y258 = y158**(-3)             # <<<<<<<<<<<<<<
 *         cdef double y259 = y257*y258
 *         cdef double y260 = y134*y162*y76
 */
  __Pyx_TraceLine(1039,0,__PYX_ERR(1, 1039, __pyx_L1_error))
  __pyx_v_y258 = pow(__pyx_v_y158, -3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1040
 *         cdef double y257 = 5807150888816.34*nu + r*y251 + r*y252 + 10215490662751.4*r + y170 + y254 + y255 - y256 - 53501685054374.1
 *         cdef double y258 = y158**(-3)
 *         cdef double y259 = y257*y258             # <<<<<<<<<<<<<<
 *         cdef double y260 = y134*y162*y76
 *         cdef double y261 = y149*y260
 */
  __Pyx_TraceLine(1040,0,__PYX_ERR(1, 1040, __pyx_L1_error))
  __pyx_v_y259 = (__pyx_v_y257 * __pyx_v_y258);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1041
 *         cdef double y258 = y158**(-3)
 *         cdef double y259 = y257*y258
 *         cdef double y260 = y134*y162*y76             # <<<<<<<<<<<<<<
 *         cdef double y261 = y149*y260
 *         cdef double y262 = y167*y261
 */
  __Pyx_TraceLine(1041,0,__PYX_ERR(1, 1041, __pyx_L1_error))
  __pyx_v_y260 = ((__pyx_v_y134 * __pyx_v_y162) * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1042
 *         cdef double y259 = y257*y258
 *         cdef double y260 = y134*y162*y76
 *         cdef double y261 = y149*y260             # <<<<<<<<<<<<<<
 *         cdef double y262 = y167*y261
 *         cdef double y263 = 9.25454462627843e-34*y262
 */
  __Pyx_TraceLine(1042,0,__PYX_ERR(1, 1042, __pyx_L1_error))
  __pyx_v_y261 = (__pyx_v_y149 * __pyx_v_y260);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1043
 *         cdef double y260 = y134*y162*y76
 *         cdef double y261 = y149*y260
 *         cdef double y262 = y167*y261             # <<<<<<<<<<<<<<
 *         cdef double y263 = 9.25454462627843e-34*y262
 *         cdef double y264 = y146*y71
 */
  __Pyx_TraceLine(1043,0,__PYX_ERR(1, 1043, __pyx_L1_error))
  __pyx_v_y262 = (__pyx_v_y167 * __pyx_v_y261);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1044
 *         cdef double y261 = y149*y260
 *         cdef double y262 = y167*y261
 *         cdef double y263 = 9.25454462627843e-34*y262             # <<<<<<<<<<<<<<
 *         cdef double y264 = y146*y71
 *         cdef double y265 = y99*(20113376778784.3*nu + 2639769108480.0*y1 + 566231040.0*y153 + y155)
 */
  __Pyx_TraceLine(1044,0,__PYX_ERR(1, 1044, __pyx_L1_error))
  __pyx_v_y263 = (9.25454462627843e-34 * __pyx_v_y262);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1045
 *         cdef double y262 = y167*y261
 *         cdef double y263 = 9.25454462627843e-34*y262
 *         cdef double y264 = y146*y71             # <<<<<<<<<<<<<<
 *         cdef double y265 = y99*(20113376778784.3*nu + 2639769108480.0*y1 + 566231040.0*y153 + y155)
 *         cdef double y266 = r*y136
 */
  __Pyx_TraceLine(1045,0,__PYX_ERR(1, 1045, __pyx_L1_error))
  __pyx_v_y264 = (__pyx_v_y146 * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1046
 *         cdef double y263 = 9.25454462627843e-34*y262
 *         cdef double y264 = y146*y71
 *         cdef double y265 = y99*(20113376778784.3*nu + 2639769108480.0*y1 + 566231040.0*y153 + y155)             # <<<<<<<<<<<<<<
 *         cdef double y266 = r*y136
 *         cdef double y267 = y1*y138
 */
  __Pyx_TraceLine(1046,0,__PYX_ERR(1, 1046, __pyx_L1_error))
  __pyx_v_y265 = (__pyx_v_y99 * ((((20113376778784.3 * __pyx_v_nu) + (2639769108480.0 * __pyx_v_y1)) + (566231040.0 * __pyx_v_y153)) + __pyx_v_y155));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1047
 *         cdef double y264 = y146*y71
 *         cdef double y265 = y99*(20113376778784.3*nu + 2639769108480.0*y1 + 566231040.0*y153 + y155)
 *         cdef double y266 = r*y136             # <<<<<<<<<<<<<<
 *         cdef double y267 = y1*y138
 *         cdef double y268 = y142 + y171 + y264 + y265 - 18432.0*y266 - 2903040.0*y267 + 11575876386816.0*y99
 */
  __Pyx_TraceLine(1047,0,__PYX_ERR(1, 1047, __pyx_L1_error))
  __pyx_v_y266 = (__pyx_v_r * __pyx_v_y136);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1048
 *         cdef double y265 = y99*(20113376778784.3*nu + 2639769108480.0*y1 + 566231040.0*y153 + y155)
 *         cdef double y266 = r*y136
 *         cdef double y267 = y1*y138             # <<<<<<<<<<<<<<
 *         cdef double y268 = y142 + y171 + y264 + y265 - 18432.0*y266 - 2903040.0*y267 + 11575876386816.0*y99
 *         cdef double y269 = y189*y190
 */
  __Pyx_TraceLine(1048,0,__PYX_ERR(1, 1048, __pyx_L1_error))
  __pyx_v_y267 = (__pyx_v_y1 * __pyx_v_y138);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1049
 *         cdef double y266 = r*y136
 *         cdef double y267 = y1*y138
 *         cdef double y268 = y142 + y171 + y264 + y265 - 18432.0*y266 - 2903040.0*y267 + 11575876386816.0*y99             # <<<<<<<<<<<<<<
 *         cdef double y269 = y189*y190
 *         cdef double y270 = y169*y188
 */
  __Pyx_TraceLine(1049,0,__PYX_ERR(1, 1049, __pyx_L1_error))
  __pyx_v_y268 = ((((((__pyx_v_y142 + __pyx_v_y171) + __pyx_v_y264) + __pyx_v_y265) - (18432.0 * __pyx_v_y266)) - (2903040.0 * __pyx_v_y267)) + (11575876386816.0 * __pyx_v_y99));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1050
 *         cdef double y267 = y1*y138
 *         cdef double y268 = y142 + y171 + y264 + y265 - 18432.0*y266 - 2903040.0*y267 + 11575876386816.0*y99
 *         cdef double y269 = y189*y190             # <<<<<<<<<<<<<<
 *         cdef double y270 = y169*y188
 *         cdef double y271 = y168*y270
 */
  __Pyx_TraceLine(1050,0,__PYX_ERR(1, 1050, __pyx_L1_error))
  __pyx_v_y269 = (__pyx_v_y189 * __pyx_v_y190);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1051
 *         cdef double y268 = y142 + y171 + y264 + y265 - 18432.0*y266 - 2903040.0*y267 + 11575876386816.0*y99
 *         cdef double y269 = y189*y190
 *         cdef double y270 = y169*y188             # <<<<<<<<<<<<<<
 *         cdef double y271 = y168*y270
 *         cdef double y272 = y159*y271
 */
  __Pyx_TraceLine(1051,0,__PYX_ERR(1, 1051, __pyx_L1_error))
  __pyx_v_y270 = (__pyx_v_y169 * __pyx_v_y188);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1052
 *         cdef double y269 = y189*y190
 *         cdef double y270 = y169*y188
 *         cdef double y271 = y168*y270             # <<<<<<<<<<<<<<
 *         cdef double y272 = y159*y271
 *         cdef double y273 = y257*y272
 */
  __Pyx_TraceLine(1052,0,__PYX_ERR(1, 1052, __pyx_L1_error))
  __pyx_v_y271 = (__pyx_v_y168 * __pyx_v_y270);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1053
 *         cdef double y270 = y169*y188
 *         cdef double y271 = y168*y270
 *         cdef double y272 = y159*y271             # <<<<<<<<<<<<<<
 *         cdef double y273 = y257*y272
 *         cdef double y274 = 2.24091649004576e-37*y191
 */
  __Pyx_TraceLine(1053,0,__PYX_ERR(1, 1053, __pyx_L1_error))
  __pyx_v_y272 = (__pyx_v_y159 * __pyx_v_y271);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1054
 *         cdef double y271 = y168*y270
 *         cdef double y272 = y159*y271
 *         cdef double y273 = y257*y272             # <<<<<<<<<<<<<<
 *         cdef double y274 = 2.24091649004576e-37*y191
 *         cdef double y275 = y133**(-5)
 */
  __Pyx_TraceLine(1054,0,__PYX_ERR(1, 1054, __pyx_L1_error))
  __pyx_v_y273 = (__pyx_v_y257 * __pyx_v_y272);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1055
 *         cdef double y272 = y159*y271
 *         cdef double y273 = y257*y272
 *         cdef double y274 = 2.24091649004576e-37*y191             # <<<<<<<<<<<<<<
 *         cdef double y275 = y133**(-5)
 *         cdef double y276 = -y234
 */
  __Pyx_TraceLine(1055,0,__PYX_ERR(1, 1055, __pyx_L1_error))
  __pyx_v_y274 = (2.24091649004576e-37 * __pyx_v_y191);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1056
 *         cdef double y273 = y257*y272
 *         cdef double y274 = 2.24091649004576e-37*y191
 *         cdef double y275 = y133**(-5)             # <<<<<<<<<<<<<<
 *         cdef double y276 = -y234
 *         cdef double y277 = y275*y276
 */
  __Pyx_TraceLine(1056,0,__PYX_ERR(1, 1056, __pyx_L1_error))
  __pyx_v_y275 = pow(__pyx_v_y133, -5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1057
 *         cdef double y274 = 2.24091649004576e-37*y191
 *         cdef double y275 = y133**(-5)
 *         cdef double y276 = -y234             # <<<<<<<<<<<<<<
 *         cdef double y277 = y275*y276
 *         cdef double y278 = y159*y167
 */
  __Pyx_TraceLine(1057,0,__PYX_ERR(1, 1057, __pyx_L1_error))
  __pyx_v_y276 = (-__pyx_v_y234);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1058
 *         cdef double y275 = y133**(-5)
 *         cdef double y276 = -y234
 *         cdef double y277 = y275*y276             # <<<<<<<<<<<<<<
 *         cdef double y278 = y159*y167
 *         cdef double y279 = y162*y278
 */
  __Pyx_TraceLine(1058,0,__PYX_ERR(1, 1058, __pyx_L1_error))
  __pyx_v_y277 = (__pyx_v_y275 * __pyx_v_y276);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1059
 *         cdef double y276 = -y234
 *         cdef double y277 = y275*y276
 *         cdef double y278 = y159*y167             # <<<<<<<<<<<<<<
 *         cdef double y279 = y162*y278
 *         cdef double y280 = y149*y76
 */
  __Pyx_TraceLine(1059,0,__PYX_ERR(1, 1059, __pyx_L1_error))
  __pyx_v_y278 = (__pyx_v_y159 * __pyx_v_y167);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1060
 *         cdef double y277 = y275*y276
 *         cdef double y278 = y159*y167
 *         cdef double y279 = y162*y278             # <<<<<<<<<<<<<<
 *         cdef double y280 = y149*y76
 *         cdef double y281 = y279*y280
 */
  __Pyx_TraceLine(1060,0,__PYX_ERR(1, 1060, __pyx_L1_error))
  __pyx_v_y279 = (__pyx_v_y162 * __pyx_v_y278);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1061
 *         cdef double y278 = y159*y167
 *         cdef double y279 = y162*y278
 *         cdef double y280 = y149*y76             # <<<<<<<<<<<<<<
 *         cdef double y281 = y279*y280
 *         cdef double y282 = 6.62902677807736e-23*y281
 */
  __Pyx_TraceLine(1061,0,__PYX_ERR(1, 1061, __pyx_L1_error))
  __pyx_v_y280 = (__pyx_v_y149 * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1062
 *         cdef double y279 = y162*y278
 *         cdef double y280 = y149*y76
 *         cdef double y281 = y279*y280             # <<<<<<<<<<<<<<
 *         cdef double y282 = 6.62902677807736e-23*y281
 *         cdef double y283 = y168*y173*y188
 */
  __Pyx_TraceLine(1062,0,__PYX_ERR(1, 1062, __pyx_L1_error))
  __pyx_v_y281 = (__pyx_v_y279 * __pyx_v_y280);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1063
 *         cdef double y280 = y149*y76
 *         cdef double y281 = y279*y280
 *         cdef double y282 = 6.62902677807736e-23*y281             # <<<<<<<<<<<<<<
 *         cdef double y283 = y168*y173*y188
 *         cdef double y284 = y133**(-3)
 */
  __Pyx_TraceLine(1063,0,__PYX_ERR(1, 1063, __pyx_L1_error))
  __pyx_v_y282 = (6.62902677807736e-23 * __pyx_v_y281);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1064
 *         cdef double y281 = y279*y280
 *         cdef double y282 = 6.62902677807736e-23*y281
 *         cdef double y283 = y168*y173*y188             # <<<<<<<<<<<<<<
 *         cdef double y284 = y133**(-3)
 *         cdef double y285 = y276*y284
 */
  __Pyx_TraceLine(1064,0,__PYX_ERR(1, 1064, __pyx_L1_error))
  __pyx_v_y283 = ((__pyx_v_y168 * __pyx_v_y173) * __pyx_v_y188);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1065
 *         cdef double y282 = 6.62902677807736e-23*y281
 *         cdef double y283 = y168*y173*y188
 *         cdef double y284 = y133**(-3)             # <<<<<<<<<<<<<<
 *         cdef double y285 = y276*y284
 *         cdef double y286 = y283*y285
 */
  __Pyx_TraceLine(1065,0,__PYX_ERR(1, 1065, __pyx_L1_error))
  __pyx_v_y284 = pow(__pyx_v_y133, -3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1066
 *         cdef double y283 = y168*y173*y188
 *         cdef double y284 = y133**(-3)
 *         cdef double y285 = y276*y284             # <<<<<<<<<<<<<<
 *         cdef double y286 = y283*y285
 *         cdef double y287 = 36.0*nu
 */
  __Pyx_TraceLine(1066,0,__PYX_ERR(1, 1066, __pyx_L1_error))
  __pyx_v_y285 = (__pyx_v_y276 * __pyx_v_y284);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1067
 *         cdef double y284 = y133**(-3)
 *         cdef double y285 = y276*y284
 *         cdef double y286 = y283*y285             # <<<<<<<<<<<<<<
 *         cdef double y287 = 36.0*nu
 *         cdef double y288 = y287 - 9.0
 */
  __Pyx_TraceLine(1067,0,__PYX_ERR(1, 1067, __pyx_L1_error))
  __pyx_v_y286 = (__pyx_v_y283 * __pyx_v_y285);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1068
 *         cdef double y285 = y276*y284
 *         cdef double y286 = y283*y285
 *         cdef double y287 = 36.0*nu             # <<<<<<<<<<<<<<
 *         cdef double y288 = y287 - 9.0
 *         cdef double y289 = -63.0*X_1 + 63.0*X_2
 */
  __Pyx_TraceLine(1068,0,__PYX_ERR(1, 1068, __pyx_L1_error))
  __pyx_v_y287 = (36.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1069
 *         cdef double y286 = y283*y285
 *         cdef double y287 = 36.0*nu
 *         cdef double y288 = y287 - 9.0             # <<<<<<<<<<<<<<
 *         cdef double y289 = -63.0*X_1 + 63.0*X_2
 *         cdef double y290 = 0.0625*y5
 */
  __Pyx_TraceLine(1069,0,__PYX_ERR(1, 1069, __pyx_L1_error))
  __pyx_v_y288 = (__pyx_v_y287 - 9.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1070
 *         cdef double y287 = 36.0*nu
 *         cdef double y288 = y287 - 9.0
 *         cdef double y289 = -63.0*X_1 + 63.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double y290 = 0.0625*y5
 *         cdef double y291 = y149**(-1)
 */
  __Pyx_TraceLine(1070,0,__PYX_ERR(1, 1070, __pyx_L1_error))
  __pyx_v_y289 = ((-63.0 * __pyx_v_X_1) + (63.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1071
 *         cdef double y288 = y287 - 9.0
 *         cdef double y289 = -63.0*X_1 + 63.0*X_2
 *         cdef double y290 = 0.0625*y5             # <<<<<<<<<<<<<<
 *         cdef double y291 = y149**(-1)
 *         cdef double y292 = y268*y291
 */
  __Pyx_TraceLine(1071,0,__PYX_ERR(1, 1071, __pyx_L1_error))
  __pyx_v_y290 = (0.0625 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1072
 *         cdef double y289 = -63.0*X_1 + 63.0*X_2
 *         cdef double y290 = 0.0625*y5
 *         cdef double y291 = y149**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y292 = y268*y291
 *         cdef double y293 = y11*y172
 */
  __Pyx_TraceLine(1072,0,__PYX_ERR(1, 1072, __pyx_L1_error))
  __pyx_v_y291 = pow(__pyx_v_y149, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1073
 *         cdef double y290 = 0.0625*y5
 *         cdef double y291 = y149**(-1)
 *         cdef double y292 = y268*y291             # <<<<<<<<<<<<<<
 *         cdef double y293 = y11*y172
 *         cdef double y294 = y131*y293
 */
  __Pyx_TraceLine(1073,0,__PYX_ERR(1, 1073, __pyx_L1_error))
  __pyx_v_y292 = (__pyx_v_y268 * __pyx_v_y291);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1074
 *         cdef double y291 = y149**(-1)
 *         cdef double y292 = y268*y291
 *         cdef double y293 = y11*y172             # <<<<<<<<<<<<<<
 *         cdef double y294 = y131*y293
 *         cdef double y295 = 2.29252167428035e-22*y294
 */
  __Pyx_TraceLine(1074,0,__PYX_ERR(1, 1074, __pyx_L1_error))
  __pyx_v_y293 = (__pyx_v_y11 * __pyx_v_y172);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1075
 *         cdef double y292 = y268*y291
 *         cdef double y293 = y11*y172
 *         cdef double y294 = y131*y293             # <<<<<<<<<<<<<<
 *         cdef double y295 = 2.29252167428035e-22*y294
 *         cdef double y296 = y130*y232
 */
  __Pyx_TraceLine(1075,0,__PYX_ERR(1, 1075, __pyx_L1_error))
  __pyx_v_y294 = (__pyx_v_y131 * __pyx_v_y293);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1076
 *         cdef double y293 = y11*y172
 *         cdef double y294 = y131*y293
 *         cdef double y295 = 2.29252167428035e-22*y294             # <<<<<<<<<<<<<<
 *         cdef double y296 = y130*y232
 *         cdef double y297 = 7680.0*y11*y128*y130*y183*y257 + 7680.0*y11*y128*y172*y183*y217 - y12*(y176*y181 + y177*y290 + 0.0625*y179) + 38400.0*y128*y130*y16*y172*y183 - y17*(y175*y288 + y176*y289 + y5*(9.0*nu + 8.4375)) - 1.31621673590926e-19*y185*y296 - y215 - y292*y295
 */
  __Pyx_TraceLine(1076,0,__PYX_ERR(1, 1076, __pyx_L1_error))
  __pyx_v_y295 = (2.29252167428035e-22 * __pyx_v_y294);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1077
 *         cdef double y294 = y131*y293
 *         cdef double y295 = 2.29252167428035e-22*y294
 *         cdef double y296 = y130*y232             # <<<<<<<<<<<<<<
 *         cdef double y297 = 7680.0*y11*y128*y130*y183*y257 + 7680.0*y11*y128*y172*y183*y217 - y12*(y176*y181 + y177*y290 + 0.0625*y179) + 38400.0*y128*y130*y16*y172*y183 - y17*(y175*y288 + y176*y289 + y5*(9.0*nu + 8.4375)) - 1.31621673590926e-19*y185*y296 - y215 - y292*y295
 *         cdef double y298 = 39.6112800271521*nu*y77*y80 - 3.0*y101*y90 + y102*y105*y30*y5*y51 + y102*y245*y246*y30*y5*y71 - y106*y244 + 1.69542100694444e-8*y12*y168*y169*y173*y182*y190*y297 + 1.69542100694444e-8*y12*y168*y169*y173*y187*y190*y268 + 1.01821851311268e-18*y134*y149*y159*y162*y249*y250*y76 + 7.59859378406358e-45*y134*y159*y162*y165*y166*y182*y268*y76 + 6.78168402777778e-8*y168*y169*y17*y173*y182*y187*y6 + y17*y242*y76 - 4.41515887225116e-12*y191*y286 - 663.496888455656*y237*y238 - y239*y86 - y240*y88 - y240*y93 - y240*y98 - y243*y57 - 1.65460508380811e-18*y247*y248 - y259*y263 - 8.47710503472222e-8*y269*y36 - y273*y274 - y277*y282 - y54 - y55*y96 - 3.70688355060912*y79*y84
 */
  __Pyx_TraceLine(1077,0,__PYX_ERR(1, 1077, __pyx_L1_error))
  __pyx_v_y296 = (__pyx_v_y130 * __pyx_v_y232);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1078
 *         cdef double y295 = 2.29252167428035e-22*y294
 *         cdef double y296 = y130*y232
 *         cdef double y297 = 7680.0*y11*y128*y130*y183*y257 + 7680.0*y11*y128*y172*y183*y217 - y12*(y176*y181 + y177*y290 + 0.0625*y179) + 38400.0*y128*y130*y16*y172*y183 - y17*(y175*y288 + y176*y289 + y5*(9.0*nu + 8.4375)) - 1.31621673590926e-19*y185*y296 - y215 - y292*y295             # <<<<<<<<<<<<<<
 *         cdef double y298 = 39.6112800271521*nu*y77*y80 - 3.0*y101*y90 + y102*y105*y30*y5*y51 + y102*y245*y246*y30*y5*y71 - y106*y244 + 1.69542100694444e-8*y12*y168*y169*y173*y182*y190*y297 + 1.69542100694444e-8*y12*y168*y169*y173*y187*y190*y268 + 1.01821851311268e-18*y134*y149*y159*y162*y249*y250*y76 + 7.59859378406358e-45*y134*y159*y162*y165*y166*y182*y268*y76 + 6.78168402777778e-8*y168*y169*y17*y173*y182*y187*y6 + y17*y242*y76 - 4.41515887225116e-12*y191*y286 - 663.496888455656*y237*y238 - y239*y86 - y240*y88 - y240*y93 - y240*y98 - y243*y57 - 1.65460508380811e-18*y247*y248 - y259*y263 - 8.47710503472222e-8*y269*y36 - y273*y274 - y277*y282 - y54 - y55*y96 - 3.70688355060912*y79*y84
 *         cdef double y299 = y204*y298 - y209*y212 + y235*y236
 */
  __Pyx_TraceLine(1078,0,__PYX_ERR(1, 1078, __pyx_L1_error))
  __pyx_v_y297 = ((((((((((((7680.0 * __pyx_v_y11) * __pyx_v_y128) * __pyx_v_y130) * __pyx_v_y183) * __pyx_v_y257) + (((((7680.0 * __pyx_v_y11) * __pyx_v_y128) * __pyx_v_y172) * __pyx_v_y183) * __pyx_v_y217)) - (__pyx_v_y12 * (((__pyx_v_y176 * __pyx_v_y181) + (__pyx_v_y177 * __pyx_v_y290)) + (0.0625 * __pyx_v_y179)))) + (((((38400.0 * __pyx_v_y128) * __pyx_v_y130) * __pyx_v_y16) * __pyx_v_y172) * __pyx_v_y183)) - (__pyx_v_y17 * (((__pyx_v_y175 * __pyx_v_y288) + (__pyx_v_y176 * __pyx_v_y289)) + (__pyx_v_y5 * ((9.0 * __pyx_v_nu) + 8.4375))))) - ((1.31621673590926e-19 * __pyx_v_y185) * __pyx_v_y296)) - __pyx_v_y215) - (__pyx_v_y292 * __pyx_v_y295));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1079
 *         cdef double y296 = y130*y232
 *         cdef double y297 = 7680.0*y11*y128*y130*y183*y257 + 7680.0*y11*y128*y172*y183*y217 - y12*(y176*y181 + y177*y290 + 0.0625*y179) + 38400.0*y128*y130*y16*y172*y183 - y17*(y175*y288 + y176*y289 + y5*(9.0*nu + 8.4375)) - 1.31621673590926e-19*y185*y296 - y215 - y292*y295
 *         cdef double y298 = 39.6112800271521*nu*y77*y80 - 3.0*y101*y90 + y102*y105*y30*y5*y51 + y102*y245*y246*y30*y5*y71 - y106*y244 + 1.69542100694444e-8*y12*y168*y169*y173*y182*y190*y297 + 1.69542100694444e-8*y12*y168*y169*y173*y187*y190*y268 + 1.01821851311268e-18*y134*y149*y159*y162*y249*y250*y76 + 7.59859378406358e-45*y134*y159*y162*y165*y166*y182*y268*y76 + 6.78168402777778e-8*y168*y169*y17*y173*y182*y187*y6 + y17*y242*y76 - 4.41515887225116e-12*y191*y286 - 663.496888455656*y237*y238 - y239*y86 - y240*y88 - y240*y93 - y240*y98 - y243*y57 - 1.65460508380811e-18*y247*y248 - y259*y263 - 8.47710503472222e-8*y269*y36 - y273*y274 - y277*y282 - y54 - y55*y96 - 3.70688355060912*y79*y84             # <<<<<<<<<<<<<<
 *         cdef double y299 = y204*y298 - y209*y212 + y235*y236
 *         cdef double y300 = y17*y5
 */
  __Pyx_TraceLine(1079,0,__PYX_ERR(1, 1079, __pyx_L1_error))
  __pyx_v_y298 = ((((((((((((((((((((((((((((39.6112800271521 * __pyx_v_nu) * __pyx_v_y77) * __pyx_v_y80) - ((3.0 * __pyx_v_y101) * __pyx_v_y90)) + ((((__pyx_v_y102 * __pyx_v_y105) * __pyx_v_y30) * __pyx_v_y5) * __pyx_v_y51)) + (((((__pyx_v_y102 * __pyx_v_y245) * __pyx_v_y246) * __pyx_v_y30) * __pyx_v_y5) * __pyx_v_y71)) - (__pyx_v_y106 * __pyx_v_y244)) + (((((((1.69542100694444e-8 * __pyx_v_y12) * __pyx_v_y168) * __pyx_v_y169) * __pyx_v_y173) * __pyx_v_y182) * __pyx_v_y190) * __pyx_v_y297)) + (((((((1.69542100694444e-8 * __pyx_v_y12) * __pyx_v_y168) * __pyx_v_y169) * __pyx_v_y173) * __pyx_v_y187) * __pyx_v_y190) * __pyx_v_y268)) + (((((((1.01821851311268e-18 * __pyx_v_y134) * __pyx_v_y149) * __pyx_v_y159) * __pyx_v_y162) * __pyx_v_y249) * __pyx_v_y250) * __pyx_v_y76)) + ((((((((7.59859378406358e-45 * __pyx_v_y134) * __pyx_v_y159) * __pyx_v_y162) * __pyx_v_y165) * __pyx_v_y166) * __pyx_v_y182) * __pyx_v_y268) * __pyx_v_y76)) + (((((((6.78168402777778e-8 * __pyx_v_y168) * __pyx_v_y169) * __pyx_v_y17) * __pyx_v_y173) * __pyx_v_y182) * __pyx_v_y187) * __pyx_v_y6)) + ((__pyx_v_y17 * __pyx_v_y242) * __pyx_v_y76)) - ((4.41515887225116e-12 * __pyx_v_y191) * __pyx_v_y286)) - ((663.496888455656 * __pyx_v_y237) * __pyx_v_y238)) - (__pyx_v_y239 * __pyx_v_y86)) - (__pyx_v_y240 * __pyx_v_y88)) - (__pyx_v_y240 * __pyx_v_y93)) - (__pyx_v_y240 * __pyx_v_y98)) - (__pyx_v_y243 * __pyx_v_y57)) - ((1.65460508380811e-18 * __pyx_v_y247) * __pyx_v_y248)) - (__pyx_v_y259 * __pyx_v_y263)) - ((8.47710503472222e-8 * __pyx_v_y269) * __pyx_v_y36)) - (__pyx_v_y273 * __pyx_v_y274)) - (__pyx_v_y277 * __pyx_v_y282)) - __pyx_v_y54) - (__pyx_v_y55 * __pyx_v_y96)) - ((3.70688355060912 * __pyx_v_y79) * __pyx_v_y84));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1080
 *         cdef double y297 = 7680.0*y11*y128*y130*y183*y257 + 7680.0*y11*y128*y172*y183*y217 - y12*(y176*y181 + y177*y290 + 0.0625*y179) + 38400.0*y128*y130*y16*y172*y183 - y17*(y175*y288 + y176*y289 + y5*(9.0*nu + 8.4375)) - 1.31621673590926e-19*y185*y296 - y215 - y292*y295
 *         cdef double y298 = 39.6112800271521*nu*y77*y80 - 3.0*y101*y90 + y102*y105*y30*y5*y51 + y102*y245*y246*y30*y5*y71 - y106*y244 + 1.69542100694444e-8*y12*y168*y169*y173*y182*y190*y297 + 1.69542100694444e-8*y12*y168*y169*y173*y187*y190*y268 + 1.01821851311268e-18*y134*y149*y159*y162*y249*y250*y76 + 7.59859378406358e-45*y134*y159*y162*y165*y166*y182*y268*y76 + 6.78168402777778e-8*y168*y169*y17*y173*y182*y187*y6 + y17*y242*y76 - 4.41515887225116e-12*y191*y286 - 663.496888455656*y237*y238 - y239*y86 - y240*y88 - y240*y93 - y240*y98 - y243*y57 - 1.65460508380811e-18*y247*y248 - y259*y263 - 8.47710503472222e-8*y269*y36 - y273*y274 - y277*y282 - y54 - y55*y96 - 3.70688355060912*y79*y84
 *         cdef double y299 = y204*y298 - y209*y212 + y235*y236             # <<<<<<<<<<<<<<
 *         cdef double y300 = y17*y5
 *         cdef double y301 = 8.0*y71 + 4.0
 */
  __Pyx_TraceLine(1080,0,__PYX_ERR(1, 1080, __pyx_L1_error))
  __pyx_v_y299 = (((__pyx_v_y204 * __pyx_v_y298) - (__pyx_v_y209 * __pyx_v_y212)) + (__pyx_v_y235 * __pyx_v_y236));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1081
 *         cdef double y298 = 39.6112800271521*nu*y77*y80 - 3.0*y101*y90 + y102*y105*y30*y5*y51 + y102*y245*y246*y30*y5*y71 - y106*y244 + 1.69542100694444e-8*y12*y168*y169*y173*y182*y190*y297 + 1.69542100694444e-8*y12*y168*y169*y173*y187*y190*y268 + 1.01821851311268e-18*y134*y149*y159*y162*y249*y250*y76 + 7.59859378406358e-45*y134*y159*y162*y165*y166*y182*y268*y76 + 6.78168402777778e-8*y168*y169*y17*y173*y182*y187*y6 + y17*y242*y76 - 4.41515887225116e-12*y191*y286 - 663.496888455656*y237*y238 - y239*y86 - y240*y88 - y240*y93 - y240*y98 - y243*y57 - 1.65460508380811e-18*y247*y248 - y259*y263 - 8.47710503472222e-8*y269*y36 - y273*y274 - y277*y282 - y54 - y55*y96 - 3.70688355060912*y79*y84
 *         cdef double y299 = y204*y298 - y209*y212 + y235*y236
 *         cdef double y300 = y17*y5             # <<<<<<<<<<<<<<
 *         cdef double y301 = 8.0*y71 + 4.0
 *         cdef double y302 = -4.0*y300 - y301*y48
 */
  __Pyx_TraceLine(1081,0,__PYX_ERR(1, 1081, __pyx_L1_error))
  __pyx_v_y300 = (__pyx_v_y17 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1082
 *         cdef double y299 = y204*y298 - y209*y212 + y235*y236
 *         cdef double y300 = y17*y5
 *         cdef double y301 = 8.0*y71 + 4.0             # <<<<<<<<<<<<<<
 *         cdef double y302 = -4.0*y300 - y301*y48
 *         cdef double y303 = r**(-7)
 */
  __Pyx_TraceLine(1082,0,__PYX_ERR(1, 1082, __pyx_L1_error))
  __pyx_v_y301 = ((8.0 * __pyx_v_y71) + 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1083
 *         cdef double y300 = y17*y5
 *         cdef double y301 = 8.0*y71 + 4.0
 *         cdef double y302 = -4.0*y300 - y301*y48             # <<<<<<<<<<<<<<
 *         cdef double y303 = r**(-7)
 *         cdef double y304 = 0.03125*y5
 */
  __Pyx_TraceLine(1083,0,__PYX_ERR(1, 1083, __pyx_L1_error))
  __pyx_v_y302 = ((-4.0 * __pyx_v_y300) - (__pyx_v_y301 * __pyx_v_y48));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1084
 *         cdef double y301 = 8.0*y71 + 4.0
 *         cdef double y302 = -4.0*y300 - y301*y48
 *         cdef double y303 = r**(-7)             # <<<<<<<<<<<<<<
 *         cdef double y304 = 0.03125*y5
 *         cdef double y305 = 0.0625*y200*y24
 */
  __Pyx_TraceLine(1084,0,__PYX_ERR(1, 1084, __pyx_L1_error))
  __pyx_v_y303 = pow(__pyx_v_r, -7.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1085
 *         cdef double y302 = -4.0*y300 - y301*y48
 *         cdef double y303 = r**(-7)
 *         cdef double y304 = 0.03125*y5             # <<<<<<<<<<<<<<
 *         cdef double y305 = 0.0625*y200*y24
 *         cdef double y306 = 6.0*y300
 */
  __Pyx_TraceLine(1085,0,__PYX_ERR(1, 1085, __pyx_L1_error))
  __pyx_v_y304 = (0.03125 * __pyx_v_y5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1086
 *         cdef double y303 = r**(-7)
 *         cdef double y304 = 0.03125*y5
 *         cdef double y305 = 0.0625*y200*y24             # <<<<<<<<<<<<<<
 *         cdef double y306 = 6.0*y300
 *         cdef double y307 = y128*y16
 */
  __Pyx_TraceLine(1086,0,__PYX_ERR(1, 1086, __pyx_L1_error))
  __pyx_v_y305 = ((0.0625 * __pyx_v_y200) * __pyx_v_y24);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1087
 *         cdef double y304 = 0.03125*y5
 *         cdef double y305 = 0.0625*y200*y24
 *         cdef double y306 = 6.0*y300             # <<<<<<<<<<<<<<
 *         cdef double y307 = y128*y16
 *         cdef double y308 = -7680.0*y216*y239 + 10569646080.0*y85
 */
  __Pyx_TraceLine(1087,0,__PYX_ERR(1, 1087, __pyx_L1_error))
  __pyx_v_y306 = (6.0 * __pyx_v_y300);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1088
 *         cdef double y305 = 0.0625*y200*y24
 *         cdef double y306 = 6.0*y300
 *         cdef double y307 = y128*y16             # <<<<<<<<<<<<<<
 *         cdef double y308 = -7680.0*y216*y239 + 10569646080.0*y85
 *         cdef double y309 = y128*y217
 */
  __Pyx_TraceLine(1088,0,__PYX_ERR(1, 1088, __pyx_L1_error))
  __pyx_v_y307 = (__pyx_v_y128 * __pyx_v_y16);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1089
 *         cdef double y306 = 6.0*y300
 *         cdef double y307 = y128*y16
 *         cdef double y308 = -7680.0*y216*y239 + 10569646080.0*y85             # <<<<<<<<<<<<<<
 *         cdef double y309 = y128*y217
 *         cdef double y310 = 2.63243347181853e-19*y232
 */
  __Pyx_TraceLine(1089,0,__PYX_ERR(1, 1089, __pyx_L1_error))
  __pyx_v_y308 = (((-7680.0 * __pyx_v_y216) * __pyx_v_y239) + (10569646080.0 * __pyx_v_y85));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1090
 *         cdef double y307 = y128*y16
 *         cdef double y308 = -7680.0*y216*y239 + 10569646080.0*y85
 *         cdef double y309 = y128*y217             # <<<<<<<<<<<<<<
 *         cdef double y310 = 2.63243347181853e-19*y232
 *         cdef double y311 = y217*y310
 */
  __Pyx_TraceLine(1090,0,__PYX_ERR(1, 1090, __pyx_L1_error))
  __pyx_v_y309 = (__pyx_v_y128 * __pyx_v_y217);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1091
 *         cdef double y308 = -7680.0*y216*y239 + 10569646080.0*y85
 *         cdef double y309 = y128*y217
 *         cdef double y310 = 2.63243347181853e-19*y232             # <<<<<<<<<<<<<<
 *         cdef double y311 = y217*y310
 *         cdef double y312 = 1.99471718230171e-8*(0.48828125*y16 + 5.17401430341932e-11*y221 + y223 + 5.17401430341932e-11*y224 + 2.42203000992063e-7*y227 + 2.42203000992063e-7*y228 + 3.97364298502604e-7*y231)**2/y219**3
 */
  __Pyx_TraceLine(1091,0,__PYX_ERR(1, 1091, __pyx_L1_error))
  __pyx_v_y310 = (2.63243347181853e-19 * __pyx_v_y232);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1092
 *         cdef double y309 = y128*y217
 *         cdef double y310 = 2.63243347181853e-19*y232
 *         cdef double y311 = y217*y310             # <<<<<<<<<<<<<<
 *         cdef double y312 = 1.99471718230171e-8*(0.48828125*y16 + 5.17401430341932e-11*y221 + y223 + 5.17401430341932e-11*y224 + 2.42203000992063e-7*y227 + 2.42203000992063e-7*y228 + 3.97364298502604e-7*y231)**2/y219**3
 *         cdef double y313 = 135291469824.0*y32*y51
 */
  __Pyx_TraceLine(1092,0,__PYX_ERR(1, 1092, __pyx_L1_error))
  __pyx_v_y311 = (__pyx_v_y217 * __pyx_v_y310);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1093
 *         cdef double y310 = 2.63243347181853e-19*y232
 *         cdef double y311 = y217*y310
 *         cdef double y312 = 1.99471718230171e-8*(0.48828125*y16 + 5.17401430341932e-11*y221 + y223 + 5.17401430341932e-11*y224 + 2.42203000992063e-7*y227 + 2.42203000992063e-7*y228 + 3.97364298502604e-7*y231)**2/y219**3             # <<<<<<<<<<<<<<
 *         cdef double y313 = 135291469824.0*y32*y51
 *         cdef double y314 = 12.0*y1
 */
  __Pyx_TraceLine(1093,0,__PYX_ERR(1, 1093, __pyx_L1_error))
  __pyx_v_y312 = ((1.99471718230171e-8 * pow((((((((0.48828125 * __pyx_v_y16) + (5.17401430341932e-11 * __pyx_v_y221)) + __pyx_v_y223) + (5.17401430341932e-11 * __pyx_v_y224)) + (2.42203000992063e-7 * __pyx_v_y227)) + (2.42203000992063e-7 * __pyx_v_y228)) + (3.97364298502604e-7 * __pyx_v_y231)), 2.0)) / pow(__pyx_v_y219, 3.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1094
 *         cdef double y311 = y217*y310
 *         cdef double y312 = 1.99471718230171e-8*(0.48828125*y16 + 5.17401430341932e-11*y221 + y223 + 5.17401430341932e-11*y224 + 2.42203000992063e-7*y227 + 2.42203000992063e-7*y228 + 3.97364298502604e-7*y231)**2/y219**3
 *         cdef double y313 = 135291469824.0*y32*y51             # <<<<<<<<<<<<<<
 *         cdef double y314 = 12.0*y1
 *         cdef double y315 = 12.0*r + 8.0
 */
  __Pyx_TraceLine(1094,0,__PYX_ERR(1, 1094, __pyx_L1_error))
  __pyx_v_y313 = ((135291469824.0 * __pyx_v_y32) * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1095
 *         cdef double y312 = 1.99471718230171e-8*(0.48828125*y16 + 5.17401430341932e-11*y221 + y223 + 5.17401430341932e-11*y224 + 2.42203000992063e-7*y227 + 2.42203000992063e-7*y228 + 3.97364298502604e-7*y231)**2/y219**3
 *         cdef double y313 = 135291469824.0*y32*y51
 *         cdef double y314 = 12.0*y1             # <<<<<<<<<<<<<<
 *         cdef double y315 = 12.0*r + 8.0
 *         cdef double y316 = 1.31621673590926e-19*y220*(53760.0*nu*(8463875.43631609*r + 6347906.57723707*y1 + y122*(y314 + y315) + y123*(25588.1776641618*r - 82228.1776641618*y1 + 17058.7851094412) + y125*(11556.0*r + 4188.0*y1 + 7704.0) + y126*(-y314 + y315) - 7511347.20125054*y27 + 7480835.43631609) - 32768.0*y117*y239 + 32768.0*y118*(2257920.0*nu + 5760.0*r*y115 + 5760.0*y225 + 3225600.0*y27 + 4143360.0) + 65536.0*y226*y85 + 264241152000.0*y27 - y313*y99 + y313 + 7.0*y32*(-37071008445.2255*r - 37071008445.2255*y1 + 28533211037.6879*y27 + 4129567622.65173) - 39946495452.7631*y89)
 */
  __Pyx_TraceLine(1095,0,__PYX_ERR(1, 1095, __pyx_L1_error))
  __pyx_v_y314 = (12.0 * __pyx_v_y1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1096
 *         cdef double y313 = 135291469824.0*y32*y51
 *         cdef double y314 = 12.0*y1
 *         cdef double y315 = 12.0*r + 8.0             # <<<<<<<<<<<<<<
 *         cdef double y316 = 1.31621673590926e-19*y220*(53760.0*nu*(8463875.43631609*r + 6347906.57723707*y1 + y122*(y314 + y315) + y123*(25588.1776641618*r - 82228.1776641618*y1 + 17058.7851094412) + y125*(11556.0*r + 4188.0*y1 + 7704.0) + y126*(-y314 + y315) - 7511347.20125054*y27 + 7480835.43631609) - 32768.0*y117*y239 + 32768.0*y118*(2257920.0*nu + 5760.0*r*y115 + 5760.0*y225 + 3225600.0*y27 + 4143360.0) + 65536.0*y226*y85 + 264241152000.0*y27 - y313*y99 + y313 + 7.0*y32*(-37071008445.2255*r - 37071008445.2255*y1 + 28533211037.6879*y27 + 4129567622.65173) - 39946495452.7631*y89)
 *         cdef double y317 = 92160.0*y1*y131 - y16*y311 + y218*y312 - y218*y316 - 1.05297338872741e-18*y27*y296 + 61440.0*y27*y309 + y306 + y307*y308
 */
  __Pyx_TraceLine(1096,0,__PYX_ERR(1, 1096, __pyx_L1_error))
  __pyx_v_y315 = ((12.0 * __pyx_v_r) + 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1097
 *         cdef double y314 = 12.0*y1
 *         cdef double y315 = 12.0*r + 8.0
 *         cdef double y316 = 1.31621673590926e-19*y220*(53760.0*nu*(8463875.43631609*r + 6347906.57723707*y1 + y122*(y314 + y315) + y123*(25588.1776641618*r - 82228.1776641618*y1 + 17058.7851094412) + y125*(11556.0*r + 4188.0*y1 + 7704.0) + y126*(-y314 + y315) - 7511347.20125054*y27 + 7480835.43631609) - 32768.0*y117*y239 + 32768.0*y118*(2257920.0*nu + 5760.0*r*y115 + 5760.0*y225 + 3225600.0*y27 + 4143360.0) + 65536.0*y226*y85 + 264241152000.0*y27 - y313*y99 + y313 + 7.0*y32*(-37071008445.2255*r - 37071008445.2255*y1 + 28533211037.6879*y27 + 4129567622.65173) - 39946495452.7631*y89)             # <<<<<<<<<<<<<<
 *         cdef double y317 = 92160.0*y1*y131 - y16*y311 + y218*y312 - y218*y316 - 1.05297338872741e-18*y27*y296 + 61440.0*y27*y309 + y306 + y307*y308
 *         cdef double y318 = y105*y8
 */
  __Pyx_TraceLine(1097,0,__PYX_ERR(1, 1097, __pyx_L1_error))
  __pyx_v_y316 = ((1.31621673590926e-19 * __pyx_v_y220) * ((((((((((53760.0 * __pyx_v_nu) * ((((((((8463875.43631609 * __pyx_v_r) + (6347906.57723707 * __pyx_v_y1)) + (__pyx_v_y122 * (__pyx_v_y314 + __pyx_v_y315))) + (__pyx_v_y123 * (((25588.1776641618 * __pyx_v_r) - (82228.1776641618 * __pyx_v_y1)) + 17058.7851094412))) + (__pyx_v_y125 * (((11556.0 * __pyx_v_r) + (4188.0 * __pyx_v_y1)) + 7704.0))) + (__pyx_v_y126 * ((-__pyx_v_y314) + __pyx_v_y315))) - (7511347.20125054 * __pyx_v_y27)) + 7480835.43631609)) - ((32768.0 * __pyx_v_y117) * __pyx_v_y239)) + ((32768.0 * __pyx_v_y118) * (((((2257920.0 * __pyx_v_nu) + ((5760.0 * __pyx_v_r) * __pyx_v_y115)) + (5760.0 * __pyx_v_y225)) + (3225600.0 * __pyx_v_y27)) + 4143360.0))) + ((65536.0 * __pyx_v_y226) * __pyx_v_y85)) + (264241152000.0 * __pyx_v_y27)) - (__pyx_v_y313 * __pyx_v_y99)) + __pyx_v_y313) + ((7.0 * __pyx_v_y32) * ((((-37071008445.2255 * __pyx_v_r) - (37071008445.2255 * __pyx_v_y1)) + (28533211037.6879 * __pyx_v_y27)) + 4129567622.65173))) - (39946495452.7631 * __pyx_v_y89)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1098
 *         cdef double y315 = 12.0*r + 8.0
 *         cdef double y316 = 1.31621673590926e-19*y220*(53760.0*nu*(8463875.43631609*r + 6347906.57723707*y1 + y122*(y314 + y315) + y123*(25588.1776641618*r - 82228.1776641618*y1 + 17058.7851094412) + y125*(11556.0*r + 4188.0*y1 + 7704.0) + y126*(-y314 + y315) - 7511347.20125054*y27 + 7480835.43631609) - 32768.0*y117*y239 + 32768.0*y118*(2257920.0*nu + 5760.0*r*y115 + 5760.0*y225 + 3225600.0*y27 + 4143360.0) + 65536.0*y226*y85 + 264241152000.0*y27 - y313*y99 + y313 + 7.0*y32*(-37071008445.2255*r - 37071008445.2255*y1 + 28533211037.6879*y27 + 4129567622.65173) - 39946495452.7631*y89)
 *         cdef double y317 = 92160.0*y1*y131 - y16*y311 + y218*y312 - y218*y316 - 1.05297338872741e-18*y27*y296 + 61440.0*y27*y309 + y306 + y307*y308             # <<<<<<<<<<<<<<
 *         cdef double y318 = y105*y8
 *         cdef double y319 = y102*y318
 */
  __Pyx_TraceLine(1098,0,__PYX_ERR(1, 1098, __pyx_L1_error))
  __pyx_v_y317 = (((((((((92160.0 * __pyx_v_y1) * __pyx_v_y131) - (__pyx_v_y16 * __pyx_v_y311)) + (__pyx_v_y218 * __pyx_v_y312)) - (__pyx_v_y218 * __pyx_v_y316)) - ((1.05297338872741e-18 * __pyx_v_y27) * __pyx_v_y296)) + ((61440.0 * __pyx_v_y27) * __pyx_v_y309)) + __pyx_v_y306) + (__pyx_v_y307 * __pyx_v_y308));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1099
 *         cdef double y316 = 1.31621673590926e-19*y220*(53760.0*nu*(8463875.43631609*r + 6347906.57723707*y1 + y122*(y314 + y315) + y123*(25588.1776641618*r - 82228.1776641618*y1 + 17058.7851094412) + y125*(11556.0*r + 4188.0*y1 + 7704.0) + y126*(-y314 + y315) - 7511347.20125054*y27 + 7480835.43631609) - 32768.0*y117*y239 + 32768.0*y118*(2257920.0*nu + 5760.0*r*y115 + 5760.0*y225 + 3225600.0*y27 + 4143360.0) + 65536.0*y226*y85 + 264241152000.0*y27 - y313*y99 + y313 + 7.0*y32*(-37071008445.2255*r - 37071008445.2255*y1 + 28533211037.6879*y27 + 4129567622.65173) - 39946495452.7631*y89)
 *         cdef double y317 = 92160.0*y1*y131 - y16*y311 + y218*y312 - y218*y316 - 1.05297338872741e-18*y27*y296 + 61440.0*y27*y309 + y306 + y307*y308
 *         cdef double y318 = y105*y8             # <<<<<<<<<<<<<<
 *         cdef double y319 = y102*y318
 *         cdef double y320 = y245*y30
 */
  __Pyx_TraceLine(1099,0,__PYX_ERR(1, 1099, __pyx_L1_error))
  __pyx_v_y318 = (__pyx_v_y105 * __pyx_v_y8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1100
 *         cdef double y317 = 92160.0*y1*y131 - y16*y311 + y218*y312 - y218*y316 - 1.05297338872741e-18*y27*y296 + 61440.0*y27*y309 + y306 + y307*y308
 *         cdef double y318 = y105*y8
 *         cdef double y319 = y102*y318             # <<<<<<<<<<<<<<
 *         cdef double y320 = y245*y30
 *         cdef double y321 = y102*y245*y246*y8
 */
  __Pyx_TraceLine(1100,0,__PYX_ERR(1, 1100, __pyx_L1_error))
  __pyx_v_y319 = (__pyx_v_y102 * __pyx_v_y318);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1101
 *         cdef double y318 = y105*y8
 *         cdef double y319 = y102*y318
 *         cdef double y320 = y245*y30             # <<<<<<<<<<<<<<
 *         cdef double y321 = y102*y245*y246*y8
 *         cdef double y322 = (0.230275523363951*nu + 0.0307148905018684*y109 + 0.459657725867658*y141 + 5.30670671930294e-15*y264 + 5.30670671930294e-15*y265 - 9.78132182501918e-11*y266 - 1.54055818744052e-8*y267 + 0.228897162687159*y32 + 0.031457442188381*y89 + 0.0614297810037367*y99 + 1)**2
 */
  __Pyx_TraceLine(1101,0,__PYX_ERR(1, 1101, __pyx_L1_error))
  __pyx_v_y320 = (__pyx_v_y245 * __pyx_v_y30);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1102
 *         cdef double y319 = y102*y318
 *         cdef double y320 = y245*y30
 *         cdef double y321 = y102*y245*y246*y8             # <<<<<<<<<<<<<<
 *         cdef double y322 = (0.230275523363951*nu + 0.0307148905018684*y109 + 0.459657725867658*y141 + 5.30670671930294e-15*y264 + 5.30670671930294e-15*y265 - 9.78132182501918e-11*y266 - 1.54055818744052e-8*y267 + 0.228897162687159*y32 + 0.031457442188381*y89 + 0.0614297810037367*y99 + 1)**2
 *         cdef double y323 = y260*y278
 */
  __Pyx_TraceLine(1102,0,__PYX_ERR(1, 1102, __pyx_L1_error))
  __pyx_v_y321 = (((__pyx_v_y102 * __pyx_v_y245) * __pyx_v_y246) * __pyx_v_y8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1103
 *         cdef double y320 = y245*y30
 *         cdef double y321 = y102*y245*y246*y8
 *         cdef double y322 = (0.230275523363951*nu + 0.0307148905018684*y109 + 0.459657725867658*y141 + 5.30670671930294e-15*y264 + 5.30670671930294e-15*y265 - 9.78132182501918e-11*y266 - 1.54055818744052e-8*y267 + 0.228897162687159*y32 + 0.031457442188381*y89 + 0.0614297810037367*y99 + 1)**2             # <<<<<<<<<<<<<<
 *         cdef double y323 = y260*y278
 *         cdef double y324 = 11575876386816.0*y51
 */
  __Pyx_TraceLine(1103,0,__PYX_ERR(1, 1103, __pyx_L1_error))
  __pyx_v_y322 = pow((((((((((((0.230275523363951 * __pyx_v_nu) + (0.0307148905018684 * __pyx_v_y109)) + (0.459657725867658 * __pyx_v_y141)) + (5.30670671930294e-15 * __pyx_v_y264)) + (5.30670671930294e-15 * __pyx_v_y265)) - (9.78132182501918e-11 * __pyx_v_y266)) - (1.54055818744052e-8 * __pyx_v_y267)) + (0.228897162687159 * __pyx_v_y32)) + (0.031457442188381 * __pyx_v_y89)) + (0.0614297810037367 * __pyx_v_y99)) + 1.0), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1104
 *         cdef double y321 = y102*y245*y246*y8
 *         cdef double y322 = (0.230275523363951*nu + 0.0307148905018684*y109 + 0.459657725867658*y141 + 5.30670671930294e-15*y264 + 5.30670671930294e-15*y265 - 9.78132182501918e-11*y266 - 1.54055818744052e-8*y267 + 0.228897162687159*y32 + 0.031457442188381*y89 + 0.0614297810037367*y99 + 1)**2
 *         cdef double y323 = y260*y278             # <<<<<<<<<<<<<<
 *         cdef double y324 = 11575876386816.0*y51
 *         cdef double y325 = 8323596288000.0*nu + 24297540157440.0
 */
  __Pyx_TraceLine(1104,0,__PYX_ERR(1, 1104, __pyx_L1_error))
  __pyx_v_y323 = (__pyx_v_y260 * __pyx_v_y278);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1105
 *         cdef double y322 = (0.230275523363951*nu + 0.0307148905018684*y109 + 0.459657725867658*y141 + 5.30670671930294e-15*y264 + 5.30670671930294e-15*y265 - 9.78132182501918e-11*y266 - 1.54055818744052e-8*y267 + 0.228897162687159*y32 + 0.031457442188381*y89 + 0.0614297810037367*y99 + 1)**2
 *         cdef double y323 = y260*y278
 *         cdef double y324 = 11575876386816.0*y51             # <<<<<<<<<<<<<<
 *         cdef double y325 = 8323596288000.0*nu + 24297540157440.0
 *         cdef double y326 = y156*y51 + y251 + y252 - y324*y99 + y324 + y71*(3519692144640.0*r + y325) + 1759846072320.0*y99 + 10215490662751.4
 */
  __Pyx_TraceLine(1105,0,__PYX_ERR(1, 1105, __pyx_L1_error))
  __pyx_v_y324 = (11575876386816.0 * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1106
 *         cdef double y323 = y260*y278
 *         cdef double y324 = 11575876386816.0*y51
 *         cdef double y325 = 8323596288000.0*nu + 24297540157440.0             # <<<<<<<<<<<<<<
 *         cdef double y326 = y156*y51 + y251 + y252 - y324*y99 + y324 + y71*(3519692144640.0*r + y325) + 1759846072320.0*y99 + 10215490662751.4
 *         cdef double y327 = y166*y247
 */
  __Pyx_TraceLine(1106,0,__PYX_ERR(1, 1106, __pyx_L1_error))
  __pyx_v_y325 = ((8323596288000.0 * __pyx_v_nu) + 24297540157440.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1107
 *         cdef double y324 = 11575876386816.0*y51
 *         cdef double y325 = 8323596288000.0*nu + 24297540157440.0
 *         cdef double y326 = y156*y51 + y251 + y252 - y324*y99 + y324 + y71*(3519692144640.0*r + y325) + 1759846072320.0*y99 + 10215490662751.4             # <<<<<<<<<<<<<<
 *         cdef double y327 = y166*y247
 *         cdef double y328 = y259*y261
 */
  __Pyx_TraceLine(1107,0,__PYX_ERR(1, 1107, __pyx_L1_error))
  __pyx_v_y326 = ((((((((__pyx_v_y156 * __pyx_v_y51) + __pyx_v_y251) + __pyx_v_y252) - (__pyx_v_y324 * __pyx_v_y99)) + __pyx_v_y324) + (__pyx_v_y71 * ((3519692144640.0 * __pyx_v_r) + __pyx_v_y325))) + (1759846072320.0 * __pyx_v_y99)) + 10215490662751.4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1108
 *         cdef double y325 = 8323596288000.0*nu + 24297540157440.0
 *         cdef double y326 = y156*y51 + y251 + y252 - y324*y99 + y324 + y71*(3519692144640.0*r + y325) + 1759846072320.0*y99 + 10215490662751.4
 *         cdef double y327 = y166*y247             # <<<<<<<<<<<<<<
 *         cdef double y328 = y259*y261
 *         cdef double y329 = y249*y250
 */
  __Pyx_TraceLine(1108,0,__PYX_ERR(1, 1108, __pyx_L1_error))
  __pyx_v_y327 = (__pyx_v_y166 * __pyx_v_y247);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1109
 *         cdef double y326 = y156*y51 + y251 + y252 - y324*y99 + y324 + y71*(3519692144640.0*r + y325) + 1759846072320.0*y99 + 10215490662751.4
 *         cdef double y327 = y166*y247
 *         cdef double y328 = y259*y261             # <<<<<<<<<<<<<<
 *         cdef double y329 = y249*y250
 *         cdef double y330 = (0.108541457767442*nu + 0.190937736865098*r + 0.0967857763822762*y150 + 0.00500066803742898*y152 + 0.216364706551791*y222 + 1.86910000868887e-14*y255 - 1.86910000868887e-14*y256 + 0.0340677222520525*y32 - 1)**2
 */
  __Pyx_TraceLine(1109,0,__PYX_ERR(1, 1109, __pyx_L1_error))
  __pyx_v_y328 = (__pyx_v_y259 * __pyx_v_y261);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1110
 *         cdef double y327 = y166*y247
 *         cdef double y328 = y259*y261
 *         cdef double y329 = y249*y250             # <<<<<<<<<<<<<<
 *         cdef double y330 = (0.108541457767442*nu + 0.190937736865098*r + 0.0967857763822762*y150 + 0.00500066803742898*y152 + 0.216364706551791*y222 + 1.86910000868887e-14*y255 - 1.86910000868887e-14*y256 + 0.0340677222520525*y32 - 1)**2
 *         cdef double y331 = 11614301777632.7*nu - 5806080.0*r*y138 - y146*y51 + y253 + y254 + 3645361092898.41*y32 + y71*(40226753557568.7*nu + 5279538216960.0*y1 + 1132462080.0*y153 + 10083442360320.0*y32 - 208372220299875.0) + y99*(5279538216960.0*r + y325) - 107003370108748.0
 */
  __Pyx_TraceLine(1110,0,__PYX_ERR(1, 1110, __pyx_L1_error))
  __pyx_v_y329 = (__pyx_v_y249 * __pyx_v_y250);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1111
 *         cdef double y328 = y259*y261
 *         cdef double y329 = y249*y250
 *         cdef double y330 = (0.108541457767442*nu + 0.190937736865098*r + 0.0967857763822762*y150 + 0.00500066803742898*y152 + 0.216364706551791*y222 + 1.86910000868887e-14*y255 - 1.86910000868887e-14*y256 + 0.0340677222520525*y32 - 1)**2             # <<<<<<<<<<<<<<
 *         cdef double y331 = 11614301777632.7*nu - 5806080.0*r*y138 - y146*y51 + y253 + y254 + 3645361092898.41*y32 + y71*(40226753557568.7*nu + 5279538216960.0*y1 + 1132462080.0*y153 + 10083442360320.0*y32 - 208372220299875.0) + y99*(5279538216960.0*r + y325) - 107003370108748.0
 *         cdef double y332 = y159*y327
 */
  __Pyx_TraceLine(1111,0,__PYX_ERR(1, 1111, __pyx_L1_error))
  __pyx_v_y330 = pow((((((((((0.108541457767442 * __pyx_v_nu) + (0.190937736865098 * __pyx_v_r)) + (0.0967857763822762 * __pyx_v_y150)) + (0.00500066803742898 * __pyx_v_y152)) + (0.216364706551791 * __pyx_v_y222)) + (1.86910000868887e-14 * __pyx_v_y255)) - (1.86910000868887e-14 * __pyx_v_y256)) + (0.0340677222520525 * __pyx_v_y32)) - 1.0), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1112
 *         cdef double y329 = y249*y250
 *         cdef double y330 = (0.108541457767442*nu + 0.190937736865098*r + 0.0967857763822762*y150 + 0.00500066803742898*y152 + 0.216364706551791*y222 + 1.86910000868887e-14*y255 - 1.86910000868887e-14*y256 + 0.0340677222520525*y32 - 1)**2
 *         cdef double y331 = 11614301777632.7*nu - 5806080.0*r*y138 - y146*y51 + y253 + y254 + 3645361092898.41*y32 + y71*(40226753557568.7*nu + 5279538216960.0*y1 + 1132462080.0*y153 + 10083442360320.0*y32 - 208372220299875.0) + y99*(5279538216960.0*r + y325) - 107003370108748.0             # <<<<<<<<<<<<<<
 *         cdef double y332 = y159*y327
 *         cdef double y333 = y182*y268
 */
  __Pyx_TraceLine(1112,0,__PYX_ERR(1, 1112, __pyx_L1_error))
  __pyx_v_y331 = (((((((((11614301777632.7 * __pyx_v_nu) - ((5806080.0 * __pyx_v_r) * __pyx_v_y138)) - (__pyx_v_y146 * __pyx_v_y51)) + __pyx_v_y253) + __pyx_v_y254) + (3645361092898.41 * __pyx_v_y32)) + (__pyx_v_y71 * (((((40226753557568.7 * __pyx_v_nu) + (5279538216960.0 * __pyx_v_y1)) + (1132462080.0 * __pyx_v_y153)) + (10083442360320.0 * __pyx_v_y32)) - 208372220299875.0))) + (__pyx_v_y99 * ((5279538216960.0 * __pyx_v_r) + __pyx_v_y325))) - 107003370108748.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1113
 *         cdef double y330 = (0.108541457767442*nu + 0.190937736865098*r + 0.0967857763822762*y150 + 0.00500066803742898*y152 + 0.216364706551791*y222 + 1.86910000868887e-14*y255 - 1.86910000868887e-14*y256 + 0.0340677222520525*y32 - 1)**2
 *         cdef double y331 = 11614301777632.7*nu - 5806080.0*r*y138 - y146*y51 + y253 + y254 + 3645361092898.41*y32 + y71*(40226753557568.7*nu + 5279538216960.0*y1 + 1132462080.0*y153 + 10083442360320.0*y32 - 208372220299875.0) + y99*(5279538216960.0*r + y325) - 107003370108748.0
 *         cdef double y332 = y159*y327             # <<<<<<<<<<<<<<
 *         cdef double y333 = y182*y268
 *         cdef double y334 = y260*y333
 */
  __Pyx_TraceLine(1113,0,__PYX_ERR(1, 1113, __pyx_L1_error))
  __pyx_v_y332 = (__pyx_v_y159 * __pyx_v_y327);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1114
 *         cdef double y331 = 11614301777632.7*nu - 5806080.0*r*y138 - y146*y51 + y253 + y254 + 3645361092898.41*y32 + y71*(40226753557568.7*nu + 5279538216960.0*y1 + 1132462080.0*y153 + 10083442360320.0*y32 - 208372220299875.0) + y99*(5279538216960.0*r + y325) - 107003370108748.0
 *         cdef double y332 = y159*y327
 *         cdef double y333 = y182*y268             # <<<<<<<<<<<<<<
 *         cdef double y334 = y260*y333
 *         cdef double y335 = y159*y329
 */
  __Pyx_TraceLine(1114,0,__PYX_ERR(1, 1114, __pyx_L1_error))
  __pyx_v_y333 = (__pyx_v_y182 * __pyx_v_y268);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1115
 *         cdef double y332 = y159*y327
 *         cdef double y333 = y182*y268
 *         cdef double y334 = y260*y333             # <<<<<<<<<<<<<<
 *         cdef double y335 = y159*y329
 *         cdef double y336 = y167*y259
 */
  __Pyx_TraceLine(1115,0,__PYX_ERR(1, 1115, __pyx_L1_error))
  __pyx_v_y334 = (__pyx_v_y260 * __pyx_v_y333);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1116
 *         cdef double y333 = y182*y268
 *         cdef double y334 = y260*y333
 *         cdef double y335 = y159*y329             # <<<<<<<<<<<<<<
 *         cdef double y336 = y167*y259
 *         cdef double y337 = y174*y192
 */
  __Pyx_TraceLine(1116,0,__PYX_ERR(1, 1116, __pyx_L1_error))
  __pyx_v_y335 = (__pyx_v_y159 * __pyx_v_y329);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1117
 *         cdef double y334 = y260*y333
 *         cdef double y335 = y159*y329
 *         cdef double y336 = y167*y259             # <<<<<<<<<<<<<<
 *         cdef double y337 = y174*y192
 *         cdef double y338 = y174*y268
 */
  __Pyx_TraceLine(1117,0,__PYX_ERR(1, 1117, __pyx_L1_error))
  __pyx_v_y336 = (__pyx_v_y167 * __pyx_v_y259);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1118
 *         cdef double y335 = y159*y329
 *         cdef double y336 = y167*y259
 *         cdef double y337 = y174*y192             # <<<<<<<<<<<<<<
 *         cdef double y338 = y174*y268
 *         cdef double y339 = y187*y338
 */
  __Pyx_TraceLine(1118,0,__PYX_ERR(1, 1118, __pyx_L1_error))
  __pyx_v_y337 = (__pyx_v_y174 * __pyx_v_y192);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1119
 *         cdef double y336 = y167*y259
 *         cdef double y337 = y174*y192
 *         cdef double y338 = y174*y268             # <<<<<<<<<<<<<<
 *         cdef double y339 = y187*y338
 *         cdef double y340 = y17*y6
 */
  __Pyx_TraceLine(1119,0,__PYX_ERR(1, 1119, __pyx_L1_error))
  __pyx_v_y338 = (__pyx_v_y174 * __pyx_v_y268);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1120
 *         cdef double y337 = y174*y192
 *         cdef double y338 = y174*y268
 *         cdef double y339 = y187*y338             # <<<<<<<<<<<<<<
 *         cdef double y340 = y17*y6
 *         cdef double y341 = 1.35633680555556e-7*y340
 */
  __Pyx_TraceLine(1120,0,__PYX_ERR(1, 1120, __pyx_L1_error))
  __pyx_v_y339 = (__pyx_v_y187 * __pyx_v_y338);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1121
 *         cdef double y338 = y174*y268
 *         cdef double y339 = y187*y338
 *         cdef double y340 = y17*y6             # <<<<<<<<<<<<<<
 *         cdef double y341 = 1.35633680555556e-7*y340
 *         cdef double y342 = y190*y36
 */
  __Pyx_TraceLine(1121,0,__PYX_ERR(1, 1121, __pyx_L1_error))
  __pyx_v_y340 = (__pyx_v_y17 * __pyx_v_y6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1122
 *         cdef double y339 = y187*y338
 *         cdef double y340 = y17*y6
 *         cdef double y341 = 1.35633680555556e-7*y340             # <<<<<<<<<<<<<<
 *         cdef double y342 = y190*y36
 *         cdef double y343 = 1.69542100694444e-7*y342
 */
  __Pyx_TraceLine(1122,0,__PYX_ERR(1, 1122, __pyx_L1_error))
  __pyx_v_y341 = (1.35633680555556e-7 * __pyx_v_y340);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1123
 *         cdef double y340 = y17*y6
 *         cdef double y341 = 1.35633680555556e-7*y340
 *         cdef double y342 = y190*y36             # <<<<<<<<<<<<<<
 *         cdef double y343 = 1.69542100694444e-7*y342
 *         cdef double y344 = y168*y191
 */
  __Pyx_TraceLine(1123,0,__PYX_ERR(1, 1123, __pyx_L1_error))
  __pyx_v_y342 = (__pyx_v_y190 * __pyx_v_y36);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1124
 *         cdef double y341 = 1.35633680555556e-7*y340
 *         cdef double y342 = y190*y36
 *         cdef double y343 = 1.69542100694444e-7*y342             # <<<<<<<<<<<<<<
 *         cdef double y344 = y168*y191
 *         cdef double y345 = y187*y268*y344
 */
  __Pyx_TraceLine(1124,0,__PYX_ERR(1, 1124, __pyx_L1_error))
  __pyx_v_y343 = (1.69542100694444e-7 * __pyx_v_y342);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1125
 *         cdef double y342 = y190*y36
 *         cdef double y343 = 1.69542100694444e-7*y342
 *         cdef double y344 = y168*y191             # <<<<<<<<<<<<<<
 *         cdef double y345 = y187*y268*y344
 *         cdef double y346 = 4.48183298009152e-37*y159*y257
 */
  __Pyx_TraceLine(1125,0,__PYX_ERR(1, 1125, __pyx_L1_error))
  __pyx_v_y344 = (__pyx_v_y168 * __pyx_v_y191);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1126
 *         cdef double y343 = 1.69542100694444e-7*y342
 *         cdef double y344 = y168*y191
 *         cdef double y345 = y187*y268*y344             # <<<<<<<<<<<<<<
 *         cdef double y346 = 4.48183298009152e-37*y159*y257
 *         cdef double y347 = y169*y346
 */
  __Pyx_TraceLine(1126,0,__PYX_ERR(1, 1126, __pyx_L1_error))
  __pyx_v_y345 = ((__pyx_v_y187 * __pyx_v_y268) * __pyx_v_y344);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1127
 *         cdef double y344 = y168*y191
 *         cdef double y345 = y187*y268*y344
 *         cdef double y346 = 4.48183298009152e-37*y159*y257             # <<<<<<<<<<<<<<
 *         cdef double y347 = y169*y346
 *         cdef double y348 = y162*y277*y280
 */
  __Pyx_TraceLine(1127,0,__PYX_ERR(1, 1127, __pyx_L1_error))
  __pyx_v_y346 = ((4.48183298009152e-37 * __pyx_v_y159) * __pyx_v_y257);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1128
 *         cdef double y345 = y187*y268*y344
 *         cdef double y346 = 4.48183298009152e-37*y159*y257
 *         cdef double y347 = y169*y346             # <<<<<<<<<<<<<<
 *         cdef double y348 = y162*y277*y280
 *         cdef double y349 = (y128*y130*y27 + 0.25*y128*y16*y217 - 4.28455968720463e-24*y233 - 6.51041666666667e-5*y48)**2
 */
  __Pyx_TraceLine(1128,0,__PYX_ERR(1, 1128, __pyx_L1_error))
  __pyx_v_y347 = (__pyx_v_y169 * __pyx_v_y346);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1129
 *         cdef double y346 = 4.48183298009152e-37*y159*y257
 *         cdef double y347 = y169*y346
 *         cdef double y348 = y162*y277*y280             # <<<<<<<<<<<<<<
 *         cdef double y349 = (y128*y130*y27 + 0.25*y128*y16*y217 - 4.28455968720463e-24*y233 - 6.51041666666667e-5*y48)**2
 *         cdef double y350 = y191*y283
 */
  __Pyx_TraceLine(1129,0,__PYX_ERR(1, 1129, __pyx_L1_error))
  __pyx_v_y348 = ((__pyx_v_y162 * __pyx_v_y277) * __pyx_v_y280);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1130
 *         cdef double y347 = y169*y346
 *         cdef double y348 = y162*y277*y280
 *         cdef double y349 = (y128*y130*y27 + 0.25*y128*y16*y217 - 4.28455968720463e-24*y233 - 6.51041666666667e-5*y48)**2             # <<<<<<<<<<<<<<
 *         cdef double y350 = y191*y283
 *         cdef double y351 = 8.83031774450231e-12*y285
 */
  __Pyx_TraceLine(1130,0,__PYX_ERR(1, 1130, __pyx_L1_error))
  __pyx_v_y349 = pow((((((__pyx_v_y128 * __pyx_v_y130) * __pyx_v_y27) + (((0.25 * __pyx_v_y128) * __pyx_v_y16) * __pyx_v_y217)) - (4.28455968720463e-24 * __pyx_v_y233)) - (6.51041666666667e-5 * __pyx_v_y48)), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1131
 *         cdef double y348 = y162*y277*y280
 *         cdef double y349 = (y128*y130*y27 + 0.25*y128*y16*y217 - 4.28455968720463e-24*y233 - 6.51041666666667e-5*y48)**2
 *         cdef double y350 = y191*y283             # <<<<<<<<<<<<<<
 *         cdef double y351 = 8.83031774450231e-12*y285
 *         cdef double y352 = y173*y351
 */
  __Pyx_TraceLine(1131,0,__PYX_ERR(1, 1131, __pyx_L1_error))
  __pyx_v_y350 = (__pyx_v_y191 * __pyx_v_y283);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1132
 *         cdef double y349 = (y128*y130*y27 + 0.25*y128*y16*y217 - 4.28455968720463e-24*y233 - 6.51041666666667e-5*y48)**2
 *         cdef double y350 = y191*y283
 *         cdef double y351 = 8.83031774450231e-12*y285             # <<<<<<<<<<<<<<
 *         cdef double y352 = y173*y351
 *         cdef double y353 = y182*y297
 */
  __Pyx_TraceLine(1132,0,__PYX_ERR(1, 1132, __pyx_L1_error))
  __pyx_v_y351 = (8.83031774450231e-12 * __pyx_v_y285);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1133
 *         cdef double y350 = y191*y283
 *         cdef double y351 = 8.83031774450231e-12*y285
 *         cdef double y352 = y173*y351             # <<<<<<<<<<<<<<
 *         cdef double y353 = y182*y297
 *         cdef double y354 = y174*y353
 */
  __Pyx_TraceLine(1133,0,__PYX_ERR(1, 1133, __pyx_L1_error))
  __pyx_v_y352 = (__pyx_v_y173 * __pyx_v_y351);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1134
 *         cdef double y351 = 8.83031774450231e-12*y285
 *         cdef double y352 = y173*y351
 *         cdef double y353 = y182*y297             # <<<<<<<<<<<<<<
 *         cdef double y354 = y174*y353
 *         cdef double y355 = 3.39084201388889e-8*y191
 */
  __Pyx_TraceLine(1134,0,__PYX_ERR(1, 1134, __pyx_L1_error))
  __pyx_v_y353 = (__pyx_v_y182 * __pyx_v_y297);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1135
 *         cdef double y352 = y173*y351
 *         cdef double y353 = y182*y297
 *         cdef double y354 = y174*y353             # <<<<<<<<<<<<<<
 *         cdef double y355 = 3.39084201388889e-8*y191
 *         cdef double y356 = y344*y353
 */
  __Pyx_TraceLine(1135,0,__PYX_ERR(1, 1135, __pyx_L1_error))
  __pyx_v_y354 = (__pyx_v_y174 * __pyx_v_y353);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1136
 *         cdef double y353 = y182*y297
 *         cdef double y354 = y174*y353
 *         cdef double y355 = 3.39084201388889e-8*y191             # <<<<<<<<<<<<<<
 *         cdef double y356 = y344*y353
 *         cdef double y357 = y184*y257
 */
  __Pyx_TraceLine(1136,0,__PYX_ERR(1, 1136, __pyx_L1_error))
  __pyx_v_y355 = (3.39084201388889e-8 * __pyx_v_y191);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1137
 *         cdef double y354 = y174*y353
 *         cdef double y355 = 3.39084201388889e-8*y191
 *         cdef double y356 = y344*y353             # <<<<<<<<<<<<<<
 *         cdef double y357 = y184*y257
 *         cdef double y358 = 76800.0*y183
 */
  __Pyx_TraceLine(1137,0,__PYX_ERR(1, 1137, __pyx_L1_error))
  __pyx_v_y356 = (__pyx_v_y344 * __pyx_v_y353);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1138
 *         cdef double y355 = 3.39084201388889e-8*y191
 *         cdef double y356 = y344*y353
 *         cdef double y357 = y184*y257             # <<<<<<<<<<<<<<
 *         cdef double y358 = 76800.0*y183
 *         cdef double y359 = y172*y183
 */
  __Pyx_TraceLine(1138,0,__PYX_ERR(1, 1138, __pyx_L1_error))
  __pyx_v_y357 = (__pyx_v_y184 * __pyx_v_y257);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1139
 *         cdef double y356 = y344*y353
 *         cdef double y357 = y184*y257
 *         cdef double y358 = 76800.0*y183             # <<<<<<<<<<<<<<
 *         cdef double y359 = y172*y183
 *         cdef double y360 = 4.5850433485607e-22*y292
 */
  __Pyx_TraceLine(1139,0,__PYX_ERR(1, 1139, __pyx_L1_error))
  __pyx_v_y358 = (76800.0 * __pyx_v_y183);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1140
 *         cdef double y357 = y184*y257
 *         cdef double y358 = 76800.0*y183
 *         cdef double y359 = y172*y183             # <<<<<<<<<<<<<<
 *         cdef double y360 = 4.5850433485607e-22*y292
 *         cdef double y361 = y130*y185
 */
  __Pyx_TraceLine(1140,0,__PYX_ERR(1, 1140, __pyx_L1_error))
  __pyx_v_y359 = (__pyx_v_y172 * __pyx_v_y183);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1141
 *         cdef double y358 = 76800.0*y183
 *         cdef double y359 = y172*y183
 *         cdef double y360 = 4.5850433485607e-22*y292             # <<<<<<<<<<<<<<
 *         cdef double y361 = y130*y185
 *         cdef double y362 = y205**(-0.5)
 */
  __Pyx_TraceLine(1141,0,__PYX_ERR(1, 1141, __pyx_L1_error))
  __pyx_v_y360 = (4.5850433485607e-22 * __pyx_v_y292);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1142
 *         cdef double y359 = y172*y183
 *         cdef double y360 = 4.5850433485607e-22*y292
 *         cdef double y361 = y130*y185             # <<<<<<<<<<<<<<
 *         cdef double y362 = y205**(-0.5)
 *         cdef double y363 = (y207*y67 + 2.0)**(-1)
 */
  __Pyx_TraceLine(1142,0,__PYX_ERR(1, 1142, __pyx_L1_error))
  __pyx_v_y361 = (__pyx_v_y130 * __pyx_v_y185);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1143
 *         cdef double y360 = 4.5850433485607e-22*y292
 *         cdef double y361 = y130*y185
 *         cdef double y362 = y205**(-0.5)             # <<<<<<<<<<<<<<
 *         cdef double y363 = (y207*y67 + 2.0)**(-1)
 *         cdef double y364 = 12.0*y168
 */
  __Pyx_TraceLine(1143,0,__PYX_ERR(1, 1143, __pyx_L1_error))
  __pyx_v_y362 = pow(__pyx_v_y205, -0.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1144
 *         cdef double y361 = y130*y185
 *         cdef double y362 = y205**(-0.5)
 *         cdef double y363 = (y207*y67 + 2.0)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double y364 = 12.0*y168
 *         cdef double y365 = y51*y87
 */
  __Pyx_TraceLine(1144,0,__PYX_ERR(1, 1144, __pyx_L1_error))
  __pyx_v_y363 = pow(((__pyx_v_y207 * __pyx_v_y67) + 2.0), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1145
 *         cdef double y362 = y205**(-0.5)
 *         cdef double y363 = (y207*y67 + 2.0)**(-1)
 *         cdef double y364 = 12.0*y168             # <<<<<<<<<<<<<<
 *         cdef double y365 = y51*y87
 *         cdef double y366 = y28*y90
 */
  __Pyx_TraceLine(1145,0,__PYX_ERR(1, 1145, __pyx_L1_error))
  __pyx_v_y364 = (12.0 * __pyx_v_y168);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1146
 *         cdef double y363 = (y207*y67 + 2.0)**(-1)
 *         cdef double y364 = 12.0*y168
 *         cdef double y365 = y51*y87             # <<<<<<<<<<<<<<
 *         cdef double y366 = y28*y90
 *         cdef double y367 = 30.0*y76
 */
  __Pyx_TraceLine(1146,0,__PYX_ERR(1, 1146, __pyx_L1_error))
  __pyx_v_y365 = (__pyx_v_y51 * __pyx_v_y87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1147
 *         cdef double y364 = 12.0*y168
 *         cdef double y365 = y51*y87
 *         cdef double y366 = y28*y90             # <<<<<<<<<<<<<<
 *         cdef double y367 = 30.0*y76
 *         cdef double y368 = y51*y92
 */
  __Pyx_TraceLine(1147,0,__PYX_ERR(1, 1147, __pyx_L1_error))
  __pyx_v_y366 = (__pyx_v_y28 * __pyx_v_y90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1148
 *         cdef double y365 = y51*y87
 *         cdef double y366 = y28*y90
 *         cdef double y367 = 30.0*y76             # <<<<<<<<<<<<<<
 *         cdef double y368 = y51*y92
 *         cdef double y369 = y28*y95
 */
  __Pyx_TraceLine(1148,0,__PYX_ERR(1, 1148, __pyx_L1_error))
  __pyx_v_y367 = (30.0 * __pyx_v_y76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1149
 *         cdef double y366 = y28*y90
 *         cdef double y367 = 30.0*y76
 *         cdef double y368 = y51*y92             # <<<<<<<<<<<<<<
 *         cdef double y369 = y28*y95
 *         cdef double y370 = y51*y97
 */
  __Pyx_TraceLine(1149,0,__PYX_ERR(1, 1149, __pyx_L1_error))
  __pyx_v_y368 = (__pyx_v_y51 * __pyx_v_y92);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1150
 *         cdef double y367 = 30.0*y76
 *         cdef double y368 = y51*y92
 *         cdef double y369 = y28*y95             # <<<<<<<<<<<<<<
 *         cdef double y370 = y51*y97
 *         cdef double y371 = y100*y17
 */
  __Pyx_TraceLine(1150,0,__PYX_ERR(1, 1150, __pyx_L1_error))
  __pyx_v_y369 = (__pyx_v_y28 * __pyx_v_y95);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1151
 *         cdef double y368 = y51*y92
 *         cdef double y369 = y28*y95
 *         cdef double y370 = y51*y97             # <<<<<<<<<<<<<<
 *         cdef double y371 = y100*y17
 *         cdef double y372 = y163*y167
 */
  __Pyx_TraceLine(1151,0,__PYX_ERR(1, 1151, __pyx_L1_error))
  __pyx_v_y370 = (__pyx_v_y51 * __pyx_v_y97);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1152
 *         cdef double y369 = y28*y95
 *         cdef double y370 = y51*y97
 *         cdef double y371 = y100*y17             # <<<<<<<<<<<<<<
 *         cdef double y372 = y163*y167
 *         cdef double y373 = y173*y270
 */
  __Pyx_TraceLine(1152,0,__PYX_ERR(1, 1152, __pyx_L1_error))
  __pyx_v_y371 = (__pyx_v_y100 * __pyx_v_y17);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1153
 *         cdef double y370 = y51*y97
 *         cdef double y371 = y100*y17
 *         cdef double y372 = y163*y167             # <<<<<<<<<<<<<<
 *         cdef double y373 = y173*y270
 *         cdef double y374 = y355*y373
 */
  __Pyx_TraceLine(1153,0,__PYX_ERR(1, 1153, __pyx_L1_error))
  __pyx_v_y372 = (__pyx_v_y163 * __pyx_v_y167);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1154
 *         cdef double y371 = y100*y17
 *         cdef double y372 = y163*y167
 *         cdef double y373 = y173*y270             # <<<<<<<<<<<<<<
 *         cdef double y374 = y355*y373
 *         cdef double y375 = prst**3
 */
  __Pyx_TraceLine(1154,0,__PYX_ERR(1, 1154, __pyx_L1_error))
  __pyx_v_y373 = (__pyx_v_y173 * __pyx_v_y270);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1155
 *         cdef double y372 = y163*y167
 *         cdef double y373 = y173*y270
 *         cdef double y374 = y355*y373             # <<<<<<<<<<<<<<
 *         cdef double y375 = prst**3
 *         cdef double y376 = y375*y78
 */
  __Pyx_TraceLine(1155,0,__PYX_ERR(1, 1155, __pyx_L1_error))
  __pyx_v_y374 = (__pyx_v_y355 * __pyx_v_y373);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1156
 *         cdef double y373 = y173*y270
 *         cdef double y374 = y355*y373
 *         cdef double y375 = prst**3             # <<<<<<<<<<<<<<
 *         cdef double y376 = y375*y78
 *         cdef double y377 = prst**5
 */
  __Pyx_TraceLine(1156,0,__PYX_ERR(1, 1156, __pyx_L1_error))
  __pyx_v_y375 = pow(__pyx_v_prst, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1157
 *         cdef double y374 = y355*y373
 *         cdef double y375 = prst**3
 *         cdef double y376 = y375*y78             # <<<<<<<<<<<<<<
 *         cdef double y377 = prst**5
 *         cdef double y378 = nu*y377*y79
 */
  __Pyx_TraceLine(1157,0,__PYX_ERR(1, 1157, __pyx_L1_error))
  __pyx_v_y376 = (__pyx_v_y375 * __pyx_v_y78);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1158
 *         cdef double y375 = prst**3
 *         cdef double y376 = y375*y78
 *         cdef double y377 = prst**5             # <<<<<<<<<<<<<<
 *         cdef double y378 = nu*y377*y79
 *         cdef double y379 = prst**7
 */
  __Pyx_TraceLine(1158,0,__PYX_ERR(1, 1158, __pyx_L1_error))
  __pyx_v_y377 = pow(__pyx_v_prst, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1159
 *         cdef double y376 = y375*y78
 *         cdef double y377 = prst**5
 *         cdef double y378 = nu*y377*y79             # <<<<<<<<<<<<<<
 *         cdef double y379 = prst**7
 *         cdef double y380 = nu*y379
 */
  __Pyx_TraceLine(1159,0,__PYX_ERR(1, 1159, __pyx_L1_error))
  __pyx_v_y378 = ((__pyx_v_nu * __pyx_v_y377) * __pyx_v_y79);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1160
 *         cdef double y377 = prst**5
 *         cdef double y378 = nu*y377*y79
 *         cdef double y379 = prst**7             # <<<<<<<<<<<<<<
 *         cdef double y380 = nu*y379
 *         cdef double y381 = y380*y82
 */
  __Pyx_TraceLine(1160,0,__PYX_ERR(1, 1160, __pyx_L1_error))
  __pyx_v_y379 = pow(__pyx_v_prst, 7.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1161
 *         cdef double y378 = nu*y377*y79
 *         cdef double y379 = prst**7
 *         cdef double y380 = nu*y379             # <<<<<<<<<<<<<<
 *         cdef double y381 = y380*y82
 *         cdef double y382 = y379*y85
 */
  __Pyx_TraceLine(1161,0,__PYX_ERR(1, 1161, __pyx_L1_error))
  __pyx_v_y380 = (__pyx_v_nu * __pyx_v_y379);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1162
 *         cdef double y379 = prst**7
 *         cdef double y380 = nu*y379
 *         cdef double y381 = y380*y82             # <<<<<<<<<<<<<<
 *         cdef double y382 = y379*y85
 *         cdef double y383 = 0.00678224732971111*y375
 */
  __Pyx_TraceLine(1162,0,__PYX_ERR(1, 1162, __pyx_L1_error))
  __pyx_v_y381 = (__pyx_v_y380 * __pyx_v_y82);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1163
 *         cdef double y380 = nu*y379
 *         cdef double y381 = y380*y82
 *         cdef double y382 = y379*y85             # <<<<<<<<<<<<<<
 *         cdef double y383 = 0.00678224732971111*y375
 *         cdef double y384 = 0.0101733709945667*y377
 */
  __Pyx_TraceLine(1163,0,__PYX_ERR(1, 1163, __pyx_L1_error))
  __pyx_v_y382 = (__pyx_v_y379 * __pyx_v_y85);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1164
 *         cdef double y381 = y380*y82
 *         cdef double y382 = y379*y85
 *         cdef double y383 = 0.00678224732971111*y375             # <<<<<<<<<<<<<<
 *         cdef double y384 = 0.0101733709945667*y377
 *         cdef double y385 = y370*y379
 */
  __Pyx_TraceLine(1164,0,__PYX_ERR(1, 1164, __pyx_L1_error))
  __pyx_v_y383 = (0.00678224732971111 * __pyx_v_y375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1165
 *         cdef double y382 = y379*y85
 *         cdef double y383 = 0.00678224732971111*y375
 *         cdef double y384 = 0.0101733709945667*y377             # <<<<<<<<<<<<<<
 *         cdef double y385 = y370*y379
 *         cdef double y386 = y372*y375
 */
  __Pyx_TraceLine(1165,0,__PYX_ERR(1, 1165, __pyx_L1_error))
  __pyx_v_y384 = (0.0101733709945667 * __pyx_v_y377);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1166
 *         cdef double y383 = 0.00678224732971111*y375
 *         cdef double y384 = 0.0101733709945667*y377
 *         cdef double y385 = y370*y379             # <<<<<<<<<<<<<<
 *         cdef double y386 = y372*y375
 *         cdef double y387 = prst*y373
 */
  __Pyx_TraceLine(1166,0,__PYX_ERR(1, 1166, __pyx_L1_error))
  __pyx_v_y385 = (__pyx_v_y370 * __pyx_v_y379);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1167
 *         cdef double y384 = 0.0101733709945667*y377
 *         cdef double y385 = y370*y379
 *         cdef double y386 = y372*y375             # <<<<<<<<<<<<<<
 *         cdef double y387 = prst*y373
 *         cdef double y388 = y206*y210*(y133 + 0.000130208333333333*y198 + 0.000130208333333333*y202)**2
 */
  __Pyx_TraceLine(1167,0,__PYX_ERR(1, 1167, __pyx_L1_error))
  __pyx_v_y386 = (__pyx_v_y372 * __pyx_v_y375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1168
 *         cdef double y385 = y370*y379
 *         cdef double y386 = y372*y375
 *         cdef double y387 = prst*y373             # <<<<<<<<<<<<<<
 *         cdef double y388 = y206*y210*(y133 + 0.000130208333333333*y198 + 0.000130208333333333*y202)**2
 *         cdef double y389 = y17*y39
 */
  __Pyx_TraceLine(1168,0,__PYX_ERR(1, 1168, __pyx_L1_error))
  __pyx_v_y387 = (__pyx_v_prst * __pyx_v_y373);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1169
 *         cdef double y386 = y372*y375
 *         cdef double y387 = prst*y373
 *         cdef double y388 = y206*y210*(y133 + 0.000130208333333333*y198 + 0.000130208333333333*y202)**2             # <<<<<<<<<<<<<<
 *         cdef double y389 = y17*y39
 *         cdef double y390 = 12.0*y30
 */
  __Pyx_TraceLine(1169,0,__PYX_ERR(1, 1169, __pyx_L1_error))
  __pyx_v_y388 = ((__pyx_v_y206 * __pyx_v_y210) * pow(((__pyx_v_y133 + (0.000130208333333333 * __pyx_v_y198)) + (0.000130208333333333 * __pyx_v_y202)), 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1170
 *         cdef double y387 = prst*y373
 *         cdef double y388 = y206*y210*(y133 + 0.000130208333333333*y198 + 0.000130208333333333*y202)**2
 *         cdef double y389 = y17*y39             # <<<<<<<<<<<<<<
 *         cdef double y390 = 12.0*y30
 *         cdef double y391 = 2.0*y2 + 2.0*y3
 */
  __Pyx_TraceLine(1170,0,__PYX_ERR(1, 1170, __pyx_L1_error))
  __pyx_v_y389 = (__pyx_v_y17 * __pyx_v_y39);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1171
 *         cdef double y388 = y206*y210*(y133 + 0.000130208333333333*y198 + 0.000130208333333333*y202)**2
 *         cdef double y389 = y17*y39
 *         cdef double y390 = 12.0*y30             # <<<<<<<<<<<<<<
 *         cdef double y391 = 2.0*y2 + 2.0*y3
 *         cdef double y392 = 2.0*y51
 */
  __Pyx_TraceLine(1171,0,__PYX_ERR(1, 1171, __pyx_L1_error))
  __pyx_v_y390 = (12.0 * __pyx_v_y30);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1172
 *         cdef double y389 = y17*y39
 *         cdef double y390 = 12.0*y30
 *         cdef double y391 = 2.0*y2 + 2.0*y3             # <<<<<<<<<<<<<<
 *         cdef double y392 = 2.0*y51
 *         cdef double y393 = pphi*y392
 */
  __Pyx_TraceLine(1172,0,__PYX_ERR(1, 1172, __pyx_L1_error))
  __pyx_v_y391 = ((2.0 * __pyx_v_y2) + (2.0 * __pyx_v_y3));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1173
 *         cdef double y390 = 12.0*y30
 *         cdef double y391 = 2.0*y2 + 2.0*y3
 *         cdef double y392 = 2.0*y51             # <<<<<<<<<<<<<<
 *         cdef double y393 = pphi*y392
 *         cdef double y394 = pphi*y28
 */
  __Pyx_TraceLine(1173,0,__PYX_ERR(1, 1173, __pyx_L1_error))
  __pyx_v_y392 = (2.0 * __pyx_v_y51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1174
 *         cdef double y391 = 2.0*y2 + 2.0*y3
 *         cdef double y392 = 2.0*y51
 *         cdef double y393 = pphi*y392             # <<<<<<<<<<<<<<
 *         cdef double y394 = pphi*y28
 *         cdef double y395 = 2.0*y394
 */
  __Pyx_TraceLine(1174,0,__PYX_ERR(1, 1174, __pyx_L1_error))
  __pyx_v_y393 = (__pyx_v_pphi * __pyx_v_y392);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1175
 *         cdef double y392 = 2.0*y51
 *         cdef double y393 = pphi*y392
 *         cdef double y394 = pphi*y28             # <<<<<<<<<<<<<<
 *         cdef double y395 = 2.0*y394
 *         cdef double y396 = pphi**3
 */
  __Pyx_TraceLine(1175,0,__PYX_ERR(1, 1175, __pyx_L1_error))
  __pyx_v_y394 = (__pyx_v_pphi * __pyx_v_y28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1176
 *         cdef double y393 = pphi*y392
 *         cdef double y394 = pphi*y28
 *         cdef double y395 = 2.0*y394             # <<<<<<<<<<<<<<
 *         cdef double y396 = pphi**3
 *         cdef double y397 = 4.0*y396
 */
  __Pyx_TraceLine(1176,0,__PYX_ERR(1, 1176, __pyx_L1_error))
  __pyx_v_y395 = (2.0 * __pyx_v_y394);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1177
 *         cdef double y394 = pphi*y28
 *         cdef double y395 = 2.0*y394
 *         cdef double y396 = pphi**3             # <<<<<<<<<<<<<<
 *         cdef double y397 = 4.0*y396
 *         cdef double y398 = y29*y393 + y33*y395 + y389*y397
 */
  __Pyx_TraceLine(1177,0,__PYX_ERR(1, 1177, __pyx_L1_error))
  __pyx_v_y396 = pow(__pyx_v_pphi, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1178
 *         cdef double y395 = 2.0*y394
 *         cdef double y396 = pphi**3
 *         cdef double y397 = 4.0*y396             # <<<<<<<<<<<<<<
 *         cdef double y398 = y29*y393 + y33*y395 + y389*y397
 *         cdef double y399 = y17*y43
 */
  __Pyx_TraceLine(1178,0,__PYX_ERR(1, 1178, __pyx_L1_error))
  __pyx_v_y397 = (4.0 * __pyx_v_y396);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1179
 *         cdef double y396 = pphi**3
 *         cdef double y397 = 4.0*y396
 *         cdef double y398 = y29*y393 + y33*y395 + y389*y397             # <<<<<<<<<<<<<<
 *         cdef double y399 = y17*y43
 *         cdef double y400 = y19*(y393*y41 + y395*y42 + y397*y399)
 */
  __Pyx_TraceLine(1179,0,__PYX_ERR(1, 1179, __pyx_L1_error))
  __pyx_v_y398 = (((__pyx_v_y29 * __pyx_v_y393) + (__pyx_v_y33 * __pyx_v_y395)) + (__pyx_v_y389 * __pyx_v_y397));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1180
 *         cdef double y397 = 4.0*y396
 *         cdef double y398 = y29*y393 + y33*y395 + y389*y397
 *         cdef double y399 = y17*y43             # <<<<<<<<<<<<<<
 *         cdef double y400 = y19*(y393*y41 + y395*y42 + y397*y399)
 *         cdef double y401 = 4.0*y375
 */
  __Pyx_TraceLine(1180,0,__PYX_ERR(1, 1180, __pyx_L1_error))
  __pyx_v_y399 = (__pyx_v_y17 * __pyx_v_y43);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1181
 *         cdef double y398 = y29*y393 + y33*y395 + y389*y397
 *         cdef double y399 = y17*y43
 *         cdef double y400 = y19*(y393*y41 + y395*y42 + y397*y399)             # <<<<<<<<<<<<<<
 *         cdef double y401 = 4.0*y375
 *         cdef double y402 = 6.0*y377
 */
  __Pyx_TraceLine(1181,0,__PYX_ERR(1, 1181, __pyx_L1_error))
  __pyx_v_y400 = (__pyx_v_y19 * (((__pyx_v_y393 * __pyx_v_y41) + (__pyx_v_y395 * __pyx_v_y42)) + (__pyx_v_y397 * __pyx_v_y399)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1182
 *         cdef double y399 = y17*y43
 *         cdef double y400 = y19*(y393*y41 + y395*y42 + y397*y399)
 *         cdef double y401 = 4.0*y375             # <<<<<<<<<<<<<<
 *         cdef double y402 = 6.0*y377
 *         cdef double y403 = prst*y374 + y365*y401 + y366*y401 + y368*y402 + y369*y402 + y371*y401 + 589.775011960583*y376 - 67.9050514751178*y378 + 11.8620273619492*y381 + 0.975638950243592*y382 + 8.0*y385 + 5.09109256556341e-19*y386
 */
  __Pyx_TraceLine(1182,0,__PYX_ERR(1, 1182, __pyx_L1_error))
  __pyx_v_y401 = (4.0 * __pyx_v_y375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1183
 *         cdef double y400 = y19*(y393*y41 + y395*y42 + y397*y399)
 *         cdef double y401 = 4.0*y375
 *         cdef double y402 = 6.0*y377             # <<<<<<<<<<<<<<
 *         cdef double y403 = prst*y374 + y365*y401 + y366*y401 + y368*y402 + y369*y402 + y371*y401 + 589.775011960583*y376 - 67.9050514751178*y378 + 11.8620273619492*y381 + 0.975638950243592*y382 + 8.0*y385 + 5.09109256556341e-19*y386
 *         cdef double y404 = y209*y211
 */
  __Pyx_TraceLine(1183,0,__PYX_ERR(1, 1183, __pyx_L1_error))
  __pyx_v_y402 = (6.0 * __pyx_v_y377);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1184
 *         cdef double y401 = 4.0*y375
 *         cdef double y402 = 6.0*y377
 *         cdef double y403 = prst*y374 + y365*y401 + y366*y401 + y368*y402 + y369*y402 + y371*y401 + 589.775011960583*y376 - 67.9050514751178*y378 + 11.8620273619492*y381 + 0.975638950243592*y382 + 8.0*y385 + 5.09109256556341e-19*y386             # <<<<<<<<<<<<<<
 *         cdef double y404 = y209*y211
 *         cdef double y405 = y195*y235
 */
  __Pyx_TraceLine(1184,0,__PYX_ERR(1, 1184, __pyx_L1_error))
  __pyx_v_y403 = ((((((((((((__pyx_v_prst * __pyx_v_y374) + (__pyx_v_y365 * __pyx_v_y401)) + (__pyx_v_y366 * __pyx_v_y401)) + (__pyx_v_y368 * __pyx_v_y402)) + (__pyx_v_y369 * __pyx_v_y402)) + (__pyx_v_y371 * __pyx_v_y401)) + (589.775011960583 * __pyx_v_y376)) - (67.9050514751178 * __pyx_v_y378)) + (11.8620273619492 * __pyx_v_y381)) + (0.975638950243592 * __pyx_v_y382)) + (8.0 * __pyx_v_y385)) + (5.09109256556341e-19 * __pyx_v_y386));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1185
 *         cdef double y402 = 6.0*y377
 *         cdef double y403 = prst*y374 + y365*y401 + y366*y401 + y368*y402 + y369*y402 + y371*y401 + 589.775011960583*y376 - 67.9050514751178*y378 + 11.8620273619492*y381 + 0.975638950243592*y382 + 8.0*y385 + 5.09109256556341e-19*y386
 *         cdef double y404 = y209*y211             # <<<<<<<<<<<<<<
 *         cdef double y405 = y195*y235
 *         cdef double y406 = 16.0*y12
 */
  __Pyx_TraceLine(1185,0,__PYX_ERR(1, 1185, __pyx_L1_error))
  __pyx_v_y404 = (__pyx_v_y209 * __pyx_v_y211);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1186
 *         cdef double y403 = prst*y374 + y365*y401 + y366*y401 + y368*y402 + y369*y402 + y371*y401 + 589.775011960583*y376 - 67.9050514751178*y378 + 11.8620273619492*y381 + 0.975638950243592*y382 + 8.0*y385 + 5.09109256556341e-19*y386
 *         cdef double y404 = y209*y211
 *         cdef double y405 = y195*y235             # <<<<<<<<<<<<<<
 *         cdef double y406 = 16.0*y12
 *         cdef double y407 = y203*y206*y299/(y301*y67 + 4.0)
 */
  __Pyx_TraceLine(1186,0,__PYX_ERR(1, 1186, __pyx_L1_error))
  __pyx_v_y405 = (__pyx_v_y195 * __pyx_v_y235);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1187
 *         cdef double y404 = y209*y211
 *         cdef double y405 = y195*y235
 *         cdef double y406 = 16.0*y12             # <<<<<<<<<<<<<<
 *         cdef double y407 = y203*y206*y299/(y301*y67 + 4.0)
 *         cdef double y408 = dSO*y4
 */
  __Pyx_TraceLine(1187,0,__PYX_ERR(1, 1187, __pyx_L1_error))
  __pyx_v_y406 = (16.0 * __pyx_v_y12);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1188
 *         cdef double y405 = y195*y235
 *         cdef double y406 = 16.0*y12
 *         cdef double y407 = y203*y206*y299/(y301*y67 + 4.0)             # <<<<<<<<<<<<<<
 *         cdef double y408 = dSO*y4
 *         cdef double y409 = 4.0*y394
 */
  __Pyx_TraceLine(1188,0,__PYX_ERR(1, 1188, __pyx_L1_error))
  __pyx_v_y407 = (((__pyx_v_y203 * __pyx_v_y206) * __pyx_v_y299) / ((__pyx_v_y301 * __pyx_v_y67) + 4.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1189
 *         cdef double y406 = 16.0*y12
 *         cdef double y407 = y203*y206*y299/(y301*y67 + 4.0)
 *         cdef double y408 = dSO*y4             # <<<<<<<<<<<<<<
 *         cdef double y409 = 4.0*y394
 *         cdef double y410 = pphi*y26
 */
  __Pyx_TraceLine(1189,0,__PYX_ERR(1, 1189, __pyx_L1_error))
  __pyx_v_y408 = (__pyx_v_dSO * __pyx_v_y4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1190
 *         cdef double y407 = y203*y206*y299/(y301*y67 + 4.0)
 *         cdef double y408 = dSO*y4
 *         cdef double y409 = 4.0*y394             # <<<<<<<<<<<<<<
 *         cdef double y410 = pphi*y26
 *         cdef double y411 = y396*y406
 */
  __Pyx_TraceLine(1190,0,__PYX_ERR(1, 1190, __pyx_L1_error))
  __pyx_v_y409 = (4.0 * __pyx_v_y394);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1191
 *         cdef double y408 = dSO*y4
 *         cdef double y409 = 4.0*y394
 *         cdef double y410 = pphi*y26             # <<<<<<<<<<<<<<
 *         cdef double y411 = y396*y406
 *         cdef double y412 = pphi*y71
 */
  __Pyx_TraceLine(1191,0,__PYX_ERR(1, 1191, __pyx_L1_error))
  __pyx_v_y410 = (__pyx_v_pphi * __pyx_v_y26);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1192
 *         cdef double y409 = 4.0*y394
 *         cdef double y410 = pphi*y26
 *         cdef double y411 = y396*y406             # <<<<<<<<<<<<<<
 *         cdef double y412 = pphi*y71
 *         cdef double y413 = y318*y412
 */
  __Pyx_TraceLine(1192,0,__PYX_ERR(1, 1192, __pyx_L1_error))
  __pyx_v_y411 = (__pyx_v_y396 * __pyx_v_y406);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1193
 *         cdef double y410 = pphi*y26
 *         cdef double y411 = y396*y406
 *         cdef double y412 = pphi*y71             # <<<<<<<<<<<<<<
 *         cdef double y413 = y318*y412
 *         cdef double y414 = -2.0*pphi*y51 + y102*y413
 */
  __Pyx_TraceLine(1193,0,__PYX_ERR(1, 1193, __pyx_L1_error))
  __pyx_v_y412 = (__pyx_v_pphi * __pyx_v_y71);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1194
 *         cdef double y411 = y396*y406
 *         cdef double y412 = pphi*y71
 *         cdef double y413 = y318*y412             # <<<<<<<<<<<<<<
 *         cdef double y414 = -2.0*pphi*y51 + y102*y413
 *         cdef double y415 = -y414
 */
  __Pyx_TraceLine(1194,0,__PYX_ERR(1, 1194, __pyx_L1_error))
  __pyx_v_y413 = (__pyx_v_y318 * __pyx_v_y412);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1195
 *         cdef double y412 = pphi*y71
 *         cdef double y413 = y318*y412
 *         cdef double y414 = -2.0*pphi*y51 + y102*y413             # <<<<<<<<<<<<<<
 *         cdef double y415 = -y414
 * 
 */
  __Pyx_TraceLine(1195,0,__PYX_ERR(1, 1195, __pyx_L1_error))
  __pyx_v_y414 = (((-2.0 * __pyx_v_pphi) * __pyx_v_y51) + (__pyx_v_y102 * __pyx_v_y413));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1196
 *         cdef double y413 = y318*y412
 *         cdef double y414 = -2.0*pphi*y51 + y102*y413
 *         cdef double y415 = -y414             # <<<<<<<<<<<<<<
 * 
 *         # Evaluate Hamiltonian
 */
  __Pyx_TraceLine(1196,0,__PYX_ERR(1, 1196, __pyx_L1_error))
  __pyx_v_y415 = (-__pyx_v_y414);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1200
 *         # Evaluate Hamiltonian
 *         cdef double H,xi
 *         H,xi = self._call(q,p,chi_1,chi_2,m_1,m_2)             # <<<<<<<<<<<<<<
 * 
 *         # Evaluate Heff Jacobian
 */
  __Pyx_TraceLine(1200,0,__PYX_ERR(1, 1200, __pyx_L1_error))
  __pyx_t_1 = ((struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self->__pyx_base.__pyx_vtab)->_call(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(1, 1200, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_9);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 1200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
    index = 0; __pyx_t_2 = __pyx_t_14(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_9 = __pyx_t_14(__pyx_t_8); if (unlikely(!__pyx_t_9)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_8), 2) < 0) __PYX_ERR(1, 1200, __pyx_L1_error)
    __pyx_t_14 = NULL;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_14 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(1, 1200, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1200, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_t_9); if (unlikely((__pyx_t_15 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1200, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_v_H = __pyx_t_13;
  __pyx_v_xi = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1203
 * 
 *         # Evaluate Heff Jacobian
 *         cdef double dHeffdr = 0.5*x169*(x160*x162*(-x171*(-x150*(875.0*nu + 1125.0) + 0.234375*x165 + x166*(10.0*nu - 15.0)) - x178 - x38*(0.5*x163 + x164 + 4.5*x4)) - x160*x167*(-x11*x5 - x16*x170)/x161**2 + x168*(-663.496888455656*nu*r**(-5.5)*x54 - nu*x25*x64 + 39.6112800271521*nu*x55*x57 + 6.78168402777778e-8*x11*x141*x142*x146*x154*x158*x7 + x11*x54*(118.4*x174 - 51.6952380952381*x63) + 7.59859378406358e-45*x112*x135*x138*x154*x182*x54*x86*x87 - 9.25454462627843e-34*x112*x180*x181/x134**3 - 2.24091649004576e-37*x135*x140*x142*x154*x180*x183*x38 + 1.69542100694444e-8*x140*x141*x142*x146*x154*x38*(38400.0*x10*x109*x145*x155*x90 + 7680.0*x109*x145*x155*x173*x37 + 7680.0*x109*x155*x180*x37*x90 - x11*(x147*(36.0*nu - 9.0) + x148*(-63.0*X_1 + 63.0*X_2) + x4*(9.0*nu + 8.4375)) - x156*x177 - x172 - x38*(x148*x153 + 0.0625*x149*x4 + 0.0625*x151) - 2.29252167428035e-22*x145*x157*x182*x37/x125) + 1.69542100694444e-8*x140*x141*x142*x146*x158*x182*x38 - 8.47710503472222e-8*x159*x171 - x24*x76 + x25*x28*x4*x80*x84 + x28*x4*x49*x80*(x175 + x81 + x82)/x83**2 - x30 - x33*x57*x73 - x39*x54*x78 - x4*x85 - 3.70688355060912*x58*x62 - 2.0*x65*x69 - 3.0*x68*x79 - 2.0*x70*x74 - 4.41515887225116e-12*x140*x146*x183*x184*x185/x111**3 - 6.62902677807736e-23*x135*x181*x184/x111**5 + 1.01821851311268e-18*x112*x125*x135*x138*x54*x7**3/r**12 - 1.65460508380811e-18*x139/r**14)) + x9*(-dSO*x11*x12*x13 + pphi*x17*x18*(-x15*(-0.0625*nu + 1.07291666666667*x31 + 0.15625) - x25*x41 - x30*x42 - x34*x43 - x40*x44) + pphi*x3*(-x15*(-11.0625*nu + 1.13541666666667*x31 - 0.15625) - x25*x26 - x27*x30 - x32*x34 - x35*x40) - x13*x23*x24 - 0.0833333333333333*x16*x20) - 0.25*(r*(x6 - 2.0) + x6 + x7)*(pphi*x52 + pphi*x53 + x13*x45 + x13*x48 + x20*x47)/(x7 + 0.5*x8)**2             # <<<<<<<<<<<<<<
 * 
 *         cdef double dHeffdphi = 0
 */
  __Pyx_TraceLine(1203,0,__PYX_ERR(1, 1203, __pyx_L1_error))
  __pyx_t_15 = __Pyx_SoftComplexToDouble(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((0.5 * __pyx_v_x169), 0), __Pyx_c_sum_double(__pyx_t_double_complex_from_parts((((__pyx_v_x160 * __pyx_v_x162) * ((((-__pyx_v_x171) * ((((-__pyx_v_x150) * ((875.0 * __pyx_v_nu) + 1125.0)) + (0.234375 * __pyx_v_x165)) + (__pyx_v_x166 * ((10.0 * __pyx_v_nu) - 15.0)))) - __pyx_v_x178) - (__pyx_v_x38 * (((0.5 * __pyx_v_x163) + __pyx_v_x164) + (4.5 * __pyx_v_x4))))) - (((__pyx_v_x160 * __pyx_v_x167) * (((-__pyx_v_x11) * __pyx_v_x5) - (__pyx_v_x16 * __pyx_v_x170))) / pow(__pyx_v_x161, 2.0))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_x168, 0), __Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((-663.496888455656 * __pyx_v_nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-5.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_x54, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_nu * __pyx_v_x25) * __pyx_v_x64), 0)), __pyx_t_double_complex_from_parts((((39.6112800271521 * __pyx_v_nu) * __pyx_v_x55) * __pyx_v_x57), 0)), __pyx_t_double_complex_from_parts((((((((6.78168402777778e-8 * __pyx_v_x11) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x158) * __pyx_v_x7), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x11 * __pyx_v_x54) * ((118.4 * __pyx_v_x174) - (51.6952380952381 * __pyx_v_x63))), 0)), __pyx_t_double_complex_from_parts(((((((((7.59859378406358e-45 * __pyx_v_x112) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x154) * __pyx_v_x182) * __pyx_v_x54) * __pyx_v_x86) * __pyx_v_x87), 0)), __pyx_t_double_complex_from_parts(((((9.25454462627843e-34 * __pyx_v_x112) * __pyx_v_x180) * __pyx_v_x181) / pow(__pyx_v_x134, 3.0)), 0)), __pyx_t_double_complex_from_parts((((((((2.24091649004576e-37 * __pyx_v_x135) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x154) * __pyx_v_x180) * __pyx_v_x183) * __pyx_v_x38), 0)), __pyx_t_double_complex_from_parts((((((((1.69542100694444e-8 * __pyx_v_x140) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x38) * ((((((((((((38400.0 * __pyx_v_x10) * __pyx_v_x109) * __pyx_v_x145) * __pyx_v_x155) * __pyx_v_x90) + (((((7680.0 * __pyx_v_x109) * __pyx_v_x145) * __pyx_v_x155) * __pyx_v_x173) * __pyx_v_x37)) + (((((7680.0 * __pyx_v_x109) * __pyx_v_x155) * __pyx_v_x180) * __pyx_v_x37) * __pyx_v_x90)) - (__pyx_v_x11 * (((__pyx_v_x147 * ((36.0 * __pyx_v_nu) - 9.0)) + (__pyx_v_x148 * ((-63.0 * __pyx_v_X_1) + (63.0 * __pyx_v_X_2)))) + (__pyx_v_x4 * ((9.0 * __pyx_v_nu) + 8.4375))))) - (__pyx_v_x156 * __pyx_v_x177)) - __pyx_v_x172) - (__pyx_v_x38 * (((__pyx_v_x148 * __pyx_v_x153) + ((0.0625 * __pyx_v_x149) * __pyx_v_x4)) + (0.0625 * __pyx_v_x151)))) - (((((2.29252167428035e-22 * __pyx_v_x145) * __pyx_v_x157) * __pyx_v_x182) * __pyx_v_x37) / __pyx_v_x125))), 0)), __pyx_t_double_complex_from_parts((((((((1.69542100694444e-8 * __pyx_v_x140) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x158) * __pyx_v_x182) * __pyx_v_x38), 0)), __pyx_t_double_complex_from_parts(((8.47710503472222e-8 * __pyx_v_x159) * __pyx_v_x171), 0)), __pyx_t_double_complex_from_parts((__pyx_v_x24 * __pyx_v_x76), 0)), __pyx_t_double_complex_from_parts(((((__pyx_v_x25 * __pyx_v_x28) * __pyx_v_x4) * __pyx_v_x80) * __pyx_v_x84), 0)), __pyx_t_double_complex_from_parts((((((__pyx_v_x28 * __pyx_v_x4) * __pyx_v_x49) * __pyx_v_x80) * ((__pyx_v_x175 + __pyx_v_x81) + __pyx_v_x82)) / pow(__pyx_v_x83, 2.0)), 0)), __pyx_t_double_complex_from_parts(__pyx_v_x30, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x33 * __pyx_v_x57) * __pyx_v_x73), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x39 * __pyx_v_x54) * __pyx_v_x78), 0)), __pyx_t_double_complex_from_parts((__pyx_v_x4 * __pyx_v_x85), 0)), __pyx_t_double_complex_from_parts(((3.70688355060912 * __pyx_v_x58) * __pyx_v_x62), 0)), __pyx_t_double_complex_from_parts(((2.0 * __pyx_v_x65) * __pyx_v_x69), 0)), __pyx_t_double_complex_from_parts(((3.0 * __pyx_v_x68) * __pyx_v_x79), 0)), __pyx_t_double_complex_from_parts(((2.0 * __pyx_v_x70) * __pyx_v_x74), 0)), __pyx_t_double_complex_from_parts(((((((4.41515887225116e-12 * __pyx_v_x140) * __pyx_v_x146) * __pyx_v_x183) * __pyx_v_x184) * __pyx_v_x185) / pow(__pyx_v_x111, 3.0)), 0)), __pyx_t_double_complex_from_parts(((((6.62902677807736e-23 * __pyx_v_x135) * __pyx_v_x181) * __pyx_v_x184) / pow(__pyx_v_x111, 5.0)), 0)), __pyx_t_double_complex_from_parts((((((((1.01821851311268e-18 * __pyx_v_x112) * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x54) * pow(__pyx_v_x7, 3.0)) / pow(__pyx_v_r, 12.0)), 0)), __pyx_t_double_complex_from_parts(((1.65460508380811e-18 * __pyx_v_x139) / pow(__pyx_v_r, 14.0)), 0))))), __pyx_t_double_complex_from_parts((__pyx_v_x9 * ((((((((-__pyx_v_dSO) * __pyx_v_x11) * __pyx_v_x12) * __pyx_v_x13) + (((__pyx_v_pphi * __pyx_v_x17) * __pyx_v_x18) * ((((((-__pyx_v_x15) * (((-0.0625 * __pyx_v_nu) + (1.07291666666667 * __pyx_v_x31)) + 0.15625)) - (__pyx_v_x25 * __pyx_v_x41)) - (__pyx_v_x30 * __pyx_v_x42)) - (__pyx_v_x34 * __pyx_v_x43)) - (__pyx_v_x40 * __pyx_v_x44)))) + ((__pyx_v_pphi * __pyx_v_x3) * ((((((-__pyx_v_x15) * (((-11.0625 * __pyx_v_nu) + (1.13541666666667 * __pyx_v_x31)) - 0.15625)) - (__pyx_v_x25 * __pyx_v_x26)) - (__pyx_v_x27 * __pyx_v_x30)) - (__pyx_v_x32 * __pyx_v_x34)) - (__pyx_v_x35 * __pyx_v_x40)))) - ((__pyx_v_x13 * __pyx_v_x23) * __pyx_v_x24)) - ((0.0833333333333333 * __pyx_v_x16) * __pyx_v_x20))), 0)), __pyx_t_double_complex_from_parts((((0.25 * (((__pyx_v_r * (__pyx_v_x6 - 2.0)) + __pyx_v_x6) + __pyx_v_x7)) * (((((__pyx_v_pphi * __pyx_v_x52) + (__pyx_v_pphi * __pyx_v_x53)) + (__pyx_v_x13 * __pyx_v_x45)) + (__pyx_v_x13 * __pyx_v_x48)) + (__pyx_v_x20 * __pyx_v_x47))) / pow((__pyx_v_x7 + (0.5 * __pyx_v_x8)), 2.0)), 0)), 1); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1203, __pyx_L1_error)
  __pyx_v_dHeffdr = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1205
 *         cdef double dHeffdr = 0.5*x169*(x160*x162*(-x171*(-x150*(875.0*nu + 1125.0) + 0.234375*x165 + x166*(10.0*nu - 15.0)) - x178 - x38*(0.5*x163 + x164 + 4.5*x4)) - x160*x167*(-x11*x5 - x16*x170)/x161**2 + x168*(-663.496888455656*nu*r**(-5.5)*x54 - nu*x25*x64 + 39.6112800271521*nu*x55*x57 + 6.78168402777778e-8*x11*x141*x142*x146*x154*x158*x7 + x11*x54*(118.4*x174 - 51.6952380952381*x63) + 7.59859378406358e-45*x112*x135*x138*x154*x182*x54*x86*x87 - 9.25454462627843e-34*x112*x180*x181/x134**3 - 2.24091649004576e-37*x135*x140*x142*x154*x180*x183*x38 + 1.69542100694444e-8*x140*x141*x142*x146*x154*x38*(38400.0*x10*x109*x145*x155*x90 + 7680.0*x109*x145*x155*x173*x37 + 7680.0*x109*x155*x180*x37*x90 - x11*(x147*(36.0*nu - 9.0) + x148*(-63.0*X_1 + 63.0*X_2) + x4*(9.0*nu + 8.4375)) - x156*x177 - x172 - x38*(x148*x153 + 0.0625*x149*x4 + 0.0625*x151) - 2.29252167428035e-22*x145*x157*x182*x37/x125) + 1.69542100694444e-8*x140*x141*x142*x146*x158*x182*x38 - 8.47710503472222e-8*x159*x171 - x24*x76 + x25*x28*x4*x80*x84 + x28*x4*x49*x80*(x175 + x81 + x82)/x83**2 - x30 - x33*x57*x73 - x39*x54*x78 - x4*x85 - 3.70688355060912*x58*x62 - 2.0*x65*x69 - 3.0*x68*x79 - 2.0*x70*x74 - 4.41515887225116e-12*x140*x146*x183*x184*x185/x111**3 - 6.62902677807736e-23*x135*x181*x184/x111**5 + 1.01821851311268e-18*x112*x125*x135*x138*x54*x7**3/r**12 - 1.65460508380811e-18*x139/r**14)) + x9*(-dSO*x11*x12*x13 + pphi*x17*x18*(-x15*(-0.0625*nu + 1.07291666666667*x31 + 0.15625) - x25*x41 - x30*x42 - x34*x43 - x40*x44) + pphi*x3*(-x15*(-11.0625*nu + 1.13541666666667*x31 - 0.15625) - x25*x26 - x27*x30 - x32*x34 - x35*x40) - x13*x23*x24 - 0.0833333333333333*x16*x20) - 0.25*(r*(x6 - 2.0) + x6 + x7)*(pphi*x52 + pphi*x53 + x13*x45 + x13*x48 + x20*x47)/(x7 + 0.5*x8)**2
 * 
 *         cdef double dHeffdphi = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)
 */
  __Pyx_TraceLine(1205,0,__PYX_ERR(1, 1205, __pyx_L1_error))
  __pyx_v_dHeffdphi = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1207
 *         cdef double dHeffdphi = 0
 * 
 *         cdef double dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)             # <<<<<<<<<<<<<<
 * 
 *         cdef double dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)
 */
  __Pyx_TraceLine(1207,0,__PYX_ERR(1, 1207, __pyx_L1_error))
  __pyx_v_dHeffdpr = (__pyx_v_x191 * ((((((((((((((11.8620273619492 * __pyx_v_nu) * __pyx_v_x188) * __pyx_v_x60) + ((((((3.39084201388889e-8 * __pyx_v_prst) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x158) * __pyx_v_x185)) + ((__pyx_v_x11 * __pyx_v_x189) * __pyx_v_x78)) + (((((((5.09109256556341e-19 * __pyx_v_x112) * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x186) * __pyx_v_x86) * __pyx_v_x87)) + ((__pyx_v_x15 * __pyx_v_x189) * __pyx_v_x68)) + ((__pyx_v_x15 * __pyx_v_x190) * __pyx_v_x73)) + ((589.775011960583 * __pyx_v_x186) * __pyx_v_x56)) - ((67.9050514751178 * __pyx_v_x187) * __pyx_v_x59)) + (((8.0 * __pyx_v_x188) * __pyx_v_x25) * __pyx_v_x75)) + ((0.975638950243592 * __pyx_v_x188) * __pyx_v_x63)) + (__pyx_v_x189 * __pyx_v_x66)) + (__pyx_v_x190 * __pyx_v_x71)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1209
 *         cdef double dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)
 * 
 *         cdef double dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)             # <<<<<<<<<<<<<<
 * 
 *         # Evaluate Heff Hessian
 */
  __Pyx_TraceLine(1209,0,__PYX_ERR(1, 1209, __pyx_L1_error))
  __pyx_v_dHeffdpphi = ((__pyx_v_x191 * (((2.0 * __pyx_v_pphi) * __pyx_v_x25) - ((((__pyx_v_pphi * __pyx_v_x49) * __pyx_v_x5) * __pyx_v_x80) * __pyx_v_x84))) + (__pyx_v_x9 * (((((((__pyx_v_x13 * (((__pyx_v_x193 * __pyx_v_x27) + (__pyx_v_x194 * __pyx_v_x32)) + (__pyx_v_x195 * __pyx_v_x35))) + (__pyx_v_x19 * __pyx_v_x47)) + (__pyx_v_x20 * (((__pyx_v_x193 * __pyx_v_x42) + (__pyx_v_x194 * __pyx_v_x43)) + (__pyx_v_x195 * __pyx_v_x44)))) + (__pyx_v_x3 * __pyx_v_x45)) + (__pyx_v_x3 * __pyx_v_x48)) + __pyx_v_x52) + __pyx_v_x53)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1212
 * 
 *         # Evaluate Heff Hessian
 *         cdef double d2Heffdr2 = y10*(y12*y13*y15 + y14*y25*y26 + y14*(y17*(-33.1875*nu + 3.40625*y32 - 0.46875) + y28*(1.4375*nu - 0.1875) + y29*y31 + y33*y35 + y37*y40) + y17*y18*y22 + y22*(y17*(-0.1875*nu + 3.21875*y32 + 0.46875) + y28*(0.6875*nu + 0.1875) + y31*y41 + y35*y42 + y37*y44)) - 0.25*y206*y299**2 + 0.5*y362*(-y193*y210*y235*y302 + 8.0*y193*y203*(y208*y28*y65 - y300)**2/y194**3 + y195*y298*(-y12*(y196 + 2.0*y197 + 9.0*y5) + 61440.0*y128*y130*y27 + 15360.0*y128*y16*y217 - 2.63243347181853e-19*y233 - y36*(0.46875*y199 - y213*y304 + y214*y305) - 4.0*y48) + y204*(3649.23288650611*r**(-6.5)*y238 + 6.0*y101*y87 + y101*(51.6952380952381*nu*y51 - y241*y51) + y108*y320*(y314 + y8) - 6.103515625e-7*y12*y189*y6 - 8.0*y12*y242*y76 + 1.62760416666667e-6*y134*y349*y350 + 1.16714400523217e-40*y159*y188*y257*y285*y344 - 2.5455462827817e-17*y164*y165*y250 + 7.59859378406358e-45*y182*y323*y331 + y182*y337*(-y11*y131*y257*y360 + y12*(0.25*y161*y288 + 0.5*y24*y289 + y5*(y287 + 33.75)) + y128*y185*y308 - y130*y310*y357 + 153600.0*y131*y27*y359 - 2.29252167428035e-21*y132*y172*y292 + y132*y257*y358 + y172*y217*y307*y358 + y184*y186*y326 - y185*y311 - 1.31621673590926e-18*y233*y359 - y291*y295*y331 + 7.85795675813156e-45*y292*y293*y296 - y293*y309*y360 + y306 + 15360.0*y309*y357 + y312*y361 - y316*y361 + y36*(y176*y20*(130.0*nu + 2245.0) + 0.3125*y179 + y290*(-5855.0*nu - 4305.0)) + 2.81299777100766e-6*y294*y322/y148**3) + y187*y331*y337 + 1.35633680555556e-7*y189*y28 + 4.66406554828496e-24*y191*y258*y271*y330 - 178.250760122184*y237*y81 + y243*y37 + y246*y320*y71*y8 - y258*y263*y326 + y26*y93 + y26*y98 + 5.08626302083333e-7*y269*y303 - y272*y274*y326 - 1.79273319203661e-36*y273*y340 + 2.24091649004576e-36*y273*y342 - y275*y282*y317 - 7.91520185839956e-48*y277*y279*y333*y76 + 0.243909737560898*y28*y84 - 4.41515887225116e-12*y284*y317*y350 - 3.53212709780093e-11*y286*y340 + 4.41515887225116e-11*y286*y342 + y297*y338*y355 + y31 + y318*y72 - y319*y53 - y321*y72 + 2.69825540021952e-16*y322*y323 + 2.40618160283239e-32*y327*y328 - 1.48072714020455e-32*y328*y329 - 1.97563438385653e-43*y332*y334 + 1.72354696230011e-21*y332*y348 + 1.21577500545017e-43*y334*y335 - 1.10501271569469e-58*y334*y336 - 1.06064428449238e-21*y335*y348 + 9.64015065237337e-37*y336*y348 + y339*y341 - y339*y343 + y34*y91 + y34*y96 + y341*y354 - y343*y354 - y345*y347 - y345*y352 - y347*y356 - y352*y356 + 12.9740924271319*y78*y83 + 2.88925109089694e-20*y262*y330/y158**4 + 4.07287405245073e-17*y281*y349/y133**6 - 32.0*y108*y30*(r*y18 + y102*y18 + y27)**2/y104**3 + 6.10931107867609e-18*y164*y190/r**11 + 2.31644711733135e-17*y248/r**15) - y211*y298*y302 - y212*(y300*(12.0*y71 + 6.0) + y34*y5) + y236*(y303*(1.40625*y199 - y304*(2625.0*nu + 3375.0) + y305*(30.0*nu - 45.0)) + y317 + y36*(0.5*y161*(20.0*nu + 5.0) + y24*(-25.0*X_1 + 25.0*X_2) + 22.5*y5))) - y63*(4.0*r + y0*y45 + y9)*(pphi*y19*y20*y60 + pphi*y4*y58 - 2.0*y14*y50 - y15*y47 - y22*y49) + (-1.5*r*y62 + 1.0*(r + 0.5*y1 + 0.5*y64 + y65)**2/y61**3)*(pphi*y74 + pphi*y75 + y15*y66 + y22*y68 + y69*y70)             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdphi2 = 0
 */
  __Pyx_TraceLine(1212,0,__PYX_ERR(1, 1212, __pyx_L1_error))
  __pyx_t_15 = __Pyx_SoftComplexToDouble(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__pyx_t_double_complex_from_parts(((__pyx_v_y10 * ((((((__pyx_v_y12 * __pyx_v_y13) * __pyx_v_y15) + ((__pyx_v_y14 * __pyx_v_y25) * __pyx_v_y26)) + (__pyx_v_y14 * (((((__pyx_v_y17 * (((-33.1875 * __pyx_v_nu) + (3.40625 * __pyx_v_y32)) - 0.46875)) + (__pyx_v_y28 * ((1.4375 * __pyx_v_nu) - 0.1875))) + (__pyx_v_y29 * __pyx_v_y31)) + (__pyx_v_y33 * __pyx_v_y35)) + (__pyx_v_y37 * __pyx_v_y40)))) + ((__pyx_v_y17 * __pyx_v_y18) * __pyx_v_y22)) + (__pyx_v_y22 * (((((__pyx_v_y17 * (((-0.1875 * __pyx_v_nu) + (3.21875 * __pyx_v_y32)) + 0.46875)) + (__pyx_v_y28 * ((0.6875 * __pyx_v_nu) + 0.1875))) + (__pyx_v_y31 * __pyx_v_y41)) + (__pyx_v_y35 * __pyx_v_y42)) + (__pyx_v_y37 * __pyx_v_y44))))) - ((0.25 * __pyx_v_y206) * pow(__pyx_v_y299, 2.0))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts((0.5 * __pyx_v_y362), 0), __Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__pyx_t_double_complex_from_parts(((((((-__pyx_v_y193) * __pyx_v_y210) * __pyx_v_y235) * __pyx_v_y302) + ((((8.0 * __pyx_v_y193) * __pyx_v_y203) * pow((((__pyx_v_y208 * __pyx_v_y28) * __pyx_v_y65) - __pyx_v_y300), 2.0)) / pow(__pyx_v_y194, 3.0))) + ((__pyx_v_y195 * __pyx_v_y298) * (((((((-__pyx_v_y12) * ((__pyx_v_y196 + (2.0 * __pyx_v_y197)) + (9.0 * __pyx_v_y5))) + (((61440.0 * __pyx_v_y128) * __pyx_v_y130) * __pyx_v_y27)) + (((15360.0 * __pyx_v_y128) * __pyx_v_y16) * __pyx_v_y217)) - (2.63243347181853e-19 * __pyx_v_y233)) - (__pyx_v_y36 * (((0.46875 * __pyx_v_y199) - (__pyx_v_y213 * __pyx_v_y304)) + (__pyx_v_y214 * __pyx_v_y305)))) - (4.0 * __pyx_v_y48)))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_y204, 0), __Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts(3649.23288650611, 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-6.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_y238, 0)), __pyx_t_double_complex_from_parts(((6.0 * __pyx_v_y101) * __pyx_v_y87), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y101 * (((51.6952380952381 * __pyx_v_nu) * __pyx_v_y51) - (__pyx_v_y241 * __pyx_v_y51))), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y108 * __pyx_v_y320) * (__pyx_v_y314 + __pyx_v_y8)), 0)), __pyx_t_double_complex_from_parts((((6.103515625e-7 * __pyx_v_y12) * __pyx_v_y189) * __pyx_v_y6), 0)), __pyx_t_double_complex_from_parts((((8.0 * __pyx_v_y12) * __pyx_v_y242) * __pyx_v_y76), 0)), __pyx_t_double_complex_from_parts((((1.62760416666667e-6 * __pyx_v_y134) * __pyx_v_y349) * __pyx_v_y350), 0)), __pyx_t_double_complex_from_parts((((((1.16714400523217e-40 * __pyx_v_y159) * __pyx_v_y188) * __pyx_v_y257) * __pyx_v_y285) * __pyx_v_y344), 0)), __pyx_t_double_complex_from_parts((((2.5455462827817e-17 * __pyx_v_y164) * __pyx_v_y165) * __pyx_v_y250), 0)), __pyx_t_double_complex_from_parts((((7.59859378406358e-45 * __pyx_v_y182) * __pyx_v_y323) * __pyx_v_y331), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y182 * __pyx_v_y337) * (((((((((((((((((((((((-__pyx_v_y11) * __pyx_v_y131) * __pyx_v_y257) * __pyx_v_y360) + (__pyx_v_y12 * ((((0.25 * __pyx_v_y161) * __pyx_v_y288) + ((0.5 * __pyx_v_y24) * __pyx_v_y289)) + (__pyx_v_y5 * (__pyx_v_y287 + 33.75))))) + ((__pyx_v_y128 * __pyx_v_y185) * __pyx_v_y308)) - ((__pyx_v_y130 * __pyx_v_y310) * __pyx_v_y357)) + (((153600.0 * __pyx_v_y131) * __pyx_v_y27) * __pyx_v_y359)) - (((2.29252167428035e-21 * __pyx_v_y132) * __pyx_v_y172) * __pyx_v_y292)) + ((__pyx_v_y132 * __pyx_v_y257) * __pyx_v_y358)) + (((__pyx_v_y172 * __pyx_v_y217) * __pyx_v_y307) * __pyx_v_y358)) + ((__pyx_v_y184 * __pyx_v_y186) * __pyx_v_y326)) - (__pyx_v_y185 * __pyx_v_y311)) - ((1.31621673590926e-18 * __pyx_v_y233) * __pyx_v_y359)) - ((__pyx_v_y291 * __pyx_v_y295) * __pyx_v_y331)) + (((7.85795675813156e-45 * __pyx_v_y292) * __pyx_v_y293) * __pyx_v_y296)) - ((__pyx_v_y293 * __pyx_v_y309) * __pyx_v_y360)) + __pyx_v_y306) + ((15360.0 * __pyx_v_y309) * __pyx_v_y357)) + (__pyx_v_y312 * __pyx_v_y361)) - (__pyx_v_y316 * __pyx_v_y361)) + (__pyx_v_y36 * ((((__pyx_v_y176 * __pyx_v_y20) * ((130.0 * __pyx_v_nu) + 2245.0)) + (0.3125 * __pyx_v_y179)) + (__pyx_v_y290 * ((-5855.0 * __pyx_v_nu) - 4305.0))))) + (((2.81299777100766e-6 * __pyx_v_y294) * __pyx_v_y322) / pow(__pyx_v_y148, 3.0)))), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y187 * __pyx_v_y331) * __pyx_v_y337), 0)), __pyx_t_double_complex_from_parts(((1.35633680555556e-7 * __pyx_v_y189) * __pyx_v_y28), 0)), __pyx_t_double_complex_from_parts(((((4.66406554828496e-24 * __pyx_v_y191) * __pyx_v_y258) * __pyx_v_y271) * __pyx_v_y330), 0)), __pyx_t_double_complex_from_parts(((178.250760122184 * __pyx_v_y237) * __pyx_v_y81), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y243 * __pyx_v_y37), 0)), __pyx_t_double_complex_from_parts((((__pyx_v_y246 * __pyx_v_y320) * __pyx_v_y71) * __pyx_v_y8), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y258 * __pyx_v_y263) * __pyx_v_y326), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y26 * __pyx_v_y93), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y26 * __pyx_v_y98), 0)), __pyx_t_double_complex_from_parts(((5.08626302083333e-7 * __pyx_v_y269) * __pyx_v_y303), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y272 * __pyx_v_y274) * __pyx_v_y326), 0)), __pyx_t_double_complex_from_parts(((1.79273319203661e-36 * __pyx_v_y273) * __pyx_v_y340), 0)), __pyx_t_double_complex_from_parts(((2.24091649004576e-36 * __pyx_v_y273) * __pyx_v_y342), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y275 * __pyx_v_y282) * __pyx_v_y317), 0)), __pyx_t_double_complex_from_parts(((((7.91520185839956e-48 * __pyx_v_y277) * __pyx_v_y279) * __pyx_v_y333) * __pyx_v_y76), 0)), __pyx_t_double_complex_from_parts(((0.243909737560898 * __pyx_v_y28) * __pyx_v_y84), 0)), __pyx_t_double_complex_from_parts((((4.41515887225116e-12 * __pyx_v_y284) * __pyx_v_y317) * __pyx_v_y350), 0)), __pyx_t_double_complex_from_parts(((3.53212709780093e-11 * __pyx_v_y286) * __pyx_v_y340), 0)), __pyx_t_double_complex_from_parts(((4.41515887225116e-11 * __pyx_v_y286) * __pyx_v_y342), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_y297 * __pyx_v_y338) * __pyx_v_y355), 0)), __pyx_t_double_complex_from_parts(__pyx_v_y31, 0)), __pyx_t_double_complex_from_parts((__pyx_v_y318 * __pyx_v_y72), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y319 * __pyx_v_y53), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y321 * __pyx_v_y72), 0)), __pyx_t_double_complex_from_parts(((2.69825540021952e-16 * __pyx_v_y322) * __pyx_v_y323), 0)), __pyx_t_double_complex_from_parts(((2.40618160283239e-32 * __pyx_v_y327) * __pyx_v_y328), 0)), __pyx_t_double_complex_from_parts(((1.48072714020455e-32 * __pyx_v_y328) * __pyx_v_y329), 0)), __pyx_t_double_complex_from_parts(((1.97563438385653e-43 * __pyx_v_y332) * __pyx_v_y334), 0)), __pyx_t_double_complex_from_parts(((1.72354696230011e-21 * __pyx_v_y332) * __pyx_v_y348), 0)), __pyx_t_double_complex_from_parts(((1.21577500545017e-43 * __pyx_v_y334) * __pyx_v_y335), 0)), __pyx_t_double_complex_from_parts(((1.10501271569469e-58 * __pyx_v_y334) * __pyx_v_y336), 0)), __pyx_t_double_complex_from_parts(((1.06064428449238e-21 * __pyx_v_y335) * __pyx_v_y348), 0)), __pyx_t_double_complex_from_parts(((9.64015065237337e-37 * __pyx_v_y336) * __pyx_v_y348), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y339 * __pyx_v_y341), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y339 * __pyx_v_y343), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y34 * __pyx_v_y91), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y34 * __pyx_v_y96), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y341 * __pyx_v_y354), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y343 * __pyx_v_y354), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y345 * __pyx_v_y347), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y345 * __pyx_v_y352), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y347 * __pyx_v_y356), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y352 * __pyx_v_y356), 0)), __pyx_t_double_complex_from_parts(((12.9740924271319 * __pyx_v_y78) * __pyx_v_y83), 0)), __pyx_t_double_complex_from_parts((((2.88925109089694e-20 * __pyx_v_y262) * __pyx_v_y330) / pow(__pyx_v_y158, 4.0)), 0)), __pyx_t_double_complex_from_parts((((4.07287405245073e-17 * __pyx_v_y281) * __pyx_v_y349) / pow(__pyx_v_y133, 6.0)), 0)), __pyx_t_double_complex_from_parts(((((32.0 * __pyx_v_y108) * __pyx_v_y30) * pow((((__pyx_v_r * __pyx_v_y18) + (__pyx_v_y102 * __pyx_v_y18)) + __pyx_v_y27), 2.0)) / pow(__pyx_v_y104, 3.0)), 0)), __pyx_t_double_complex_from_parts((((6.10931107867609e-18 * __pyx_v_y164) * __pyx_v_y190) / pow(__pyx_v_r, 11.0)), 0)), __pyx_t_double_complex_from_parts(((2.31644711733135e-17 * __pyx_v_y248) / pow(__pyx_v_r, 15.0)), 0)))), __pyx_t_double_complex_from_parts(((__pyx_v_y211 * __pyx_v_y298) * __pyx_v_y302), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y212 * ((__pyx_v_y300 * ((12.0 * __pyx_v_y71) + 6.0)) + (__pyx_v_y34 * __pyx_v_y5))), 0)), __pyx_t_double_complex_from_parts((__pyx_v_y236 * (((__pyx_v_y303 * (((1.40625 * __pyx_v_y199) - (__pyx_v_y304 * ((2625.0 * __pyx_v_nu) + 3375.0))) + (__pyx_v_y305 * ((30.0 * __pyx_v_nu) - 45.0)))) + __pyx_v_y317) + (__pyx_v_y36 * ((((0.5 * __pyx_v_y161) * ((20.0 * __pyx_v_nu) + 5.0)) + (__pyx_v_y24 * ((-25.0 * __pyx_v_X_1) + (25.0 * __pyx_v_X_2)))) + (22.5 * __pyx_v_y5))))), 0)))), __pyx_t_double_complex_from_parts(((__pyx_v_y63 * (((4.0 * __pyx_v_r) + (__pyx_v_y0 * __pyx_v_y45)) + __pyx_v_y9)) * (((((((__pyx_v_pphi * __pyx_v_y19) * __pyx_v_y20) * __pyx_v_y60) + ((__pyx_v_pphi * __pyx_v_y4) * __pyx_v_y58)) - ((2.0 * __pyx_v_y14) * __pyx_v_y50)) - (__pyx_v_y15 * __pyx_v_y47)) - (__pyx_v_y22 * __pyx_v_y49))), 0)), __pyx_t_double_complex_from_parts(((((-1.5 * __pyx_v_r) * __pyx_v_y62) + ((1.0 * pow((((__pyx_v_r + (0.5 * __pyx_v_y1)) + (0.5 * __pyx_v_y64)) + __pyx_v_y65), 2.0)) / pow(__pyx_v_y61, 3.0))) * (((((__pyx_v_pphi * __pyx_v_y74) + (__pyx_v_pphi * __pyx_v_y75)) + (__pyx_v_y15 * __pyx_v_y66)) + (__pyx_v_y22 * __pyx_v_y68)) + (__pyx_v_y69 * __pyx_v_y70))), 0)), 1); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1212, __pyx_L1_error)
  __pyx_v_d2Heffdr2 = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1214
 *         cdef double d2Heffdr2 = y10*(y12*y13*y15 + y14*y25*y26 + y14*(y17*(-33.1875*nu + 3.40625*y32 - 0.46875) + y28*(1.4375*nu - 0.1875) + y29*y31 + y33*y35 + y37*y40) + y17*y18*y22 + y22*(y17*(-0.1875*nu + 3.21875*y32 + 0.46875) + y28*(0.6875*nu + 0.1875) + y31*y41 + y35*y42 + y37*y44)) - 0.25*y206*y299**2 + 0.5*y362*(-y193*y210*y235*y302 + 8.0*y193*y203*(y208*y28*y65 - y300)**2/y194**3 + y195*y298*(-y12*(y196 + 2.0*y197 + 9.0*y5) + 61440.0*y128*y130*y27 + 15360.0*y128*y16*y217 - 2.63243347181853e-19*y233 - y36*(0.46875*y199 - y213*y304 + y214*y305) - 4.0*y48) + y204*(3649.23288650611*r**(-6.5)*y238 + 6.0*y101*y87 + y101*(51.6952380952381*nu*y51 - y241*y51) + y108*y320*(y314 + y8) - 6.103515625e-7*y12*y189*y6 - 8.0*y12*y242*y76 + 1.62760416666667e-6*y134*y349*y350 + 1.16714400523217e-40*y159*y188*y257*y285*y344 - 2.5455462827817e-17*y164*y165*y250 + 7.59859378406358e-45*y182*y323*y331 + y182*y337*(-y11*y131*y257*y360 + y12*(0.25*y161*y288 + 0.5*y24*y289 + y5*(y287 + 33.75)) + y128*y185*y308 - y130*y310*y357 + 153600.0*y131*y27*y359 - 2.29252167428035e-21*y132*y172*y292 + y132*y257*y358 + y172*y217*y307*y358 + y184*y186*y326 - y185*y311 - 1.31621673590926e-18*y233*y359 - y291*y295*y331 + 7.85795675813156e-45*y292*y293*y296 - y293*y309*y360 + y306 + 15360.0*y309*y357 + y312*y361 - y316*y361 + y36*(y176*y20*(130.0*nu + 2245.0) + 0.3125*y179 + y290*(-5855.0*nu - 4305.0)) + 2.81299777100766e-6*y294*y322/y148**3) + y187*y331*y337 + 1.35633680555556e-7*y189*y28 + 4.66406554828496e-24*y191*y258*y271*y330 - 178.250760122184*y237*y81 + y243*y37 + y246*y320*y71*y8 - y258*y263*y326 + y26*y93 + y26*y98 + 5.08626302083333e-7*y269*y303 - y272*y274*y326 - 1.79273319203661e-36*y273*y340 + 2.24091649004576e-36*y273*y342 - y275*y282*y317 - 7.91520185839956e-48*y277*y279*y333*y76 + 0.243909737560898*y28*y84 - 4.41515887225116e-12*y284*y317*y350 - 3.53212709780093e-11*y286*y340 + 4.41515887225116e-11*y286*y342 + y297*y338*y355 + y31 + y318*y72 - y319*y53 - y321*y72 + 2.69825540021952e-16*y322*y323 + 2.40618160283239e-32*y327*y328 - 1.48072714020455e-32*y328*y329 - 1.97563438385653e-43*y332*y334 + 1.72354696230011e-21*y332*y348 + 1.21577500545017e-43*y334*y335 - 1.10501271569469e-58*y334*y336 - 1.06064428449238e-21*y335*y348 + 9.64015065237337e-37*y336*y348 + y339*y341 - y339*y343 + y34*y91 + y34*y96 + y341*y354 - y343*y354 - y345*y347 - y345*y352 - y347*y356 - y352*y356 + 12.9740924271319*y78*y83 + 2.88925109089694e-20*y262*y330/y158**4 + 4.07287405245073e-17*y281*y349/y133**6 - 32.0*y108*y30*(r*y18 + y102*y18 + y27)**2/y104**3 + 6.10931107867609e-18*y164*y190/r**11 + 2.31644711733135e-17*y248/r**15) - y211*y298*y302 - y212*(y300*(12.0*y71 + 6.0) + y34*y5) + y236*(y303*(1.40625*y199 - y304*(2625.0*nu + 3375.0) + y305*(30.0*nu - 45.0)) + y317 + y36*(0.5*y161*(20.0*nu + 5.0) + y24*(-25.0*X_1 + 25.0*X_2) + 22.5*y5))) - y63*(4.0*r + y0*y45 + y9)*(pphi*y19*y20*y60 + pphi*y4*y58 - 2.0*y14*y50 - y15*y47 - y22*y49) + (-1.5*r*y62 + 1.0*(r + 0.5*y1 + 0.5*y64 + y65)**2/y61**3)*(pphi*y74 + pphi*y75 + y15*y66 + y22*y68 + y69*y70)
 * 
 *         cdef double d2Heffdphi2 = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdpr2 = y203*y362*y363*(1.52732776966902e-18*y168*y372 + 1769.32503588175*y168*y78 - 339.525257375589*y238*y79 + y364*y365 + y364*y366 + y364*y371 + y367*y368 + y367*y369 + 56.0*y370*y80 + y374 + 6.82947265356779*y80*y85 + 83.0341915336443*y81*y82) - 5129029357728.48*y388*(5.74938229854254e-11*y191*y387 + y365*y383 + y366*y383 + y368*y384 + y369*y384 + y371*y383 + y376 - 0.115137213510253*y378 + 0.020112800850135*y381 + 0.00165425616626294*y382 + 0.0135644946594222*y385 + 8.63226223952612e-22*y386)**2
 */
  __Pyx_TraceLine(1214,0,__PYX_ERR(1, 1214, __pyx_L1_error))
  __pyx_v_d2Heffdphi2 = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1216
 *         cdef double d2Heffdphi2 = 0
 * 
 *         cdef double d2Heffdpr2 = y203*y362*y363*(1.52732776966902e-18*y168*y372 + 1769.32503588175*y168*y78 - 339.525257375589*y238*y79 + y364*y365 + y364*y366 + y364*y371 + y367*y368 + y367*y369 + 56.0*y370*y80 + y374 + 6.82947265356779*y80*y85 + 83.0341915336443*y81*y82) - 5129029357728.48*y388*(5.74938229854254e-11*y191*y387 + y365*y383 + y366*y383 + y368*y384 + y369*y384 + y371*y383 + y376 - 0.115137213510253*y378 + 0.020112800850135*y381 + 0.00165425616626294*y382 + 0.0135644946594222*y385 + 8.63226223952612e-22*y386)**2             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdpphi2 = y10*(y14*(y28*(-4.171875*nu - 4.14322916666667*y32 + 0.4609375) + y389*y390 + y51*(-2.8125*nu - 0.9375)) + y22*(y28*(-0.546875*nu - 1.59635416666667*y32 - 0.4609375) + y390*y399 + y51*(0.9375 - 0.5625*nu)) + y391*y398 + y400*(2.0*X_1 - 2.0*X_2)) + y203*y362*y363*(y105*y244*(-y0 - 4.0) + y392) - 58982400.0*y388*(-pphi*y105*y108 + pphi*y51)**2
 */
  __Pyx_TraceLine(1216,0,__PYX_ERR(1, 1216, __pyx_L1_error))
  __pyx_v_d2Heffdpr2 = ((((__pyx_v_y203 * __pyx_v_y362) * __pyx_v_y363) * (((((((((((((1.52732776966902e-18 * __pyx_v_y168) * __pyx_v_y372) + ((1769.32503588175 * __pyx_v_y168) * __pyx_v_y78)) - ((339.525257375589 * __pyx_v_y238) * __pyx_v_y79)) + (__pyx_v_y364 * __pyx_v_y365)) + (__pyx_v_y364 * __pyx_v_y366)) + (__pyx_v_y364 * __pyx_v_y371)) + (__pyx_v_y367 * __pyx_v_y368)) + (__pyx_v_y367 * __pyx_v_y369)) + ((56.0 * __pyx_v_y370) * __pyx_v_y80)) + __pyx_v_y374) + ((6.82947265356779 * __pyx_v_y80) * __pyx_v_y85)) + ((83.0341915336443 * __pyx_v_y81) * __pyx_v_y82))) - ((5129029357728.48 * __pyx_v_y388) * pow((((((((((((((5.74938229854254e-11 * __pyx_v_y191) * __pyx_v_y387) + (__pyx_v_y365 * __pyx_v_y383)) + (__pyx_v_y366 * __pyx_v_y383)) + (__pyx_v_y368 * __pyx_v_y384)) + (__pyx_v_y369 * __pyx_v_y384)) + (__pyx_v_y371 * __pyx_v_y383)) + __pyx_v_y376) - (0.115137213510253 * __pyx_v_y378)) + (0.020112800850135 * __pyx_v_y381)) + (0.00165425616626294 * __pyx_v_y382)) + (0.0135644946594222 * __pyx_v_y385)) + (8.63226223952612e-22 * __pyx_v_y386)), 2.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1218
 *         cdef double d2Heffdpr2 = y203*y362*y363*(1.52732776966902e-18*y168*y372 + 1769.32503588175*y168*y78 - 339.525257375589*y238*y79 + y364*y365 + y364*y366 + y364*y371 + y367*y368 + y367*y369 + 56.0*y370*y80 + y374 + 6.82947265356779*y80*y85 + 83.0341915336443*y81*y82) - 5129029357728.48*y388*(5.74938229854254e-11*y191*y387 + y365*y383 + y366*y383 + y368*y384 + y369*y384 + y371*y383 + y376 - 0.115137213510253*y378 + 0.020112800850135*y381 + 0.00165425616626294*y382 + 0.0135644946594222*y385 + 8.63226223952612e-22*y386)**2
 * 
 *         cdef double d2Heffdpphi2 = y10*(y14*(y28*(-4.171875*nu - 4.14322916666667*y32 + 0.4609375) + y389*y390 + y51*(-2.8125*nu - 0.9375)) + y22*(y28*(-0.546875*nu - 1.59635416666667*y32 - 0.4609375) + y390*y399 + y51*(0.9375 - 0.5625*nu)) + y391*y398 + y400*(2.0*X_1 - 2.0*X_2)) + y203*y362*y363*(y105*y244*(-y0 - 4.0) + y392) - 58982400.0*y388*(-pphi*y105*y108 + pphi*y51)**2             # <<<<<<<<<<<<<<
 * 
 *         cdef double  d2Heffdrdphi = 0
 */
  __Pyx_TraceLine(1218,0,__PYX_ERR(1, 1218, __pyx_L1_error))
  __pyx_v_d2Heffdpphi2 = (((__pyx_v_y10 * ((((__pyx_v_y14 * (((__pyx_v_y28 * (((-4.171875 * __pyx_v_nu) - (4.14322916666667 * __pyx_v_y32)) + 0.4609375)) + (__pyx_v_y389 * __pyx_v_y390)) + (__pyx_v_y51 * ((-2.8125 * __pyx_v_nu) - 0.9375)))) + (__pyx_v_y22 * (((__pyx_v_y28 * (((-0.546875 * __pyx_v_nu) - (1.59635416666667 * __pyx_v_y32)) - 0.4609375)) + (__pyx_v_y390 * __pyx_v_y399)) + (__pyx_v_y51 * (0.9375 - (0.5625 * __pyx_v_nu)))))) + (__pyx_v_y391 * __pyx_v_y398)) + (__pyx_v_y400 * ((2.0 * __pyx_v_X_1) - (2.0 * __pyx_v_X_2))))) + (((__pyx_v_y203 * __pyx_v_y362) * __pyx_v_y363) * (((__pyx_v_y105 * __pyx_v_y244) * ((-__pyx_v_y0) - 4.0)) + __pyx_v_y392))) - ((58982400.0 * __pyx_v_y388) * pow(((((-__pyx_v_pphi) * __pyx_v_y105) * __pyx_v_y108) + (__pyx_v_pphi * __pyx_v_y51)), 2.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1220
 *         cdef double d2Heffdpphi2 = y10*(y14*(y28*(-4.171875*nu - 4.14322916666667*y32 + 0.4609375) + y389*y390 + y51*(-2.8125*nu - 0.9375)) + y22*(y28*(-0.546875*nu - 1.59635416666667*y32 - 0.4609375) + y390*y399 + y51*(0.9375 - 0.5625*nu)) + y391*y398 + y400*(2.0*X_1 - 2.0*X_2)) + y203*y362*y363*(y105*y244*(-y0 - 4.0) + y392) - 58982400.0*y388*(-pphi*y105*y108 + pphi*y51)**2
 * 
 *         cdef double  d2Heffdrdphi = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdrdpr = 0.5*y362*(y204*(-2653.98755382262*nu*y237*y375 + 237.667680162912*nu*y377*y77 + 3.39084201388889e-8*prst*y12*y169*y173*y182*y190*y297 + 3.39084201388889e-8*prst*y12*y169*y173*y187*y190*y268 + 1.35633680555556e-7*prst*y169*y17*y173*y182*y187*y6 - prst*y173*y188*y191*y351 - prst*y191*y270*y346 - y100*y375*y406 + 4.07287405245073e-18*y134*y149*y159*y162*y249*y250*y375 - 3.70181785051137e-33*y134*y149*y162*y336*y375 + 3.03943751362543e-44*y134*y159*y162*y165*y166*y182*y268*y375 - 2.65161071123094e-22*y149*y277*y279*y375 - 6.61842033523243e-18*y163*y327*y375 + 4.0*y17*y242*y375 - 12.0*y17*y375*y90 - 18.0*y17*y377*y95 - 0.975638950243592*y239*y379 - 8.0*y28*y375*y87 - 12.0*y28*y377*y92 - 16.0*y28*y379*y97 - y343*y387 - 29.655068404873*y380*y79) - y403*y404 + y403*y405) - y403*y407
 */
  __Pyx_TraceLine(1220,0,__PYX_ERR(1, 1220, __pyx_L1_error))
  __pyx_v_d2Heffdrdphi = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1222
 *         cdef double  d2Heffdrdphi = 0
 * 
 *         cdef double d2Heffdrdpr = 0.5*y362*(y204*(-2653.98755382262*nu*y237*y375 + 237.667680162912*nu*y377*y77 + 3.39084201388889e-8*prst*y12*y169*y173*y182*y190*y297 + 3.39084201388889e-8*prst*y12*y169*y173*y187*y190*y268 + 1.35633680555556e-7*prst*y169*y17*y173*y182*y187*y6 - prst*y173*y188*y191*y351 - prst*y191*y270*y346 - y100*y375*y406 + 4.07287405245073e-18*y134*y149*y159*y162*y249*y250*y375 - 3.70181785051137e-33*y134*y149*y162*y336*y375 + 3.03943751362543e-44*y134*y159*y162*y165*y166*y182*y268*y375 - 2.65161071123094e-22*y149*y277*y279*y375 - 6.61842033523243e-18*y163*y327*y375 + 4.0*y17*y242*y375 - 12.0*y17*y375*y90 - 18.0*y17*y377*y95 - 0.975638950243592*y239*y379 - 8.0*y28*y375*y87 - 12.0*y28*y377*y92 - 16.0*y28*y379*y97 - y343*y387 - 29.655068404873*y380*y79) - y403*y404 + y403*y405) - y403*y407             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdrdpphi = y10*(y14*(-y29*y409 - y33*y410 - y39*y411) - y21*y49 + y21*y60 + y22*(-y409*y41 - y410*y42 - y411*y43) - y391*y50 + y4*y58 - y408*y47) + 0.5*y362*(y204*(y319*y69 + y321*y412 - y409 - y413) - y404*y415 + y405*y415) - y407*y415 - y63*(y0 + y6 + y64)*(pphi*y20*y400 + y14*y398 + y21*y68 + y408*y66 + y51*y70 + y74 + y75)
 */
  __Pyx_TraceLine(1222,0,__PYX_ERR(1, 1222, __pyx_L1_error))
  __pyx_v_d2Heffdrdpr = (((0.5 * __pyx_v_y362) * (((__pyx_v_y204 * ((((((((((((((((((((((((-2653.98755382262 * __pyx_v_nu) * __pyx_v_y237) * __pyx_v_y375) + (((237.667680162912 * __pyx_v_nu) * __pyx_v_y377) * __pyx_v_y77)) + (((((((3.39084201388889e-8 * __pyx_v_prst) * __pyx_v_y12) * __pyx_v_y169) * __pyx_v_y173) * __pyx_v_y182) * __pyx_v_y190) * __pyx_v_y297)) + (((((((3.39084201388889e-8 * __pyx_v_prst) * __pyx_v_y12) * __pyx_v_y169) * __pyx_v_y173) * __pyx_v_y187) * __pyx_v_y190) * __pyx_v_y268)) + (((((((1.35633680555556e-7 * __pyx_v_prst) * __pyx_v_y169) * __pyx_v_y17) * __pyx_v_y173) * __pyx_v_y182) * __pyx_v_y187) * __pyx_v_y6)) - ((((__pyx_v_prst * __pyx_v_y173) * __pyx_v_y188) * __pyx_v_y191) * __pyx_v_y351)) - (((__pyx_v_prst * __pyx_v_y191) * __pyx_v_y270) * __pyx_v_y346)) - ((__pyx_v_y100 * __pyx_v_y375) * __pyx_v_y406)) + (((((((4.07287405245073e-18 * __pyx_v_y134) * __pyx_v_y149) * __pyx_v_y159) * __pyx_v_y162) * __pyx_v_y249) * __pyx_v_y250) * __pyx_v_y375)) - (((((3.70181785051137e-33 * __pyx_v_y134) * __pyx_v_y149) * __pyx_v_y162) * __pyx_v_y336) * __pyx_v_y375)) + ((((((((3.03943751362543e-44 * __pyx_v_y134) * __pyx_v_y159) * __pyx_v_y162) * __pyx_v_y165) * __pyx_v_y166) * __pyx_v_y182) * __pyx_v_y268) * __pyx_v_y375)) - ((((2.65161071123094e-22 * __pyx_v_y149) * __pyx_v_y277) * __pyx_v_y279) * __pyx_v_y375)) - (((6.61842033523243e-18 * __pyx_v_y163) * __pyx_v_y327) * __pyx_v_y375)) + (((4.0 * __pyx_v_y17) * __pyx_v_y242) * __pyx_v_y375)) - (((12.0 * __pyx_v_y17) * __pyx_v_y375) * __pyx_v_y90)) - (((18.0 * __pyx_v_y17) * __pyx_v_y377) * __pyx_v_y95)) - ((0.975638950243592 * __pyx_v_y239) * __pyx_v_y379)) - (((8.0 * __pyx_v_y28) * __pyx_v_y375) * __pyx_v_y87)) - (((12.0 * __pyx_v_y28) * __pyx_v_y377) * __pyx_v_y92)) - (((16.0 * __pyx_v_y28) * __pyx_v_y379) * __pyx_v_y97)) - (__pyx_v_y343 * __pyx_v_y387)) - ((29.655068404873 * __pyx_v_y380) * __pyx_v_y79))) - (__pyx_v_y403 * __pyx_v_y404)) + (__pyx_v_y403 * __pyx_v_y405))) - (__pyx_v_y403 * __pyx_v_y407));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1224
 *         cdef double d2Heffdrdpr = 0.5*y362*(y204*(-2653.98755382262*nu*y237*y375 + 237.667680162912*nu*y377*y77 + 3.39084201388889e-8*prst*y12*y169*y173*y182*y190*y297 + 3.39084201388889e-8*prst*y12*y169*y173*y187*y190*y268 + 1.35633680555556e-7*prst*y169*y17*y173*y182*y187*y6 - prst*y173*y188*y191*y351 - prst*y191*y270*y346 - y100*y375*y406 + 4.07287405245073e-18*y134*y149*y159*y162*y249*y250*y375 - 3.70181785051137e-33*y134*y149*y162*y336*y375 + 3.03943751362543e-44*y134*y159*y162*y165*y166*y182*y268*y375 - 2.65161071123094e-22*y149*y277*y279*y375 - 6.61842033523243e-18*y163*y327*y375 + 4.0*y17*y242*y375 - 12.0*y17*y375*y90 - 18.0*y17*y377*y95 - 0.975638950243592*y239*y379 - 8.0*y28*y375*y87 - 12.0*y28*y377*y92 - 16.0*y28*y379*y97 - y343*y387 - 29.655068404873*y380*y79) - y403*y404 + y403*y405) - y403*y407
 * 
 *         cdef double d2Heffdrdpphi = y10*(y14*(-y29*y409 - y33*y410 - y39*y411) - y21*y49 + y21*y60 + y22*(-y409*y41 - y410*y42 - y411*y43) - y391*y50 + y4*y58 - y408*y47) + 0.5*y362*(y204*(y319*y69 + y321*y412 - y409 - y413) - y404*y415 + y405*y415) - y407*y415 - y63*(y0 + y6 + y64)*(pphi*y20*y400 + y14*y398 + y21*y68 + y408*y66 + y51*y70 + y74 + y75)             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdphidpr = 0
 */
  __Pyx_TraceLine(1224,0,__PYX_ERR(1, 1224, __pyx_L1_error))
  __pyx_v_d2Heffdrdpphi = ((((__pyx_v_y10 * (((((((__pyx_v_y14 * ((((-__pyx_v_y29) * __pyx_v_y409) - (__pyx_v_y33 * __pyx_v_y410)) - (__pyx_v_y39 * __pyx_v_y411))) - (__pyx_v_y21 * __pyx_v_y49)) + (__pyx_v_y21 * __pyx_v_y60)) + (__pyx_v_y22 * ((((-__pyx_v_y409) * __pyx_v_y41) - (__pyx_v_y410 * __pyx_v_y42)) - (__pyx_v_y411 * __pyx_v_y43)))) - (__pyx_v_y391 * __pyx_v_y50)) + (__pyx_v_y4 * __pyx_v_y58)) - (__pyx_v_y408 * __pyx_v_y47))) + ((0.5 * __pyx_v_y362) * (((__pyx_v_y204 * ((((__pyx_v_y319 * __pyx_v_y69) + (__pyx_v_y321 * __pyx_v_y412)) - __pyx_v_y409) - __pyx_v_y413)) - (__pyx_v_y404 * __pyx_v_y415)) + (__pyx_v_y405 * __pyx_v_y415)))) - (__pyx_v_y407 * __pyx_v_y415)) - ((__pyx_v_y63 * ((__pyx_v_y0 + __pyx_v_y6) + __pyx_v_y64)) * ((((((((__pyx_v_pphi * __pyx_v_y20) * __pyx_v_y400) + (__pyx_v_y14 * __pyx_v_y398)) + (__pyx_v_y21 * __pyx_v_y68)) + (__pyx_v_y408 * __pyx_v_y66)) + (__pyx_v_y51 * __pyx_v_y70)) + __pyx_v_y74) + __pyx_v_y75)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1226
 *         cdef double d2Heffdrdpphi = y10*(y14*(-y29*y409 - y33*y410 - y39*y411) - y21*y49 + y21*y60 + y22*(-y409*y41 - y410*y42 - y411*y43) - y391*y50 + y4*y58 - y408*y47) + 0.5*y362*(y204*(y319*y69 + y321*y412 - y409 - y413) - y404*y415 + y405*y415) - y407*y415 - y63*(y0 + y6 + y64)*(pphi*y20*y400 + y14*y398 + y21*y68 + y408*y66 + y51*y70 + y74 + y75)
 * 
 *         cdef double d2Heffdphidpr = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdphidpphi = 0
 */
  __Pyx_TraceLine(1226,0,__PYX_ERR(1, 1226, __pyx_L1_error))
  __pyx_v_d2Heffdphidpr = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1228
 *         cdef double d2Heffdphidpr = 0
 * 
 *         cdef double d2Heffdphidpphi = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double d2Heffdprdpphi = 14745600.0*y388*y403*y414
 */
  __Pyx_TraceLine(1228,0,__PYX_ERR(1, 1228, __pyx_L1_error))
  __pyx_v_d2Heffdphidpphi = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1230
 *         cdef double d2Heffdphidpphi = 0
 * 
 *         cdef double d2Heffdprdpphi = 14745600.0*y388*y403*y414             # <<<<<<<<<<<<<<
 * 
 *         # Compute H Hessian
 */
  __Pyx_TraceLine(1230,0,__PYX_ERR(1, 1230, __pyx_L1_error))
  __pyx_v_d2Heffdprdpphi = (((14745600.0 * __pyx_v_y388) * __pyx_v_y403) * __pyx_v_y414);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1233
 * 
 *         # Compute H Hessian
 *         cdef double d2Hdr2 = (-(dHeffdr**2/H**3)*(M**2/nu) + d2Heffdr2/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdphi2 = (-(dHeffdphi**2/H**3)*(M**2/nu) + d2Heffdphi2/H) * M*M / nu
 *         cdef double d2Hdpr2 = (-(dHeffdpr**2/H**3)*(M**2/nu) + d2Heffdpr2/H) * M*M / nu
 */
  __Pyx_TraceLine(1233,0,__PYX_ERR(1, 1233, __pyx_L1_error))
  __pyx_v_d2Hdr2 = ((((((-(pow(__pyx_v_dHeffdr, 2.0) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdr2 / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1234
 *         # Compute H Hessian
 *         cdef double d2Hdr2 = (-(dHeffdr**2/H**3)*(M**2/nu) + d2Heffdr2/H) * M*M / nu
 *         cdef double d2Hdphi2 = (-(dHeffdphi**2/H**3)*(M**2/nu) + d2Heffdphi2/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdpr2 = (-(dHeffdpr**2/H**3)*(M**2/nu) + d2Heffdpr2/H) * M*M / nu
 *         cdef double d2Hdpphi2 = (-(dHeffdpphi**2/H**3)*(M**2/nu) + d2Heffdpphi2/H) * M*M / nu
 */
  __Pyx_TraceLine(1234,0,__PYX_ERR(1, 1234, __pyx_L1_error))
  __pyx_v_d2Hdphi2 = ((((((-(pow(__pyx_v_dHeffdphi, 2.0) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdphi2 / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1235
 *         cdef double d2Hdr2 = (-(dHeffdr**2/H**3)*(M**2/nu) + d2Heffdr2/H) * M*M / nu
 *         cdef double d2Hdphi2 = (-(dHeffdphi**2/H**3)*(M**2/nu) + d2Heffdphi2/H) * M*M / nu
 *         cdef double d2Hdpr2 = (-(dHeffdpr**2/H**3)*(M**2/nu) + d2Heffdpr2/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdpphi2 = (-(dHeffdpphi**2/H**3)*(M**2/nu) + d2Heffdpphi2/H) * M*M / nu
 *         cdef double d2Hdrdphi = (-(dHeffdr*dHeffdphi/H**3)*(M**2/nu) + d2Heffdrdphi/H) * M*M / nu
 */
  __Pyx_TraceLine(1235,0,__PYX_ERR(1, 1235, __pyx_L1_error))
  __pyx_v_d2Hdpr2 = ((((((-(pow(__pyx_v_dHeffdpr, 2.0) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdpr2 / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1236
 *         cdef double d2Hdphi2 = (-(dHeffdphi**2/H**3)*(M**2/nu) + d2Heffdphi2/H) * M*M / nu
 *         cdef double d2Hdpr2 = (-(dHeffdpr**2/H**3)*(M**2/nu) + d2Heffdpr2/H) * M*M / nu
 *         cdef double d2Hdpphi2 = (-(dHeffdpphi**2/H**3)*(M**2/nu) + d2Heffdpphi2/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdrdphi = (-(dHeffdr*dHeffdphi/H**3)*(M**2/nu) + d2Heffdrdphi/H) * M*M / nu
 *         cdef double d2Hdrdpr = (-(dHeffdr*dHeffdpr/H**3)*(M**2/nu) + d2Heffdrdpr/H) * M*M / nu
 */
  __Pyx_TraceLine(1236,0,__PYX_ERR(1, 1236, __pyx_L1_error))
  __pyx_v_d2Hdpphi2 = ((((((-(pow(__pyx_v_dHeffdpphi, 2.0) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdpphi2 / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1237
 *         cdef double d2Hdpr2 = (-(dHeffdpr**2/H**3)*(M**2/nu) + d2Heffdpr2/H) * M*M / nu
 *         cdef double d2Hdpphi2 = (-(dHeffdpphi**2/H**3)*(M**2/nu) + d2Heffdpphi2/H) * M*M / nu
 *         cdef double d2Hdrdphi = (-(dHeffdr*dHeffdphi/H**3)*(M**2/nu) + d2Heffdrdphi/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdrdpr = (-(dHeffdr*dHeffdpr/H**3)*(M**2/nu) + d2Heffdrdpr/H) * M*M / nu
 *         cdef double d2Hdrdpphi = (-(dHeffdr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdrdpphi/H) * M*M / nu
 */
  __Pyx_TraceLine(1237,0,__PYX_ERR(1, 1237, __pyx_L1_error))
  __pyx_v_d2Hdrdphi = ((((((-((__pyx_v_dHeffdr * __pyx_v_dHeffdphi) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdrdphi / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1238
 *         cdef double d2Hdpphi2 = (-(dHeffdpphi**2/H**3)*(M**2/nu) + d2Heffdpphi2/H) * M*M / nu
 *         cdef double d2Hdrdphi = (-(dHeffdr*dHeffdphi/H**3)*(M**2/nu) + d2Heffdrdphi/H) * M*M / nu
 *         cdef double d2Hdrdpr = (-(dHeffdr*dHeffdpr/H**3)*(M**2/nu) + d2Heffdrdpr/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdrdpphi = (-(dHeffdr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdrdpphi/H) * M*M / nu
 *         cdef double d2Hdphidpr = (-(dHeffdphi*dHeffdpr/H**3)*(M**2/nu) + d2Heffdphidpr/H) * M*M / nu
 */
  __Pyx_TraceLine(1238,0,__PYX_ERR(1, 1238, __pyx_L1_error))
  __pyx_v_d2Hdrdpr = ((((((-((__pyx_v_dHeffdr * __pyx_v_dHeffdpr) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdrdpr / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1239
 *         cdef double d2Hdrdphi = (-(dHeffdr*dHeffdphi/H**3)*(M**2/nu) + d2Heffdrdphi/H) * M*M / nu
 *         cdef double d2Hdrdpr = (-(dHeffdr*dHeffdpr/H**3)*(M**2/nu) + d2Heffdrdpr/H) * M*M / nu
 *         cdef double d2Hdrdpphi = (-(dHeffdr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdrdpphi/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdphidpr = (-(dHeffdphi*dHeffdpr/H**3)*(M**2/nu) + d2Heffdphidpr/H) * M*M / nu
 *         cdef double d2Hdphidpphi = (-(dHeffdphi*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdphidpphi/H) * M*M / nu
 */
  __Pyx_TraceLine(1239,0,__PYX_ERR(1, 1239, __pyx_L1_error))
  __pyx_v_d2Hdrdpphi = ((((((-((__pyx_v_dHeffdr * __pyx_v_dHeffdpphi) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdrdpphi / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1240
 *         cdef double d2Hdrdpr = (-(dHeffdr*dHeffdpr/H**3)*(M**2/nu) + d2Heffdrdpr/H) * M*M / nu
 *         cdef double d2Hdrdpphi = (-(dHeffdr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdrdpphi/H) * M*M / nu
 *         cdef double d2Hdphidpr = (-(dHeffdphi*dHeffdpr/H**3)*(M**2/nu) + d2Heffdphidpr/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdphidpphi = (-(dHeffdphi*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdphidpphi/H) * M*M / nu
 *         cdef double d2Hdprdpphi = (-(dHeffdpr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdprdpphi/H) * M*M / nu
 */
  __Pyx_TraceLine(1240,0,__PYX_ERR(1, 1240, __pyx_L1_error))
  __pyx_v_d2Hdphidpr = ((((((-((__pyx_v_dHeffdphi * __pyx_v_dHeffdpr) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdphidpr / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1241
 *         cdef double d2Hdrdpphi = (-(dHeffdr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdrdpphi/H) * M*M / nu
 *         cdef double d2Hdphidpr = (-(dHeffdphi*dHeffdpr/H**3)*(M**2/nu) + d2Heffdphidpr/H) * M*M / nu
 *         cdef double d2Hdphidpphi = (-(dHeffdphi*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdphidpphi/H) * M*M / nu             # <<<<<<<<<<<<<<
 *         cdef double d2Hdprdpphi = (-(dHeffdpr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdprdpphi/H) * M*M / nu
 * 
 */
  __Pyx_TraceLine(1241,0,__PYX_ERR(1, 1241, __pyx_L1_error))
  __pyx_v_d2Hdphidpphi = ((((((-((__pyx_v_dHeffdphi * __pyx_v_dHeffdpphi) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdphidpphi / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1242
 *         cdef double d2Hdphidpr = (-(dHeffdphi*dHeffdpr/H**3)*(M**2/nu) + d2Heffdphidpr/H) * M*M / nu
 *         cdef double d2Hdphidpphi = (-(dHeffdphi*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdphidpphi/H) * M*M / nu
 *         cdef double d2Hdprdpphi = (-(dHeffdpr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdprdpphi/H) * M*M / nu             # <<<<<<<<<<<<<<
 * 
 *         return np.array([d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2]).reshape(4, 4)
 */
  __Pyx_TraceLine(1242,0,__PYX_ERR(1, 1242, __pyx_L1_error))
  __pyx_v_d2Hdprdpphi = ((((((-((__pyx_v_dHeffdpr * __pyx_v_dHeffdpphi) / pow(__pyx_v_H, 3.0))) * (pow(__pyx_v_M, 2.0) / __pyx_v_nu)) + (__pyx_v_d2Heffdprdpphi / __pyx_v_H)) * __pyx_v_M) * __pyx_v_M) / __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1244
 *         cdef double d2Hdprdpphi = (-(dHeffdpr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdprdpphi/H) * M*M / nu
 * 
 *         return np.array([d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2]).reshape(4, 4)             # <<<<<<<<<<<<<<
 * 
 *     cdef double xi(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):
 */
  __Pyx_TraceLine(1244,0,__PYX_ERR(1, 1244, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyFloat_FromDouble(__pyx_v_d2Hdr2); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = PyFloat_FromDouble(__pyx_v_d2Hdrdphi); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyFloat_FromDouble(__pyx_v_d2Hdrdpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_d2Hdrdpphi); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_d2Hdrdphi); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_d2Hdphi2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_d2Hdphidpr); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyFloat_FromDouble(__pyx_v_d2Hdphidpphi); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_16 = PyFloat_FromDouble(__pyx_v_d2Hdrdpr); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_17 = PyFloat_FromDouble(__pyx_v_d2Hdphidpr); if (unlikely(!__pyx_t_17)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_18 = PyFloat_FromDouble(__pyx_v_d2Hdpr2); if (unlikely(!__pyx_t_18)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __pyx_t_19 = PyFloat_FromDouble(__pyx_v_d2Hdprdpphi); if (unlikely(!__pyx_t_19)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_20 = PyFloat_FromDouble(__pyx_v_d2Hdrdpphi); if (unlikely(!__pyx_t_20)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __pyx_t_21 = PyFloat_FromDouble(__pyx_v_d2Hdphidpphi); if (unlikely(!__pyx_t_21)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_22 = PyFloat_FromDouble(__pyx_v_d2Hdprdpphi); if (unlikely(!__pyx_t_22)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_23 = PyFloat_FromDouble(__pyx_v_d2Hdpphi2); if (unlikely(!__pyx_t_23)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_t_24 = PyList_New(16); if (unlikely(!__pyx_t_24)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_24, 0, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_24, 1, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_24, 2, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_24, 3, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_24, 4, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_24, 5, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_24, 6, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_24, 7, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_16);
  PyList_SET_ITEM(__pyx_t_24, 8, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_17);
  PyList_SET_ITEM(__pyx_t_24, 9, __pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_18);
  PyList_SET_ITEM(__pyx_t_24, 10, __pyx_t_18);
  __Pyx_GIVEREF(__pyx_t_19);
  PyList_SET_ITEM(__pyx_t_24, 11, __pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_20);
  PyList_SET_ITEM(__pyx_t_24, 12, __pyx_t_20);
  __Pyx_GIVEREF(__pyx_t_21);
  PyList_SET_ITEM(__pyx_t_24, 13, __pyx_t_21);
  __Pyx_GIVEREF(__pyx_t_22);
  PyList_SET_ITEM(__pyx_t_24, 14, __pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_23);
  PyList_SET_ITEM(__pyx_t_24, 15, __pyx_t_23);
  __pyx_t_9 = 0;
  __pyx_t_8 = 0;
  __pyx_t_7 = 0;
  __pyx_t_6 = 0;
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_10 = 0;
  __pyx_t_16 = 0;
  __pyx_t_17 = 0;
  __pyx_t_18 = 0;
  __pyx_t_19 = 0;
  __pyx_t_20 = 0;
  __pyx_t_21 = 0;
  __pyx_t_22 = 0;
  __pyx_t_23 = 0;
  __pyx_t_23 = NULL;
  __pyx_t_11 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_23)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_23);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_11 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_23, __pyx_t_24};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
    __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_reshape); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":547
 *         return dHdr, dHdphi, dHdpr, dHdpphi
 * 
 *     cpdef hessian(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.hessian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_8hessian, "\n        Evaluate the Hessian of the Hamiltonian.\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n\n        Returns:\n           (np.array)  d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2\n\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian = {"hessian", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_8hessian};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hessian (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("hessian", 1, 6, 6, 1); __PYX_ERR(1, 547, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("hessian", 1, 6, 6, 2); __PYX_ERR(1, 547, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("hessian", 1, 6, 6, 3); __PYX_ERR(1, 547, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("hessian", 1, 6, 6, 4); __PYX_ERR(1, 547, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("hessian", 1, 6, 6, 5); __PYX_ERR(1, 547, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "hessian") < 0)) __PYX_ERR(1, 547, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 547, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 547, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 547, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("hessian", 1, 6, 6, __pyx_nargs); __PYX_ERR(1, 547, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.hessian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_8hessian(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_8hessian(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__14)
  __Pyx_RefNannySetupContext("hessian", 0);
  __Pyx_TraceCall("hessian (wrapper)", __pyx_f[1], 547, 0, __PYX_ERR(1, 547, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 547, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 547, __pyx_L1_error) }
  __pyx_t_1 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_hessian(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.hessian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1246
 *         return np.array([d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2]).reshape(4, 4)
 * 
 *     cdef double xi(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static double __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_xi(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, CYTHON_UNUSED double __pyx_v_m_1, CYTHON_UNUSED double __pyx_v_m_2) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  CYTHON_UNUSED double __pyx_v_prst;
  double __pyx_v_L;
  CYTHON_UNUSED double __pyx_v_pphi;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  CYTHON_UNUSED double __pyx_v_dSO;
  CYTHON_UNUSED double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_d5;
  double __pyx_v_Dbpm;
  double __pyx_v_Apm;
  double __pyx_v_ap;
  double __pyx_v_ap2;
  double __pyx_v_xi;
  double __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  double __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("xi", 0);
  __Pyx_TraceCall("xi", __pyx_f[1], 1246, 0, __PYX_ERR(1, 1246, __pyx_L1_error));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1265
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(1265,0,__PYX_ERR(1, 1265, __pyx_L1_error))
  __pyx_t_1 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_1 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1266
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(1266,0,__PYX_ERR(1, 1266, __pyx_L1_error))
  __pyx_t_1 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_1 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1268
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(1268,0,__PYX_ERR(1, 1268, __pyx_L1_error))
  __pyx_t_1 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_1 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1269
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(1269,0,__PYX_ERR(1, 1269, __pyx_L1_error))
  __pyx_t_1 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_1 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1271
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(1271,0,__PYX_ERR(1, 1271, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1273
 *         cdef double pphi = L
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs.a6
 *         cdef double dSO = c_coeffs.dSO
 */
  __Pyx_TraceLine(1273,0,__PYX_ERR(1, 1273, __pyx_L1_error))
  __pyx_t_2 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1274
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs.a6             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs.dSO
 * 
 */
  __Pyx_TraceLine(1274,0,__PYX_ERR(1, 1274, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_c_coeffs), __pyx_n_s_a6); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1274, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_a6 = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1275
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs.a6
 *         cdef double dSO = c_coeffs.dSO             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(1275,0,__PYX_ERR(1, 1275, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_c_coeffs), __pyx_n_s_dSO); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1275, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_dSO = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1279
 * 
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M             # <<<<<<<<<<<<<<
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 */
  __Pyx_TraceLine(1279,0,__PYX_ERR(1, 1279, __pyx_L1_error))
  __pyx_t_3 = __pyx_v_self->__pyx_base.EOBpars->p_params->M;
  __pyx_v_M = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1280
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu             # <<<<<<<<<<<<<<
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 */
  __Pyx_TraceLine(1280,0,__PYX_ERR(1, 1280, __pyx_L1_error))
  __pyx_t_3 = __pyx_v_self->__pyx_base.EOBpars->p_params->nu;
  __pyx_v_nu = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1281
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1             # <<<<<<<<<<<<<<
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 * 
 */
  __Pyx_TraceLine(1281,0,__PYX_ERR(1, 1281, __pyx_L1_error))
  __pyx_t_3 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_1;
  __pyx_v_X_1 = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1282
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2             # <<<<<<<<<<<<<<
 * 
 *         # Actual Hamiltonian expressions
 */
  __Pyx_TraceLine(1282,0,__PYX_ERR(1, 1282, __pyx_L1_error))
  __pyx_t_3 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_2;
  __pyx_v_X_2 = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1285
 * 
 *         # Actual Hamiltonian expressions
 *         cdef double d5 = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double Dbpm = r*(6730497718123.02*nu**3 + 22295347200.0*nu**2*d5 + 133772083200.0*nu**2*r**2 + 1822680546449.21*nu**2*r + 80059249540278.2*nu**2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r**2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r**2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu**2 - 25392914995744.3*nu - 879923036160.0*r**2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*log(r) + 5787938193408.0*log(r)**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu**3 - 42636451.6032331*nu**2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r**3*(-138240.0*nu**2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r**2*(-197773496.793534*nu**2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu**3 + 70778880.0*nu**2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu**2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*log(r)**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r**3 + 283115520.0*r**2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu**2 + 409207698.136075*nu - 2119671837.36038))*log(r))
 */
  __Pyx_TraceLine(1285,0,__PYX_ERR(1, 1285, __pyx_L1_error))
  __pyx_v_d5 = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1287
 *         cdef double d5 = 0
 * 
 *         cdef double Dbpm = r*(6730497718123.02*nu**3 + 22295347200.0*nu**2*d5 + 133772083200.0*nu**2*r**2 + 1822680546449.21*nu**2*r + 80059249540278.2*nu**2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r**2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r**2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu**2 - 25392914995744.3*nu - 879923036160.0*r**2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*log(r) + 5787938193408.0*log(r)**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu**3 - 42636451.6032331*nu**2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r**3*(-138240.0*nu**2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r**2*(-197773496.793534*nu**2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu**3 + 70778880.0*nu**2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu**2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*log(r)**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r**3 + 283115520.0*r**2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu**2 + 409207698.136075*nu - 2119671837.36038))*log(r))             # <<<<<<<<<<<<<<
 * 
 *         cdef double Apm = 7680.0*r**4*(-5416406.59541186*nu**2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*log(r) - 7.0*r*(-185763.092693281*nu**2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu**4 + 1120.0*nu**3*(-17833256.898555*r**2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu**2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r**5 - 3089250703.76879*r**4 - 6178501407.53758*r**3 + 2064783811.32587*r**2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu**2*log(r)**2 + 53760.0*nu*(7680.0*a6*(r**4 + 2.0*r**3 + 4.0*r**2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r**4 + 4264.6962773603*r**3 + 8529.39255472061*r**2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r**4 + 2.0*r**3 + 4.0*r**2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r**4 + 1926.0*r**3 + 3852.0*r**2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu**2 - 38842241.4769507*nu + 161280.0*r**5 + 480.0*r**4*(756.0*nu + 1079.0) + 960.0*r**3*(756.0*nu + 1079.0) + 1920.0*r**2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu**2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*log(r) + 13212057600.0*r**5)
 */
  __Pyx_TraceLine(1287,0,__PYX_ERR(1, 1287, __pyx_L1_error))
  __pyx_v_Dbpm = ((__pyx_v_r * ((((((((((((((((6730497718123.02 * pow(__pyx_v_nu, 3.0)) + ((22295347200.0 * pow(__pyx_v_nu, 2.0)) * __pyx_v_d5)) + ((133772083200.0 * pow(__pyx_v_nu, 2.0)) * pow(__pyx_v_r, 2.0))) + ((1822680546449.21 * pow(__pyx_v_nu, 2.0)) * __pyx_v_r)) + (80059249540278.2 * pow(__pyx_v_nu, 2.0))) + (((22295347200.0 * __pyx_v_nu) * __pyx_v_d5) * __pyx_v_r)) - ((193226342400.0 * __pyx_v_nu) * __pyx_v_d5)) + ((2589101062873.81 * __pyx_v_nu) * pow(__pyx_v_r, 2.0))) + ((10611661054566.2 * __pyx_v_nu) * __pyx_v_r)) - (12049908701745.2 * __pyx_v_nu)) + (5107745331375.71 * pow(__pyx_v_r, 2.0))) - ((326837426.241486 * __pyx_v_r) * ((14700.0 * __pyx_v_nu) + 42911.0))) - (39476764256925.6 * __pyx_v_r)) - ((((((-5041721180160.0 * pow(__pyx_v_nu, 2.0)) - (25392914995744.3 * __pyx_v_nu)) - (879923036160.0 * pow(__pyx_v_r, 2.0))) - ((283115520.0 * __pyx_v_r) * ((14700.0 * __pyx_v_nu) + 42911.0))) + 104186110149937.0) * log(__pyx_v_r))) + (5787938193408.0 * pow(log(__pyx_v_r), 2.0))) + 275059053208689.0)) / (((((((55296.0 * __pyx_v_nu) * (((((14515200.0 * pow(__pyx_v_nu, 3.0)) - (42636451.6032331 * pow(__pyx_v_nu, 2.0))) - ((7680.0 * __pyx_v_nu) * ((315.0 * __pyx_v_d5) + 890888.810272497))) + (4331361844.61149 * __pyx_v_nu)) + 1002013764.01019)) - ((967680.0 * pow(__pyx_v_r, 3.0)) * (((-138240.0 * pow(__pyx_v_nu, 2.0)) - (2675575.66847905 * __pyx_v_nu)) - 5278341.3229329))) - ((9216.0 * pow(__pyx_v_r, 2.0)) * ((((-197773496.793534 * pow(__pyx_v_nu, 2.0)) - ((7680.0 * __pyx_v_nu) * ((315.0 * __pyx_v_d5) + 405152.309729121))) + (2481453539.84635 * __pyx_v_nu)) + 5805304367.87913))) + (__pyx_v_r * (((((((5927865218923.02 * pow(__pyx_v_nu, 3.0)) + ((70778880.0 * pow(__pyx_v_nu, 2.0)) * ((315.0 * __pyx_v_d5) + 2561145.80918574))) - (138141470005001.0 * pow(__pyx_v_nu, 2.0))) - ((4718592.0 * __pyx_v_nu) * ((40950.0 * __pyx_v_d5) + 86207832.4415642))) + (450172889755120.0 * __pyx_v_nu)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0))) + ((5787938193408.0 * __pyx_v_r) * pow(log(__pyx_v_r), 2.0))) + ((((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + (879923036160.0 * pow(__pyx_v_r, 3.0))) + ((283115520.0 * pow(__pyx_v_r, 2.0)) * ((14700.0 * __pyx_v_nu) + 42911.0))) + ((49152.0 * __pyx_v_r) * (((102574080.0 * pow(__pyx_v_nu, 2.0)) + (409207698.136075 * __pyx_v_nu)) - 2119671837.36038))) * log(__pyx_v_r))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1289
 *         cdef double Dbpm = r*(6730497718123.02*nu**3 + 22295347200.0*nu**2*d5 + 133772083200.0*nu**2*r**2 + 1822680546449.21*nu**2*r + 80059249540278.2*nu**2 + 22295347200.0*nu*d5*r - 193226342400.0*nu*d5 + 2589101062873.81*nu*r**2 + 10611661054566.2*nu*r - 12049908701745.2*nu + 5107745331375.71*r**2 - 326837426.241486*r*(14700.0*nu + 42911.0) - 39476764256925.6*r - (-5041721180160.0*nu**2 - 25392914995744.3*nu - 879923036160.0*r**2 - 283115520.0*r*(14700.0*nu + 42911.0) + 104186110149937.0)*log(r) + 5787938193408.0*log(r)**2 + 275059053208689.0)/(55296.0*nu*(14515200.0*nu**3 - 42636451.6032331*nu**2 - 7680.0*nu*(315.0*d5 + 890888.810272497) + 4331361844.61149*nu + 1002013764.01019) - 967680.0*r**3*(-138240.0*nu**2 - 2675575.66847905*nu - 5278341.3229329) - 9216.0*r**2*(-197773496.793534*nu**2 - 7680.0*nu*(315.0*d5 + 405152.309729121) + 2481453539.84635*nu + 5805304367.87913) + r*(5927865218923.02*nu**3 + 70778880.0*nu**2*(315.0*d5 + 2561145.80918574) - 138141470005001.0*nu**2 - 4718592.0*nu*(40950.0*d5 + 86207832.4415642) + 450172889755120.0*nu + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0) + 5787938193408.0*r*log(r)**2 + (-1698693120.0*nu*(11592.0*nu + 69847.0) + 879923036160.0*r**3 + 283115520.0*r**2*(14700.0*nu + 42911.0) + 49152.0*r*(102574080.0*nu**2 + 409207698.136075*nu - 2119671837.36038))*log(r))
 * 
 *         cdef double Apm = 7680.0*r**4*(-5416406.59541186*nu**2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*log(r) - 7.0*r*(-185763.092693281*nu**2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu**4 + 1120.0*nu**3*(-17833256.898555*r**2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu**2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r**5 - 3089250703.76879*r**4 - 6178501407.53758*r**3 + 2064783811.32587*r**2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu**2*log(r)**2 + 53760.0*nu*(7680.0*a6*(r**4 + 2.0*r**3 + 4.0*r**2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r**4 + 4264.6962773603*r**3 + 8529.39255472061*r**2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r**4 + 2.0*r**3 + 4.0*r**2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r**4 + 1926.0*r**3 + 3852.0*r**2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu**2 - 38842241.4769507*nu + 161280.0*r**5 + 480.0*r**4*(756.0*nu + 1079.0) + 960.0*r**3*(756.0*nu + 1079.0) + 1920.0*r**2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu**2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*log(r) + 13212057600.0*r**5)             # <<<<<<<<<<<<<<
 * 
 *         cdef double ap = chi_1*X_1 + chi_2*X_2
 */
  __Pyx_TraceLine(1289,0,__PYX_ERR(1, 1289, __pyx_L1_error))
  __pyx_v_Apm = (((7680.0 * pow(__pyx_v_r, 4.0)) * (((((-5416406.59541186 * pow(__pyx_v_nu, 2.0)) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) + (((2048.0 * __pyx_v_nu) * (((756.0 * __pyx_v_nu) + (336.0 * __pyx_v_r)) + 407.0)) * log(__pyx_v_r))) - ((7.0 * __pyx_v_r) * (((-185763.092693281 * pow(__pyx_v_nu, 2.0)) + (938918.400156317 * __pyx_v_nu)) - 245760.0))) - 3440640.0)) / (((((((241555486248.807 * pow(__pyx_v_nu, 4.0)) + ((1120.0 * pow(__pyx_v_nu, 3.0)) * (((-17833256.898555 * pow(__pyx_v_r, 2.0)) - (163683964.822551 * __pyx_v_r)) - 1188987459.03162))) + ((7.0 * pow(__pyx_v_nu, 2.0)) * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (1426660551.8844 * pow(__pyx_v_r, 5.0))) - (3089250703.76879 * pow(__pyx_v_r, 4.0))) - (6178501407.53758 * pow(__pyx_v_r, 3.0))) + (2064783811.32587 * pow(__pyx_v_r, 2.0))) + (122635399361.987 * __pyx_v_r)) + 276057889687.011))) + ((67645734912.0 * pow(__pyx_v_nu, 2.0)) * pow(log(__pyx_v_r), 2.0))) + ((53760.0 * __pyx_v_nu) * (((((7680.0 * __pyx_v_a6) * ((((pow(__pyx_v_r, 4.0) + (2.0 * pow(__pyx_v_r, 3.0))) + (4.0 * pow(__pyx_v_r, 2.0))) + (8.0 * __pyx_v_r)) + 16.0)) + ((128.0 * __pyx_v_r) * (((((-6852.34813868015 * pow(__pyx_v_r, 4.0)) + (4264.6962773603 * pow(__pyx_v_r, 3.0))) + (8529.39255472061 * pow(__pyx_v_r, 2.0))) + (13218.7851094412 * __pyx_v_r)) - 33722.4297811176))) + ((113485.217444961 * __pyx_v_r) * (((((-pow(__pyx_v_r, 4.0)) + (2.0 * pow(__pyx_v_r, 3.0))) + (4.0 * pow(__pyx_v_r, 2.0))) + (8.0 * __pyx_v_r)) + 16.0))) + ((148.04406601634 * __pyx_v_r) * (((((349.0 * pow(__pyx_v_r, 4.0)) + (1926.0 * pow(__pyx_v_r, 3.0))) + (3852.0 * pow(__pyx_v_r, 2.0))) + (7704.0 * __pyx_v_r)) + 36400.0))))) + (((32768.0 * __pyx_v_nu) * ((((((((-1882456.23663972 * pow(__pyx_v_nu, 2.0)) - (38842241.4769507 * __pyx_v_nu)) + (161280.0 * pow(__pyx_v_r, 5.0))) + ((480.0 * pow(__pyx_v_r, 4.0)) * ((756.0 * __pyx_v_nu) + 1079.0))) + ((960.0 * pow(__pyx_v_r, 3.0)) * ((756.0 * __pyx_v_nu) + 1079.0))) + ((1920.0 * pow(__pyx_v_r, 2.0)) * ((588.0 * __pyx_v_nu) + 1079.0))) + ((240.0 * __pyx_v_r) * (((-3024.0 * pow(__pyx_v_nu, 2.0)) - (7466.27061066206 * __pyx_v_nu)) + 17264.0))) + 13447680.0)) * log(__pyx_v_r))) + (13212057600.0 * pow(__pyx_v_r, 5.0))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1291
 *         cdef double Apm = 7680.0*r**4*(-5416406.59541186*nu**2 + 28.0*nu*(1920.0*a6 + 733955.307463037) + 2048.0*nu*(756.0*nu + 336.0*r + 407.0)*log(r) - 7.0*r*(-185763.092693281*nu**2 + 938918.400156317*nu - 245760.0) - 3440640.0)/(241555486248.807*nu**4 + 1120.0*nu**3*(-17833256.898555*r**2 - 163683964.822551*r - 1188987459.03162) + 7.0*nu**2*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 1426660551.8844*r**5 - 3089250703.76879*r**4 - 6178501407.53758*r**3 + 2064783811.32587*r**2 + 122635399361.987*r + 276057889687.011) + 67645734912.0*nu**2*log(r)**2 + 53760.0*nu*(7680.0*a6*(r**4 + 2.0*r**3 + 4.0*r**2 + 8.0*r + 16.0) + 128.0*r*(-6852.34813868015*r**4 + 4264.6962773603*r**3 + 8529.39255472061*r**2 + 13218.7851094412*r - 33722.4297811176) + 113485.217444961*r*(-r**4 + 2.0*r**3 + 4.0*r**2 + 8.0*r + 16.0) + 148.04406601634*r*(349.0*r**4 + 1926.0*r**3 + 3852.0*r**2 + 7704.0*r + 36400.0)) + 32768.0*nu*(-1882456.23663972*nu**2 - 38842241.4769507*nu + 161280.0*r**5 + 480.0*r**4*(756.0*nu + 1079.0) + 960.0*r**3*(756.0*nu + 1079.0) + 1920.0*r**2*(588.0*nu + 1079.0) + 240.0*r*(-3024.0*nu**2 - 7466.27061066206*nu + 17264.0) + 13447680.0)*log(r) + 13212057600.0*r**5)
 * 
 *         cdef double ap = chi_1*X_1 + chi_2*X_2             # <<<<<<<<<<<<<<
 * 
 *         cdef double ap2 = ap**2
 */
  __Pyx_TraceLine(1291,0,__PYX_ERR(1, 1291, __pyx_L1_error))
  __pyx_v_ap = ((__pyx_v_chi_1 * __pyx_v_X_1) + (__pyx_v_chi_2 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1293
 *         cdef double ap = chi_1*X_1 + chi_2*X_2
 * 
 *         cdef double ap2 = ap**2             # <<<<<<<<<<<<<<
 * 
 *         cdef double xi = Dbpm**0.5*r**2*(Apm + ap2/r**2)/(ap2 + r**2)
 */
  __Pyx_TraceLine(1293,0,__PYX_ERR(1, 1293, __pyx_L1_error))
  __pyx_v_ap2 = pow(__pyx_v_ap, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1295
 *         cdef double ap2 = ap**2
 * 
 *         cdef double xi = Dbpm**0.5*r**2*(Apm + ap2/r**2)/(ap2 + r**2)             # <<<<<<<<<<<<<<
 * 
 *         return xi
 */
  __Pyx_TraceLine(1295,0,__PYX_ERR(1, 1295, __pyx_L1_error))
  __pyx_t_3 = __Pyx_SoftComplexToDouble(__Pyx_c_quot_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_Dbpm, 0), __pyx_t_double_complex_from_parts(0.5, 0)), __pyx_t_double_complex_from_parts(pow(__pyx_v_r, 2.0), 0)), __pyx_t_double_complex_from_parts((__pyx_v_Apm + (__pyx_v_ap2 / pow(__pyx_v_r, 2.0))), 0)), __pyx_t_double_complex_from_parts((__pyx_v_ap2 + pow(__pyx_v_r, 2.0)), 0)), 1); if (unlikely(__pyx_t_3 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1295, __pyx_L1_error)
  __pyx_v_xi = __pyx_t_3;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1297
 *         cdef double xi = Dbpm**0.5*r**2*(Apm + ap2/r**2)/(ap2 + r**2)
 * 
 *         return xi             # <<<<<<<<<<<<<<
 * 
 *     cpdef dynamics(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):
 */
  __Pyx_TraceLine(1297,0,__PYX_ERR(1, 1297, __pyx_L1_error))
  __pyx_r = __pyx_v_xi;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1246
 *         return np.array([d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2]).reshape(4, 4)
 * 
 *     cdef double xi(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.xi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1299
 *         return xi
 * 
 *     cpdef dynamics(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_dynamics(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  double __pyx_v_pphi;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_x0;
  double __pyx_v_x1;
  double __pyx_v_x2;
  double __pyx_v_x3;
  double __pyx_v_x4;
  double __pyx_v_x5;
  double __pyx_v_x6;
  double __pyx_v_x7;
  double __pyx_v_x8;
  double __pyx_v_x9;
  double __pyx_v_x10;
  double __pyx_v_x11;
  double __pyx_v_x12;
  double __pyx_v_x13;
  double __pyx_v_x14;
  double __pyx_v_x15;
  double __pyx_v_x16;
  double __pyx_v_x17;
  double __pyx_v_x18;
  double __pyx_v_x19;
  double __pyx_v_x20;
  double __pyx_v_x21;
  double __pyx_v_x22;
  double __pyx_v_x23;
  double __pyx_v_x24;
  double __pyx_v_x25;
  double __pyx_v_x26;
  double __pyx_v_x27;
  double __pyx_v_x28;
  double __pyx_v_x29;
  double __pyx_v_x30;
  double __pyx_v_x31;
  double __pyx_v_x32;
  double __pyx_v_x33;
  double __pyx_v_x34;
  double __pyx_v_x35;
  double __pyx_v_x36;
  double __pyx_v_x37;
  double __pyx_v_x38;
  double __pyx_v_x39;
  double __pyx_v_x40;
  double __pyx_v_x41;
  double __pyx_v_x42;
  double __pyx_v_x43;
  double __pyx_v_x44;
  double __pyx_v_x45;
  double __pyx_v_x46;
  double __pyx_v_x47;
  double __pyx_v_x48;
  double __pyx_v_x49;
  double __pyx_v_x50;
  double __pyx_v_x51;
  double __pyx_v_x52;
  double __pyx_v_x53;
  double __pyx_v_x54;
  double __pyx_v_x55;
  double __pyx_v_x56;
  double __pyx_v_x57;
  double __pyx_v_x58;
  double __pyx_v_x59;
  double __pyx_v_x60;
  double __pyx_v_x61;
  double __pyx_v_x62;
  double __pyx_v_x63;
  double __pyx_v_x64;
  double __pyx_v_x65;
  double __pyx_v_x66;
  double __pyx_v_x67;
  double __pyx_v_x68;
  double __pyx_v_x69;
  double __pyx_v_x70;
  double __pyx_v_x71;
  double __pyx_v_x72;
  double __pyx_v_x73;
  double __pyx_v_x74;
  double __pyx_v_x75;
  double __pyx_v_x76;
  double __pyx_v_x77;
  double __pyx_v_x78;
  double __pyx_v_x79;
  double __pyx_v_x80;
  double __pyx_v_x81;
  double __pyx_v_x82;
  double __pyx_v_x83;
  double __pyx_v_x84;
  double __pyx_v_x85;
  double __pyx_v_x86;
  double __pyx_v_x87;
  double __pyx_v_x88;
  double __pyx_v_x89;
  double __pyx_v_x90;
  double __pyx_v_x91;
  double __pyx_v_x92;
  double __pyx_v_x93;
  double __pyx_v_x94;
  double __pyx_v_x95;
  double __pyx_v_x96;
  double __pyx_v_x97;
  double __pyx_v_x98;
  double __pyx_v_x99;
  double __pyx_v_x100;
  double __pyx_v_x101;
  double __pyx_v_x102;
  double __pyx_v_x103;
  double __pyx_v_x104;
  double __pyx_v_x105;
  double __pyx_v_x106;
  double __pyx_v_x107;
  double __pyx_v_x108;
  double __pyx_v_x109;
  double __pyx_v_x110;
  double __pyx_v_x111;
  double __pyx_v_x112;
  double __pyx_v_x113;
  double __pyx_v_x114;
  double __pyx_v_x115;
  double __pyx_v_x116;
  double __pyx_v_x117;
  double __pyx_v_x118;
  double __pyx_v_x119;
  double __pyx_v_x120;
  double __pyx_v_x121;
  double __pyx_v_x122;
  double __pyx_v_x123;
  double __pyx_v_x124;
  double __pyx_v_x125;
  double __pyx_v_x126;
  double __pyx_v_x127;
  double __pyx_v_x128;
  double __pyx_v_x129;
  double __pyx_v_x130;
  double __pyx_v_x131;
  double __pyx_v_x132;
  double __pyx_v_x133;
  double __pyx_v_x134;
  double __pyx_v_x135;
  double __pyx_v_x136;
  double __pyx_v_x137;
  double __pyx_v_x138;
  double __pyx_v_x139;
  double __pyx_v_x140;
  double __pyx_v_x141;
  double __pyx_v_x142;
  double __pyx_v_x143;
  double __pyx_v_x144;
  double __pyx_v_x145;
  double __pyx_v_x146;
  double __pyx_v_x147;
  double __pyx_v_x148;
  double __pyx_v_x149;
  double __pyx_v_x150;
  double __pyx_v_x151;
  double __pyx_v_x152;
  double __pyx_v_x153;
  double __pyx_v_x154;
  double __pyx_v_x155;
  double __pyx_v_x156;
  double __pyx_v_x157;
  double __pyx_v_x158;
  double __pyx_v_x159;
  double __pyx_v_x160;
  double __pyx_v_x161;
  double __pyx_v_x162;
  double __pyx_v_x163;
  double __pyx_v_x164;
  double __pyx_v_x165;
  double __pyx_v_x166;
  double __pyx_v_x167;
  double __pyx_v_x168;
  double __pyx_v_x169;
  double __pyx_v_x170;
  double __pyx_v_x171;
  double __pyx_v_x172;
  double __pyx_v_x173;
  double __pyx_v_x174;
  double __pyx_v_x175;
  double __pyx_v_x176;
  double __pyx_v_x177;
  double __pyx_v_x178;
  double __pyx_v_x179;
  double __pyx_v_x180;
  double __pyx_v_x181;
  double __pyx_v_x182;
  double __pyx_v_x183;
  double __pyx_v_x184;
  double __pyx_v_x185;
  double __pyx_v_x186;
  double __pyx_v_x187;
  double __pyx_v_x188;
  double __pyx_v_x189;
  double __pyx_v_x190;
  double __pyx_v_x191;
  double __pyx_v_x192;
  double __pyx_v_x193;
  double __pyx_v_x194;
  double __pyx_v_x195;
  double __pyx_v_H;
  double __pyx_v_xi;
  double __pyx_v_dHeffdr;
  double __pyx_v_dHeffdphi;
  double __pyx_v_dHeffdpr;
  double __pyx_v_dHeffdpphi;
  double __pyx_v_M2;
  double __pyx_v_nuH;
  double __pyx_v_dHdr;
  double __pyx_v_dHdphi;
  double __pyx_v_dHdpr;
  double __pyx_v_dHdpphi;
  double __pyx_v_result[6];
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  double __pyx_t_13;
  __pyx_ctuple_double__and_double __pyx_t_14;
  double __pyx_t_15;
  double __pyx_t_16[6];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__16)
  __Pyx_RefNannySetupContext("dynamics", 0);
  __Pyx_TraceCall("dynamics", __pyx_f[1], 1299, 0, __PYX_ERR(1, 1299, __pyx_L1_error));
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_dynamics); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #ifdef __Pyx_CyFunction_USED
      if (!__Pyx_IsCyOrPyCFunction(__pyx_t_1)
      #else
      if (!PyCFunction_Check(__pyx_t_1)
      #endif
              || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics)) {
        __Pyx_XDECREF(__pyx_r);
        if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 1299, __pyx_L1_error) }
        __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_q, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 1299, __pyx_L1_error) }
        __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_p, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyFloat_FromDouble(__pyx_v_chi_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyFloat_FromDouble(__pyx_v_chi_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyFloat_FromDouble(__pyx_v_m_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_m_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = __pyx_t_1; __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_11 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[7] = {__pyx_t_10, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 6+__pyx_t_11);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1299, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1318
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(1318,0,__PYX_ERR(1, 1318, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1319
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(1319,0,__PYX_ERR(1, 1319, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1321
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(1321,0,__PYX_ERR(1, 1321, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1322
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(1322,0,__PYX_ERR(1, 1322, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1324
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(1324,0,__PYX_ERR(1, 1324, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1326
 *         cdef double pphi = L
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']
 */
  __Pyx_TraceLine(1326,0,__PYX_ERR(1, 1326, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1327
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs['dSO']
 * 
 */
  __Pyx_TraceLine(1327,0,__PYX_ERR(1, 1327, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_a6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_a6 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1328
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']             # <<<<<<<<<<<<<<
 * 
 *         # Extra quantities used in the Jacobian
 */
  __Pyx_TraceLine(1328,0,__PYX_ERR(1, 1328, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_dSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_dSO = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1331
 * 
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M             # <<<<<<<<<<<<<<
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 */
  __Pyx_TraceLine(1331,0,__PYX_ERR(1, 1331, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->M;
  __pyx_v_M = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1332
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu             # <<<<<<<<<<<<<<
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 */
  __Pyx_TraceLine(1332,0,__PYX_ERR(1, 1332, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->nu;
  __pyx_v_nu = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1333
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1             # <<<<<<<<<<<<<<
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2
 */
  __Pyx_TraceLine(1333,0,__PYX_ERR(1, 1333, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_1;
  __pyx_v_X_1 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1334
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2             # <<<<<<<<<<<<<<
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1
 */
  __Pyx_TraceLine(1334,0,__PYX_ERR(1, 1334, __pyx_L1_error))
  __pyx_t_13 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_2;
  __pyx_v_X_2 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1335
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2             # <<<<<<<<<<<<<<
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2
 */
  __Pyx_TraceLine(1335,0,__PYX_ERR(1, 1335, __pyx_L1_error))
  __pyx_v_x0 = pow(__pyx_v_r, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1336
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1             # <<<<<<<<<<<<<<
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2
 */
  __Pyx_TraceLine(1336,0,__PYX_ERR(1, 1336, __pyx_L1_error))
  __pyx_v_x1 = (__pyx_v_chi_1 * __pyx_v_X_1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1337
 *         cdef double x0 = r**2
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2             # <<<<<<<<<<<<<<
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2
 */
  __Pyx_TraceLine(1337,0,__PYX_ERR(1, 1337, __pyx_L1_error))
  __pyx_v_x2 = (__pyx_v_chi_2 * __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1338
 *         cdef double x1 = chi_1*X_1
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2             # <<<<<<<<<<<<<<
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4
 */
  __Pyx_TraceLine(1338,0,__PYX_ERR(1, 1338, __pyx_L1_error))
  __pyx_v_x3 = (__pyx_v_x1 + __pyx_v_x2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1339
 *         cdef double x2 = chi_2*X_2
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2             # <<<<<<<<<<<<<<
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r
 */
  __Pyx_TraceLine(1339,0,__PYX_ERR(1, 1339, __pyx_L1_error))
  __pyx_v_x4 = pow(__pyx_v_x3, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1340
 *         cdef double x3 = x1 + x2
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4             # <<<<<<<<<<<<<<
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4
 */
  __Pyx_TraceLine(1340,0,__PYX_ERR(1, 1340, __pyx_L1_error))
  __pyx_v_x5 = (2.0 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1341
 *         cdef double x4 = x3**2
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r             # <<<<<<<<<<<<<<
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)
 */
  __Pyx_TraceLine(1341,0,__PYX_ERR(1, 1341, __pyx_L1_error))
  __pyx_v_x6 = (2.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1342
 *         cdef double x5 = 2.0*x4
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4             # <<<<<<<<<<<<<<
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 */
  __Pyx_TraceLine(1342,0,__PYX_ERR(1, 1342, __pyx_L1_error))
  __pyx_v_x7 = (__pyx_v_x0 + __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1343
 *         cdef double x6 = 2.0*r
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)             # <<<<<<<<<<<<<<
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4
 */
  __Pyx_TraceLine(1343,0,__PYX_ERR(1, 1343, __pyx_L1_error))
  __pyx_v_x8 = (__pyx_v_r * ((-__pyx_v_x6) + __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1344
 *         cdef double x7 = x0 + x4
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x10 = r**4
 *         cdef double x11 = 1/x10
 */
  __Pyx_TraceLine(1344,0,__PYX_ERR(1, 1344, __pyx_L1_error))
  __pyx_v_x9 = pow((((2.0 * __pyx_v_x0) + __pyx_v_x5) + __pyx_v_x8), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1345
 *         cdef double x8 = r*(-x6 + x7)
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4             # <<<<<<<<<<<<<<
 *         cdef double x11 = 1/x10
 *         cdef double x12 = 3.0*nu
 */
  __Pyx_TraceLine(1345,0,__PYX_ERR(1, 1345, __pyx_L1_error))
  __pyx_v_x10 = pow(__pyx_v_r, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1346
 *         cdef double x9 = (2.0*x0 + x5 + x8)**(-1)
 *         cdef double x10 = r**4
 *         cdef double x11 = 1/x10             # <<<<<<<<<<<<<<
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3
 */
  __Pyx_TraceLine(1346,0,__PYX_ERR(1, 1346, __pyx_L1_error))
  __pyx_v_x11 = (1.0 / __pyx_v_x10);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1347
 *         cdef double x10 = r**4
 *         cdef double x11 = 1/x10
 *         cdef double x12 = 3.0*nu             # <<<<<<<<<<<<<<
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3
 */
  __Pyx_TraceLine(1347,0,__PYX_ERR(1, 1347, __pyx_L1_error))
  __pyx_v_x12 = (3.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1348
 *         cdef double x11 = 1/x10
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3             # <<<<<<<<<<<<<<
 *         cdef double x14 = r**3
 *         cdef double x15 = 1/x14
 */
  __Pyx_TraceLine(1348,0,__PYX_ERR(1, 1348, __pyx_L1_error))
  __pyx_v_x13 = (__pyx_v_pphi * __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1349
 *         cdef double x12 = 3.0*nu
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3             # <<<<<<<<<<<<<<
 *         cdef double x15 = 1/x14
 *         cdef double x16 = x15*x4
 */
  __Pyx_TraceLine(1349,0,__PYX_ERR(1, 1349, __pyx_L1_error))
  __pyx_v_x14 = pow(__pyx_v_r, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1350
 *         cdef double x13 = pphi*x3
 *         cdef double x14 = r**3
 *         cdef double x15 = 1/x14             # <<<<<<<<<<<<<<
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2
 */
  __Pyx_TraceLine(1350,0,__PYX_ERR(1, 1350, __pyx_L1_error))
  __pyx_v_x15 = (1.0 / __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1351
 *         cdef double x14 = r**3
 *         cdef double x15 = 1/x14
 *         cdef double x16 = x15*x4             # <<<<<<<<<<<<<<
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2
 */
  __Pyx_TraceLine(1351,0,__PYX_ERR(1, 1351, __pyx_L1_error))
  __pyx_v_x16 = (__pyx_v_x15 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1352
 *         cdef double x15 = 1/x14
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2             # <<<<<<<<<<<<<<
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18
 */
  __Pyx_TraceLine(1352,0,__PYX_ERR(1, 1352, __pyx_L1_error))
  __pyx_v_x17 = (__pyx_v_x1 - __pyx_v_x2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1353
 *         cdef double x16 = x15*x4
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2             # <<<<<<<<<<<<<<
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19
 */
  __Pyx_TraceLine(1353,0,__PYX_ERR(1, 1353, __pyx_L1_error))
  __pyx_v_x18 = (__pyx_v_X_1 - __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1354
 *         cdef double x17 = x1 - x2
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18             # <<<<<<<<<<<<<<
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 */
  __Pyx_TraceLine(1354,0,__PYX_ERR(1, 1354, __pyx_L1_error))
  __pyx_v_x19 = (__pyx_v_x17 * __pyx_v_x18);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1355
 *         cdef double x18 = X_1 - X_2
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19             # <<<<<<<<<<<<<<
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3
 */
  __Pyx_TraceLine(1355,0,__PYX_ERR(1, 1355, __pyx_L1_error))
  __pyx_v_x20 = (__pyx_v_pphi * __pyx_v_x19);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1356
 *         cdef double x19 = x17*x18
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 */
  __Pyx_TraceLine(1356,0,__PYX_ERR(1, 1356, __pyx_L1_error))
  __pyx_v_x21 = ((5.0 * __pyx_v_X_1) - (5.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1357
 *         cdef double x20 = pphi*x19
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3             # <<<<<<<<<<<<<<
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15
 */
  __Pyx_TraceLine(1357,0,__PYX_ERR(1, 1357, __pyx_L1_error))
  __pyx_v_x22 = (__pyx_v_x17 * __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1358
 *         cdef double x21 = 5.0*X_1 - 5.0*X_2
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4             # <<<<<<<<<<<<<<
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = 1/x0
 */
  __Pyx_TraceLine(1358,0,__PYX_ERR(1, 1358, __pyx_L1_error))
  __pyx_v_x23 = (((0.0416666666666667 * __pyx_v_x21) * __pyx_v_x22) - (0.25 * __pyx_v_x4));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1359
 *         cdef double x22 = x17*x3
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15             # <<<<<<<<<<<<<<
 *         cdef double x25 = 1/x0
 *         cdef double x26 = 0.71875*nu - 0.09375
 */
  __Pyx_TraceLine(1359,0,__PYX_ERR(1, 1359, __pyx_L1_error))
  __pyx_v_x24 = (2.0 * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1360
 *         cdef double x23 = 0.0416666666666667*x21*x22 - 0.25*x4
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = 1/x0             # <<<<<<<<<<<<<<
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875
 */
  __Pyx_TraceLine(1360,0,__PYX_ERR(1, 1360, __pyx_L1_error))
  __pyx_v_x25 = (1.0 / __pyx_v_x0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1361
 *         cdef double x24 = 2.0*x15
 *         cdef double x25 = 1/x0
 *         cdef double x26 = 0.71875*nu - 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2
 */
  __Pyx_TraceLine(1361,0,__PYX_ERR(1, 1361, __pyx_L1_error))
  __pyx_v_x26 = ((0.71875 * __pyx_v_nu) - 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1362
 *         cdef double x25 = 1/x0
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875             # <<<<<<<<<<<<<<
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28
 */
  __Pyx_TraceLine(1362,0,__PYX_ERR(1, 1362, __pyx_L1_error))
  __pyx_v_x27 = ((-1.40625 * __pyx_v_nu) - 0.46875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1363
 *         cdef double x26 = 0.71875*nu - 0.09375
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2             # <<<<<<<<<<<<<<
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29
 */
  __Pyx_TraceLine(1363,0,__PYX_ERR(1, 1363, __pyx_L1_error))
  __pyx_v_x28 = pow(__pyx_v_pphi, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1364
 *         cdef double x27 = -1.40625*nu - 0.46875
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28             # <<<<<<<<<<<<<<
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2
 */
  __Pyx_TraceLine(1364,0,__PYX_ERR(1, 1364, __pyx_L1_error))
  __pyx_v_x29 = (__pyx_v_x15 * __pyx_v_x28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1365
 *         cdef double x28 = pphi**2
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29             # <<<<<<<<<<<<<<
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 */
  __Pyx_TraceLine(1365,0,__PYX_ERR(1, 1365, __pyx_L1_error))
  __pyx_v_x30 = (2.0 * __pyx_v_x29);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1366
 *         cdef double x29 = x15*x28
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2             # <<<<<<<<<<<<<<
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11
 */
  __Pyx_TraceLine(1366,0,__PYX_ERR(1, 1366, __pyx_L1_error))
  __pyx_v_x31 = pow(__pyx_v_nu, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1367
 *         cdef double x30 = 2.0*x29
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33
 */
  __Pyx_TraceLine(1367,0,__PYX_ERR(1, 1367, __pyx_L1_error))
  __pyx_v_x32 = (((-2.0859375 * __pyx_v_nu) - (2.07161458333333 * __pyx_v_x31)) + 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1368
 *         cdef double x31 = nu**2
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11             # <<<<<<<<<<<<<<
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 */
  __Pyx_TraceLine(1368,0,__PYX_ERR(1, 1368, __pyx_L1_error))
  __pyx_v_x33 = (3.0 * __pyx_v_x11);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1369
 *         cdef double x32 = -2.0859375*nu - 2.07161458333333*x31 + 0.23046875
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33             # <<<<<<<<<<<<<<
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4
 */
  __Pyx_TraceLine(1369,0,__PYX_ERR(1, 1369, __pyx_L1_error))
  __pyx_v_x34 = (__pyx_v_x28 * __pyx_v_x33);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1370
 *         cdef double x33 = 3.0*x11
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5
 */
  __Pyx_TraceLine(1370,0,__PYX_ERR(1, 1370, __pyx_L1_error))
  __pyx_v_x35 = (((0.5859375 * __pyx_v_nu) + (1.34765625 * __pyx_v_x31)) + 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1371
 *         cdef double x34 = x28*x33
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4             # <<<<<<<<<<<<<<
 *         cdef double x37 = r**5
 *         cdef double x38 = 1/x37
 */
  __Pyx_TraceLine(1371,0,__PYX_ERR(1, 1371, __pyx_L1_error))
  __pyx_v_x36 = pow(__pyx_v_pphi, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1372
 *         cdef double x35 = 0.5859375*nu + 1.34765625*x31 + 0.41015625
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5             # <<<<<<<<<<<<<<
 *         cdef double x38 = 1/x37
 *         cdef double x39 = 4.0*x38
 */
  __Pyx_TraceLine(1372,0,__PYX_ERR(1, 1372, __pyx_L1_error))
  __pyx_v_x37 = pow(__pyx_v_r, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1373
 *         cdef double x36 = pphi**4
 *         cdef double x37 = r**5
 *         cdef double x38 = 1/x37             # <<<<<<<<<<<<<<
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39
 */
  __Pyx_TraceLine(1373,0,__PYX_ERR(1, 1373, __pyx_L1_error))
  __pyx_v_x38 = (1.0 / __pyx_v_x37);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1374
 *         cdef double x37 = r**5
 *         cdef double x38 = 1/x37
 *         cdef double x39 = 4.0*x38             # <<<<<<<<<<<<<<
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375
 */
  __Pyx_TraceLine(1374,0,__PYX_ERR(1, 1374, __pyx_L1_error))
  __pyx_v_x39 = (4.0 * __pyx_v_x38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1375
 *         cdef double x38 = 1/x37
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39             # <<<<<<<<<<<<<<
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu
 */
  __Pyx_TraceLine(1375,0,__PYX_ERR(1, 1375, __pyx_L1_error))
  __pyx_v_x40 = (__pyx_v_x36 * __pyx_v_x39);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1376
 *         cdef double x39 = 4.0*x38
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 */
  __Pyx_TraceLine(1376,0,__PYX_ERR(1, 1376, __pyx_L1_error))
  __pyx_v_x41 = ((0.34375 * __pyx_v_nu) + 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1377
 *         cdef double x40 = x36*x39
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu             # <<<<<<<<<<<<<<
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 */
  __Pyx_TraceLine(1377,0,__PYX_ERR(1, 1377, __pyx_L1_error))
  __pyx_v_x42 = (0.46875 - (0.28125 * __pyx_v_nu));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1378
 *         cdef double x41 = 0.34375*nu + 0.09375
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15
 */
  __Pyx_TraceLine(1378,0,__PYX_ERR(1, 1378, __pyx_L1_error))
  __pyx_v_x43 = (((-0.2734375 * __pyx_v_nu) - (0.798177083333333 * __pyx_v_x31)) - 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1379
 *         cdef double x42 = 0.46875 - 0.28125*nu
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4
 */
  __Pyx_TraceLine(1379,0,__PYX_ERR(1, 1379, __pyx_L1_error))
  __pyx_v_x44 = (((-0.3515625 * __pyx_v_nu) + (0.29296875 * __pyx_v_x31)) - 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1380
 *         cdef double x43 = -0.2734375*nu - 0.798177083333333*x31 - 0.23046875
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15             # <<<<<<<<<<<<<<
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46
 */
  __Pyx_TraceLine(1380,0,__PYX_ERR(1, 1380, __pyx_L1_error))
  __pyx_v_x45 = ((__pyx_v_nu * __pyx_v_dSO) * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1381
 *         cdef double x44 = -0.3515625*nu + 0.29296875*x31 - 0.41015625
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4             # <<<<<<<<<<<<<<
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25
 */
  __Pyx_TraceLine(1381,0,__PYX_ERR(1, 1381, __pyx_L1_error))
  __pyx_v_x46 = (__pyx_v_x25 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1382
 *         cdef double x45 = nu*dSO*x15
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46             # <<<<<<<<<<<<<<
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)
 */
  __Pyx_TraceLine(1382,0,__PYX_ERR(1, 1382, __pyx_L1_error))
  __pyx_v_x47 = (0.0416666666666667 * __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1383
 *         cdef double x46 = x25*x4
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25             # <<<<<<<<<<<<<<
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28
 */
  __Pyx_TraceLine(1383,0,__PYX_ERR(1, 1383, __pyx_L1_error))
  __pyx_v_x48 = (__pyx_v_x23 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1384
 *         cdef double x47 = 0.0416666666666667*x46
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36
 */
  __Pyx_TraceLine(1384,0,__PYX_ERR(1, 1384, __pyx_L1_error))
  __pyx_v_x49 = pow(__pyx_v_r, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1385
 *         cdef double x48 = x23*x25
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28             # <<<<<<<<<<<<<<
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 */
  __Pyx_TraceLine(1385,0,__PYX_ERR(1, 1385, __pyx_L1_error))
  __pyx_v_x50 = (__pyx_v_x25 * __pyx_v_x28);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1386
 *         cdef double x49 = r**(-1)
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36             # <<<<<<<<<<<<<<
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 */
  __Pyx_TraceLine(1386,0,__PYX_ERR(1, 1386, __pyx_L1_error))
  __pyx_v_x51 = (__pyx_v_x11 * __pyx_v_x36);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1387
 *         cdef double x50 = x25*x28
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)             # <<<<<<<<<<<<<<
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4
 */
  __Pyx_TraceLine(1387,0,__PYX_ERR(1, 1387, __pyx_L1_error))
  __pyx_v_x52 = (__pyx_v_x3 * ((((((__pyx_v_x25 * (((-5.53125 * __pyx_v_nu) + (0.567708333333333 * __pyx_v_x31)) - 0.078125)) + (__pyx_v_x26 * __pyx_v_x49)) + (__pyx_v_x27 * __pyx_v_x50)) + (__pyx_v_x29 * __pyx_v_x32)) + (__pyx_v_x35 * __pyx_v_x51)) + 1.75));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1388
 *         cdef double x51 = x11*x36
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)             # <<<<<<<<<<<<<<
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)
 */
  __Pyx_TraceLine(1388,0,__PYX_ERR(1, 1388, __pyx_L1_error))
  __pyx_v_x53 = (__pyx_v_x19 * ((((((__pyx_v_x25 * (((-0.03125 * __pyx_v_nu) + (0.536458333333333 * __pyx_v_x31)) + 0.078125)) + (__pyx_v_x29 * __pyx_v_x43)) + (__pyx_v_x41 * __pyx_v_x49)) + (__pyx_v_x42 * __pyx_v_x50)) + (__pyx_v_x44 * __pyx_v_x51)) + 0.25));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1389
 *         cdef double x52 = x3*(x25*(-5.53125*nu + 0.567708333333333*x31 - 0.078125) + x26*x49 + x27*x50 + x29*x32 + x35*x51 + 1.75)
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4             # <<<<<<<<<<<<<<
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55
 */
  __Pyx_TraceLine(1389,0,__PYX_ERR(1, 1389, __pyx_L1_error))
  __pyx_v_x54 = pow(__pyx_v_prst, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1390
 *         cdef double x53 = x19*(x25*(-0.03125*nu + 0.536458333333333*x31 + 0.078125) + x29*x43 + x41*x49 + x42*x50 + x44*x51 + 0.25)
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)             # <<<<<<<<<<<<<<
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6
 */
  __Pyx_TraceLine(1390,0,__PYX_ERR(1, 1390, __pyx_L1_error))
  __pyx_v_x55 = pow(__pyx_v_r, -4.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1391
 *         cdef double x54 = prst**4
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55             # <<<<<<<<<<<<<<
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)
 */
  __Pyx_TraceLine(1391,0,__PYX_ERR(1, 1391, __pyx_L1_error))
  __pyx_v_x56 = (__pyx_v_nu * __pyx_v_x55);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1392
 *         cdef double x55 = r**(-4.5)
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6             # <<<<<<<<<<<<<<
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58
 */
  __Pyx_TraceLine(1392,0,__PYX_ERR(1, 1392, __pyx_L1_error))
  __pyx_v_x57 = pow(__pyx_v_prst, 6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1393
 *         cdef double x56 = nu*x55
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)             # <<<<<<<<<<<<<<
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)
 */
  __Pyx_TraceLine(1393,0,__PYX_ERR(1, 1393, __pyx_L1_error))
  __pyx_v_x58 = pow(__pyx_v_r, -3.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1394
 *         cdef double x57 = prst**6
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58             # <<<<<<<<<<<<<<
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8
 */
  __Pyx_TraceLine(1394,0,__PYX_ERR(1, 1394, __pyx_L1_error))
  __pyx_v_x59 = (__pyx_v_nu * __pyx_v_x58);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1395
 *         cdef double x58 = r**(-3.5)
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)             # <<<<<<<<<<<<<<
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61
 */
  __Pyx_TraceLine(1395,0,__PYX_ERR(1, 1395, __pyx_L1_error))
  __pyx_v_x60 = pow(__pyx_v_r, -2.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1396
 *         cdef double x59 = nu*x58
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8             # <<<<<<<<<<<<<<
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49
 */
  __Pyx_TraceLine(1396,0,__PYX_ERR(1, 1396, __pyx_L1_error))
  __pyx_v_x61 = pow(__pyx_v_prst, 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1397
 *         cdef double x60 = r**(-2.5)
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61             # <<<<<<<<<<<<<<
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61
 */
  __Pyx_TraceLine(1397,0,__PYX_ERR(1, 1397, __pyx_L1_error))
  __pyx_v_x62 = (__pyx_v_nu * __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1398
 *         cdef double x61 = prst**8
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49             # <<<<<<<<<<<<<<
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31
 */
  __Pyx_TraceLine(1398,0,__PYX_ERR(1, 1398, __pyx_L1_error))
  __pyx_v_x63 = (__pyx_v_nu * __pyx_v_x49);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1399
 *         cdef double x62 = nu*x61
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61             # <<<<<<<<<<<<<<
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65
 */
  __Pyx_TraceLine(1399,0,__PYX_ERR(1, 1399, __pyx_L1_error))
  __pyx_v_x64 = (0.121954868780449 * __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1400
 *         cdef double x63 = nu*x49
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31             # <<<<<<<<<<<<<<
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3
 */
  __Pyx_TraceLine(1400,0,__PYX_ERR(1, 1400, __pyx_L1_error))
  __pyx_v_x65 = ((8.0 * __pyx_v_nu) - (6.0 * __pyx_v_x31));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1401
 *         cdef double x64 = 0.121954868780449*x61
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65             # <<<<<<<<<<<<<<
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 */
  __Pyx_TraceLine(1401,0,__PYX_ERR(1, 1401, __pyx_L1_error))
  __pyx_v_x66 = (__pyx_v_x25 * __pyx_v_x65);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1402
 *         cdef double x65 = 8.0*nu - 6.0*x31
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3             # <<<<<<<<<<<<<<
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54
 */
  __Pyx_TraceLine(1402,0,__PYX_ERR(1, 1402, __pyx_L1_error))
  __pyx_v_x67 = pow(__pyx_v_nu, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1403
 *         cdef double x66 = x25*x65
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67             # <<<<<<<<<<<<<<
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 */
  __Pyx_TraceLine(1403,0,__PYX_ERR(1, 1403, __pyx_L1_error))
  __pyx_v_x68 = (((92.7110442849544 * __pyx_v_nu) - (131.0 * __pyx_v_x31)) + (10.0 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1404
 *         cdef double x67 = nu**3
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54             # <<<<<<<<<<<<<<
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70
 */
  __Pyx_TraceLine(1404,0,__PYX_ERR(1, 1404, __pyx_L1_error))
  __pyx_v_x69 = (__pyx_v_x15 * __pyx_v_x54);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1405
 *         cdef double x68 = 92.7110442849544*nu - 131.0*x31 + 10.0*x67
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67             # <<<<<<<<<<<<<<
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4
 */
  __Pyx_TraceLine(1405,0,__PYX_ERR(1, 1405, __pyx_L1_error))
  __pyx_v_x70 = (((-2.78300763695006 * __pyx_v_nu) - (5.4 * __pyx_v_x31)) + (6.0 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1406
 *         cdef double x69 = x15*x54
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70             # <<<<<<<<<<<<<<
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 */
  __Pyx_TraceLine(1406,0,__PYX_ERR(1, 1406, __pyx_L1_error))
  __pyx_v_x71 = (__pyx_v_x25 * __pyx_v_x70);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1407
 *         cdef double x70 = -2.78300763695006*nu - 5.4*x31 + 6.0*x67
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4             # <<<<<<<<<<<<<<
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57
 */
  __Pyx_TraceLine(1407,0,__PYX_ERR(1, 1407, __pyx_L1_error))
  __pyx_v_x72 = pow(__pyx_v_nu, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1408
 *         cdef double x71 = x25*x70
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72             # <<<<<<<<<<<<<<
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 */
  __Pyx_TraceLine(1408,0,__PYX_ERR(1, 1408, __pyx_L1_error))
  __pyx_v_x73 = ((((-33.9782122170436 * __pyx_v_nu) - (89.5298327361234 * __pyx_v_x31)) + (188.0 * __pyx_v_x67)) - (14.0 * __pyx_v_x72));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1409
 *         cdef double x72 = nu**4
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57             # <<<<<<<<<<<<<<
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75
 */
  __Pyx_TraceLine(1409,0,__PYX_ERR(1, 1409, __pyx_L1_error))
  __pyx_v_x74 = (__pyx_v_x15 * __pyx_v_x57);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1410
 *         cdef double x73 = -33.9782122170436*nu - 89.5298327361234*x31 + 188.0*x67 - 14.0*x72
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72             # <<<<<<<<<<<<<<
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)
 */
  __Pyx_TraceLine(1410,0,__PYX_ERR(1, 1410, __pyx_L1_error))
  __pyx_v_x75 = ((((1.38977750996128 * __pyx_v_nu) + (3.33842023648322 * __pyx_v_x31)) + (3.42857142857143 * __pyx_v_x67)) - (6.0 * __pyx_v_x72));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1411
 *         cdef double x74 = x15*x57
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75             # <<<<<<<<<<<<<<
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 */
  __Pyx_TraceLine(1411,0,__PYX_ERR(1, 1411, __pyx_L1_error))
  __pyx_v_x76 = (__pyx_v_x61 * __pyx_v_x75);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1412
 *         cdef double x75 = 1.38977750996128*nu + 3.33842023648322*x31 + 3.42857142857143*x67 - 6.0*x72
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)             # <<<<<<<<<<<<<<
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54
 */
  __Pyx_TraceLine(1412,0,__PYX_ERR(1, 1412, __pyx_L1_error))
  __pyx_v_x77 = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1413
 *         cdef double x76 = x61*x75
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67             # <<<<<<<<<<<<<<
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0
 */
  __Pyx_TraceLine(1413,0,__PYX_ERR(1, 1413, __pyx_L1_error))
  __pyx_v_x78 = (((__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_x77))) + (__pyx_v_x31 * ((118.4 * __pyx_v_x77) - 1796.13660498019))) + (602.318540416564 * __pyx_v_x67));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1414
 *         cdef double x77 = log(r)
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54             # <<<<<<<<<<<<<<
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80
 */
  __Pyx_TraceLine(1414,0,__PYX_ERR(1, 1414, __pyx_L1_error))
  __pyx_v_x79 = (__pyx_v_x11 * __pyx_v_x54);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1415
 *         cdef double x78 = nu*(452.542166996693 - 51.6952380952381*x77) + x31*(118.4*x77 - 1796.13660498019) + 602.318540416564*x67
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4
 */
  __Pyx_TraceLine(1415,0,__PYX_ERR(1, 1415, __pyx_L1_error))
  __pyx_v_x80 = (__pyx_v_r + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1416
 *         cdef double x79 = x11*x54
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80             # <<<<<<<<<<<<<<
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82
 */
  __Pyx_TraceLine(1416,0,__PYX_ERR(1, 1416, __pyx_L1_error))
  __pyx_v_x81 = (__pyx_v_x4 * __pyx_v_x80);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1417
 *         cdef double x80 = r + 2.0
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4             # <<<<<<<<<<<<<<
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = 1/x83
 */
  __Pyx_TraceLine(1417,0,__PYX_ERR(1, 1417, __pyx_L1_error))
  __pyx_v_x82 = (__pyx_v_r * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1418
 *         cdef double x81 = x4*x80
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82             # <<<<<<<<<<<<<<
 *         cdef double x84 = 1/x83
 *         cdef double x85 = x28*x49*x84
 */
  __Pyx_TraceLine(1418,0,__PYX_ERR(1, 1418, __pyx_L1_error))
  __pyx_v_x83 = (__pyx_v_x10 + (__pyx_v_x80 * __pyx_v_x82));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1419
 *         cdef double x82 = r*x4
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = 1/x83             # <<<<<<<<<<<<<<
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)
 */
  __Pyx_TraceLine(1419,0,__PYX_ERR(1, 1419, __pyx_L1_error))
  __pyx_v_x84 = (1.0 / __pyx_v_x83);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1420
 *         cdef double x83 = x10 + x80*x82
 *         cdef double x84 = 1/x83
 *         cdef double x85 = x28*x49*x84             # <<<<<<<<<<<<<<
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4
 */
  __Pyx_TraceLine(1420,0,__PYX_ERR(1, 1420, __pyx_L1_error))
  __pyx_v_x85 = ((__pyx_v_x28 * __pyx_v_x49) * __pyx_v_x84);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1421
 *         cdef double x84 = 1/x83
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)             # <<<<<<<<<<<<<<
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu
 */
  __Pyx_TraceLine(1421,0,__PYX_ERR(1, 1421, __pyx_L1_error))
  __pyx_v_x86 = pow(__pyx_v_r, -13.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1422
 *         cdef double x85 = x28*x49*x84
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4             # <<<<<<<<<<<<<<
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0
 */
  __Pyx_TraceLine(1422,0,__PYX_ERR(1, 1422, __pyx_L1_error))
  __pyx_v_x87 = pow(__pyx_v_x7, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1423
 *         cdef double x86 = r**(-13)
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu             # <<<<<<<<<<<<<<
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 */
  __Pyx_TraceLine(1423,0,__PYX_ERR(1, 1423, __pyx_L1_error))
  __pyx_v_x88 = (756.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1424
 *         cdef double x87 = x7**4
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0             # <<<<<<<<<<<<<<
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2
 */
  __Pyx_TraceLine(1424,0,__PYX_ERR(1, 1424, __pyx_L1_error))
  __pyx_v_x89 = (((336.0 * __pyx_v_r) + __pyx_v_x88) + 407.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1425
 *         cdef double x88 = 756.0*nu
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0             # <<<<<<<<<<<<<<
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91
 */
  __Pyx_TraceLine(1425,0,__PYX_ERR(1, 1425, __pyx_L1_error))
  __pyx_v_x90 = (((((((2048.0 * __pyx_v_nu) * __pyx_v_x77) * __pyx_v_x89) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) - ((7.0 * __pyx_v_r) * (((938918.400156317 * __pyx_v_nu) - (185763.092693281 * __pyx_v_x31)) - 245760.0))) - (5416406.59541186 * __pyx_v_x31)) - 3440640.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1426
 *         cdef double x89 = 336.0*r + x88 + 407.0
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2             # <<<<<<<<<<<<<<
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 */
  __Pyx_TraceLine(1426,0,__PYX_ERR(1, 1426, __pyx_L1_error))
  __pyx_v_x91 = pow(__pyx_v_x77, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1427
 *         cdef double x90 = 2048.0*nu*x77*x89 + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*x31 - 245760.0) - 5416406.59541186*x31 - 3440640.0
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91             # <<<<<<<<<<<<<<
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 */
  __Pyx_TraceLine(1427,0,__PYX_ERR(1, 1427, __pyx_L1_error))
  __pyx_v_x92 = (__pyx_v_x31 * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1428
 *         cdef double x91 = x77**2
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)             # <<<<<<<<<<<<<<
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0
 */
  __Pyx_TraceLine(1428,0,__PYX_ERR(1, 1428, __pyx_L1_error))
  __pyx_v_x93 = (__pyx_v_x67 * (((-163683964.822551 * __pyx_v_r) - (17833256.898555 * __pyx_v_x0)) - 1188987459.03162));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1429
 *         cdef double x92 = x31*x91
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)             # <<<<<<<<<<<<<<
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0
 */
  __Pyx_TraceLine(1429,0,__PYX_ERR(1, 1429, __pyx_L1_error))
  __pyx_v_x94 = (__pyx_v_x31 * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (122635399361.987 * __pyx_v_r)) + (2064783811.32587 * __pyx_v_x0)) - (3089250703.76879 * __pyx_v_x10)) - (6178501407.53758 * __pyx_v_x14)) + (1426660551.8844 * __pyx_v_x37)) + 276057889687.011));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1430
 *         cdef double x93 = x67*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96
 */
  __Pyx_TraceLine(1430,0,__PYX_ERR(1, 1430, __pyx_L1_error))
  __pyx_v_x95 = ((588.0 * __pyx_v_nu) + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1431
 *         cdef double x94 = x31*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x10 - 6178501407.53758*x14 + 1426660551.8844*x37 + 276057889687.011)
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 */
  __Pyx_TraceLine(1431,0,__PYX_ERR(1, 1431, __pyx_L1_error))
  __pyx_v_x96 = (__pyx_v_x88 + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1432
 *         cdef double x95 = 588.0*nu + 1079.0
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96             # <<<<<<<<<<<<<<
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77
 */
  __Pyx_TraceLine(1432,0,__PYX_ERR(1, 1432, __pyx_L1_error))
  __pyx_v_x97 = (__pyx_v_x14 * __pyx_v_x96);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1433
 *         cdef double x96 = x88 + 1079.0
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0             # <<<<<<<<<<<<<<
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99
 */
  __Pyx_TraceLine(1433,0,__PYX_ERR(1, 1433, __pyx_L1_error))
  __pyx_v_x98 = ((((((((-38842241.4769507 * __pyx_v_nu) + ((240.0 * __pyx_v_r) * (((-7466.27061066206 * __pyx_v_nu) - (3024.0 * __pyx_v_x31)) + 17264.0))) + ((1920.0 * __pyx_v_x0) * __pyx_v_x95)) + ((480.0 * __pyx_v_x10) * __pyx_v_x96)) - (1882456.23663972 * __pyx_v_x31)) + (161280.0 * __pyx_v_x37)) + (960.0 * __pyx_v_x97)) + 13447680.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1434
 *         cdef double x97 = x14*x96
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77             # <<<<<<<<<<<<<<
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r
 */
  __Pyx_TraceLine(1434,0,__PYX_ERR(1, 1434, __pyx_L1_error))
  __pyx_v_x99 = (__pyx_v_nu * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1435
 *         cdef double x98 = -38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*x31 + 17264.0) + 1920.0*x0*x95 + 480.0*x10*x96 - 1882456.23663972*x31 + 161280.0*x37 + 960.0*x97 + 13447680.0
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99             # <<<<<<<<<<<<<<
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 */
  __Pyx_TraceLine(1435,0,__PYX_ERR(1, 1435, __pyx_L1_error))
  __pyx_v_x100 = (__pyx_v_x98 * __pyx_v_x99);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1436
 *         cdef double x99 = nu*x77
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r             # <<<<<<<<<<<<<<
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6
 */
  __Pyx_TraceLine(1436,0,__PYX_ERR(1, 1436, __pyx_L1_error))
  __pyx_v_x101 = (8.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1437
 *         cdef double x100 = x98*x99
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0             # <<<<<<<<<<<<<<
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r
 */
  __Pyx_TraceLine(1437,0,__PYX_ERR(1, 1437, __pyx_L1_error))
  __pyx_v_x102 = ((((4.0 * __pyx_v_x0) + __pyx_v_x101) + (2.0 * __pyx_v_x14)) + 16.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1438
 *         cdef double x101 = 8.0*r
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6             # <<<<<<<<<<<<<<
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r
 */
  __Pyx_TraceLine(1438,0,__PYX_ERR(1, 1438, __pyx_L1_error))
  __pyx_v_x103 = (7680.0 * __pyx_v_a6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1439
 *         cdef double x102 = 4.0*x0 + x101 + 2.0*x14 + 16.0
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r             # <<<<<<<<<<<<<<
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r
 */
  __Pyx_TraceLine(1439,0,__PYX_ERR(1, 1439, __pyx_L1_error))
  __pyx_v_x104 = (128.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1440
 *         cdef double x103 = 7680.0*a6
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r             # <<<<<<<<<<<<<<
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r
 */
  __Pyx_TraceLine(1440,0,__PYX_ERR(1, 1440, __pyx_L1_error))
  __pyx_v_x105 = (7704.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1441
 *         cdef double x104 = 128.0*r
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r             # <<<<<<<<<<<<<<
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 */
  __Pyx_TraceLine(1441,0,__PYX_ERR(1, 1441, __pyx_L1_error))
  __pyx_v_x106 = (148.04406601634 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1442
 *         cdef double x105 = 7704.0*r
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r             # <<<<<<<<<<<<<<
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 */
  __Pyx_TraceLine(1442,0,__PYX_ERR(1, 1442, __pyx_L1_error))
  __pyx_v_x107 = (113485.217444961 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1443
 *         cdef double x106 = 148.04406601634*r
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))             # <<<<<<<<<<<<<<
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90
 */
  __Pyx_TraceLine(1443,0,__PYX_ERR(1, 1443, __pyx_L1_error))
  __pyx_v_x108 = (__pyx_v_nu * ((((__pyx_v_x103 * (__pyx_v_x10 + __pyx_v_x102)) + (__pyx_v_x104 * (((((13218.7851094412 * __pyx_v_r) + (8529.39255472061 * __pyx_v_x0)) - (6852.34813868015 * __pyx_v_x10)) + (4264.6962773603 * __pyx_v_x14)) - 33722.4297811176))) + (__pyx_v_x106 * (((((3852.0 * __pyx_v_x0) + (349.0 * __pyx_v_x10)) + __pyx_v_x105) + (1926.0 * __pyx_v_x14)) + 36400.0))) + (__pyx_v_x107 * ((-__pyx_v_x10) + __pyx_v_x102))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1444
 *         cdef double x107 = 113485.217444961*r
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 */
  __Pyx_TraceLine(1444,0,__PYX_ERR(1, 1444, __pyx_L1_error))
  __pyx_v_x109 = pow((((((((32768.0 * __pyx_v_x100) + (53760.0 * __pyx_v_x108)) + (13212057600.0 * __pyx_v_x37)) + (241555486248.807 * __pyx_v_x72)) + (67645734912.0 * __pyx_v_x92)) + (1120.0 * __pyx_v_x93)) + (7.0 * __pyx_v_x94)), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1445
 *         cdef double x108 = nu*(x103*(x10 + x102) + x104*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x10 + 4264.6962773603*x14 - 33722.4297811176) + x106*(3852.0*x0 + 349.0*x10 + x105 + 1926.0*x14 + 36400.0) + x107*(-x10 + x102))
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90             # <<<<<<<<<<<<<<
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)
 */
  __Pyx_TraceLine(1445,0,__PYX_ERR(1, 1445, __pyx_L1_error))
  __pyx_v_x110 = ((__pyx_v_x10 * __pyx_v_x109) * __pyx_v_x90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1446
 *         cdef double x109 = (32768.0*x100 + 53760.0*x108 + 13212057600.0*x37 + 241555486248.807*x72 + 67645734912.0*x92 + 1120.0*x93 + 7.0*x94)**(-1)
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46             # <<<<<<<<<<<<<<
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91
 */
  __Pyx_TraceLine(1446,0,__PYX_ERR(1, 1446, __pyx_L1_error))
  __pyx_v_x111 = (__pyx_v_x110 + (0.000130208333333333 * __pyx_v_x46));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1447
 *         cdef double x110 = x10*x109*x90
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)             # <<<<<<<<<<<<<<
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 */
  __Pyx_TraceLine(1447,0,__PYX_ERR(1, 1447, __pyx_L1_error))
  __pyx_v_x112 = pow(__pyx_v_x111, -4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1448
 *         cdef double x111 = x110 + 0.000130208333333333*x46
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91             # <<<<<<<<<<<<<<
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114
 */
  __Pyx_TraceLine(1448,0,__PYX_ERR(1, 1448, __pyx_L1_error))
  __pyx_v_x113 = (__pyx_v_r * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1449
 *         cdef double x112 = x111**(-4)
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913             # <<<<<<<<<<<<<<
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 */
  __Pyx_TraceLine(1449,0,__PYX_ERR(1, 1449, __pyx_L1_error))
  __pyx_v_x114 = (((-630116198.873299 * __pyx_v_nu) - (197773496.793534 * __pyx_v_x31)) + 5805304367.87913);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1450
 *         cdef double x113 = r*x91
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114             # <<<<<<<<<<<<<<
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14
 */
  __Pyx_TraceLine(1450,0,__PYX_ERR(1, 1450, __pyx_L1_error))
  __pyx_v_x115 = (__pyx_v_x0 * __pyx_v_x114);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1451
 *         cdef double x114 = -630116198.873299*nu - 197773496.793534*x31 + 5805304367.87913
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329             # <<<<<<<<<<<<<<
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 */
  __Pyx_TraceLine(1451,0,__PYX_ERR(1, 1451, __pyx_L1_error))
  __pyx_v_x116 = (((-2675575.66847905 * __pyx_v_nu) - (138240.0 * __pyx_v_x31)) - 5278341.3229329);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1452
 *         cdef double x115 = x0*x114
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14             # <<<<<<<<<<<<<<
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 */
  __Pyx_TraceLine(1452,0,__PYX_ERR(1, 1452, __pyx_L1_error))
  __pyx_v_x117 = (__pyx_v_x116 * __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1453
 *         cdef double x116 = -2675575.66847905*nu - 138240.0*x31 - 5278341.3229329
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)             # <<<<<<<<<<<<<<
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119
 */
  __Pyx_TraceLine(1453,0,__PYX_ERR(1, 1453, __pyx_L1_error))
  __pyx_v_x118 = (__pyx_v_nu * ((((-2510664218.28128 * __pyx_v_nu) - (42636451.6032331 * __pyx_v_x31)) + (14515200.0 * __pyx_v_x67)) + 1002013764.01019));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1454
 *         cdef double x117 = x116*x14
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0             # <<<<<<<<<<<<<<
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0
 */
  __Pyx_TraceLine(1454,0,__PYX_ERR(1, 1454, __pyx_L1_error))
  __pyx_v_x119 = (((((43393301259014.8 * __pyx_v_nu) + (43133561885859.3 * __pyx_v_x31)) + (5927865218923.02 * __pyx_v_x67)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1455
 *         cdef double x118 = nu*(-2510664218.28128*nu - 42636451.6032331*x31 + 14515200.0*x67 + 1002013764.01019)
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119             # <<<<<<<<<<<<<<
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121
 */
  __Pyx_TraceLine(1455,0,__PYX_ERR(1, 1455, __pyx_L1_error))
  __pyx_v_x120 = (__pyx_v_r * __pyx_v_x119);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1456
 *         cdef double x119 = 43393301259014.8*nu + 43133561885859.3*x31 + 5927865218923.02*x67 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0             # <<<<<<<<<<<<<<
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 */
  __Pyx_TraceLine(1456,0,__PYX_ERR(1, 1456, __pyx_L1_error))
  __pyx_v_x121 = ((14700.0 * __pyx_v_nu) + 42911.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1457
 *         cdef double x120 = r*x119
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121             # <<<<<<<<<<<<<<
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77
 */
  __Pyx_TraceLine(1457,0,__PYX_ERR(1, 1457, __pyx_L1_error))
  __pyx_v_x122 = (283115520.0 * __pyx_v_x121);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1458
 *         cdef double x121 = 14700.0*nu + 42911.0
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14             # <<<<<<<<<<<<<<
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 */
  __Pyx_TraceLine(1458,0,__PYX_ERR(1, 1458, __pyx_L1_error))
  __pyx_v_x123 = (((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + ((49152.0 * __pyx_v_r) * (((409207698.136075 * __pyx_v_nu) + (102574080.0 * __pyx_v_x31)) - 2119671837.36038))) + (__pyx_v_x0 * __pyx_v_x122)) + (879923036160.0 * __pyx_v_x14));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1459
 *         cdef double x122 = 283115520.0*x121
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77             # <<<<<<<<<<<<<<
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r
 */
  __Pyx_TraceLine(1459,0,__PYX_ERR(1, 1459, __pyx_L1_error))
  __pyx_v_x124 = (__pyx_v_x123 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1460
 *         cdef double x123 = -1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*x31 - 2119671837.36038) + x0*x122 + 879923036160.0*x14
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2             # <<<<<<<<<<<<<<
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0
 */
  __Pyx_TraceLine(1460,0,__PYX_ERR(1, 1460, __pyx_L1_error))
  __pyx_v_x125 = pow((((((__pyx_v_x113 - (1.59227685093395e-9 * __pyx_v_x115)) - (1.67189069348064e-7 * __pyx_v_x117)) + (9.55366110560367e-9 * __pyx_v_x118)) + (1.72773095804465e-13 * __pyx_v_x120)) + (1.72773095804465e-13 * __pyx_v_x124)), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1461
 *         cdef double x124 = x123*x77
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r             # <<<<<<<<<<<<<<
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31
 */
  __Pyx_TraceLine(1461,0,__PYX_ERR(1, 1461, __pyx_L1_error))
  __pyx_v_x126 = (__pyx_v_nu * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1462
 *         cdef double x125 = (x113 - 1.59227685093395e-9*x115 - 1.67189069348064e-7*x117 + 9.55366110560367e-9*x118 + 1.72773095804465e-13*x120 + 1.72773095804465e-13*x124)**2
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0             # <<<<<<<<<<<<<<
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121
 */
  __Pyx_TraceLine(1462,0,__PYX_ERR(1, 1462, __pyx_L1_error))
  __pyx_v_x127 = (__pyx_v_nu * __pyx_v_x0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1463
 *         cdef double x126 = nu*r
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31             # <<<<<<<<<<<<<<
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31
 */
  __Pyx_TraceLine(1463,0,__PYX_ERR(1, 1463, __pyx_L1_error))
  __pyx_v_x128 = (__pyx_v_r * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1464
 *         cdef double x127 = nu*x0
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121             # <<<<<<<<<<<<<<
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 */
  __Pyx_TraceLine(1464,0,__PYX_ERR(1, 1464, __pyx_L1_error))
  __pyx_v_x129 = (__pyx_v_r * __pyx_v_x121);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1465
 *         cdef double x128 = r*x31
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31             # <<<<<<<<<<<<<<
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 */
  __Pyx_TraceLine(1465,0,__PYX_ERR(1, 1465, __pyx_L1_error))
  __pyx_v_x130 = (__pyx_v_x0 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1466
 *         cdef double x129 = r*x121
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0             # <<<<<<<<<<<<<<
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77
 */
  __Pyx_TraceLine(1466,0,__PYX_ERR(1, 1466, __pyx_L1_error))
  __pyx_v_x131 = ((5041721180160.0 * __pyx_v_x31) - 104186110149937.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1467
 *         cdef double x130 = x0*x31
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131             # <<<<<<<<<<<<<<
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 */
  __Pyx_TraceLine(1467,0,__PYX_ERR(1, 1467, __pyx_L1_error))
  __pyx_v_x132 = ((((-25392914995744.3 * __pyx_v_nu) - (__pyx_v_r * __pyx_v_x122)) - (879923036160.0 * __pyx_v_x0)) - __pyx_v_x131);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1468
 *         cdef double x131 = 5041721180160.0*x31 - 104186110149937.0
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77             # <<<<<<<<<<<<<<
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)
 */
  __Pyx_TraceLine(1468,0,__PYX_ERR(1, 1468, __pyx_L1_error))
  __pyx_v_x133 = (__pyx_v_x132 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1469
 *         cdef double x132 = -25392914995744.3*nu - r*x122 - 879923036160.0*x0 - x131
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1             # <<<<<<<<<<<<<<
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31
 */
  __Pyx_TraceLine(1469,0,__PYX_ERR(1, 1469, __pyx_L1_error))
  __pyx_v_x134 = (((((((((((((-0.0438084424460039 * __pyx_v_nu) - (0.143521050466841 * __pyx_v_r)) + (0.0185696317637669 * __pyx_v_x0)) + (0.0385795738434214 * __pyx_v_x126)) + (0.00941289164152486 * __pyx_v_x127)) + (0.00662650629087394 * __pyx_v_x128)) - (1.18824456940711e-6 * __pyx_v_x129)) + (0.000486339502879429 * __pyx_v_x130)) - (3.63558293513537e-15 * __pyx_v_x133)) + (0.291062041428379 * __pyx_v_x31)) + (0.0244692826489756 * __pyx_v_x67)) + (0.0210425293255724 * __pyx_v_x91)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1470
 *         cdef double x133 = x132*x77
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2
 */
  __Pyx_TraceLine(1470,0,__PYX_ERR(1, 1470, __pyx_L1_error))
  __pyx_v_x135 = pow(__pyx_v_x134, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1471
 *         cdef double x134 = -0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0385795738434214*x126 + 0.00941289164152486*x127 + 0.00662650629087394*x128 - 1.18824456940711e-6*x129 + 0.000486339502879429*x130 - 3.63558293513537e-15*x133 + 0.291062041428379*x31 + 0.0244692826489756*x67 + 0.0210425293255724*x91 + 1
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31             # <<<<<<<<<<<<<<
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 */
  __Pyx_TraceLine(1471,0,__PYX_ERR(1, 1471, __pyx_L1_error))
  __pyx_v_x136 = (4.0 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1472
 *         cdef double x135 = x134**(-2)
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2             # <<<<<<<<<<<<<<
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 */
  __Pyx_TraceLine(1472,0,__PYX_ERR(1, 1472, __pyx_L1_error))
  __pyx_v_x137 = pow(__pyx_v_x17, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1473
 *         cdef double x136 = 4.0*x31
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)             # <<<<<<<<<<<<<<
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2
 */
  __Pyx_TraceLine(1473,0,__PYX_ERR(1, 1473, __pyx_L1_error))
  __pyx_v_x138 = ((((-0.46875 * __pyx_v_x137) * (((-5.0 * __pyx_v_nu) + __pyx_v_x136) + 1.0)) + ((((0.0625 * __pyx_v_x17) * __pyx_v_x21) * __pyx_v_x3) * ((18.0 * __pyx_v_nu) - 1.0))) - ((0.15625 * __pyx_v_x4) * (((-33.0 * __pyx_v_nu) + (32.0 * __pyx_v_x31)) - 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1474
 *         cdef double x137 = x17**2
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87             # <<<<<<<<<<<<<<
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2
 */
  __Pyx_TraceLine(1474,0,__PYX_ERR(1, 1474, __pyx_L1_error))
  __pyx_v_x139 = (((((__pyx_v_x112 * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x54) * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1475
 *         cdef double x138 = -0.46875*x137*(-5.0*nu + x136 + 1.0) + 0.0625*x17*x21*x3*(18.0*nu - 1.0) - 0.15625*x4*(-33.0*nu + 32.0*x31 - 5.0)
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2             # <<<<<<<<<<<<<<
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)
 */
  __Pyx_TraceLine(1475,0,__PYX_ERR(1, 1475, __pyx_L1_error))
  __pyx_v_x140 = pow(__pyx_v_x7, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1476
 *         cdef double x139 = x112*x125*x135*x138*x54*x87
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2             # <<<<<<<<<<<<<<
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31
 */
  __Pyx_TraceLine(1476,0,__PYX_ERR(1, 1476, __pyx_L1_error))
  __pyx_v_x141 = pow(__pyx_v_prst, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1477
 *         cdef double x140 = x7**2
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91
 */
  __Pyx_TraceLine(1477,0,__PYX_ERR(1, 1477, __pyx_L1_error))
  __pyx_v_x142 = pow(__pyx_v_x111, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1478
 *         cdef double x141 = prst**2
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31             # <<<<<<<<<<<<<<
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 */
  __Pyx_TraceLine(1478,0,__PYX_ERR(1, 1478, __pyx_L1_error))
  __pyx_v_x143 = (1822680546449.21 * __pyx_v_x31);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1479
 *         cdef double x142 = x111**(-2)
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91             # <<<<<<<<<<<<<<
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = 1/x145
 */
  __Pyx_TraceLine(1479,0,__PYX_ERR(1, 1479, __pyx_L1_error))
  __pyx_v_x144 = (5787938193408.0 * __pyx_v_x91);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1480
 *         cdef double x143 = 1822680546449.21*x31
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0             # <<<<<<<<<<<<<<
 *         cdef double x146 = 1/x145
 *         cdef double x147 = 0.0625*x137
 */
  __Pyx_TraceLine(1480,0,__PYX_ERR(1, 1480, __pyx_L1_error))
  __pyx_v_x145 = (((((((((((((-12049908701745.2 * __pyx_v_nu) + (__pyx_v_r * __pyx_v_x143)) - (39476764256925.6 * __pyx_v_r)) + (5107745331375.71 * __pyx_v_x0)) + (10611661054566.2 * __pyx_v_x126)) + (2589101062873.81 * __pyx_v_x127)) - (326837426.241486 * __pyx_v_x129)) + (133772083200.0 * __pyx_v_x130)) - __pyx_v_x133) + __pyx_v_x144) + (80059249540278.2 * __pyx_v_x31)) + (6730497718123.02 * __pyx_v_x67)) + 275059053208689.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1481
 *         cdef double x144 = 5787938193408.0*x91
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = 1/x145             # <<<<<<<<<<<<<<
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22
 */
  __Pyx_TraceLine(1481,0,__PYX_ERR(1, 1481, __pyx_L1_error))
  __pyx_v_x146 = (1.0 / __pyx_v_x145);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1482
 *         cdef double x145 = -12049908701745.2*nu + r*x143 - 39476764256925.6*r + 5107745331375.71*x0 + 10611661054566.2*x126 + 2589101062873.81*x127 - 326837426.241486*x129 + 133772083200.0*x130 - x133 + x144 + 80059249540278.2*x31 + 6730497718123.02*x67 + 275059053208689.0
 *         cdef double x146 = 1/x145
 *         cdef double x147 = 0.0625*x137             # <<<<<<<<<<<<<<
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0
 */
  __Pyx_TraceLine(1482,0,__PYX_ERR(1, 1482, __pyx_L1_error))
  __pyx_v_x147 = (0.0625 * __pyx_v_x137);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1483
 *         cdef double x146 = 1/x145
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22             # <<<<<<<<<<<<<<
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4
 */
  __Pyx_TraceLine(1483,0,__PYX_ERR(1, 1483, __pyx_L1_error))
  __pyx_v_x148 = (0.125 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1484
 *         cdef double x147 = 0.0625*x137
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0             # <<<<<<<<<<<<<<
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 */
  __Pyx_TraceLine(1484,0,__PYX_ERR(1, 1484, __pyx_L1_error))
  __pyx_v_x149 = ((-1171.0 * __pyx_v_nu) - 861.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1485
 *         cdef double x148 = 0.125*x22
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4             # <<<<<<<<<<<<<<
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22
 */
  __Pyx_TraceLine(1485,0,__PYX_ERR(1, 1485, __pyx_L1_error))
  __pyx_v_x150 = (0.015625 * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1486
 *         cdef double x149 = -1171.0*nu - 861.0
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)             # <<<<<<<<<<<<<<
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 */
  __Pyx_TraceLine(1486,0,__PYX_ERR(1, 1486, __pyx_L1_error))
  __pyx_v_x151 = (__pyx_v_x137 * (((115.0 * __pyx_v_nu) + __pyx_v_x136) - 37.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1487
 *         cdef double x150 = 0.015625*x4
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22             # <<<<<<<<<<<<<<
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 */
  __Pyx_TraceLine(1487,0,__PYX_ERR(1, 1487, __pyx_L1_error))
  __pyx_v_x152 = (0.03125 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1488
 *         cdef double x151 = x137*(115.0*nu + x136 - 37.0)
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)             # <<<<<<<<<<<<<<
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = 1/x154
 */
  __Pyx_TraceLine(1488,0,__PYX_ERR(1, 1488, __pyx_L1_error))
  __pyx_v_x153 = (__pyx_v_x18 * ((26.0 * __pyx_v_nu) + 449.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1489
 *         cdef double x152 = 0.03125*x22
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124             # <<<<<<<<<<<<<<
 *         cdef double x155 = 1/x154
 *         cdef double x156 = x145*x155*x37
 */
  __Pyx_TraceLine(1489,0,__PYX_ERR(1, 1489, __pyx_L1_error))
  __pyx_v_x154 = ((((((5787938193408.0 * __pyx_v_x113) - (9216.0 * __pyx_v_x115)) - (967680.0 * __pyx_v_x117)) + (55296.0 * __pyx_v_x118)) + __pyx_v_x120) + __pyx_v_x124);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1490
 *         cdef double x153 = x18*(26.0*nu + 449.0)
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = 1/x154             # <<<<<<<<<<<<<<
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90
 */
  __Pyx_TraceLine(1490,0,__PYX_ERR(1, 1490, __pyx_L1_error))
  __pyx_v_x155 = (1.0 / __pyx_v_x154);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1491
 *         cdef double x154 = 5787938193408.0*x113 - 9216.0*x115 - 967680.0*x117 + 55296.0*x118 + x120 + x124
 *         cdef double x155 = 1/x154
 *         cdef double x156 = x145*x155*x37             # <<<<<<<<<<<<<<
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 */
  __Pyx_TraceLine(1491,0,__PYX_ERR(1, 1491, __pyx_L1_error))
  __pyx_v_x156 = ((__pyx_v_x145 * __pyx_v_x155) * __pyx_v_x37);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1492
 *         cdef double x155 = 1/x154
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90             # <<<<<<<<<<<<<<
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 */
  __Pyx_TraceLine(1492,0,__PYX_ERR(1, 1492, __pyx_L1_error))
  __pyx_v_x157 = (__pyx_v_x109 * __pyx_v_x90);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1493
 *         cdef double x156 = x145*x155*x37
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46             # <<<<<<<<<<<<<<
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 */
  __Pyx_TraceLine(1493,0,__PYX_ERR(1, 1493, __pyx_L1_error))
  __pyx_v_x158 = ((((__pyx_v_x11 * (((__pyx_v_x149 * __pyx_v_x150) + (0.015625 * __pyx_v_x151)) + (__pyx_v_x152 * __pyx_v_x153))) + (__pyx_v_x15 * (((__pyx_v_x147 * ((12.0 * __pyx_v_nu) - 3.0)) + (__pyx_v_x148 * ((-21.0 * __pyx_v_X_1) + (21.0 * __pyx_v_X_2)))) + (__pyx_v_x4 * (__pyx_v_x12 + 2.8125))))) + ((7680.0 * __pyx_v_x156) * __pyx_v_x157)) + __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1494
 *         cdef double x157 = x109*x90
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158             # <<<<<<<<<<<<<<
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 */
  __Pyx_TraceLine(1494,0,__PYX_ERR(1, 1494, __pyx_L1_error))
  __pyx_v_x159 = (((((__pyx_v_x140 * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x158);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1495
 *         cdef double x158 = x11*(x149*x150 + 0.015625*x151 + x152*x153) + x15*(x147*(12.0*nu - 3.0) + x148*(-21.0*X_1 + 21.0*X_2) + x4*(x12 + 2.8125)) + 7680.0*x156*x157 + x46
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = 1/x161
 */
  __Pyx_TraceLine(1495,0,__PYX_ERR(1, 1495, __pyx_L1_error))
  __pyx_v_x160 = ((((((((((((((((1.27277314139085e-19 * __pyx_v_x139) * __pyx_v_x86) + ((1.69542100694444e-8 * __pyx_v_x159) * __pyx_v_x38)) + (__pyx_v_x25 * __pyx_v_x76)) + __pyx_v_x50) + ((147.443752990146 * __pyx_v_x54) * __pyx_v_x56)) + (__pyx_v_x54 * __pyx_v_x66)) - ((11.3175085791863 * __pyx_v_x57) * __pyx_v_x59)) + (__pyx_v_x57 * __pyx_v_x71)) + ((1.48275342024365 * __pyx_v_x60) * __pyx_v_x62)) + (__pyx_v_x63 * __pyx_v_x64)) + (__pyx_v_x68 * __pyx_v_x69)) + (__pyx_v_x73 * __pyx_v_x74)) + (__pyx_v_x78 * __pyx_v_x79)) - (__pyx_v_x81 * __pyx_v_x85)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1496
 *         cdef double x159 = x140*x141*x142*x146*x154*x158
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x162 = 1/x161
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 */
  __Pyx_TraceLine(1496,0,__PYX_ERR(1, 1496, __pyx_L1_error))
  __pyx_v_x161 = ((__pyx_v_x46 * ((2.0 * __pyx_v_x49) + 1.0)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1497
 *         cdef double x160 = 1.27277314139085e-19*x139*x86 + 1.69542100694444e-8*x159*x38 + x25*x76 + x50 + 147.443752990146*x54*x56 + x54*x66 - 11.3175085791863*x57*x59 + x57*x71 + 1.48275342024365*x60*x62 + x63*x64 + x68*x69 + x73*x74 + x78*x79 - x81*x85 + 1.0
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = 1/x161             # <<<<<<<<<<<<<<
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22
 */
  __Pyx_TraceLine(1497,0,__PYX_ERR(1, 1497, __pyx_L1_error))
  __pyx_v_x162 = (1.0 / __pyx_v_x161);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1498
 *         cdef double x161 = x46*(2.0*x49 + 1.0) + 1.0
 *         cdef double x162 = 1/x161
 *         cdef double x163 = x137*(4.0*nu + 1.0)             # <<<<<<<<<<<<<<
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 */
  __Pyx_TraceLine(1498,0,__PYX_ERR(1, 1498, __pyx_L1_error))
  __pyx_v_x163 = (__pyx_v_x137 * ((4.0 * __pyx_v_nu) + 1.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1499
 *         cdef double x162 = 1/x161
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22             # <<<<<<<<<<<<<<
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 */
  __Pyx_TraceLine(1499,0,__PYX_ERR(1, 1499, __pyx_L1_error))
  __pyx_v_x164 = ((-__pyx_v_x21) * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1500
 *         cdef double x163 = x137*(4.0*nu + 1.0)
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)             # <<<<<<<<<<<<<<
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 */
  __Pyx_TraceLine(1500,0,__PYX_ERR(1, 1500, __pyx_L1_error))
  __pyx_v_x165 = (__pyx_v_x137 * (((-27.0 * __pyx_v_nu) + (28.0 * __pyx_v_x31)) - 3.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1501
 *         cdef double x164 = -x21*x22
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)             # <<<<<<<<<<<<<<
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167
 */
  __Pyx_TraceLine(1501,0,__PYX_ERR(1, 1501, __pyx_L1_error))
  __pyx_v_x166 = (__pyx_v_x152 * ((-39.0 * __pyx_v_X_1) + (39.0 * __pyx_v_X_2)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1502
 *         cdef double x165 = x137*(-27.0*nu + 28.0*x31 - 3.0)
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46             # <<<<<<<<<<<<<<
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)
 */
  __Pyx_TraceLine(1502,0,__PYX_ERR(1, 1502, __pyx_L1_error))
  __pyx_v_x167 = ((((__pyx_v_x11 * (((0.125 * __pyx_v_x163) + (0.25 * __pyx_v_x164)) + (1.125 * __pyx_v_x4))) + (7680.0 * __pyx_v_x110)) + (__pyx_v_x38 * ((((-__pyx_v_x150) * ((175.0 * __pyx_v_nu) + 225.0)) + (0.046875 * __pyx_v_x165)) + (__pyx_v_x166 * ((2.0 * __pyx_v_nu) - 3.0))))) + __pyx_v_x46);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1503
 *         cdef double x166 = x152*(-39.0*X_1 + 39.0*X_2)
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167             # <<<<<<<<<<<<<<
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0
 */
  __Pyx_TraceLine(1503,0,__PYX_ERR(1, 1503, __pyx_L1_error))
  __pyx_v_x168 = (__pyx_v_x162 * __pyx_v_x167);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1504
 *         cdef double x167 = x11*(0.125*x163 + 0.25*x164 + 1.125*x4) + 7680.0*x110 + x38*(-x150*(175.0*nu + 225.0) + 0.046875*x165 + x166*(2.0*nu - 3.0)) + x46
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)             # <<<<<<<<<<<<<<
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)
 */
  __Pyx_TraceLine(1504,0,__PYX_ERR(1, 1504, __pyx_L1_error))
  __pyx_v_x169 = pow((__pyx_v_x160 * __pyx_v_x168), -0.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1505
 *         cdef double x168 = x162*x167
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5
 */
  __Pyx_TraceLine(1505,0,__PYX_ERR(1, 1505, __pyx_L1_error))
  __pyx_v_x170 = ((4.0 * __pyx_v_x49) + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1506
 *         cdef double x169 = (x160*x168)**(-0.5)
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)             # <<<<<<<<<<<<<<
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 */
  __Pyx_TraceLine(1506,0,__PYX_ERR(1, 1506, __pyx_L1_error))
  __pyx_v_x171 = pow(__pyx_v_r, -6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1507
 *         cdef double x170 = 4.0*x49 + 2.0
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5             # <<<<<<<<<<<<<<
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49
 */
  __Pyx_TraceLine(1507,0,__PYX_ERR(1, 1507, __pyx_L1_error))
  __pyx_v_x172 = (__pyx_v_x15 * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1508
 *         cdef double x171 = r**(-6)
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0             # <<<<<<<<<<<<<<
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14
 */
  __Pyx_TraceLine(1508,0,__PYX_ERR(1, 1508, __pyx_L1_error))
  __pyx_v_x173 = (((((-6572428.80109422 * __pyx_v_nu) + (1300341.64885296 * __pyx_v_x31)) + ((2048.0 * __pyx_v_x63) * __pyx_v_x89)) + (688128.0 * __pyx_v_x99)) + 1720320.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1509
 *         cdef double x172 = x15*x5
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49             # <<<<<<<<<<<<<<
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 */
  __Pyx_TraceLine(1509,0,__PYX_ERR(1, 1509, __pyx_L1_error))
  __pyx_v_x174 = (__pyx_v_x31 * __pyx_v_x49);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1510
 *         cdef double x173 = -6572428.80109422*nu + 1300341.64885296*x31 + 2048.0*x63*x89 + 688128.0*x99 + 1720320.0
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14             # <<<<<<<<<<<<<<
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 */
  __Pyx_TraceLine(1510,0,__PYX_ERR(1, 1510, __pyx_L1_error))
  __pyx_v_x175 = (4.0 * __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1511
 *         cdef double x174 = x31*x49
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0             # <<<<<<<<<<<<<<
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 */
  __Pyx_TraceLine(1511,0,__PYX_ERR(1, 1511, __pyx_L1_error))
  __pyx_v_x176 = (((6.0 * __pyx_v_x0) + __pyx_v_x101) + 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1512
 *         cdef double x175 = 4.0*x14
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2             # <<<<<<<<<<<<<<
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77
 */
  __Pyx_TraceLine(1512,0,__PYX_ERR(1, 1512, __pyx_L1_error))
  __pyx_v_x177 = (((1.31621673590926e-19 * __pyx_v_x90) * ((((((((53760.0 * __pyx_v_nu) * (((((((((3740417.71815805 * __pyx_v_r) + (2115968.85907902 * __pyx_v_x0)) - (938918.400156317 * __pyx_v_x10)) + (__pyx_v_x103 * (__pyx_v_x175 + __pyx_v_x176))) + (__pyx_v_x104 * ((((17058.7851094412 * __pyx_v_r) + (12794.0888320809 * __pyx_v_x0)) - (27409.3925547206 * __pyx_v_x14)) + 13218.7851094412))) + (__pyx_v_x106 * ((((5778.0 * __pyx_v_x0) + __pyx_v_x105) + (1396.0 * __pyx_v_x14)) + 7704.0))) + (__pyx_v_x107 * ((-__pyx_v_x175) + __pyx_v_x176))) + (1057984.42953951 * __pyx_v_x14)) + 2888096.47013111)) + (66060288000.0 * __pyx_v_x10)) + ((135291469824.0 * __pyx_v_x174) * __pyx_v_x77)) + ((7.0 * __pyx_v_x31) * ((((((-117964800.0 * __pyx_v_a6) + (4129567622.65173 * __pyx_v_r)) - (18535504222.6128 * __pyx_v_x0)) + (7133302759.42198 * __pyx_v_x10)) - (12357002815.0752 * __pyx_v_x14)) + 122635399361.987))) + ((32768.0 * __pyx_v_x63) * __pyx_v_x98)) + ((7.0 * __pyx_v_x67) * ((-5706642207.53758 * __pyx_v_r) - 26189434371.6082))) + ((32768.0 * __pyx_v_x99) * (((((((-1791904.9465589 * __pyx_v_nu) + ((3840.0 * __pyx_v_r) * __pyx_v_x95)) + ((2880.0 * __pyx_v_x0) * __pyx_v_x96)) + (806400.0 * __pyx_v_x10)) - (725760.0 * __pyx_v_x31)) + (1920.0 * __pyx_v_x97)) + 4143360.0)))) / pow((((((((1.35654132757922e-7 * __pyx_v_x100) + (2.22557561555966e-7 * __pyx_v_x108)) + (0.0546957463279941 * __pyx_v_x37)) + __pyx_v_x72) + (0.28004222119933 * __pyx_v_x92)) + (4.63661586574928e-9 * __pyx_v_x93)) + (2.8978849160933e-11 * __pyx_v_x94)), 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1513
 *         cdef double x176 = 6.0*x0 + x101 + 8.0
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172             # <<<<<<<<<<<<<<
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 */
  __Pyx_TraceLine(1513,0,__PYX_ERR(1, 1513, __pyx_L1_error))
  __pyx_v_x178 = ((((((-7680.0 * __pyx_v_x10) * __pyx_v_x109) * __pyx_v_x173) + (__pyx_v_x10 * __pyx_v_x177)) - (((30720.0 * __pyx_v_x109) * __pyx_v_x14) * __pyx_v_x90)) + __pyx_v_x172);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1514
 *         cdef double x177 = 1.31621673590926e-19*x90*(53760.0*nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x10 + x103*(x175 + x176) + x104*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x14 + 13218.7851094412) + x106*(5778.0*x0 + x105 + 1396.0*x14 + 7704.0) + x107*(-x175 + x176) + 1057984.42953951*x14 + 2888096.47013111) + 66060288000.0*x10 + 135291469824.0*x174*x77 + 7.0*x31*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x10 - 12357002815.0752*x14 + 122635399361.987) + 32768.0*x63*x98 + 7.0*x67*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x99*(-1791904.9465589*nu + 3840.0*r*x95 + 2880.0*x0*x96 + 806400.0*x10 - 725760.0*x31 + 1920.0*x97 + 4143360.0))/(1.35654132757922e-7*x100 + 2.22557561555966e-7*x108 + 0.0546957463279941*x37 + x72 + 0.28004222119933*x92 + 4.63661586574928e-9*x93 + 2.8978849160933e-11*x94)**2
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77             # <<<<<<<<<<<<<<
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87
 */
  __Pyx_TraceLine(1514,0,__PYX_ERR(1, 1514, __pyx_L1_error))
  __pyx_v_x179 = (11575876386816.0 * __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1515
 *         cdef double x178 = -7680.0*x10*x109*x173 + x10*x177 - 30720.0*x109*x14*x90 + x172
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1             # <<<<<<<<<<<<<<
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 */
  __Pyx_TraceLine(1515,0,__PYX_ERR(1, 1515, __pyx_L1_error))
  __pyx_v_x180 = (((((((((5807150888816.34 * __pyx_v_nu) + (10215490662751.4 * __pyx_v_r)) + (5178202125747.62 * __pyx_v_x126)) + (267544166400.0 * __pyx_v_x128)) - (__pyx_v_x132 * __pyx_v_x49)) + __pyx_v_x143) + (__pyx_v_x179 * __pyx_v_x49)) + (__pyx_v_x77 * (((4161798144000.0 * __pyx_v_nu) + (1759846072320.0 * __pyx_v_r)) + 12148770078720.0))) - 53501685054374.1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1516
 *         cdef double x179 = 11575876386816.0*x77
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87             # <<<<<<<<<<<<<<
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158
 */
  __Pyx_TraceLine(1516,0,__PYX_ERR(1, 1516, __pyx_L1_error))
  __pyx_v_x181 = ((((__pyx_v_x125 * __pyx_v_x138) * __pyx_v_x54) * __pyx_v_x86) * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1517
 *         cdef double x180 = 5807150888816.34*nu + 10215490662751.4*r + 5178202125747.62*x126 + 267544166400.0*x128 - x132*x49 + x143 + x179*x49 + x77*(4161798144000.0*nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)             # <<<<<<<<<<<<<<
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178
 */
  __Pyx_TraceLine(1517,0,__PYX_ERR(1, 1517, __pyx_L1_error))
  __pyx_v_x182 = ((((((((-18432.0 * __pyx_v_r) * __pyx_v_x114) - ((2903040.0 * __pyx_v_x0) * __pyx_v_x116)) + __pyx_v_x119) + (__pyx_v_x123 * __pyx_v_x49)) + __pyx_v_x144) + __pyx_v_x179) + (__pyx_v_x77 * ((((20113376778784.3 * __pyx_v_nu) + (2639769108480.0 * __pyx_v_x0)) + (566231040.0 * __pyx_v_x129)) + __pyx_v_x131)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1518
 *         cdef double x181 = x125*x138*x54*x86*x87
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158             # <<<<<<<<<<<<<<
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38
 */
  __Pyx_TraceLine(1518,0,__PYX_ERR(1, 1518, __pyx_L1_error))
  __pyx_v_x183 = (__pyx_v_x141 * __pyx_v_x158);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1519
 *         cdef double x182 = -18432.0*r*x114 - 2903040.0*x0*x116 + x119 + x123*x49 + x144 + x179 + x77*(20113376778784.3*nu + 2639769108480.0*x0 + 566231040.0*x129 + x131)
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178             # <<<<<<<<<<<<<<
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3
 */
  __Pyx_TraceLine(1519,0,__PYX_ERR(1, 1519, __pyx_L1_error))
  __pyx_v_x184 = (-__pyx_v_x178);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1520
 *         cdef double x183 = x141*x158
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38             # <<<<<<<<<<<<<<
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5
 */
  __Pyx_TraceLine(1520,0,__PYX_ERR(1, 1520, __pyx_L1_error))
  __pyx_v_x185 = (__pyx_v_x154 * __pyx_v_x38);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1521
 *         cdef double x184 = -x178
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3             # <<<<<<<<<<<<<<
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7
 */
  __Pyx_TraceLine(1521,0,__PYX_ERR(1, 1521, __pyx_L1_error))
  __pyx_v_x186 = pow(__pyx_v_prst, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1522
 *         cdef double x185 = x154*x38
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5             # <<<<<<<<<<<<<<
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186
 */
  __Pyx_TraceLine(1522,0,__PYX_ERR(1, 1522, __pyx_L1_error))
  __pyx_v_x187 = pow(__pyx_v_prst, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1523
 *         cdef double x186 = prst**3
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7             # <<<<<<<<<<<<<<
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187
 */
  __Pyx_TraceLine(1523,0,__PYX_ERR(1, 1523, __pyx_L1_error))
  __pyx_v_x188 = pow(__pyx_v_prst, 7.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1524
 *         cdef double x187 = prst**5
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186             # <<<<<<<<<<<<<<
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 */
  __Pyx_TraceLine(1524,0,__PYX_ERR(1, 1524, __pyx_L1_error))
  __pyx_v_x189 = (4.0 * __pyx_v_x186);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1525
 *         cdef double x188 = prst**7
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187             # <<<<<<<<<<<<<<
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi
 */
  __Pyx_TraceLine(1525,0,__PYX_ERR(1, 1525, __pyx_L1_error))
  __pyx_v_x190 = (6.0 * __pyx_v_x187);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1526
 *         cdef double x189 = 4.0*x186
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)             # <<<<<<<<<<<<<<
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25
 */
  __Pyx_TraceLine(1526,0,__PYX_ERR(1, 1526, __pyx_L1_error))
  __pyx_v_x191 = ((__pyx_v_x167 * __pyx_v_x169) / ((__pyx_v_x170 * __pyx_v_x46) + 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1527
 *         cdef double x190 = 6.0*x187
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi             # <<<<<<<<<<<<<<
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192
 */
  __Pyx_TraceLine(1527,0,__PYX_ERR(1, 1527, __pyx_L1_error))
  __pyx_v_x192 = (2.0 * __pyx_v_pphi);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1528
 *         cdef double x191 = x167*x169/(x170*x46 + 2.0)
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25             # <<<<<<<<<<<<<<
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11
 */
  __Pyx_TraceLine(1528,0,__PYX_ERR(1, 1528, __pyx_L1_error))
  __pyx_v_x193 = (__pyx_v_x192 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1529
 *         cdef double x192 = 2.0*pphi
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192             # <<<<<<<<<<<<<<
 *         cdef double x195 = 4.0*pphi**3*x11
 * 
 */
  __Pyx_TraceLine(1529,0,__PYX_ERR(1, 1529, __pyx_L1_error))
  __pyx_v_x194 = (__pyx_v_x15 * __pyx_v_x192);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1530
 *         cdef double x193 = x192*x25
 *         cdef double x194 = x15*x192
 *         cdef double x195 = 4.0*pphi**3*x11             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(1530,0,__PYX_ERR(1, 1530, __pyx_L1_error))
  __pyx_v_x195 = ((4.0 * pow(__pyx_v_pphi, 3.0)) * __pyx_v_x11);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1535
 *         # Evaluate Hamiltonian
 *         cdef double H,xi
 *         H,xi = evaluate_H(q,p,chi_1,chi_2,m_1,m_2,M,nu,X_1,X_2,a6,dSO)             # <<<<<<<<<<<<<<
 * 
 *         # Heff Jacobian expressions
 */
  __Pyx_TraceLine(1535,0,__PYX_ERR(1, 1535, __pyx_L1_error))
  __pyx_t_14 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_M, __pyx_v_nu, __pyx_v_X_1, __pyx_v_X_2, __pyx_v_a6, __pyx_v_dSO, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1535, __pyx_L1_error)
  __pyx_t_13 = __pyx_t_14.f0;
  __pyx_t_15 = __pyx_t_14.f1;
  __pyx_v_H = __pyx_t_13;
  __pyx_v_xi = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1538
 * 
 *         # Heff Jacobian expressions
 *         cdef double dHeffdr = 0.5*x169*(x160*x162*(-x171*(-x150*(875.0*nu + 1125.0) + 0.234375*x165 + x166*(10.0*nu - 15.0)) - x178 - x38*(0.5*x163 + x164 + 4.5*x4)) - x160*x167*(-x11*x5 - x16*x170)/x161**2 + x168*(-663.496888455656*nu*r**(-5.5)*x54 - nu*x25*x64 + 39.6112800271521*nu*x55*x57 + 6.78168402777778e-8*x11*x141*x142*x146*x154*x158*x7 + x11*x54*(118.4*x174 - 51.6952380952381*x63) + 7.59859378406358e-45*x112*x135*x138*x154*x182*x54*x86*x87 - 9.25454462627843e-34*x112*x180*x181/x134**3 - 2.24091649004576e-37*x135*x140*x142*x154*x180*x183*x38 + 1.69542100694444e-8*x140*x141*x142*x146*x154*x38*(38400.0*x10*x109*x145*x155*x90 + 7680.0*x109*x145*x155*x173*x37 + 7680.0*x109*x155*x180*x37*x90 - x11*(x147*(36.0*nu - 9.0) + x148*(-63.0*X_1 + 63.0*X_2) + x4*(9.0*nu + 8.4375)) - x156*x177 - x172 - x38*(x148*x153 + 0.0625*x149*x4 + 0.0625*x151) - 2.29252167428035e-22*x145*x157*x182*x37/x125) + 1.69542100694444e-8*x140*x141*x142*x146*x158*x182*x38 - 8.47710503472222e-8*x159*x171 - x24*x76 + x25*x28*x4*x80*x84 + x28*x4*x49*x80*(x175 + x81 + x82)/x83**2 - x30 - x33*x57*x73 - x39*x54*x78 - x4*x85 - 3.70688355060912*x58*x62 - 2.0*x65*x69 - 3.0*x68*x79 - 2.0*x70*x74 - 4.41515887225116e-12*x140*x146*x183*x184*x185/x111**3 - 6.62902677807736e-23*x135*x181*x184/x111**5 + 1.01821851311268e-18*x112*x125*x135*x138*x54*x7**3/r**12 - 1.65460508380811e-18*x139/r**14)) + x9*(-dSO*x11*x12*x13 + pphi*x17*x18*(-x15*(-0.0625*nu + 1.07291666666667*x31 + 0.15625) - x25*x41 - x30*x42 - x34*x43 - x40*x44) + pphi*x3*(-x15*(-11.0625*nu + 1.13541666666667*x31 - 0.15625) - x25*x26 - x27*x30 - x32*x34 - x35*x40) - x13*x23*x24 - 0.0833333333333333*x16*x20) - 0.25*(r*(x6 - 2.0) + x6 + x7)*(pphi*x52 + pphi*x53 + x13*x45 + x13*x48 + x20*x47)/(x7 + 0.5*x8)**2             # <<<<<<<<<<<<<<
 * 
 *         cdef double  dHeffdphi = 0
 */
  __Pyx_TraceLine(1538,0,__PYX_ERR(1, 1538, __pyx_L1_error))
  __pyx_t_15 = __Pyx_SoftComplexToDouble(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((0.5 * __pyx_v_x169), 0), __Pyx_c_sum_double(__pyx_t_double_complex_from_parts((((__pyx_v_x160 * __pyx_v_x162) * ((((-__pyx_v_x171) * ((((-__pyx_v_x150) * ((875.0 * __pyx_v_nu) + 1125.0)) + (0.234375 * __pyx_v_x165)) + (__pyx_v_x166 * ((10.0 * __pyx_v_nu) - 15.0)))) - __pyx_v_x178) - (__pyx_v_x38 * (((0.5 * __pyx_v_x163) + __pyx_v_x164) + (4.5 * __pyx_v_x4))))) - (((__pyx_v_x160 * __pyx_v_x167) * (((-__pyx_v_x11) * __pyx_v_x5) - (__pyx_v_x16 * __pyx_v_x170))) / pow(__pyx_v_x161, 2.0))), 0), __Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_x168, 0), __Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((-663.496888455656 * __pyx_v_nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-5.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_x54, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_nu * __pyx_v_x25) * __pyx_v_x64), 0)), __pyx_t_double_complex_from_parts((((39.6112800271521 * __pyx_v_nu) * __pyx_v_x55) * __pyx_v_x57), 0)), __pyx_t_double_complex_from_parts((((((((6.78168402777778e-8 * __pyx_v_x11) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x158) * __pyx_v_x7), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x11 * __pyx_v_x54) * ((118.4 * __pyx_v_x174) - (51.6952380952381 * __pyx_v_x63))), 0)), __pyx_t_double_complex_from_parts(((((((((7.59859378406358e-45 * __pyx_v_x112) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x154) * __pyx_v_x182) * __pyx_v_x54) * __pyx_v_x86) * __pyx_v_x87), 0)), __pyx_t_double_complex_from_parts(((((9.25454462627843e-34 * __pyx_v_x112) * __pyx_v_x180) * __pyx_v_x181) / pow(__pyx_v_x134, 3.0)), 0)), __pyx_t_double_complex_from_parts((((((((2.24091649004576e-37 * __pyx_v_x135) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x154) * __pyx_v_x180) * __pyx_v_x183) * __pyx_v_x38), 0)), __pyx_t_double_complex_from_parts((((((((1.69542100694444e-8 * __pyx_v_x140) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x154) * __pyx_v_x38) * ((((((((((((38400.0 * __pyx_v_x10) * __pyx_v_x109) * __pyx_v_x145) * __pyx_v_x155) * __pyx_v_x90) + (((((7680.0 * __pyx_v_x109) * __pyx_v_x145) * __pyx_v_x155) * __pyx_v_x173) * __pyx_v_x37)) + (((((7680.0 * __pyx_v_x109) * __pyx_v_x155) * __pyx_v_x180) * __pyx_v_x37) * __pyx_v_x90)) - (__pyx_v_x11 * (((__pyx_v_x147 * ((36.0 * __pyx_v_nu) - 9.0)) + (__pyx_v_x148 * ((-63.0 * __pyx_v_X_1) + (63.0 * __pyx_v_X_2)))) + (__pyx_v_x4 * ((9.0 * __pyx_v_nu) + 8.4375))))) - (__pyx_v_x156 * __pyx_v_x177)) - __pyx_v_x172) - (__pyx_v_x38 * (((__pyx_v_x148 * __pyx_v_x153) + ((0.0625 * __pyx_v_x149) * __pyx_v_x4)) + (0.0625 * __pyx_v_x151)))) - (((((2.29252167428035e-22 * __pyx_v_x145) * __pyx_v_x157) * __pyx_v_x182) * __pyx_v_x37) / __pyx_v_x125))), 0)), __pyx_t_double_complex_from_parts((((((((1.69542100694444e-8 * __pyx_v_x140) * __pyx_v_x141) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x158) * __pyx_v_x182) * __pyx_v_x38), 0)), __pyx_t_double_complex_from_parts(((8.47710503472222e-8 * __pyx_v_x159) * __pyx_v_x171), 0)), __pyx_t_double_complex_from_parts((__pyx_v_x24 * __pyx_v_x76), 0)), __pyx_t_double_complex_from_parts(((((__pyx_v_x25 * __pyx_v_x28) * __pyx_v_x4) * __pyx_v_x80) * __pyx_v_x84), 0)), __pyx_t_double_complex_from_parts((((((__pyx_v_x28 * __pyx_v_x4) * __pyx_v_x49) * __pyx_v_x80) * ((__pyx_v_x175 + __pyx_v_x81) + __pyx_v_x82)) / pow(__pyx_v_x83, 2.0)), 0)), __pyx_t_double_complex_from_parts(__pyx_v_x30, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x33 * __pyx_v_x57) * __pyx_v_x73), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x39 * __pyx_v_x54) * __pyx_v_x78), 0)), __pyx_t_double_complex_from_parts((__pyx_v_x4 * __pyx_v_x85), 0)), __pyx_t_double_complex_from_parts(((3.70688355060912 * __pyx_v_x58) * __pyx_v_x62), 0)), __pyx_t_double_complex_from_parts(((2.0 * __pyx_v_x65) * __pyx_v_x69), 0)), __pyx_t_double_complex_from_parts(((3.0 * __pyx_v_x68) * __pyx_v_x79), 0)), __pyx_t_double_complex_from_parts(((2.0 * __pyx_v_x70) * __pyx_v_x74), 0)), __pyx_t_double_complex_from_parts(((((((4.41515887225116e-12 * __pyx_v_x140) * __pyx_v_x146) * __pyx_v_x183) * __pyx_v_x184) * __pyx_v_x185) / pow(__pyx_v_x111, 3.0)), 0)), __pyx_t_double_complex_from_parts(((((6.62902677807736e-23 * __pyx_v_x135) * __pyx_v_x181) * __pyx_v_x184) / pow(__pyx_v_x111, 5.0)), 0)), __pyx_t_double_complex_from_parts((((((((1.01821851311268e-18 * __pyx_v_x112) * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x54) * pow(__pyx_v_x7, 3.0)) / pow(__pyx_v_r, 12.0)), 0)), __pyx_t_double_complex_from_parts(((1.65460508380811e-18 * __pyx_v_x139) / pow(__pyx_v_r, 14.0)), 0))))), __pyx_t_double_complex_from_parts((__pyx_v_x9 * ((((((((-__pyx_v_dSO) * __pyx_v_x11) * __pyx_v_x12) * __pyx_v_x13) + (((__pyx_v_pphi * __pyx_v_x17) * __pyx_v_x18) * ((((((-__pyx_v_x15) * (((-0.0625 * __pyx_v_nu) + (1.07291666666667 * __pyx_v_x31)) + 0.15625)) - (__pyx_v_x25 * __pyx_v_x41)) - (__pyx_v_x30 * __pyx_v_x42)) - (__pyx_v_x34 * __pyx_v_x43)) - (__pyx_v_x40 * __pyx_v_x44)))) + ((__pyx_v_pphi * __pyx_v_x3) * ((((((-__pyx_v_x15) * (((-11.0625 * __pyx_v_nu) + (1.13541666666667 * __pyx_v_x31)) - 0.15625)) - (__pyx_v_x25 * __pyx_v_x26)) - (__pyx_v_x27 * __pyx_v_x30)) - (__pyx_v_x32 * __pyx_v_x34)) - (__pyx_v_x35 * __pyx_v_x40)))) - ((__pyx_v_x13 * __pyx_v_x23) * __pyx_v_x24)) - ((0.0833333333333333 * __pyx_v_x16) * __pyx_v_x20))), 0)), __pyx_t_double_complex_from_parts((((0.25 * (((__pyx_v_r * (__pyx_v_x6 - 2.0)) + __pyx_v_x6) + __pyx_v_x7)) * (((((__pyx_v_pphi * __pyx_v_x52) + (__pyx_v_pphi * __pyx_v_x53)) + (__pyx_v_x13 * __pyx_v_x45)) + (__pyx_v_x13 * __pyx_v_x48)) + (__pyx_v_x20 * __pyx_v_x47))) / pow((__pyx_v_x7 + (0.5 * __pyx_v_x8)), 2.0)), 0)), 1); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1538, __pyx_L1_error)
  __pyx_v_dHeffdr = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1540
 *         cdef double dHeffdr = 0.5*x169*(x160*x162*(-x171*(-x150*(875.0*nu + 1125.0) + 0.234375*x165 + x166*(10.0*nu - 15.0)) - x178 - x38*(0.5*x163 + x164 + 4.5*x4)) - x160*x167*(-x11*x5 - x16*x170)/x161**2 + x168*(-663.496888455656*nu*r**(-5.5)*x54 - nu*x25*x64 + 39.6112800271521*nu*x55*x57 + 6.78168402777778e-8*x11*x141*x142*x146*x154*x158*x7 + x11*x54*(118.4*x174 - 51.6952380952381*x63) + 7.59859378406358e-45*x112*x135*x138*x154*x182*x54*x86*x87 - 9.25454462627843e-34*x112*x180*x181/x134**3 - 2.24091649004576e-37*x135*x140*x142*x154*x180*x183*x38 + 1.69542100694444e-8*x140*x141*x142*x146*x154*x38*(38400.0*x10*x109*x145*x155*x90 + 7680.0*x109*x145*x155*x173*x37 + 7680.0*x109*x155*x180*x37*x90 - x11*(x147*(36.0*nu - 9.0) + x148*(-63.0*X_1 + 63.0*X_2) + x4*(9.0*nu + 8.4375)) - x156*x177 - x172 - x38*(x148*x153 + 0.0625*x149*x4 + 0.0625*x151) - 2.29252167428035e-22*x145*x157*x182*x37/x125) + 1.69542100694444e-8*x140*x141*x142*x146*x158*x182*x38 - 8.47710503472222e-8*x159*x171 - x24*x76 + x25*x28*x4*x80*x84 + x28*x4*x49*x80*(x175 + x81 + x82)/x83**2 - x30 - x33*x57*x73 - x39*x54*x78 - x4*x85 - 3.70688355060912*x58*x62 - 2.0*x65*x69 - 3.0*x68*x79 - 2.0*x70*x74 - 4.41515887225116e-12*x140*x146*x183*x184*x185/x111**3 - 6.62902677807736e-23*x135*x181*x184/x111**5 + 1.01821851311268e-18*x112*x125*x135*x138*x54*x7**3/r**12 - 1.65460508380811e-18*x139/r**14)) + x9*(-dSO*x11*x12*x13 + pphi*x17*x18*(-x15*(-0.0625*nu + 1.07291666666667*x31 + 0.15625) - x25*x41 - x30*x42 - x34*x43 - x40*x44) + pphi*x3*(-x15*(-11.0625*nu + 1.13541666666667*x31 - 0.15625) - x25*x26 - x27*x30 - x32*x34 - x35*x40) - x13*x23*x24 - 0.0833333333333333*x16*x20) - 0.25*(r*(x6 - 2.0) + x6 + x7)*(pphi*x52 + pphi*x53 + x13*x45 + x13*x48 + x20*x47)/(x7 + 0.5*x8)**2
 * 
 *         cdef double  dHeffdphi = 0             # <<<<<<<<<<<<<<
 * 
 *         cdef double  dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)
 */
  __Pyx_TraceLine(1540,0,__PYX_ERR(1, 1540, __pyx_L1_error))
  __pyx_v_dHeffdphi = 0.0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1542
 *         cdef double  dHeffdphi = 0
 * 
 *         cdef double  dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)             # <<<<<<<<<<<<<<
 * 
 *         cdef double  dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)
 */
  __Pyx_TraceLine(1542,0,__PYX_ERR(1, 1542, __pyx_L1_error))
  __pyx_v_dHeffdpr = (__pyx_v_x191 * ((((((((((((((11.8620273619492 * __pyx_v_nu) * __pyx_v_x188) * __pyx_v_x60) + ((((((3.39084201388889e-8 * __pyx_v_prst) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x146) * __pyx_v_x158) * __pyx_v_x185)) + ((__pyx_v_x11 * __pyx_v_x189) * __pyx_v_x78)) + (((((((5.09109256556341e-19 * __pyx_v_x112) * __pyx_v_x125) * __pyx_v_x135) * __pyx_v_x138) * __pyx_v_x186) * __pyx_v_x86) * __pyx_v_x87)) + ((__pyx_v_x15 * __pyx_v_x189) * __pyx_v_x68)) + ((__pyx_v_x15 * __pyx_v_x190) * __pyx_v_x73)) + ((589.775011960583 * __pyx_v_x186) * __pyx_v_x56)) - ((67.9050514751178 * __pyx_v_x187) * __pyx_v_x59)) + (((8.0 * __pyx_v_x188) * __pyx_v_x25) * __pyx_v_x75)) + ((0.975638950243592 * __pyx_v_x188) * __pyx_v_x63)) + (__pyx_v_x189 * __pyx_v_x66)) + (__pyx_v_x190 * __pyx_v_x71)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1544
 *         cdef double  dHeffdpr = x191*(11.8620273619492*nu*x188*x60 + 3.39084201388889e-8*prst*x140*x142*x146*x158*x185 + x11*x189*x78 + 5.09109256556341e-19*x112*x125*x135*x138*x186*x86*x87 + x15*x189*x68 + x15*x190*x73 + 589.775011960583*x186*x56 - 67.9050514751178*x187*x59 + 8.0*x188*x25*x75 + 0.975638950243592*x188*x63 + x189*x66 + x190*x71)
 * 
 *         cdef double  dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)             # <<<<<<<<<<<<<<
 *         cdef double  M2 = M*M
 *         cdef double  nuH = nu*H
 */
  __Pyx_TraceLine(1544,0,__PYX_ERR(1, 1544, __pyx_L1_error))
  __pyx_v_dHeffdpphi = ((__pyx_v_x191 * (((2.0 * __pyx_v_pphi) * __pyx_v_x25) - ((((__pyx_v_pphi * __pyx_v_x49) * __pyx_v_x5) * __pyx_v_x80) * __pyx_v_x84))) + (__pyx_v_x9 * (((((((__pyx_v_x13 * (((__pyx_v_x193 * __pyx_v_x27) + (__pyx_v_x194 * __pyx_v_x32)) + (__pyx_v_x195 * __pyx_v_x35))) + (__pyx_v_x19 * __pyx_v_x47)) + (__pyx_v_x20 * (((__pyx_v_x193 * __pyx_v_x42) + (__pyx_v_x194 * __pyx_v_x43)) + (__pyx_v_x195 * __pyx_v_x44)))) + (__pyx_v_x3 * __pyx_v_x45)) + (__pyx_v_x3 * __pyx_v_x48)) + __pyx_v_x52) + __pyx_v_x53)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1545
 * 
 *         cdef double  dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)
 *         cdef double  M2 = M*M             # <<<<<<<<<<<<<<
 *         cdef double  nuH = nu*H
 *         # Compute H Jacobian
 */
  __Pyx_TraceLine(1545,0,__PYX_ERR(1, 1545, __pyx_L1_error))
  __pyx_v_M2 = (__pyx_v_M * __pyx_v_M);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1546
 *         cdef double  dHeffdpphi = x191*(2.0*pphi*x25 - pphi*x49*x5*x80*x84) + x9*(x13*(x193*x27 + x194*x32 + x195*x35) + x19*x47 + x20*(x193*x42 + x194*x43 + x195*x44) + x3*x45 + x3*x48 + x52 + x53)
 *         cdef double  M2 = M*M
 *         cdef double  nuH = nu*H             # <<<<<<<<<<<<<<
 *         # Compute H Jacobian
 *         cdef double  dHdr = M2 * dHeffdr / nuH
 */
  __Pyx_TraceLine(1546,0,__PYX_ERR(1, 1546, __pyx_L1_error))
  __pyx_v_nuH = (__pyx_v_nu * __pyx_v_H);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1548
 *         cdef double  nuH = nu*H
 *         # Compute H Jacobian
 *         cdef double  dHdr = M2 * dHeffdr / nuH             # <<<<<<<<<<<<<<
 *         cdef double  dHdphi = M2 * dHeffdphi / nuH
 *         cdef double  dHdpr = M2 * dHeffdpr / nuH
 */
  __Pyx_TraceLine(1548,0,__PYX_ERR(1, 1548, __pyx_L1_error))
  __pyx_v_dHdr = ((__pyx_v_M2 * __pyx_v_dHeffdr) / __pyx_v_nuH);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1549
 *         # Compute H Jacobian
 *         cdef double  dHdr = M2 * dHeffdr / nuH
 *         cdef double  dHdphi = M2 * dHeffdphi / nuH             # <<<<<<<<<<<<<<
 *         cdef double  dHdpr = M2 * dHeffdpr / nuH
 *         cdef double  dHdpphi = M2 * dHeffdpphi / nuH
 */
  __Pyx_TraceLine(1549,0,__PYX_ERR(1, 1549, __pyx_L1_error))
  __pyx_v_dHdphi = ((__pyx_v_M2 * __pyx_v_dHeffdphi) / __pyx_v_nuH);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1550
 *         cdef double  dHdr = M2 * dHeffdr / nuH
 *         cdef double  dHdphi = M2 * dHeffdphi / nuH
 *         cdef double  dHdpr = M2 * dHeffdpr / nuH             # <<<<<<<<<<<<<<
 *         cdef double  dHdpphi = M2 * dHeffdpphi / nuH
 *         cdef double result[6]
 */
  __Pyx_TraceLine(1550,0,__PYX_ERR(1, 1550, __pyx_L1_error))
  __pyx_v_dHdpr = ((__pyx_v_M2 * __pyx_v_dHeffdpr) / __pyx_v_nuH);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1551
 *         cdef double  dHdphi = M2 * dHeffdphi / nuH
 *         cdef double  dHdpr = M2 * dHeffdpr / nuH
 *         cdef double  dHdpphi = M2 * dHeffdpphi / nuH             # <<<<<<<<<<<<<<
 *         cdef double result[6]
 *         result[:] = [dHdr, dHdphi, dHdpr, dHdpphi,H,xi]
 */
  __Pyx_TraceLine(1551,0,__PYX_ERR(1, 1551, __pyx_L1_error))
  __pyx_v_dHdpphi = ((__pyx_v_M2 * __pyx_v_dHeffdpphi) / __pyx_v_nuH);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1553
 *         cdef double  dHdpphi = M2 * dHeffdpphi / nuH
 *         cdef double result[6]
 *         result[:] = [dHdr, dHdphi, dHdpr, dHdpphi,H,xi]             # <<<<<<<<<<<<<<
 *         return result
 *         #return dHdr, dHdphi, dHdpr, dHdpphi,H,xi
 */
  __Pyx_TraceLine(1553,0,__PYX_ERR(1, 1553, __pyx_L1_error))
  __pyx_t_16[0] = __pyx_v_dHdr;
  __pyx_t_16[1] = __pyx_v_dHdphi;
  __pyx_t_16[2] = __pyx_v_dHdpr;
  __pyx_t_16[3] = __pyx_v_dHdpphi;
  __pyx_t_16[4] = __pyx_v_H;
  __pyx_t_16[5] = __pyx_v_xi;
  memcpy(&(__pyx_v_result[0]), __pyx_t_16, sizeof(__pyx_v_result[0]) * (6));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1554
 *         cdef double result[6]
 *         result[:] = [dHdr, dHdphi, dHdpr, dHdpphi,H,xi]
 *         return result             # <<<<<<<<<<<<<<
 *         #return dHdr, dHdphi, dHdpr, dHdpphi,H,xi
 * 
 */
  __Pyx_TraceLine(1554,0,__PYX_ERR(1, 1554, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_carray_to_py_double(__pyx_v_result, 6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1299
 *         return xi
 * 
 *     cpdef dynamics(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.dynamics", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_10dynamics, "\n        Compute the dynamics from the Hamiltonian,i.e., dHdr, dHdphi, dHdpr, dHdpphi,H and xi.\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n\n        Returns:\n           (tuple) dHdr, dHdphi, dHdpr, dHdpphi, H and xi\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics = {"dynamics", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_10dynamics};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dynamics (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dynamics", 1, 6, 6, 1); __PYX_ERR(1, 1299, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dynamics", 1, 6, 6, 2); __PYX_ERR(1, 1299, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dynamics", 1, 6, 6, 3); __PYX_ERR(1, 1299, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dynamics", 1, 6, 6, 4); __PYX_ERR(1, 1299, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dynamics", 1, 6, 6, 5); __PYX_ERR(1, 1299, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dynamics") < 0)) __PYX_ERR(1, 1299, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 1299, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 1299, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1299, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dynamics", 1, 6, 6, __pyx_nargs); __PYX_ERR(1, 1299, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.dynamics", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_10dynamics(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_10dynamics(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__16)
  __Pyx_RefNannySetupContext("dynamics", 0);
  __Pyx_TraceCall("dynamics (wrapper)", __pyx_f[1], 1299, 0, __PYX_ERR(1, 1299, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 1299, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 1299, __pyx_L1_error) }
  __pyx_t_1 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_dynamics(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.dynamics", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1557
 *         #return dHdr, dHdphi, dHdpr, dHdpphi,H,xi
 * 
 *     cpdef double omega(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static double __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_omega(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  double __pyx_v_pphi;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  double __pyx_v_M;
  double __pyx_v_nu;
  double __pyx_v_X_1;
  double __pyx_v_X_2;
  double __pyx_v_z0;
  double __pyx_v_z1;
  double __pyx_v_z2;
  double __pyx_v_z3;
  double __pyx_v_z4;
  double __pyx_v_z5;
  double __pyx_v_z6;
  double __pyx_v_z7;
  double __pyx_v_z8;
  double __pyx_v_z9;
  double __pyx_v_z10;
  double __pyx_v_z11;
  double __pyx_v_z12;
  double __pyx_v_z13;
  double __pyx_v_z14;
  double __pyx_v_z15;
  double __pyx_v_z16;
  double __pyx_v_z17;
  double __pyx_v_z18;
  double __pyx_v_z19;
  double __pyx_v_z20;
  double __pyx_v_z21;
  double __pyx_v_z22;
  double __pyx_v_z23;
  double __pyx_v_z24;
  double __pyx_v_z25;
  double __pyx_v_z26;
  double __pyx_v_z27;
  double __pyx_v_z28;
  double __pyx_v_z29;
  double __pyx_v_z30;
  double __pyx_v_z31;
  double __pyx_v_z32;
  double __pyx_v_z33;
  double __pyx_v_z34;
  double __pyx_v_z35;
  double __pyx_v_z36;
  double __pyx_v_z37;
  double __pyx_v_z38;
  double __pyx_v_z39;
  double __pyx_v_z40;
  double __pyx_v_z41;
  double __pyx_v_z42;
  double __pyx_v_z43;
  double __pyx_v_z44;
  double __pyx_v_z45;
  double __pyx_v_z46;
  double __pyx_v_z47;
  double __pyx_v_z48;
  double __pyx_v_z49;
  double __pyx_v_z50;
  double __pyx_v_z51;
  double __pyx_v_z52;
  double __pyx_v_z53;
  double __pyx_v_z54;
  double __pyx_v_z55;
  double __pyx_v_z56;
  double __pyx_v_z57;
  double __pyx_v_z58;
  double __pyx_v_z59;
  double __pyx_v_z60;
  double __pyx_v_z61;
  double __pyx_v_z62;
  double __pyx_v_z63;
  double __pyx_v_z64;
  double __pyx_v_z65;
  double __pyx_v_z66;
  double __pyx_v_z67;
  double __pyx_v_z68;
  double __pyx_v_z69;
  double __pyx_v_z70;
  double __pyx_v_z71;
  double __pyx_v_H;
  CYTHON_UNUSED double __pyx_v_xi;
  double __pyx_v_dHeffdpphi;
  double __pyx_v_omega;
  double __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  double __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  __pyx_ctuple_double__and_double __pyx_t_14;
  double __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__17)
  __Pyx_RefNannySetupContext("omega", 0);
  __Pyx_TraceCall("omega", __pyx_f[1], 1557, 0, __PYX_ERR(1, 1557, __pyx_L1_error));
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_omega); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #ifdef __Pyx_CyFunction_USED
      if (!__Pyx_IsCyOrPyCFunction(__pyx_t_1)
      #else
      if (!PyCFunction_Check(__pyx_t_1)
      #endif
              || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega)) {
        if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 1557, __pyx_L1_error) }
        __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_q, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 1557, __pyx_L1_error) }
        __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_p, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyFloat_FromDouble(__pyx_v_chi_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyFloat_FromDouble(__pyx_v_chi_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyFloat_FromDouble(__pyx_v_m_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_m_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = __pyx_t_1; __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_11 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[7] = {__pyx_t_10, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 6+__pyx_t_11);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1557, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_12;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1576
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(1576,0,__PYX_ERR(1, 1576, __pyx_L1_error))
  __pyx_t_13 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_13 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1577
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(1577,0,__PYX_ERR(1, 1577, __pyx_L1_error))
  __pyx_t_13 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_13 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1579
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(1579,0,__PYX_ERR(1, 1579, __pyx_L1_error))
  __pyx_t_13 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_13 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1580
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(1580,0,__PYX_ERR(1, 1580, __pyx_L1_error))
  __pyx_t_13 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_13 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1582
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(1582,0,__PYX_ERR(1, 1582, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1584
 *         cdef double pphi = L
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']
 */
  __Pyx_TraceLine(1584,0,__PYX_ERR(1, 1584, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1585
 * 
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs['dSO']
 * 
 */
  __Pyx_TraceLine(1585,0,__PYX_ERR(1, 1585, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_a6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_a6 = __pyx_t_12;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1586
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(1586,0,__PYX_ERR(1, 1586, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_dSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1586, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_dSO = __pyx_t_12;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1590
 * 
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M             # <<<<<<<<<<<<<<
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 */
  __Pyx_TraceLine(1590,0,__PYX_ERR(1, 1590, __pyx_L1_error))
  __pyx_t_12 = __pyx_v_self->__pyx_base.EOBpars->p_params->M;
  __pyx_v_M = __pyx_t_12;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1591
 *         # Extra quantities used in the Jacobian
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu             # <<<<<<<<<<<<<<
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 */
  __Pyx_TraceLine(1591,0,__PYX_ERR(1, 1591, __pyx_L1_error))
  __pyx_t_12 = __pyx_v_self->__pyx_base.EOBpars->p_params->nu;
  __pyx_v_nu = __pyx_t_12;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1592
 *         cdef double M = self.EOBpars.p_params.M
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1             # <<<<<<<<<<<<<<
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double z0 = r**2
 */
  __Pyx_TraceLine(1592,0,__PYX_ERR(1, 1592, __pyx_L1_error))
  __pyx_t_12 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_1;
  __pyx_v_X_1 = __pyx_t_12;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1593
 *         cdef double nu = self.EOBpars.p_params.nu
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2             # <<<<<<<<<<<<<<
 *         cdef double z0 = r**2
 *         cdef double z1 = chi_1*X_1
 */
  __Pyx_TraceLine(1593,0,__PYX_ERR(1, 1593, __pyx_L1_error))
  __pyx_t_12 = __pyx_v_self->__pyx_base.EOBpars->p_params->X_2;
  __pyx_v_X_2 = __pyx_t_12;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1594
 *         cdef double X_1 = self.EOBpars.p_params.X_1
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double z0 = r**2             # <<<<<<<<<<<<<<
 *         cdef double z1 = chi_1*X_1
 *         cdef double z2 = chi_2*X_2
 */
  __Pyx_TraceLine(1594,0,__PYX_ERR(1, 1594, __pyx_L1_error))
  __pyx_v_z0 = pow(__pyx_v_r, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1595
 *         cdef double X_2 = self.EOBpars.p_params.X_2
 *         cdef double z0 = r**2
 *         cdef double z1 = chi_1*X_1             # <<<<<<<<<<<<<<
 *         cdef double z2 = chi_2*X_2
 *         cdef double z3 = z1 + z2
 */
  __Pyx_TraceLine(1595,0,__PYX_ERR(1, 1595, __pyx_L1_error))
  __pyx_v_z1 = (__pyx_v_chi_1 * __pyx_v_X_1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1596
 *         cdef double z0 = r**2
 *         cdef double z1 = chi_1*X_1
 *         cdef double z2 = chi_2*X_2             # <<<<<<<<<<<<<<
 *         cdef double z3 = z1 + z2
 *         cdef double z4 = z3**2
 */
  __Pyx_TraceLine(1596,0,__PYX_ERR(1, 1596, __pyx_L1_error))
  __pyx_v_z2 = (__pyx_v_chi_2 * __pyx_v_X_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1597
 *         cdef double z1 = chi_1*X_1
 *         cdef double z2 = chi_2*X_2
 *         cdef double z3 = z1 + z2             # <<<<<<<<<<<<<<
 *         cdef double z4 = z3**2
 *         cdef double z5 = 2.0*z4
 */
  __Pyx_TraceLine(1597,0,__PYX_ERR(1, 1597, __pyx_L1_error))
  __pyx_v_z3 = (__pyx_v_z1 + __pyx_v_z2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1598
 *         cdef double z2 = chi_2*X_2
 *         cdef double z3 = z1 + z2
 *         cdef double z4 = z3**2             # <<<<<<<<<<<<<<
 *         cdef double z5 = 2.0*z4
 *         cdef double z6 = z0 + z4
 */
  __Pyx_TraceLine(1598,0,__PYX_ERR(1, 1598, __pyx_L1_error))
  __pyx_v_z4 = pow(__pyx_v_z3, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1599
 *         cdef double z3 = z1 + z2
 *         cdef double z4 = z3**2
 *         cdef double z5 = 2.0*z4             # <<<<<<<<<<<<<<
 *         cdef double z6 = z0 + z4
 *         cdef double z7 = r**3
 */
  __Pyx_TraceLine(1599,0,__PYX_ERR(1, 1599, __pyx_L1_error))
  __pyx_v_z5 = (2.0 * __pyx_v_z4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1600
 *         cdef double z4 = z3**2
 *         cdef double z5 = 2.0*z4
 *         cdef double z6 = z0 + z4             # <<<<<<<<<<<<<<
 *         cdef double z7 = r**3
 *         cdef double z8 = 1/z7
 */
  __Pyx_TraceLine(1600,0,__PYX_ERR(1, 1600, __pyx_L1_error))
  __pyx_v_z6 = (__pyx_v_z0 + __pyx_v_z4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1601
 *         cdef double z5 = 2.0*z4
 *         cdef double z6 = z0 + z4
 *         cdef double z7 = r**3             # <<<<<<<<<<<<<<
 *         cdef double z8 = 1/z7
 *         cdef double z9 = 1/z0
 */
  __Pyx_TraceLine(1601,0,__PYX_ERR(1, 1601, __pyx_L1_error))
  __pyx_v_z7 = pow(__pyx_v_r, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1602
 *         cdef double z6 = z0 + z4
 *         cdef double z7 = r**3
 *         cdef double z8 = 1/z7             # <<<<<<<<<<<<<<
 *         cdef double z9 = 1/z0
 *         cdef double z10 = z4*z9
 */
  __Pyx_TraceLine(1602,0,__PYX_ERR(1, 1602, __pyx_L1_error))
  __pyx_v_z8 = (1.0 / __pyx_v_z7);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1603
 *         cdef double z7 = r**3
 *         cdef double z8 = 1/z7
 *         cdef double z9 = 1/z0             # <<<<<<<<<<<<<<
 *         cdef double z10 = z4*z9
 *         cdef double z11 = z1 - z2
 */
  __Pyx_TraceLine(1603,0,__PYX_ERR(1, 1603, __pyx_L1_error))
  __pyx_v_z9 = (1.0 / __pyx_v_z0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1604
 *         cdef double z8 = 1/z7
 *         cdef double z9 = 1/z0
 *         cdef double z10 = z4*z9             # <<<<<<<<<<<<<<
 *         cdef double z11 = z1 - z2
 *         cdef double z12 = z11*(X_1 - X_2)
 */
  __Pyx_TraceLine(1604,0,__PYX_ERR(1, 1604, __pyx_L1_error))
  __pyx_v_z10 = (__pyx_v_z4 * __pyx_v_z9);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1605
 *         cdef double z9 = 1/z0
 *         cdef double z10 = z4*z9
 *         cdef double z11 = z1 - z2             # <<<<<<<<<<<<<<
 *         cdef double z12 = z11*(X_1 - X_2)
 *         cdef double z13 = 5.0*X_1 - 5.0*X_2
 */
  __Pyx_TraceLine(1605,0,__PYX_ERR(1, 1605, __pyx_L1_error))
  __pyx_v_z11 = (__pyx_v_z1 - __pyx_v_z2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1606
 *         cdef double z10 = z4*z9
 *         cdef double z11 = z1 - z2
 *         cdef double z12 = z11*(X_1 - X_2)             # <<<<<<<<<<<<<<
 *         cdef double z13 = 5.0*X_1 - 5.0*X_2
 *         cdef double z14 = z11*z3
 */
  __Pyx_TraceLine(1606,0,__PYX_ERR(1, 1606, __pyx_L1_error))
  __pyx_v_z12 = (__pyx_v_z11 * (__pyx_v_X_1 - __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1607
 *         cdef double z11 = z1 - z2
 *         cdef double z12 = z11*(X_1 - X_2)
 *         cdef double z13 = 5.0*X_1 - 5.0*X_2             # <<<<<<<<<<<<<<
 *         cdef double z14 = z11*z3
 *         cdef double z15 = -1.40625*nu - 0.46875
 */
  __Pyx_TraceLine(1607,0,__PYX_ERR(1, 1607, __pyx_L1_error))
  __pyx_v_z13 = ((5.0 * __pyx_v_X_1) - (5.0 * __pyx_v_X_2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1608
 *         cdef double z12 = z11*(X_1 - X_2)
 *         cdef double z13 = 5.0*X_1 - 5.0*X_2
 *         cdef double z14 = z11*z3             # <<<<<<<<<<<<<<
 *         cdef double z15 = -1.40625*nu - 0.46875
 *         cdef double z16 = 2.0*pphi
 */
  __Pyx_TraceLine(1608,0,__PYX_ERR(1, 1608, __pyx_L1_error))
  __pyx_v_z14 = (__pyx_v_z11 * __pyx_v_z3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1609
 *         cdef double z13 = 5.0*X_1 - 5.0*X_2
 *         cdef double z14 = z11*z3
 *         cdef double z15 = -1.40625*nu - 0.46875             # <<<<<<<<<<<<<<
 *         cdef double z16 = 2.0*pphi
 *         cdef double z17 = z16*z9
 */
  __Pyx_TraceLine(1609,0,__PYX_ERR(1, 1609, __pyx_L1_error))
  __pyx_v_z15 = ((-1.40625 * __pyx_v_nu) - 0.46875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1610
 *         cdef double z14 = z11*z3
 *         cdef double z15 = -1.40625*nu - 0.46875
 *         cdef double z16 = 2.0*pphi             # <<<<<<<<<<<<<<
 *         cdef double z17 = z16*z9
 *         cdef double z18 = nu**2
 */
  __Pyx_TraceLine(1610,0,__PYX_ERR(1, 1610, __pyx_L1_error))
  __pyx_v_z16 = (2.0 * __pyx_v_pphi);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1611
 *         cdef double z15 = -1.40625*nu - 0.46875
 *         cdef double z16 = 2.0*pphi
 *         cdef double z17 = z16*z9             # <<<<<<<<<<<<<<
 *         cdef double z18 = nu**2
 *         cdef double z19 = -2.0859375*nu - 2.07161458333333*z18 + 0.23046875
 */
  __Pyx_TraceLine(1611,0,__PYX_ERR(1, 1611, __pyx_L1_error))
  __pyx_v_z17 = (__pyx_v_z16 * __pyx_v_z9);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1612
 *         cdef double z16 = 2.0*pphi
 *         cdef double z17 = z16*z9
 *         cdef double z18 = nu**2             # <<<<<<<<<<<<<<
 *         cdef double z19 = -2.0859375*nu - 2.07161458333333*z18 + 0.23046875
 *         cdef double z20 = z16*z8
 */
  __Pyx_TraceLine(1612,0,__PYX_ERR(1, 1612, __pyx_L1_error))
  __pyx_v_z18 = pow(__pyx_v_nu, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1613
 *         cdef double z17 = z16*z9
 *         cdef double z18 = nu**2
 *         cdef double z19 = -2.0859375*nu - 2.07161458333333*z18 + 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double z20 = z16*z8
 *         cdef double z21 = 0.5859375*nu + 1.34765625*z18 + 0.41015625
 */
  __Pyx_TraceLine(1613,0,__PYX_ERR(1, 1613, __pyx_L1_error))
  __pyx_v_z19 = (((-2.0859375 * __pyx_v_nu) - (2.07161458333333 * __pyx_v_z18)) + 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1614
 *         cdef double z18 = nu**2
 *         cdef double z19 = -2.0859375*nu - 2.07161458333333*z18 + 0.23046875
 *         cdef double z20 = z16*z8             # <<<<<<<<<<<<<<
 *         cdef double z21 = 0.5859375*nu + 1.34765625*z18 + 0.41015625
 *         cdef double z22 = r**4
 */
  __Pyx_TraceLine(1614,0,__PYX_ERR(1, 1614, __pyx_L1_error))
  __pyx_v_z20 = (__pyx_v_z16 * __pyx_v_z8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1615
 *         cdef double z19 = -2.0859375*nu - 2.07161458333333*z18 + 0.23046875
 *         cdef double z20 = z16*z8
 *         cdef double z21 = 0.5859375*nu + 1.34765625*z18 + 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double z22 = r**4
 *         cdef double z23 = 1/z22
 */
  __Pyx_TraceLine(1615,0,__PYX_ERR(1, 1615, __pyx_L1_error))
  __pyx_v_z21 = (((0.5859375 * __pyx_v_nu) + (1.34765625 * __pyx_v_z18)) + 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1616
 *         cdef double z20 = z16*z8
 *         cdef double z21 = 0.5859375*nu + 1.34765625*z18 + 0.41015625
 *         cdef double z22 = r**4             # <<<<<<<<<<<<<<
 *         cdef double z23 = 1/z22
 *         cdef double z24 = 4.0*pphi**3*z23
 */
  __Pyx_TraceLine(1616,0,__PYX_ERR(1, 1616, __pyx_L1_error))
  __pyx_v_z22 = pow(__pyx_v_r, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1617
 *         cdef double z21 = 0.5859375*nu + 1.34765625*z18 + 0.41015625
 *         cdef double z22 = r**4
 *         cdef double z23 = 1/z22             # <<<<<<<<<<<<<<
 *         cdef double z24 = 4.0*pphi**3*z23
 *         cdef double z25 = 0.46875 - 0.28125*nu
 */
  __Pyx_TraceLine(1617,0,__PYX_ERR(1, 1617, __pyx_L1_error))
  __pyx_v_z23 = (1.0 / __pyx_v_z22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1618
 *         cdef double z22 = r**4
 *         cdef double z23 = 1/z22
 *         cdef double z24 = 4.0*pphi**3*z23             # <<<<<<<<<<<<<<
 *         cdef double z25 = 0.46875 - 0.28125*nu
 *         cdef double z26 = -0.2734375*nu - 0.798177083333333*z18 - 0.23046875
 */
  __Pyx_TraceLine(1618,0,__PYX_ERR(1, 1618, __pyx_L1_error))
  __pyx_v_z24 = ((4.0 * pow(__pyx_v_pphi, 3.0)) * __pyx_v_z23);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1619
 *         cdef double z23 = 1/z22
 *         cdef double z24 = 4.0*pphi**3*z23
 *         cdef double z25 = 0.46875 - 0.28125*nu             # <<<<<<<<<<<<<<
 *         cdef double z26 = -0.2734375*nu - 0.798177083333333*z18 - 0.23046875
 *         cdef double z27 = -0.3515625*nu + 0.29296875*z18 - 0.41015625
 */
  __Pyx_TraceLine(1619,0,__PYX_ERR(1, 1619, __pyx_L1_error))
  __pyx_v_z25 = (0.46875 - (0.28125 * __pyx_v_nu));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1620
 *         cdef double z24 = 4.0*pphi**3*z23
 *         cdef double z25 = 0.46875 - 0.28125*nu
 *         cdef double z26 = -0.2734375*nu - 0.798177083333333*z18 - 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double z27 = -0.3515625*nu + 0.29296875*z18 - 0.41015625
 *         cdef double z28 = r**(-1)
 */
  __Pyx_TraceLine(1620,0,__PYX_ERR(1, 1620, __pyx_L1_error))
  __pyx_v_z26 = (((-0.2734375 * __pyx_v_nu) - (0.798177083333333 * __pyx_v_z18)) - 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1621
 *         cdef double z25 = 0.46875 - 0.28125*nu
 *         cdef double z26 = -0.2734375*nu - 0.798177083333333*z18 - 0.23046875
 *         cdef double z27 = -0.3515625*nu + 0.29296875*z18 - 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double z28 = r**(-1)
 *         cdef double z29 = pphi**2
 */
  __Pyx_TraceLine(1621,0,__PYX_ERR(1, 1621, __pyx_L1_error))
  __pyx_v_z27 = (((-0.3515625 * __pyx_v_nu) + (0.29296875 * __pyx_v_z18)) - 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1622
 *         cdef double z26 = -0.2734375*nu - 0.798177083333333*z18 - 0.23046875
 *         cdef double z27 = -0.3515625*nu + 0.29296875*z18 - 0.41015625
 *         cdef double z28 = r**(-1)             # <<<<<<<<<<<<<<
 *         cdef double z29 = pphi**2
 *         cdef double z30 = z29*z9
 */
  __Pyx_TraceLine(1622,0,__PYX_ERR(1, 1622, __pyx_L1_error))
  __pyx_v_z28 = pow(__pyx_v_r, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1623
 *         cdef double z27 = -0.3515625*nu + 0.29296875*z18 - 0.41015625
 *         cdef double z28 = r**(-1)
 *         cdef double z29 = pphi**2             # <<<<<<<<<<<<<<
 *         cdef double z30 = z29*z9
 *         cdef double z31 = z29*z8
 */
  __Pyx_TraceLine(1623,0,__PYX_ERR(1, 1623, __pyx_L1_error))
  __pyx_v_z29 = pow(__pyx_v_pphi, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1624
 *         cdef double z28 = r**(-1)
 *         cdef double z29 = pphi**2
 *         cdef double z30 = z29*z9             # <<<<<<<<<<<<<<
 *         cdef double z31 = z29*z8
 *         cdef double z32 = pphi**4*z23
 */
  __Pyx_TraceLine(1624,0,__PYX_ERR(1, 1624, __pyx_L1_error))
  __pyx_v_z30 = (__pyx_v_z29 * __pyx_v_z9);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1625
 *         cdef double z29 = pphi**2
 *         cdef double z30 = z29*z9
 *         cdef double z31 = z29*z8             # <<<<<<<<<<<<<<
 *         cdef double z32 = pphi**4*z23
 *         cdef double z33 = r + 2.0
 */
  __Pyx_TraceLine(1625,0,__PYX_ERR(1, 1625, __pyx_L1_error))
  __pyx_v_z31 = (__pyx_v_z29 * __pyx_v_z8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1626
 *         cdef double z30 = z29*z9
 *         cdef double z31 = z29*z8
 *         cdef double z32 = pphi**4*z23             # <<<<<<<<<<<<<<
 *         cdef double z33 = r + 2.0
 *         cdef double z34 = z33*z4
 */
  __Pyx_TraceLine(1626,0,__PYX_ERR(1, 1626, __pyx_L1_error))
  __pyx_v_z32 = (pow(__pyx_v_pphi, 4.0) * __pyx_v_z23);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1627
 *         cdef double z31 = z29*z8
 *         cdef double z32 = pphi**4*z23
 *         cdef double z33 = r + 2.0             # <<<<<<<<<<<<<<
 *         cdef double z34 = z33*z4
 *         cdef double z35 = z28/(r*z34 + z22)
 */
  __Pyx_TraceLine(1627,0,__PYX_ERR(1, 1627, __pyx_L1_error))
  __pyx_v_z33 = (__pyx_v_r + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1628
 *         cdef double z32 = pphi**4*z23
 *         cdef double z33 = r + 2.0
 *         cdef double z34 = z33*z4             # <<<<<<<<<<<<<<
 *         cdef double z35 = z28/(r*z34 + z22)
 *         cdef double z36 = z11**2
 */
  __Pyx_TraceLine(1628,0,__PYX_ERR(1, 1628, __pyx_L1_error))
  __pyx_v_z34 = (__pyx_v_z33 * __pyx_v_z4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1629
 *         cdef double z33 = r + 2.0
 *         cdef double z34 = z33*z4
 *         cdef double z35 = z28/(r*z34 + z22)             # <<<<<<<<<<<<<<
 *         cdef double z36 = z11**2
 *         cdef double z37 = r**5
 */
  __Pyx_TraceLine(1629,0,__PYX_ERR(1, 1629, __pyx_L1_error))
  __pyx_v_z35 = (__pyx_v_z28 / ((__pyx_v_r * __pyx_v_z34) + __pyx_v_z22));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1630
 *         cdef double z34 = z33*z4
 *         cdef double z35 = z28/(r*z34 + z22)
 *         cdef double z36 = z11**2             # <<<<<<<<<<<<<<
 *         cdef double z37 = r**5
 *         cdef double z38 = 1/z37
 */
  __Pyx_TraceLine(1630,0,__PYX_ERR(1, 1630, __pyx_L1_error))
  __pyx_v_z36 = pow(__pyx_v_z11, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1631
 *         cdef double z35 = z28/(r*z34 + z22)
 *         cdef double z36 = z11**2
 *         cdef double z37 = r**5             # <<<<<<<<<<<<<<
 *         cdef double z38 = 1/z37
 *         cdef double z39 = 0.015625*z4
 */
  __Pyx_TraceLine(1631,0,__PYX_ERR(1, 1631, __pyx_L1_error))
  __pyx_v_z37 = pow(__pyx_v_r, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1632
 *         cdef double z36 = z11**2
 *         cdef double z37 = r**5
 *         cdef double z38 = 1/z37             # <<<<<<<<<<<<<<
 *         cdef double z39 = 0.015625*z4
 *         cdef double z40 = nu**4
 */
  __Pyx_TraceLine(1632,0,__PYX_ERR(1, 1632, __pyx_L1_error))
  __pyx_v_z38 = (1.0 / __pyx_v_z37);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1633
 *         cdef double z37 = r**5
 *         cdef double z38 = 1/z37
 *         cdef double z39 = 0.015625*z4             # <<<<<<<<<<<<<<
 *         cdef double z40 = nu**4
 *         cdef double z41 = log(r)
 */
  __Pyx_TraceLine(1633,0,__PYX_ERR(1, 1633, __pyx_L1_error))
  __pyx_v_z39 = (0.015625 * __pyx_v_z4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1634
 *         cdef double z38 = 1/z37
 *         cdef double z39 = 0.015625*z4
 *         cdef double z40 = nu**4             # <<<<<<<<<<<<<<
 *         cdef double z41 = log(r)
 *         cdef double z42 = z41**2
 */
  __Pyx_TraceLine(1634,0,__PYX_ERR(1, 1634, __pyx_L1_error))
  __pyx_v_z40 = pow(__pyx_v_nu, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1635
 *         cdef double z39 = 0.015625*z4
 *         cdef double z40 = nu**4
 *         cdef double z41 = log(r)             # <<<<<<<<<<<<<<
 *         cdef double z42 = z41**2
 *         cdef double z43 = nu**3
 */
  __Pyx_TraceLine(1635,0,__PYX_ERR(1, 1635, __pyx_L1_error))
  __pyx_v_z41 = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1636
 *         cdef double z40 = nu**4
 *         cdef double z41 = log(r)
 *         cdef double z42 = z41**2             # <<<<<<<<<<<<<<
 *         cdef double z43 = nu**3
 *         cdef double z44 = 756.0*nu
 */
  __Pyx_TraceLine(1636,0,__PYX_ERR(1, 1636, __pyx_L1_error))
  __pyx_v_z42 = pow(__pyx_v_z41, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1637
 *         cdef double z41 = log(r)
 *         cdef double z42 = z41**2
 *         cdef double z43 = nu**3             # <<<<<<<<<<<<<<
 *         cdef double z44 = 756.0*nu
 *         cdef double z45 = z44 + 1079.0
 */
  __Pyx_TraceLine(1637,0,__PYX_ERR(1, 1637, __pyx_L1_error))
  __pyx_v_z43 = pow(__pyx_v_nu, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1638
 *         cdef double z42 = z41**2
 *         cdef double z43 = nu**3
 *         cdef double z44 = 756.0*nu             # <<<<<<<<<<<<<<
 *         cdef double z45 = z44 + 1079.0
 *         cdef double z46 = 8.0*r + 4.0*z0 + 2.0*z7 + 16.0
 */
  __Pyx_TraceLine(1638,0,__PYX_ERR(1, 1638, __pyx_L1_error))
  __pyx_v_z44 = (756.0 * __pyx_v_nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1639
 *         cdef double z43 = nu**3
 *         cdef double z44 = 756.0*nu
 *         cdef double z45 = z44 + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double z46 = 8.0*r + 4.0*z0 + 2.0*z7 + 16.0
 *         cdef double z47 = (2048.0*nu*z41*(336.0*r + z44 + 407.0) + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*z18 - 245760.0) - 5416406.59541186*z18 - 3440640.0)/(32768.0*nu*z41*(-38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*z18 + 17264.0) + 1920.0*z0*(588.0*nu + 1079.0) - 1882456.23663972*z18 + 480.0*z22*z45 + 161280.0*z37 + 960.0*z45*z7 + 13447680.0) + 53760.0*nu*(7680.0*a6*(z22 + z46) + 113485.217444961*r*(-z22 + z46) + 148.04406601634*r*(7704.0*r + 3852.0*z0 + 349.0*z22 + 1926.0*z7 + 36400.0) + 128.0*r*(13218.7851094412*r + 8529.39255472061*z0 - 6852.34813868015*z22 + 4264.6962773603*z7 - 33722.4297811176)) + 67645734912.0*z18*z42 + 7.0*z18*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*z0 - 3089250703.76879*z22 + 1426660551.8844*z37 - 6178501407.53758*z7 + 276057889687.011) + 13212057600.0*z37 + 241555486248.807*z40 + 1120.0*z43*(-163683964.822551*r - 17833256.898555*z0 - 1188987459.03162))
 */
  __Pyx_TraceLine(1639,0,__PYX_ERR(1, 1639, __pyx_L1_error))
  __pyx_v_z45 = (__pyx_v_z44 + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1640
 *         cdef double z44 = 756.0*nu
 *         cdef double z45 = z44 + 1079.0
 *         cdef double z46 = 8.0*r + 4.0*z0 + 2.0*z7 + 16.0             # <<<<<<<<<<<<<<
 *         cdef double z47 = (2048.0*nu*z41*(336.0*r + z44 + 407.0) + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*z18 - 245760.0) - 5416406.59541186*z18 - 3440640.0)/(32768.0*nu*z41*(-38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*z18 + 17264.0) + 1920.0*z0*(588.0*nu + 1079.0) - 1882456.23663972*z18 + 480.0*z22*z45 + 161280.0*z37 + 960.0*z45*z7 + 13447680.0) + 53760.0*nu*(7680.0*a6*(z22 + z46) + 113485.217444961*r*(-z22 + z46) + 148.04406601634*r*(7704.0*r + 3852.0*z0 + 349.0*z22 + 1926.0*z7 + 36400.0) + 128.0*r*(13218.7851094412*r + 8529.39255472061*z0 - 6852.34813868015*z22 + 4264.6962773603*z7 - 33722.4297811176)) + 67645734912.0*z18*z42 + 7.0*z18*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*z0 - 3089250703.76879*z22 + 1426660551.8844*z37 - 6178501407.53758*z7 + 276057889687.011) + 13212057600.0*z37 + 241555486248.807*z40 + 1120.0*z43*(-163683964.822551*r - 17833256.898555*z0 - 1188987459.03162))
 *         cdef double z48 = z22*z47
 */
  __Pyx_TraceLine(1640,0,__PYX_ERR(1, 1640, __pyx_L1_error))
  __pyx_v_z46 = ((((8.0 * __pyx_v_r) + (4.0 * __pyx_v_z0)) + (2.0 * __pyx_v_z7)) + 16.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1641
 *         cdef double z45 = z44 + 1079.0
 *         cdef double z46 = 8.0*r + 4.0*z0 + 2.0*z7 + 16.0
 *         cdef double z47 = (2048.0*nu*z41*(336.0*r + z44 + 407.0) + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*z18 - 245760.0) - 5416406.59541186*z18 - 3440640.0)/(32768.0*nu*z41*(-38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*z18 + 17264.0) + 1920.0*z0*(588.0*nu + 1079.0) - 1882456.23663972*z18 + 480.0*z22*z45 + 161280.0*z37 + 960.0*z45*z7 + 13447680.0) + 53760.0*nu*(7680.0*a6*(z22 + z46) + 113485.217444961*r*(-z22 + z46) + 148.04406601634*r*(7704.0*r + 3852.0*z0 + 349.0*z22 + 1926.0*z7 + 36400.0) + 128.0*r*(13218.7851094412*r + 8529.39255472061*z0 - 6852.34813868015*z22 + 4264.6962773603*z7 - 33722.4297811176)) + 67645734912.0*z18*z42 + 7.0*z18*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*z0 - 3089250703.76879*z22 + 1426660551.8844*z37 - 6178501407.53758*z7 + 276057889687.011) + 13212057600.0*z37 + 241555486248.807*z40 + 1120.0*z43*(-163683964.822551*r - 17833256.898555*z0 - 1188987459.03162))             # <<<<<<<<<<<<<<
 *         cdef double z48 = z22*z47
 *         cdef double z49 = z10 + z23*(-0.25*z13*z14 + 0.125*z36*(4.0*nu + 1.0) + 1.125*z4) + z38*(0.03125*z14*(2.0*nu - 3.0)*(-39.0*X_1 + 39.0*X_2) + 0.046875*z36*(-27.0*nu + 28.0*z18 - 3.0) - z39*(175.0*nu + 225.0)) + 7680.0*z48
 */
  __Pyx_TraceLine(1641,0,__PYX_ERR(1, 1641, __pyx_L1_error))
  __pyx_v_z47 = ((((((((2048.0 * __pyx_v_nu) * __pyx_v_z41) * (((336.0 * __pyx_v_r) + __pyx_v_z44) + 407.0)) + ((28.0 * __pyx_v_nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) - ((7.0 * __pyx_v_r) * (((938918.400156317 * __pyx_v_nu) - (185763.092693281 * __pyx_v_z18)) - 245760.0))) - (5416406.59541186 * __pyx_v_z18)) - 3440640.0) / (((((((((32768.0 * __pyx_v_nu) * __pyx_v_z41) * ((((((((-38842241.4769507 * __pyx_v_nu) + ((240.0 * __pyx_v_r) * (((-7466.27061066206 * __pyx_v_nu) - (3024.0 * __pyx_v_z18)) + 17264.0))) + ((1920.0 * __pyx_v_z0) * ((588.0 * __pyx_v_nu) + 1079.0))) - (1882456.23663972 * __pyx_v_z18)) + ((480.0 * __pyx_v_z22) * __pyx_v_z45)) + (161280.0 * __pyx_v_z37)) + ((960.0 * __pyx_v_z45) * __pyx_v_z7)) + 13447680.0)) + ((53760.0 * __pyx_v_nu) * (((((7680.0 * __pyx_v_a6) * (__pyx_v_z22 + __pyx_v_z46)) + ((113485.217444961 * __pyx_v_r) * ((-__pyx_v_z22) + __pyx_v_z46))) + ((148.04406601634 * __pyx_v_r) * (((((7704.0 * __pyx_v_r) + (3852.0 * __pyx_v_z0)) + (349.0 * __pyx_v_z22)) + (1926.0 * __pyx_v_z7)) + 36400.0))) + ((128.0 * __pyx_v_r) * (((((13218.7851094412 * __pyx_v_r) + (8529.39255472061 * __pyx_v_z0)) - (6852.34813868015 * __pyx_v_z22)) + (4264.6962773603 * __pyx_v_z7)) - 33722.4297811176))))) + ((67645734912.0 * __pyx_v_z18) * __pyx_v_z42)) + ((7.0 * __pyx_v_z18) * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (122635399361.987 * __pyx_v_r)) + (2064783811.32587 * __pyx_v_z0)) - (3089250703.76879 * __pyx_v_z22)) + (1426660551.8844 * __pyx_v_z37)) - (6178501407.53758 * __pyx_v_z7)) + 276057889687.011))) + (13212057600.0 * __pyx_v_z37)) + (241555486248.807 * __pyx_v_z40)) + ((1120.0 * __pyx_v_z43) * (((-163683964.822551 * __pyx_v_r) - (17833256.898555 * __pyx_v_z0)) - 1188987459.03162))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1642
 *         cdef double z46 = 8.0*r + 4.0*z0 + 2.0*z7 + 16.0
 *         cdef double z47 = (2048.0*nu*z41*(336.0*r + z44 + 407.0) + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*z18 - 245760.0) - 5416406.59541186*z18 - 3440640.0)/(32768.0*nu*z41*(-38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*z18 + 17264.0) + 1920.0*z0*(588.0*nu + 1079.0) - 1882456.23663972*z18 + 480.0*z22*z45 + 161280.0*z37 + 960.0*z45*z7 + 13447680.0) + 53760.0*nu*(7680.0*a6*(z22 + z46) + 113485.217444961*r*(-z22 + z46) + 148.04406601634*r*(7704.0*r + 3852.0*z0 + 349.0*z22 + 1926.0*z7 + 36400.0) + 128.0*r*(13218.7851094412*r + 8529.39255472061*z0 - 6852.34813868015*z22 + 4264.6962773603*z7 - 33722.4297811176)) + 67645734912.0*z18*z42 + 7.0*z18*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*z0 - 3089250703.76879*z22 + 1426660551.8844*z37 - 6178501407.53758*z7 + 276057889687.011) + 13212057600.0*z37 + 241555486248.807*z40 + 1120.0*z43*(-163683964.822551*r - 17833256.898555*z0 - 1188987459.03162))
 *         cdef double z48 = z22*z47             # <<<<<<<<<<<<<<
 *         cdef double z49 = z10 + z23*(-0.25*z13*z14 + 0.125*z36*(4.0*nu + 1.0) + 1.125*z4) + z38*(0.03125*z14*(2.0*nu - 3.0)*(-39.0*X_1 + 39.0*X_2) + 0.046875*z36*(-27.0*nu + 28.0*z18 - 3.0) - z39*(175.0*nu + 225.0)) + 7680.0*z48
 *         cdef double z50 = prst**4
 */
  __Pyx_TraceLine(1642,0,__PYX_ERR(1, 1642, __pyx_L1_error))
  __pyx_v_z48 = (__pyx_v_z22 * __pyx_v_z47);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1643
 *         cdef double z47 = (2048.0*nu*z41*(336.0*r + z44 + 407.0) + 28.0*nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*nu - 185763.092693281*z18 - 245760.0) - 5416406.59541186*z18 - 3440640.0)/(32768.0*nu*z41*(-38842241.4769507*nu + 240.0*r*(-7466.27061066206*nu - 3024.0*z18 + 17264.0) + 1920.0*z0*(588.0*nu + 1079.0) - 1882456.23663972*z18 + 480.0*z22*z45 + 161280.0*z37 + 960.0*z45*z7 + 13447680.0) + 53760.0*nu*(7680.0*a6*(z22 + z46) + 113485.217444961*r*(-z22 + z46) + 148.04406601634*r*(7704.0*r + 3852.0*z0 + 349.0*z22 + 1926.0*z7 + 36400.0) + 128.0*r*(13218.7851094412*r + 8529.39255472061*z0 - 6852.34813868015*z22 + 4264.6962773603*z7 - 33722.4297811176)) + 67645734912.0*z18*z42 + 7.0*z18*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*z0 - 3089250703.76879*z22 + 1426660551.8844*z37 - 6178501407.53758*z7 + 276057889687.011) + 13212057600.0*z37 + 241555486248.807*z40 + 1120.0*z43*(-163683964.822551*r - 17833256.898555*z0 - 1188987459.03162))
 *         cdef double z48 = z22*z47
 *         cdef double z49 = z10 + z23*(-0.25*z13*z14 + 0.125*z36*(4.0*nu + 1.0) + 1.125*z4) + z38*(0.03125*z14*(2.0*nu - 3.0)*(-39.0*X_1 + 39.0*X_2) + 0.046875*z36*(-27.0*nu + 28.0*z18 - 3.0) - z39*(175.0*nu + 225.0)) + 7680.0*z48             # <<<<<<<<<<<<<<
 *         cdef double z50 = prst**4
 *         cdef double z51 = prst**6
 */
  __Pyx_TraceLine(1643,0,__PYX_ERR(1, 1643, __pyx_L1_error))
  __pyx_v_z49 = (((__pyx_v_z10 + (__pyx_v_z23 * ((((-0.25 * __pyx_v_z13) * __pyx_v_z14) + ((0.125 * __pyx_v_z36) * ((4.0 * __pyx_v_nu) + 1.0))) + (1.125 * __pyx_v_z4)))) + (__pyx_v_z38 * (((((0.03125 * __pyx_v_z14) * ((2.0 * __pyx_v_nu) - 3.0)) * ((-39.0 * __pyx_v_X_1) + (39.0 * __pyx_v_X_2))) + ((0.046875 * __pyx_v_z36) * (((-27.0 * __pyx_v_nu) + (28.0 * __pyx_v_z18)) - 3.0))) - (__pyx_v_z39 * ((175.0 * __pyx_v_nu) + 225.0))))) + (7680.0 * __pyx_v_z48));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1644
 *         cdef double z48 = z22*z47
 *         cdef double z49 = z10 + z23*(-0.25*z13*z14 + 0.125*z36*(4.0*nu + 1.0) + 1.125*z4) + z38*(0.03125*z14*(2.0*nu - 3.0)*(-39.0*X_1 + 39.0*X_2) + 0.046875*z36*(-27.0*nu + 28.0*z18 - 3.0) - z39*(175.0*nu + 225.0)) + 7680.0*z48
 *         cdef double z50 = prst**4             # <<<<<<<<<<<<<<
 *         cdef double z51 = prst**6
 *         cdef double z52 = prst**8
 */
  __Pyx_TraceLine(1644,0,__PYX_ERR(1, 1644, __pyx_L1_error))
  __pyx_v_z50 = pow(__pyx_v_prst, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1645
 *         cdef double z49 = z10 + z23*(-0.25*z13*z14 + 0.125*z36*(4.0*nu + 1.0) + 1.125*z4) + z38*(0.03125*z14*(2.0*nu - 3.0)*(-39.0*X_1 + 39.0*X_2) + 0.046875*z36*(-27.0*nu + 28.0*z18 - 3.0) - z39*(175.0*nu + 225.0)) + 7680.0*z48
 *         cdef double z50 = prst**4
 *         cdef double z51 = prst**6             # <<<<<<<<<<<<<<
 *         cdef double z52 = prst**8
 *         cdef double z53 = nu*z52
 */
  __Pyx_TraceLine(1645,0,__PYX_ERR(1, 1645, __pyx_L1_error))
  __pyx_v_z51 = pow(__pyx_v_prst, 6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1646
 *         cdef double z50 = prst**4
 *         cdef double z51 = prst**6
 *         cdef double z52 = prst**8             # <<<<<<<<<<<<<<
 *         cdef double z53 = nu*z52
 *         cdef double z54 = 4.0*z18
 */
  __Pyx_TraceLine(1646,0,__PYX_ERR(1, 1646, __pyx_L1_error))
  __pyx_v_z52 = pow(__pyx_v_prst, 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1647
 *         cdef double z51 = prst**6
 *         cdef double z52 = prst**8
 *         cdef double z53 = nu*z52             # <<<<<<<<<<<<<<
 *         cdef double z54 = 4.0*z18
 *         cdef double z55 = nu*r
 */
  __Pyx_TraceLine(1647,0,__PYX_ERR(1, 1647, __pyx_L1_error))
  __pyx_v_z53 = (__pyx_v_nu * __pyx_v_z52);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1648
 *         cdef double z52 = prst**8
 *         cdef double z53 = nu*z52
 *         cdef double z54 = 4.0*z18             # <<<<<<<<<<<<<<
 *         cdef double z55 = nu*r
 *         cdef double z56 = nu*z0
 */
  __Pyx_TraceLine(1648,0,__PYX_ERR(1, 1648, __pyx_L1_error))
  __pyx_v_z54 = (4.0 * __pyx_v_z18);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1649
 *         cdef double z53 = nu*z52
 *         cdef double z54 = 4.0*z18
 *         cdef double z55 = nu*r             # <<<<<<<<<<<<<<
 *         cdef double z56 = nu*z0
 *         cdef double z57 = r*z18
 */
  __Pyx_TraceLine(1649,0,__PYX_ERR(1, 1649, __pyx_L1_error))
  __pyx_v_z55 = (__pyx_v_nu * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1650
 *         cdef double z54 = 4.0*z18
 *         cdef double z55 = nu*r
 *         cdef double z56 = nu*z0             # <<<<<<<<<<<<<<
 *         cdef double z57 = r*z18
 *         cdef double z58 = 14700.0*nu + 42911.0
 */
  __Pyx_TraceLine(1650,0,__PYX_ERR(1, 1650, __pyx_L1_error))
  __pyx_v_z56 = (__pyx_v_nu * __pyx_v_z0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1651
 *         cdef double z55 = nu*r
 *         cdef double z56 = nu*z0
 *         cdef double z57 = r*z18             # <<<<<<<<<<<<<<
 *         cdef double z58 = 14700.0*nu + 42911.0
 *         cdef double z59 = r*z58
 */
  __Pyx_TraceLine(1651,0,__PYX_ERR(1, 1651, __pyx_L1_error))
  __pyx_v_z57 = (__pyx_v_r * __pyx_v_z18);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1652
 *         cdef double z56 = nu*z0
 *         cdef double z57 = r*z18
 *         cdef double z58 = 14700.0*nu + 42911.0             # <<<<<<<<<<<<<<
 *         cdef double z59 = r*z58
 *         cdef double z60 = z0*z18
 */
  __Pyx_TraceLine(1652,0,__PYX_ERR(1, 1652, __pyx_L1_error))
  __pyx_v_z58 = ((14700.0 * __pyx_v_nu) + 42911.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1653
 *         cdef double z57 = r*z18
 *         cdef double z58 = 14700.0*nu + 42911.0
 *         cdef double z59 = r*z58             # <<<<<<<<<<<<<<
 *         cdef double z60 = z0*z18
 *         cdef double z61 = 283115520.0*z58
 */
  __Pyx_TraceLine(1653,0,__PYX_ERR(1, 1653, __pyx_L1_error))
  __pyx_v_z59 = (__pyx_v_r * __pyx_v_z58);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1654
 *         cdef double z58 = 14700.0*nu + 42911.0
 *         cdef double z59 = r*z58
 *         cdef double z60 = z0*z18             # <<<<<<<<<<<<<<
 *         cdef double z61 = 283115520.0*z58
 *         cdef double z62 = z41*(-25392914995744.3*nu - r*z61 - 879923036160.0*z0 - 5041721180160.0*z18 + 104186110149937.0)
 */
  __Pyx_TraceLine(1654,0,__PYX_ERR(1, 1654, __pyx_L1_error))
  __pyx_v_z60 = (__pyx_v_z0 * __pyx_v_z18);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1655
 *         cdef double z59 = r*z58
 *         cdef double z60 = z0*z18
 *         cdef double z61 = 283115520.0*z58             # <<<<<<<<<<<<<<
 *         cdef double z62 = z41*(-25392914995744.3*nu - r*z61 - 879923036160.0*z0 - 5041721180160.0*z18 + 104186110149937.0)
 *         cdef double z63 = r*z42
 */
  __Pyx_TraceLine(1655,0,__PYX_ERR(1, 1655, __pyx_L1_error))
  __pyx_v_z61 = (283115520.0 * __pyx_v_z58);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1656
 *         cdef double z60 = z0*z18
 *         cdef double z61 = 283115520.0*z58
 *         cdef double z62 = z41*(-25392914995744.3*nu - r*z61 - 879923036160.0*z0 - 5041721180160.0*z18 + 104186110149937.0)             # <<<<<<<<<<<<<<
 *         cdef double z63 = r*z42
 *         cdef double z64 = z0*(-630116198.873299*nu - 197773496.793534*z18 + 5805304367.87913)
 */
  __Pyx_TraceLine(1656,0,__PYX_ERR(1, 1656, __pyx_L1_error))
  __pyx_v_z62 = (__pyx_v_z41 * (((((-25392914995744.3 * __pyx_v_nu) - (__pyx_v_r * __pyx_v_z61)) - (879923036160.0 * __pyx_v_z0)) - (5041721180160.0 * __pyx_v_z18)) + 104186110149937.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1657
 *         cdef double z61 = 283115520.0*z58
 *         cdef double z62 = z41*(-25392914995744.3*nu - r*z61 - 879923036160.0*z0 - 5041721180160.0*z18 + 104186110149937.0)
 *         cdef double z63 = r*z42             # <<<<<<<<<<<<<<
 *         cdef double z64 = z0*(-630116198.873299*nu - 197773496.793534*z18 + 5805304367.87913)
 *         cdef double z65 = z7*(-2675575.66847905*nu - 138240.0*z18 - 5278341.3229329)
 */
  __Pyx_TraceLine(1657,0,__PYX_ERR(1, 1657, __pyx_L1_error))
  __pyx_v_z63 = (__pyx_v_r * __pyx_v_z42);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1658
 *         cdef double z62 = z41*(-25392914995744.3*nu - r*z61 - 879923036160.0*z0 - 5041721180160.0*z18 + 104186110149937.0)
 *         cdef double z63 = r*z42
 *         cdef double z64 = z0*(-630116198.873299*nu - 197773496.793534*z18 + 5805304367.87913)             # <<<<<<<<<<<<<<
 *         cdef double z65 = z7*(-2675575.66847905*nu - 138240.0*z18 - 5278341.3229329)
 *         cdef double z66 = nu*(-2510664218.28128*nu - 42636451.6032331*z18 + 14515200.0*z43 + 1002013764.01019)
 */
  __Pyx_TraceLine(1658,0,__PYX_ERR(1, 1658, __pyx_L1_error))
  __pyx_v_z64 = (__pyx_v_z0 * (((-630116198.873299 * __pyx_v_nu) - (197773496.793534 * __pyx_v_z18)) + 5805304367.87913));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1659
 *         cdef double z63 = r*z42
 *         cdef double z64 = z0*(-630116198.873299*nu - 197773496.793534*z18 + 5805304367.87913)
 *         cdef double z65 = z7*(-2675575.66847905*nu - 138240.0*z18 - 5278341.3229329)             # <<<<<<<<<<<<<<
 *         cdef double z66 = nu*(-2510664218.28128*nu - 42636451.6032331*z18 + 14515200.0*z43 + 1002013764.01019)
 *         cdef double z67 = r*(43393301259014.8*nu + 43133561885859.3*z18 + 5927865218923.02*z43 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0)
 */
  __Pyx_TraceLine(1659,0,__PYX_ERR(1, 1659, __pyx_L1_error))
  __pyx_v_z65 = (__pyx_v_z7 * (((-2675575.66847905 * __pyx_v_nu) - (138240.0 * __pyx_v_z18)) - 5278341.3229329));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1660
 *         cdef double z64 = z0*(-630116198.873299*nu - 197773496.793534*z18 + 5805304367.87913)
 *         cdef double z65 = z7*(-2675575.66847905*nu - 138240.0*z18 - 5278341.3229329)
 *         cdef double z66 = nu*(-2510664218.28128*nu - 42636451.6032331*z18 + 14515200.0*z43 + 1002013764.01019)             # <<<<<<<<<<<<<<
 *         cdef double z67 = r*(43393301259014.8*nu + 43133561885859.3*z18 + 5927865218923.02*z43 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0)
 *         cdef double z68 = z41*(-1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*z18 - 2119671837.36038) + z0*z61 + 879923036160.0*z7)
 */
  __Pyx_TraceLine(1660,0,__PYX_ERR(1, 1660, __pyx_L1_error))
  __pyx_v_z66 = (__pyx_v_nu * ((((-2510664218.28128 * __pyx_v_nu) - (42636451.6032331 * __pyx_v_z18)) + (14515200.0 * __pyx_v_z43)) + 1002013764.01019));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1661
 *         cdef double z65 = z7*(-2675575.66847905*nu - 138240.0*z18 - 5278341.3229329)
 *         cdef double z66 = nu*(-2510664218.28128*nu - 42636451.6032331*z18 + 14515200.0*z43 + 1002013764.01019)
 *         cdef double z67 = r*(43393301259014.8*nu + 43133561885859.3*z18 + 5927865218923.02*z43 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0)             # <<<<<<<<<<<<<<
 *         cdef double z68 = z41*(-1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*z18 - 2119671837.36038) + z0*z61 + 879923036160.0*z7)
 *         cdef double z69 = 0.000130208333333333*z10 + z48
 */
  __Pyx_TraceLine(1661,0,__PYX_ERR(1, 1661, __pyx_L1_error))
  __pyx_v_z67 = (__pyx_v_r * (((((43393301259014.8 * __pyx_v_nu) + (43133561885859.3 * __pyx_v_z18)) + (5927865218923.02 * __pyx_v_z43)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_nu)), 2.0))) + 188440788778196.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1662
 *         cdef double z66 = nu*(-2510664218.28128*nu - 42636451.6032331*z18 + 14515200.0*z43 + 1002013764.01019)
 *         cdef double z67 = r*(43393301259014.8*nu + 43133561885859.3*z18 + 5927865218923.02*z43 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0)
 *         cdef double z68 = z41*(-1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*z18 - 2119671837.36038) + z0*z61 + 879923036160.0*z7)             # <<<<<<<<<<<<<<
 *         cdef double z69 = 0.000130208333333333*z10 + z48
 *         cdef double z70 = -12049908701745.2*nu - 39476764256925.6*r + 5107745331375.71*z0 + 80059249540278.2*z18 + 5787938193408.0*z42 + 6730497718123.02*z43 + 10611661054566.2*z55 + 2589101062873.81*z56 + 1822680546449.21*z57 - 326837426.241486*z59 + 133772083200.0*z60 - z62 + 275059053208689.0
 */
  __Pyx_TraceLine(1662,0,__PYX_ERR(1, 1662, __pyx_L1_error))
  __pyx_v_z68 = (__pyx_v_z41 * (((((-1698693120.0 * __pyx_v_nu) * ((11592.0 * __pyx_v_nu) + 69847.0)) + ((49152.0 * __pyx_v_r) * (((409207698.136075 * __pyx_v_nu) + (102574080.0 * __pyx_v_z18)) - 2119671837.36038))) + (__pyx_v_z0 * __pyx_v_z61)) + (879923036160.0 * __pyx_v_z7)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1663
 *         cdef double z67 = r*(43393301259014.8*nu + 43133561885859.3*z18 + 5927865218923.02*z43 + 86618264430493.3*(1 - 0.496948781616935*nu)**2 + 188440788778196.0)
 *         cdef double z68 = z41*(-1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*z18 - 2119671837.36038) + z0*z61 + 879923036160.0*z7)
 *         cdef double z69 = 0.000130208333333333*z10 + z48             # <<<<<<<<<<<<<<
 *         cdef double z70 = -12049908701745.2*nu - 39476764256925.6*r + 5107745331375.71*z0 + 80059249540278.2*z18 + 5787938193408.0*z42 + 6730497718123.02*z43 + 10611661054566.2*z55 + 2589101062873.81*z56 + 1822680546449.21*z57 - 326837426.241486*z59 + 133772083200.0*z60 - z62 + 275059053208689.0
 *         cdef double z71 = 5787938193408.0*z63 - 9216.0*z64 - 967680.0*z65 + 55296.0*z66 + z67 + z68
 */
  __Pyx_TraceLine(1663,0,__PYX_ERR(1, 1663, __pyx_L1_error))
  __pyx_v_z69 = ((0.000130208333333333 * __pyx_v_z10) + __pyx_v_z48);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1664
 *         cdef double z68 = z41*(-1698693120.0*nu*(11592.0*nu + 69847.0) + 49152.0*r*(409207698.136075*nu + 102574080.0*z18 - 2119671837.36038) + z0*z61 + 879923036160.0*z7)
 *         cdef double z69 = 0.000130208333333333*z10 + z48
 *         cdef double z70 = -12049908701745.2*nu - 39476764256925.6*r + 5107745331375.71*z0 + 80059249540278.2*z18 + 5787938193408.0*z42 + 6730497718123.02*z43 + 10611661054566.2*z55 + 2589101062873.81*z56 + 1822680546449.21*z57 - 326837426.241486*z59 + 133772083200.0*z60 - z62 + 275059053208689.0             # <<<<<<<<<<<<<<
 *         cdef double z71 = 5787938193408.0*z63 - 9216.0*z64 - 967680.0*z65 + 55296.0*z66 + z67 + z68
 * 
 */
  __Pyx_TraceLine(1664,0,__PYX_ERR(1, 1664, __pyx_L1_error))
  __pyx_v_z70 = (((((((((((((-12049908701745.2 * __pyx_v_nu) - (39476764256925.6 * __pyx_v_r)) + (5107745331375.71 * __pyx_v_z0)) + (80059249540278.2 * __pyx_v_z18)) + (5787938193408.0 * __pyx_v_z42)) + (6730497718123.02 * __pyx_v_z43)) + (10611661054566.2 * __pyx_v_z55)) + (2589101062873.81 * __pyx_v_z56)) + (1822680546449.21 * __pyx_v_z57)) - (326837426.241486 * __pyx_v_z59)) + (133772083200.0 * __pyx_v_z60)) - __pyx_v_z62) + 275059053208689.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1665
 *         cdef double z69 = 0.000130208333333333*z10 + z48
 *         cdef double z70 = -12049908701745.2*nu - 39476764256925.6*r + 5107745331375.71*z0 + 80059249540278.2*z18 + 5787938193408.0*z42 + 6730497718123.02*z43 + 10611661054566.2*z55 + 2589101062873.81*z56 + 1822680546449.21*z57 - 326837426.241486*z59 + 133772083200.0*z60 - z62 + 275059053208689.0
 *         cdef double z71 = 5787938193408.0*z63 - 9216.0*z64 - 967680.0*z65 + 55296.0*z66 + z67 + z68             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(1665,0,__PYX_ERR(1, 1665, __pyx_L1_error))
  __pyx_v_z71 = ((((((5787938193408.0 * __pyx_v_z63) - (9216.0 * __pyx_v_z64)) - (967680.0 * __pyx_v_z65)) + (55296.0 * __pyx_v_z66)) + __pyx_v_z67) + __pyx_v_z68);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1670
 *         # Evaluate Hamiltonian
 *         cdef double H,xi
 *         H,xi =  evaluate_H(q,p,chi_1,chi_2,m_1,m_2,M,nu,X_1,X_2,a6,dSO)             # <<<<<<<<<<<<<<
 * 
 *         # Heff Jacobian expressions
 */
  __Pyx_TraceLine(1670,0,__PYX_ERR(1, 1670, __pyx_L1_error))
  __pyx_t_14 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_evaluate_H(__pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, __pyx_v_M, __pyx_v_nu, __pyx_v_X_1, __pyx_v_X_2, __pyx_v_a6, __pyx_v_dSO, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1670, __pyx_L1_error)
  __pyx_t_12 = __pyx_t_14.f0;
  __pyx_t_15 = __pyx_t_14.f1;
  __pyx_v_H = __pyx_t_12;
  __pyx_v_xi = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1674
 *         # Heff Jacobian expressions
 * 
 *         cdef double dHeffdpphi = z49*(z49*(147.443752990146*nu*r**(-4.5)*z50 - 11.3175085791863*nu*r**(-3.5)*z51 + 1.69542100694444e-8*prst**2*z38*z6**2*z71*(z10 + z23*(0.03125*z12*z3*(26.0*nu + 449.0) + 0.015625*z36*(115.0*nu + z54 - 37.0) + z39*(-1171.0*nu - 861.0)) + 7680.0*z37*z47*z70/z71 + z8*(0.125*z14*(-21.0*X_1 + 21.0*X_2) + 0.0625*z36*(12.0*nu - 3.0) + z4*(3.0*nu + 2.8125)))/(z69**2*z70) + 1.48275342024365*r**(-2.5)*z53 + z23*z50*(nu*(452.542166996693 - 51.6952380952381*z41) + z18*(118.4*z41 - 1796.13660498019) + 602.318540416564*z43) + 0.121954868780449*z28*z53 - z29*z34*z35 + z30 + z50*z8*(92.7110442849544*nu - 131.0*z18 + 10.0*z43) + z50*z9*(8.0*nu - 6.0*z18) + z51*z8*(-33.9782122170436*nu - 89.5298327361234*z18 - 14.0*z40 + 188.0*z43) + z51*z9*(-2.78300763695006*nu - 5.4*z18 + 6.0*z43) + z52*z9*(1.38977750996128*nu + 3.33842023648322*z18 - 6.0*z40 + 3.42857142857143*z43) + 1.0 + 1.27277314139085e-19*z50*z6**4*(0.0625*z11*z13*z3*(18.0*nu - 1.0) - 0.46875*z36*(-5.0*nu + z54 + 1.0) - 0.15625*z4*(-33.0*nu + 32.0*z18 - 5.0))*(z63 - 1.59227685093395e-9*z64 - 1.67189069348064e-7*z65 + 9.55366110560367e-9*z66 + 1.72773095804465e-13*z67 + 1.72773095804465e-13*z68)**2/(r**13*z69**4*(-0.0438084424460039*nu - 0.143521050466841*r + 0.0185696317637669*z0 + 0.291062041428379*z18 + 0.0210425293255724*z42 + 0.0244692826489756*z43 + 0.0385795738434214*z55 + 0.00941289164152486*z56 + 0.00662650629087394*z57 - 1.18824456940711e-6*z59 + 0.000486339502879429*z60 - 3.63558293513537e-15*z62 + 1)**2))/(z10*(2.0*z28 + 1.0) + 1.0))**(-0.5)*(-pphi*z33*z35*z5 + 2.0*pphi*z9)/(z10*(4.0*z28 + 2.0) + 2.0) + (nu*dSO*z3*z8 + pphi*z12*(z17*z25 + z20*z26 + z24*z27) + pphi*z3*(z15*z17 + z19*z20 + z21*z24) + 0.0416666666666667*z10*z12 + z12*(z25*z30 + z26*z31 + z27*z32 + z28*(0.34375*nu + 0.09375) + z9*(-0.03125*nu + 0.536458333333333*z18 + 0.078125) + 0.25) + z3*z9*(0.0416666666666667*z13*z14 - 0.25*z4) + z3*(z15*z30 + z19*z31 + z21*z32 + z28*(0.71875*nu - 0.09375) + z9*(-5.53125*nu + 0.567708333333333*z18 - 0.078125) + 1.75))/(r*(-2.0*r + z6) + 2.0*z0 + z5)             # <<<<<<<<<<<<<<
 * 
 *         # Compute H Jacobian
 */
  __Pyx_TraceLine(1674,0,__PYX_ERR(1, 1674, __pyx_L1_error))
  __pyx_t_15 = __Pyx_SoftComplexToDouble(__Pyx_c_sum_double(__Pyx_c_quot_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_z49, 0), __Pyx_c_pow_double(__Pyx_c_quot_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_z49, 0), __Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((147.443752990146 * __pyx_v_nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-4.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_z50, 0)), __Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((11.3175085791863 * __pyx_v_nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-3.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_z51, 0))), __pyx_t_double_complex_from_parts(((((((1.69542100694444e-8 * pow(__pyx_v_prst, 2.0)) * __pyx_v_z38) * pow(__pyx_v_z6, 2.0)) * __pyx_v_z71) * (((__pyx_v_z10 + (__pyx_v_z23 * (((((0.03125 * __pyx_v_z12) * __pyx_v_z3) * ((26.0 * __pyx_v_nu) + 449.0)) + ((0.015625 * __pyx_v_z36) * (((115.0 * __pyx_v_nu) + __pyx_v_z54) - 37.0))) + (__pyx_v_z39 * ((-1171.0 * __pyx_v_nu) - 861.0))))) + ((((7680.0 * __pyx_v_z37) * __pyx_v_z47) * __pyx_v_z70) / __pyx_v_z71)) + (__pyx_v_z8 * ((((0.125 * __pyx_v_z14) * ((-21.0 * __pyx_v_X_1) + (21.0 * __pyx_v_X_2))) + ((0.0625 * __pyx_v_z36) * ((12.0 * __pyx_v_nu) - 3.0))) + (__pyx_v_z4 * ((3.0 * __pyx_v_nu) + 2.8125)))))) / (pow(__pyx_v_z69, 2.0) * __pyx_v_z70)), 0)), __Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts(1.48275342024365, 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-2.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_z53, 0))), __pyx_t_double_complex_from_parts(((__pyx_v_z23 * __pyx_v_z50) * (((__pyx_v_nu * (452.542166996693 - (51.6952380952381 * __pyx_v_z41))) + (__pyx_v_z18 * ((118.4 * __pyx_v_z41) - 1796.13660498019))) + (602.318540416564 * __pyx_v_z43))), 0)), __pyx_t_double_complex_from_parts(((0.121954868780449 * __pyx_v_z28) * __pyx_v_z53), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z29 * __pyx_v_z34) * __pyx_v_z35), 0)), __pyx_t_double_complex_from_parts(__pyx_v_z30, 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z50 * __pyx_v_z8) * (((92.7110442849544 * __pyx_v_nu) - (131.0 * __pyx_v_z18)) + (10.0 * __pyx_v_z43))), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z50 * __pyx_v_z9) * ((8.0 * __pyx_v_nu) - (6.0 * __pyx_v_z18))), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z51 * __pyx_v_z8) * ((((-33.9782122170436 * __pyx_v_nu) - (89.5298327361234 * __pyx_v_z18)) - (14.0 * __pyx_v_z40)) + (188.0 * __pyx_v_z43))), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z51 * __pyx_v_z9) * (((-2.78300763695006 * __pyx_v_nu) - (5.4 * __pyx_v_z18)) + (6.0 * __pyx_v_z43))), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z52 * __pyx_v_z9) * ((((1.38977750996128 * __pyx_v_nu) + (3.33842023648322 * __pyx_v_z18)) - (6.0 * __pyx_v_z40)) + (3.42857142857143 * __pyx_v_z43))), 0)), __pyx_t_double_complex_from_parts(1.0, 0)), __pyx_t_double_complex_from_parts((((((1.27277314139085e-19 * __pyx_v_z50) * pow(__pyx_v_z6, 4.0)) * ((((((0.0625 * __pyx_v_z11) * __pyx_v_z13) * __pyx_v_z3) * ((18.0 * __pyx_v_nu) - 1.0)) - ((0.46875 * __pyx_v_z36) * (((-5.0 * __pyx_v_nu) + __pyx_v_z54) + 1.0))) - ((0.15625 * __pyx_v_z4) * (((-33.0 * __pyx_v_nu) + (32.0 * __pyx_v_z18)) - 5.0)))) * pow((((((__pyx_v_z63 - (1.59227685093395e-9 * __pyx_v_z64)) - (1.67189069348064e-7 * __pyx_v_z65)) + (9.55366110560367e-9 * __pyx_v_z66)) + (1.72773095804465e-13 * __pyx_v_z67)) + (1.72773095804465e-13 * __pyx_v_z68)), 2.0)) / ((pow(__pyx_v_r, 13.0) * pow(__pyx_v_z69, 4.0)) * pow((((((((((((((-0.0438084424460039 * __pyx_v_nu) - (0.143521050466841 * __pyx_v_r)) + (0.0185696317637669 * __pyx_v_z0)) + (0.291062041428379 * __pyx_v_z18)) + (0.0210425293255724 * __pyx_v_z42)) + (0.0244692826489756 * __pyx_v_z43)) + (0.0385795738434214 * __pyx_v_z55)) + (0.00941289164152486 * __pyx_v_z56)) + (0.00662650629087394 * __pyx_v_z57)) - (1.18824456940711e-6 * __pyx_v_z59)) + (0.000486339502879429 * __pyx_v_z60)) - (3.63558293513537e-15 * __pyx_v_z62)) + 1.0), 2.0))), 0))), __pyx_t_double_complex_from_parts(((__pyx_v_z10 * ((2.0 * __pyx_v_z28) + 1.0)) + 1.0), 0)), __pyx_t_double_complex_from_parts(-0.5, 0))), __pyx_t_double_complex_from_parts((((((-__pyx_v_pphi) * __pyx_v_z33) * __pyx_v_z35) * __pyx_v_z5) + ((2.0 * __pyx_v_pphi) * __pyx_v_z9)), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_z10 * ((4.0 * __pyx_v_z28) + 2.0)) + 2.0), 0)), __pyx_t_double_complex_from_parts(((((((((((__pyx_v_nu * __pyx_v_dSO) * __pyx_v_z3) * __pyx_v_z8) + ((__pyx_v_pphi * __pyx_v_z12) * (((__pyx_v_z17 * __pyx_v_z25) + (__pyx_v_z20 * __pyx_v_z26)) + (__pyx_v_z24 * __pyx_v_z27)))) + ((__pyx_v_pphi * __pyx_v_z3) * (((__pyx_v_z15 * __pyx_v_z17) + (__pyx_v_z19 * __pyx_v_z20)) + (__pyx_v_z21 * __pyx_v_z24)))) + ((0.0416666666666667 * __pyx_v_z10) * __pyx_v_z12)) + (__pyx_v_z12 * ((((((__pyx_v_z25 * __pyx_v_z30) + (__pyx_v_z26 * __pyx_v_z31)) + (__pyx_v_z27 * __pyx_v_z32)) + (__pyx_v_z28 * ((0.34375 * __pyx_v_nu) + 0.09375))) + (__pyx_v_z9 * (((-0.03125 * __pyx_v_nu) + (0.536458333333333 * __pyx_v_z18)) + 0.078125))) + 0.25))) + ((__pyx_v_z3 * __pyx_v_z9) * (((0.0416666666666667 * __pyx_v_z13) * __pyx_v_z14) - (0.25 * __pyx_v_z4)))) + (__pyx_v_z3 * ((((((__pyx_v_z15 * __pyx_v_z30) + (__pyx_v_z19 * __pyx_v_z31)) + (__pyx_v_z21 * __pyx_v_z32)) + (__pyx_v_z28 * ((0.71875 * __pyx_v_nu) - 0.09375))) + (__pyx_v_z9 * (((-5.53125 * __pyx_v_nu) + (0.567708333333333 * __pyx_v_z18)) - 0.078125))) + 1.75))) / (((__pyx_v_r * ((-2.0 * __pyx_v_r) + __pyx_v_z6)) + (2.0 * __pyx_v_z0)) + __pyx_v_z5)), 0)), 1); if (unlikely(__pyx_t_15 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1674, __pyx_L1_error)
  __pyx_v_dHeffdpphi = __pyx_t_15;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1678
 *         # Compute H Jacobian
 * 
 *         cdef double omega = M * M * dHeffdpphi / (nu*H)             # <<<<<<<<<<<<<<
 * 
 *         return omega
 */
  __Pyx_TraceLine(1678,0,__PYX_ERR(1, 1678, __pyx_L1_error))
  __pyx_v_omega = (((__pyx_v_M * __pyx_v_M) * __pyx_v_dHeffdpphi) / (__pyx_v_nu * __pyx_v_H));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1680
 *         cdef double omega = M * M * dHeffdpphi / (nu*H)
 * 
 *         return omega             # <<<<<<<<<<<<<<
 * 
 *     cpdef auxderivs(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):
 */
  __Pyx_TraceLine(1680,0,__PYX_ERR(1, 1680, __pyx_L1_error))
  __pyx_r = __pyx_v_omega;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1557
 *         #return dHdr, dHdphi, dHdpr, dHdpphi,H,xi
 * 
 *     cpdef double omega(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.omega", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_12omega, "\n        Compute the orbital frequency from the Hamiltonian.\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n\n        Returns:\n           (double) dHdpphi\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega = {"omega", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_12omega};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("omega (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("omega", 1, 6, 6, 1); __PYX_ERR(1, 1557, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("omega", 1, 6, 6, 2); __PYX_ERR(1, 1557, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("omega", 1, 6, 6, 3); __PYX_ERR(1, 1557, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("omega", 1, 6, 6, 4); __PYX_ERR(1, 1557, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("omega", 1, 6, 6, 5); __PYX_ERR(1, 1557, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "omega") < 0)) __PYX_ERR(1, 1557, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 1557, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 1557, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("omega", 1, 6, 6, __pyx_nargs); __PYX_ERR(1, 1557, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.omega", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_12omega(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_12omega(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__17)
  __Pyx_RefNannySetupContext("omega", 0);
  __Pyx_TraceCall("omega (wrapper)", __pyx_f[1], 1557, 0, __PYX_ERR(1, 1557, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 1557, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 1557, __pyx_L1_error) }
  __pyx_t_1 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_omega(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1557, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.omega", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1682
 *         return omega
 * 
 *     cpdef auxderivs(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_auxderivs(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2, int __pyx_skip_dispatch) {
  double __pyx_v_r;
  CYTHON_UNUSED double __pyx_v_phi;
  double __pyx_v_prst;
  double __pyx_v_L;
  CYTHON_UNUSED double __pyx_v_pphi;
  double __pyx_v_Chi1;
  double __pyx_v_Chi2;
  double __pyx_v_Nu;
  double __pyx_v_M;
  double __pyx_v_X1;
  double __pyx_v_X2;
  struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *__pyx_v_c_coeffs = 0;
  double __pyx_v_a6;
  double __pyx_v_dSO;
  double __pyx_v_x0;
  double __pyx_v_x1;
  double __pyx_v_x2;
  double __pyx_v_x3;
  double __pyx_v_x4;
  double __pyx_v_x5;
  double __pyx_v_x6;
  double __pyx_v_x7;
  double __pyx_v_x8;
  double __pyx_v_x9;
  double __pyx_v_x10;
  double __pyx_v_x11;
  double __pyx_v_x12;
  double __pyx_v_x13;
  double __pyx_v_x14;
  double __pyx_v_x15;
  double __pyx_v_x16;
  double __pyx_v_x17;
  double __pyx_v_x18;
  double __pyx_v_x19;
  double __pyx_v_x20;
  double __pyx_v_x21;
  double __pyx_v_x22;
  double __pyx_v_x23;
  double __pyx_v_x24;
  double __pyx_v_x25;
  double __pyx_v_x26;
  double __pyx_v_x27;
  double __pyx_v_x28;
  double __pyx_v_x29;
  double __pyx_v_x30;
  double __pyx_v_x31;
  double __pyx_v_x32;
  double __pyx_v_x33;
  double __pyx_v_x34;
  double __pyx_v_x35;
  double __pyx_v_x36;
  double __pyx_v_x37;
  double __pyx_v_x38;
  double __pyx_v_x39;
  double __pyx_v_x40;
  double __pyx_v_x41;
  double __pyx_v_x42;
  double __pyx_v_x43;
  double __pyx_v_x44;
  double __pyx_v_x45;
  double __pyx_v_x46;
  double __pyx_v_x47;
  double __pyx_v_x48;
  double __pyx_v_x49;
  double __pyx_v_x50;
  double __pyx_v_x51;
  double __pyx_v_x52;
  double __pyx_v_x53;
  double __pyx_v_x54;
  double __pyx_v_x55;
  double __pyx_v_x56;
  double __pyx_v_x57;
  double __pyx_v_x58;
  double __pyx_v_x59;
  double __pyx_v_x60;
  double __pyx_v_x61;
  double __pyx_v_x62;
  double __pyx_v_x63;
  double __pyx_v_x64;
  double __pyx_v_x65;
  double __pyx_v_x66;
  double __pyx_v_x67;
  double __pyx_v_x68;
  double __pyx_v_x69;
  double __pyx_v_x70;
  double __pyx_v_x71;
  double __pyx_v_x72;
  double __pyx_v_x73;
  double __pyx_v_x74;
  double __pyx_v_x75;
  double __pyx_v_x76;
  double __pyx_v_x77;
  double __pyx_v_x78;
  double __pyx_v_x79;
  double __pyx_v_x80;
  double __pyx_v_x81;
  double __pyx_v_x82;
  double __pyx_v_x83;
  double __pyx_v_x84;
  double __pyx_v_x85;
  double __pyx_v_x86;
  double __pyx_v_x87;
  double __pyx_v_x88;
  double __pyx_v_x89;
  double __pyx_v_x90;
  double __pyx_v_x91;
  double __pyx_v_x92;
  double __pyx_v_x93;
  double __pyx_v_x94;
  double __pyx_v_x95;
  double __pyx_v_x96;
  double __pyx_v_x97;
  double __pyx_v_x98;
  double __pyx_v_x99;
  double __pyx_v_x100;
  double __pyx_v_x101;
  double __pyx_v_x102;
  double __pyx_v_x103;
  double __pyx_v_x104;
  double __pyx_v_x105;
  double __pyx_v_x106;
  double __pyx_v_x107;
  double __pyx_v_x108;
  double __pyx_v_x109;
  double __pyx_v_x110;
  double __pyx_v_x111;
  double __pyx_v_x112;
  double __pyx_v_x113;
  double __pyx_v_x114;
  double __pyx_v_x115;
  double __pyx_v_x116;
  double __pyx_v_x117;
  double __pyx_v_x118;
  double __pyx_v_x119;
  double __pyx_v_x120;
  double __pyx_v_x121;
  double __pyx_v_x122;
  double __pyx_v_x123;
  double __pyx_v_x124;
  double __pyx_v_x125;
  double __pyx_v_x126;
  double __pyx_v_x127;
  double __pyx_v_x128;
  double __pyx_v_x129;
  double __pyx_v_x130;
  double __pyx_v_x131;
  double __pyx_v_x132;
  double __pyx_v_x133;
  double __pyx_v_x134;
  double __pyx_v_x135;
  double __pyx_v_x136;
  double __pyx_v_x137;
  double __pyx_v_x138;
  double __pyx_v_x139;
  double __pyx_v_x140;
  double __pyx_v_x141;
  double __pyx_v_x142;
  double __pyx_v_x143;
  double __pyx_v_x144;
  double __pyx_v_x145;
  double __pyx_v_x146;
  double __pyx_v_x147;
  double __pyx_v_x148;
  double __pyx_v_x149;
  double __pyx_v_x150;
  double __pyx_v_x151;
  double __pyx_v_dxidr;
  double __pyx_v_dHodddr;
  double __pyx_v_dQdprst;
  double __pyx_v_dQdr;
  double __pyx_v_dBnpadr;
  double __pyx_v_dBnpdr;
  double __pyx_v_dAdr;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  double __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__18)
  __Pyx_RefNannySetupContext("auxderivs", 0);
  __Pyx_TraceCall("auxderivs", __pyx_f[1], 1682, 0, __PYX_ERR(1, 1682, __pyx_L1_error));
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_auxderivs); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #ifdef __Pyx_CyFunction_USED
      if (!__Pyx_IsCyOrPyCFunction(__pyx_t_1)
      #else
      if (!PyCFunction_Check(__pyx_t_1)
      #endif
              || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs)) {
        __Pyx_XDECREF(__pyx_r);
        if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 1682, __pyx_L1_error) }
        __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_q, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 1682, __pyx_L1_error) }
        __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_p, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyFloat_FromDouble(__pyx_v_chi_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyFloat_FromDouble(__pyx_v_chi_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyFloat_FromDouble(__pyx_v_m_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_m_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = __pyx_t_1; __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_11 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[7] = {__pyx_t_10, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 6+__pyx_t_11);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1682, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1702
 *         # Coordinate definitions
 * 
 *         cdef double r = q[0]             # <<<<<<<<<<<<<<
 *         cdef double phi = q[1]
 * 
 */
  __Pyx_TraceLine(1702,0,__PYX_ERR(1, 1702, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_r = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1703
 * 
 *         cdef double r = q[0]
 *         cdef double phi = q[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double prst = p[0]
 */
  __Pyx_TraceLine(1703,0,__PYX_ERR(1, 1703, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_phi = (*((double *) ( /* dim=0 */ (__pyx_v_q.data + __pyx_t_12 * __pyx_v_q.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1705
 *         cdef double phi = q[1]
 * 
 *         cdef double prst = p[0]             # <<<<<<<<<<<<<<
 *         cdef double L = p[1]
 * 
 */
  __Pyx_TraceLine(1705,0,__PYX_ERR(1, 1705, __pyx_L1_error))
  __pyx_t_12 = 0;
  __pyx_v_prst = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1706
 * 
 *         cdef double prst = p[0]
 *         cdef double L = p[1]             # <<<<<<<<<<<<<<
 * 
 *         cdef double pphi = L
 */
  __Pyx_TraceLine(1706,0,__PYX_ERR(1, 1706, __pyx_L1_error))
  __pyx_t_12 = 1;
  __pyx_v_L = (*((double *) ( /* dim=0 */ (__pyx_v_p.data + __pyx_t_12 * __pyx_v_p.strides[0]) )));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1708
 *         cdef double L = p[1]
 * 
 *         cdef double pphi = L             # <<<<<<<<<<<<<<
 *         cdef double Chi1 = chi_1
 *         cdef double Chi2 = chi_2
 */
  __Pyx_TraceLine(1708,0,__PYX_ERR(1, 1708, __pyx_L1_error))
  __pyx_v_pphi = __pyx_v_L;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1709
 * 
 *         cdef double pphi = L
 *         cdef double Chi1 = chi_1             # <<<<<<<<<<<<<<
 *         cdef double Chi2 = chi_2
 *         cdef double Nu = m_1*m_2
 */
  __Pyx_TraceLine(1709,0,__PYX_ERR(1, 1709, __pyx_L1_error))
  __pyx_v_Chi1 = __pyx_v_chi_1;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1710
 *         cdef double pphi = L
 *         cdef double Chi1 = chi_1
 *         cdef double Chi2 = chi_2             # <<<<<<<<<<<<<<
 *         cdef double Nu = m_1*m_2
 *         cdef double M = m_1+m_2
 */
  __Pyx_TraceLine(1710,0,__PYX_ERR(1, 1710, __pyx_L1_error))
  __pyx_v_Chi2 = __pyx_v_chi_2;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1711
 *         cdef double Chi1 = chi_1
 *         cdef double Chi2 = chi_2
 *         cdef double Nu = m_1*m_2             # <<<<<<<<<<<<<<
 *         cdef double M = m_1+m_2
 *         cdef double X1 = m_1/M
 */
  __Pyx_TraceLine(1711,0,__PYX_ERR(1, 1711, __pyx_L1_error))
  __pyx_v_Nu = (__pyx_v_m_1 * __pyx_v_m_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1712
 *         cdef double Chi2 = chi_2
 *         cdef double Nu = m_1*m_2
 *         cdef double M = m_1+m_2             # <<<<<<<<<<<<<<
 *         cdef double X1 = m_1/M
 *         cdef double X2 = m_2/M
 */
  __Pyx_TraceLine(1712,0,__PYX_ERR(1, 1712, __pyx_L1_error))
  __pyx_v_M = (__pyx_v_m_1 + __pyx_v_m_2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1713
 *         cdef double Nu = m_1*m_2
 *         cdef double M = m_1+m_2
 *         cdef double X1 = m_1/M             # <<<<<<<<<<<<<<
 *         cdef double X2 = m_2/M
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 */
  __Pyx_TraceLine(1713,0,__PYX_ERR(1, 1713, __pyx_L1_error))
  __pyx_v_X1 = (__pyx_v_m_1 / __pyx_v_M);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1714
 *         cdef double M = m_1+m_2
 *         cdef double X1 = m_1/M
 *         cdef double X2 = m_2/M             # <<<<<<<<<<<<<<
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 */
  __Pyx_TraceLine(1714,0,__PYX_ERR(1, 1714, __pyx_L1_error))
  __pyx_v_X2 = (__pyx_v_m_2 / __pyx_v_M);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1715
 *         cdef double X1 = m_1/M
 *         cdef double X2 = m_2/M
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs             # <<<<<<<<<<<<<<
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']
 */
  __Pyx_TraceLine(1715,0,__PYX_ERR(1, 1715, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_c_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1716
 *         cdef double X2 = m_2/M
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']             # <<<<<<<<<<<<<<
 *         cdef double dSO = c_coeffs['dSO']
 * 
 */
  __Pyx_TraceLine(1716,0,__PYX_ERR(1, 1716, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_a6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1716, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_a6 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1717
 *         cdef CalibCoeffs c_coeffs = self.calibration_coeffs
 *         cdef double a6 = c_coeffs['a6']
 *         cdef double dSO = c_coeffs['dSO']             # <<<<<<<<<<<<<<
 * 
 *         cdef double x0 =r**2
 */
  __Pyx_TraceLine(1717,0,__PYX_ERR(1, 1717, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_c_coeffs), __pyx_n_u_dSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_dSO = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1719
 *         cdef double dSO = c_coeffs['dSO']
 * 
 *         cdef double x0 =r**2             # <<<<<<<<<<<<<<
 *         cdef double  x1=1/x0
 *         cdef double  x2=Chi1*X1
 */
  __Pyx_TraceLine(1719,0,__PYX_ERR(1, 1719, __pyx_L1_error))
  __pyx_v_x0 = pow(__pyx_v_r, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1720
 * 
 *         cdef double x0 =r**2
 *         cdef double  x1=1/x0             # <<<<<<<<<<<<<<
 *         cdef double  x2=Chi1*X1
 *         cdef double  x3=Chi2*X2
 */
  __Pyx_TraceLine(1720,0,__PYX_ERR(1, 1720, __pyx_L1_error))
  __pyx_v_x1 = (1.0 / __pyx_v_x0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1721
 *         cdef double x0 =r**2
 *         cdef double  x1=1/x0
 *         cdef double  x2=Chi1*X1             # <<<<<<<<<<<<<<
 *         cdef double  x3=Chi2*X2
 *         cdef double  x4=x2 + x3
 */
  __Pyx_TraceLine(1721,0,__PYX_ERR(1, 1721, __pyx_L1_error))
  __pyx_v_x2 = (__pyx_v_Chi1 * __pyx_v_X1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1722
 *         cdef double  x1=1/x0
 *         cdef double  x2=Chi1*X1
 *         cdef double  x3=Chi2*X2             # <<<<<<<<<<<<<<
 *         cdef double  x4=x2 + x3
 *         cdef double  x5=x4**2
 */
  __Pyx_TraceLine(1722,0,__PYX_ERR(1, 1722, __pyx_L1_error))
  __pyx_v_x3 = (__pyx_v_Chi2 * __pyx_v_X2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1723
 *         cdef double  x2=Chi1*X1
 *         cdef double  x3=Chi2*X2
 *         cdef double  x4=x2 + x3             # <<<<<<<<<<<<<<
 *         cdef double  x5=x4**2
 *         cdef double  x6=x1*x5
 */
  __Pyx_TraceLine(1723,0,__PYX_ERR(1, 1723, __pyx_L1_error))
  __pyx_v_x4 = (__pyx_v_x2 + __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1724
 *         cdef double  x3=Chi2*X2
 *         cdef double  x4=x2 + x3
 *         cdef double  x5=x4**2             # <<<<<<<<<<<<<<
 *         cdef double  x6=x1*x5
 *         cdef double x7 =Nu**2
 */
  __Pyx_TraceLine(1724,0,__PYX_ERR(1, 1724, __pyx_L1_error))
  __pyx_v_x5 = pow(__pyx_v_x4, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1725
 *         cdef double  x4=x2 + x3
 *         cdef double  x5=x4**2
 *         cdef double  x6=x1*x5             # <<<<<<<<<<<<<<
 *         cdef double x7 =Nu**2
 *         cdef double x8 =log(r)
 */
  __Pyx_TraceLine(1725,0,__PYX_ERR(1, 1725, __pyx_L1_error))
  __pyx_v_x6 = (__pyx_v_x1 * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1726
 *         cdef double  x5=x4**2
 *         cdef double  x6=x1*x5
 *         cdef double x7 =Nu**2             # <<<<<<<<<<<<<<
 *         cdef double x8 =log(r)
 *         cdef double x9 =756.0*Nu
 */
  __Pyx_TraceLine(1726,0,__PYX_ERR(1, 1726, __pyx_L1_error))
  __pyx_v_x7 = pow(__pyx_v_Nu, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1727
 *         cdef double  x6=x1*x5
 *         cdef double x7 =Nu**2
 *         cdef double x8 =log(r)             # <<<<<<<<<<<<<<
 *         cdef double x9 =756.0*Nu
 *         cdef double x10 =336.0*r + x9 + 407.0
 */
  __Pyx_TraceLine(1727,0,__PYX_ERR(1, 1727, __pyx_L1_error))
  __pyx_v_x8 = log(__pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1728
 *         cdef double x7 =Nu**2
 *         cdef double x8 =log(r)
 *         cdef double x9 =756.0*Nu             # <<<<<<<<<<<<<<
 *         cdef double x10 =336.0*r + x9 + 407.0
 *         cdef double x11 =2048.0*Nu*x10*x8 + 28.0*Nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*Nu - 185763.092693281*x7 - 245760.0) - 5416406.59541186*x7 - 3440640.0
 */
  __Pyx_TraceLine(1728,0,__PYX_ERR(1, 1728, __pyx_L1_error))
  __pyx_v_x9 = (756.0 * __pyx_v_Nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1729
 *         cdef double x8 =log(r)
 *         cdef double x9 =756.0*Nu
 *         cdef double x10 =336.0*r + x9 + 407.0             # <<<<<<<<<<<<<<
 *         cdef double x11 =2048.0*Nu*x10*x8 + 28.0*Nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*Nu - 185763.092693281*x7 - 245760.0) - 5416406.59541186*x7 - 3440640.0
 *         cdef double x12 =r**4
 */
  __Pyx_TraceLine(1729,0,__PYX_ERR(1, 1729, __pyx_L1_error))
  __pyx_v_x10 = (((336.0 * __pyx_v_r) + __pyx_v_x9) + 407.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1730
 *         cdef double x9 =756.0*Nu
 *         cdef double x10 =336.0*r + x9 + 407.0
 *         cdef double x11 =2048.0*Nu*x10*x8 + 28.0*Nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*Nu - 185763.092693281*x7 - 245760.0) - 5416406.59541186*x7 - 3440640.0             # <<<<<<<<<<<<<<
 *         cdef double x12 =r**4
 *         cdef double x13 =Nu**4
 */
  __Pyx_TraceLine(1730,0,__PYX_ERR(1, 1730, __pyx_L1_error))
  __pyx_v_x11 = (((((((2048.0 * __pyx_v_Nu) * __pyx_v_x10) * __pyx_v_x8) + ((28.0 * __pyx_v_Nu) * ((1920.0 * __pyx_v_a6) + 733955.307463037))) - ((7.0 * __pyx_v_r) * (((938918.400156317 * __pyx_v_Nu) - (185763.092693281 * __pyx_v_x7)) - 245760.0))) - (5416406.59541186 * __pyx_v_x7)) - 3440640.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1731
 *         cdef double x10 =336.0*r + x9 + 407.0
 *         cdef double x11 =2048.0*Nu*x10*x8 + 28.0*Nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*Nu - 185763.092693281*x7 - 245760.0) - 5416406.59541186*x7 - 3440640.0
 *         cdef double x12 =r**4             # <<<<<<<<<<<<<<
 *         cdef double x13 =Nu**4
 *         cdef double x14 =r**5
 */
  __Pyx_TraceLine(1731,0,__PYX_ERR(1, 1731, __pyx_L1_error))
  __pyx_v_x12 = pow(__pyx_v_r, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1732
 *         cdef double x11 =2048.0*Nu*x10*x8 + 28.0*Nu*(1920.0*a6 + 733955.307463037) - 7.0*r*(938918.400156317*Nu - 185763.092693281*x7 - 245760.0) - 5416406.59541186*x7 - 3440640.0
 *         cdef double x12 =r**4
 *         cdef double x13 =Nu**4             # <<<<<<<<<<<<<<
 *         cdef double x14 =r**5
 *         cdef double x15 =x8**2
 */
  __Pyx_TraceLine(1732,0,__PYX_ERR(1, 1732, __pyx_L1_error))
  __pyx_v_x13 = pow(__pyx_v_Nu, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1733
 *         cdef double x12 =r**4
 *         cdef double x13 =Nu**4
 *         cdef double x14 =r**5             # <<<<<<<<<<<<<<
 *         cdef double x15 =x8**2
 *         cdef double x16 =x15*x7
 */
  __Pyx_TraceLine(1733,0,__PYX_ERR(1, 1733, __pyx_L1_error))
  __pyx_v_x14 = pow(__pyx_v_r, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1734
 *         cdef double x13 =Nu**4
 *         cdef double x14 =r**5
 *         cdef double x15 =x8**2             # <<<<<<<<<<<<<<
 *         cdef double x16 =x15*x7
 *         cdef double x17 =Nu**3
 */
  __Pyx_TraceLine(1734,0,__PYX_ERR(1, 1734, __pyx_L1_error))
  __pyx_v_x15 = pow(__pyx_v_x8, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1735
 *         cdef double x14 =r**5
 *         cdef double x15 =x8**2
 *         cdef double x16 =x15*x7             # <<<<<<<<<<<<<<
 *         cdef double x17 =Nu**3
 *         cdef double x18 =x17*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 */
  __Pyx_TraceLine(1735,0,__PYX_ERR(1, 1735, __pyx_L1_error))
  __pyx_v_x16 = (__pyx_v_x15 * __pyx_v_x7);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1736
 *         cdef double x15 =x8**2
 *         cdef double x16 =x15*x7
 *         cdef double x17 =Nu**3             # <<<<<<<<<<<<<<
 *         cdef double x18 =x17*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x19 =r**3
 */
  __Pyx_TraceLine(1736,0,__PYX_ERR(1, 1736, __pyx_L1_error))
  __pyx_v_x17 = pow(__pyx_v_Nu, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1737
 *         cdef double x16 =x15*x7
 *         cdef double x17 =Nu**3
 *         cdef double x18 =x17*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)             # <<<<<<<<<<<<<<
 *         cdef double x19 =r**3
 *         cdef double x20 =x7*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x12 + 1426660551.8844*x14 - 6178501407.53758*x19 + 276057889687.011)
 */
  __Pyx_TraceLine(1737,0,__PYX_ERR(1, 1737, __pyx_L1_error))
  __pyx_v_x18 = (__pyx_v_x17 * (((-163683964.822551 * __pyx_v_r) - (17833256.898555 * __pyx_v_x0)) - 1188987459.03162));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1738
 *         cdef double x17 =Nu**3
 *         cdef double x18 =x17*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x19 =r**3             # <<<<<<<<<<<<<<
 *         cdef double x20 =x7*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x12 + 1426660551.8844*x14 - 6178501407.53758*x19 + 276057889687.011)
 *         cdef double x21 =588.0*Nu + 1079.0
 */
  __Pyx_TraceLine(1738,0,__PYX_ERR(1, 1738, __pyx_L1_error))
  __pyx_v_x19 = pow(__pyx_v_r, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1739
 *         cdef double x18 =x17*(-163683964.822551*r - 17833256.898555*x0 - 1188987459.03162)
 *         cdef double x19 =r**3
 *         cdef double x20 =x7*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x12 + 1426660551.8844*x14 - 6178501407.53758*x19 + 276057889687.011)             # <<<<<<<<<<<<<<
 *         cdef double x21 =588.0*Nu + 1079.0
 *         cdef double x22 =x9 + 1079.0
 */
  __Pyx_TraceLine(1739,0,__PYX_ERR(1, 1739, __pyx_L1_error))
  __pyx_v_x20 = (__pyx_v_x7 * (((((((((-39321600.0 * __pyx_v_a6) * ((3.0 * __pyx_v_r) + 59.0)) + (745857848.115604 * __pyx_v_a6)) + (122635399361.987 * __pyx_v_r)) + (2064783811.32587 * __pyx_v_x0)) - (3089250703.76879 * __pyx_v_x12)) + (1426660551.8844 * __pyx_v_x14)) - (6178501407.53758 * __pyx_v_x19)) + 276057889687.011));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1740
 *         cdef double x19 =r**3
 *         cdef double x20 =x7*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x12 + 1426660551.8844*x14 - 6178501407.53758*x19 + 276057889687.011)
 *         cdef double x21 =588.0*Nu + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x22 =x9 + 1079.0
 *         cdef double x23 =x19*x22
 */
  __Pyx_TraceLine(1740,0,__PYX_ERR(1, 1740, __pyx_L1_error))
  __pyx_v_x21 = ((588.0 * __pyx_v_Nu) + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1741
 *         cdef double x20 =x7*(-39321600.0*a6*(3.0*r + 59.0) + 745857848.115604*a6 + 122635399361.987*r + 2064783811.32587*x0 - 3089250703.76879*x12 + 1426660551.8844*x14 - 6178501407.53758*x19 + 276057889687.011)
 *         cdef double x21 =588.0*Nu + 1079.0
 *         cdef double x22 =x9 + 1079.0             # <<<<<<<<<<<<<<
 *         cdef double x23 =x19*x22
 *         cdef double x24 =-38842241.4769507*Nu + 240.0*r*(-7466.27061066206*Nu - 3024.0*x7 + 17264.0) + 1920.0*x0*x21 + 480.0*x12*x22 + 161280.0*x14 + 960.0*x23 - 1882456.23663972*x7 + 13447680.0
 */
  __Pyx_TraceLine(1741,0,__PYX_ERR(1, 1741, __pyx_L1_error))
  __pyx_v_x22 = (__pyx_v_x9 + 1079.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1742
 *         cdef double x21 =588.0*Nu + 1079.0
 *         cdef double x22 =x9 + 1079.0
 *         cdef double x23 =x19*x22             # <<<<<<<<<<<<<<
 *         cdef double x24 =-38842241.4769507*Nu + 240.0*r*(-7466.27061066206*Nu - 3024.0*x7 + 17264.0) + 1920.0*x0*x21 + 480.0*x12*x22 + 161280.0*x14 + 960.0*x23 - 1882456.23663972*x7 + 13447680.0
 *         cdef double x25 =Nu*x8
 */
  __Pyx_TraceLine(1742,0,__PYX_ERR(1, 1742, __pyx_L1_error))
  __pyx_v_x23 = (__pyx_v_x19 * __pyx_v_x22);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1743
 *         cdef double x22 =x9 + 1079.0
 *         cdef double x23 =x19*x22
 *         cdef double x24 =-38842241.4769507*Nu + 240.0*r*(-7466.27061066206*Nu - 3024.0*x7 + 17264.0) + 1920.0*x0*x21 + 480.0*x12*x22 + 161280.0*x14 + 960.0*x23 - 1882456.23663972*x7 + 13447680.0             # <<<<<<<<<<<<<<
 *         cdef double x25 =Nu*x8
 *         cdef double x26 =x24*x25
 */
  __Pyx_TraceLine(1743,0,__PYX_ERR(1, 1743, __pyx_L1_error))
  __pyx_v_x24 = ((((((((-38842241.4769507 * __pyx_v_Nu) + ((240.0 * __pyx_v_r) * (((-7466.27061066206 * __pyx_v_Nu) - (3024.0 * __pyx_v_x7)) + 17264.0))) + ((1920.0 * __pyx_v_x0) * __pyx_v_x21)) + ((480.0 * __pyx_v_x12) * __pyx_v_x22)) + (161280.0 * __pyx_v_x14)) + (960.0 * __pyx_v_x23)) - (1882456.23663972 * __pyx_v_x7)) + 13447680.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1744
 *         cdef double x23 =x19*x22
 *         cdef double x24 =-38842241.4769507*Nu + 240.0*r*(-7466.27061066206*Nu - 3024.0*x7 + 17264.0) + 1920.0*x0*x21 + 480.0*x12*x22 + 161280.0*x14 + 960.0*x23 - 1882456.23663972*x7 + 13447680.0
 *         cdef double x25 =Nu*x8             # <<<<<<<<<<<<<<
 *         cdef double x26 =x24*x25
 *         cdef double x27 =8.0*r
 */
  __Pyx_TraceLine(1744,0,__PYX_ERR(1, 1744, __pyx_L1_error))
  __pyx_v_x25 = (__pyx_v_Nu * __pyx_v_x8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1745
 *         cdef double x24 =-38842241.4769507*Nu + 240.0*r*(-7466.27061066206*Nu - 3024.0*x7 + 17264.0) + 1920.0*x0*x21 + 480.0*x12*x22 + 161280.0*x14 + 960.0*x23 - 1882456.23663972*x7 + 13447680.0
 *         cdef double x25 =Nu*x8
 *         cdef double x26 =x24*x25             # <<<<<<<<<<<<<<
 *         cdef double x27 =8.0*r
 *         cdef double x28 =2.0*x19
 */
  __Pyx_TraceLine(1745,0,__PYX_ERR(1, 1745, __pyx_L1_error))
  __pyx_v_x26 = (__pyx_v_x24 * __pyx_v_x25);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1746
 *         cdef double x25 =Nu*x8
 *         cdef double x26 =x24*x25
 *         cdef double x27 =8.0*r             # <<<<<<<<<<<<<<
 *         cdef double x28 =2.0*x19
 *         cdef double x29 =4.0*x0 + x27 + x28 + 16.0
 */
  __Pyx_TraceLine(1746,0,__PYX_ERR(1, 1746, __pyx_L1_error))
  __pyx_v_x27 = (8.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1747
 *         cdef double x26 =x24*x25
 *         cdef double x27 =8.0*r
 *         cdef double x28 =2.0*x19             # <<<<<<<<<<<<<<
 *         cdef double x29 =4.0*x0 + x27 + x28 + 16.0
 *         cdef double x30 =7680.0*a6
 */
  __Pyx_TraceLine(1747,0,__PYX_ERR(1, 1747, __pyx_L1_error))
  __pyx_v_x28 = (2.0 * __pyx_v_x19);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1748
 *         cdef double x27 =8.0*r
 *         cdef double x28 =2.0*x19
 *         cdef double x29 =4.0*x0 + x27 + x28 + 16.0             # <<<<<<<<<<<<<<
 *         cdef double x30 =7680.0*a6
 *         cdef double x31 =128.0*r
 */
  __Pyx_TraceLine(1748,0,__PYX_ERR(1, 1748, __pyx_L1_error))
  __pyx_v_x29 = ((((4.0 * __pyx_v_x0) + __pyx_v_x27) + __pyx_v_x28) + 16.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1749
 *         cdef double x28 =2.0*x19
 *         cdef double x29 =4.0*x0 + x27 + x28 + 16.0
 *         cdef double x30 =7680.0*a6             # <<<<<<<<<<<<<<
 *         cdef double x31 =128.0*r
 *         cdef double x32 =7704.0*r
 */
  __Pyx_TraceLine(1749,0,__PYX_ERR(1, 1749, __pyx_L1_error))
  __pyx_v_x30 = (7680.0 * __pyx_v_a6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1750
 *         cdef double x29 =4.0*x0 + x27 + x28 + 16.0
 *         cdef double x30 =7680.0*a6
 *         cdef double x31 =128.0*r             # <<<<<<<<<<<<<<
 *         cdef double x32 =7704.0*r
 *         cdef double x33 =148.04406601634*r
 */
  __Pyx_TraceLine(1750,0,__PYX_ERR(1, 1750, __pyx_L1_error))
  __pyx_v_x31 = (128.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1751
 *         cdef double x30 =7680.0*a6
 *         cdef double x31 =128.0*r
 *         cdef double x32 =7704.0*r             # <<<<<<<<<<<<<<
 *         cdef double x33 =148.04406601634*r
 *         cdef double x34 =113485.217444961*r
 */
  __Pyx_TraceLine(1751,0,__PYX_ERR(1, 1751, __pyx_L1_error))
  __pyx_v_x32 = (7704.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1752
 *         cdef double x31 =128.0*r
 *         cdef double x32 =7704.0*r
 *         cdef double x33 =148.04406601634*r             # <<<<<<<<<<<<<<
 *         cdef double x34 =113485.217444961*r
 *         cdef double x35 =Nu*(x30*(x12 + x29) + x31*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x12 + 4264.6962773603*x19 - 33722.4297811176) + x33*(3852.0*x0 + 349.0*x12 + 1926.0*x19 + x32 + 36400.0) + x34*(-x12 + x29))
 */
  __Pyx_TraceLine(1752,0,__PYX_ERR(1, 1752, __pyx_L1_error))
  __pyx_v_x33 = (148.04406601634 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1753
 *         cdef double x32 =7704.0*r
 *         cdef double x33 =148.04406601634*r
 *         cdef double x34 =113485.217444961*r             # <<<<<<<<<<<<<<
 *         cdef double x35 =Nu*(x30*(x12 + x29) + x31*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x12 + 4264.6962773603*x19 - 33722.4297811176) + x33*(3852.0*x0 + 349.0*x12 + 1926.0*x19 + x32 + 36400.0) + x34*(-x12 + x29))
 *         cdef double x36 =(241555486248.807*x13 + 13212057600.0*x14 + 67645734912.0*x16 + 1120.0*x18 + 7.0*x20 + 32768.0*x26 + 53760.0*x35)**(-1)
 */
  __Pyx_TraceLine(1753,0,__PYX_ERR(1, 1753, __pyx_L1_error))
  __pyx_v_x34 = (113485.217444961 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1754
 *         cdef double x33 =148.04406601634*r
 *         cdef double x34 =113485.217444961*r
 *         cdef double x35 =Nu*(x30*(x12 + x29) + x31*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x12 + 4264.6962773603*x19 - 33722.4297811176) + x33*(3852.0*x0 + 349.0*x12 + 1926.0*x19 + x32 + 36400.0) + x34*(-x12 + x29))             # <<<<<<<<<<<<<<
 *         cdef double x36 =(241555486248.807*x13 + 13212057600.0*x14 + 67645734912.0*x16 + 1120.0*x18 + 7.0*x20 + 32768.0*x26 + 53760.0*x35)**(-1)
 *         cdef double x37 =x11*x12*x36
 */
  __Pyx_TraceLine(1754,0,__PYX_ERR(1, 1754, __pyx_L1_error))
  __pyx_v_x35 = (__pyx_v_Nu * ((((__pyx_v_x30 * (__pyx_v_x12 + __pyx_v_x29)) + (__pyx_v_x31 * (((((13218.7851094412 * __pyx_v_r) + (8529.39255472061 * __pyx_v_x0)) - (6852.34813868015 * __pyx_v_x12)) + (4264.6962773603 * __pyx_v_x19)) - 33722.4297811176))) + (__pyx_v_x33 * (((((3852.0 * __pyx_v_x0) + (349.0 * __pyx_v_x12)) + (1926.0 * __pyx_v_x19)) + __pyx_v_x32) + 36400.0))) + (__pyx_v_x34 * ((-__pyx_v_x12) + __pyx_v_x29))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1755
 *         cdef double x34 =113485.217444961*r
 *         cdef double x35 =Nu*(x30*(x12 + x29) + x31*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x12 + 4264.6962773603*x19 - 33722.4297811176) + x33*(3852.0*x0 + 349.0*x12 + 1926.0*x19 + x32 + 36400.0) + x34*(-x12 + x29))
 *         cdef double x36 =(241555486248.807*x13 + 13212057600.0*x14 + 67645734912.0*x16 + 1120.0*x18 + 7.0*x20 + 32768.0*x26 + 53760.0*x35)**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x37 =x11*x12*x36
 *         cdef double x38 =7680.0*x37 + x6
 */
  __Pyx_TraceLine(1755,0,__PYX_ERR(1, 1755, __pyx_L1_error))
  __pyx_v_x36 = pow((((((((241555486248.807 * __pyx_v_x13) + (13212057600.0 * __pyx_v_x14)) + (67645734912.0 * __pyx_v_x16)) + (1120.0 * __pyx_v_x18)) + (7.0 * __pyx_v_x20)) + (32768.0 * __pyx_v_x26)) + (53760.0 * __pyx_v_x35)), -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1756
 *         cdef double x35 =Nu*(x30*(x12 + x29) + x31*(13218.7851094412*r + 8529.39255472061*x0 - 6852.34813868015*x12 + 4264.6962773603*x19 - 33722.4297811176) + x33*(3852.0*x0 + 349.0*x12 + 1926.0*x19 + x32 + 36400.0) + x34*(-x12 + x29))
 *         cdef double x36 =(241555486248.807*x13 + 13212057600.0*x14 + 67645734912.0*x16 + 1120.0*x18 + 7.0*x20 + 32768.0*x26 + 53760.0*x35)**(-1)
 *         cdef double x37 =x11*x12*x36             # <<<<<<<<<<<<<<
 *         cdef double x38 =7680.0*x37 + x6
 *         cdef double x39 =2.0*r
 */
  __Pyx_TraceLine(1756,0,__PYX_ERR(1, 1756, __pyx_L1_error))
  __pyx_v_x37 = ((__pyx_v_x11 * __pyx_v_x12) * __pyx_v_x36);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1757
 *         cdef double x36 =(241555486248.807*x13 + 13212057600.0*x14 + 67645734912.0*x16 + 1120.0*x18 + 7.0*x20 + 32768.0*x26 + 53760.0*x35)**(-1)
 *         cdef double x37 =x11*x12*x36
 *         cdef double x38 =7680.0*x37 + x6             # <<<<<<<<<<<<<<
 *         cdef double x39 =2.0*r
 *         cdef double x40 =Nu*r
 */
  __Pyx_TraceLine(1757,0,__PYX_ERR(1, 1757, __pyx_L1_error))
  __pyx_v_x38 = ((7680.0 * __pyx_v_x37) + __pyx_v_x6);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1758
 *         cdef double x37 =x11*x12*x36
 *         cdef double x38 =7680.0*x37 + x6
 *         cdef double x39 =2.0*r             # <<<<<<<<<<<<<<
 *         cdef double x40 =Nu*r
 *         cdef double x41 =Nu*x0
 */
  __Pyx_TraceLine(1758,0,__PYX_ERR(1, 1758, __pyx_L1_error))
  __pyx_v_x39 = (2.0 * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1759
 *         cdef double x38 =7680.0*x37 + x6
 *         cdef double x39 =2.0*r
 *         cdef double x40 =Nu*r             # <<<<<<<<<<<<<<
 *         cdef double x41 =Nu*x0
 *         cdef double x42 =1822680546449.21*x7
 */
  __Pyx_TraceLine(1759,0,__PYX_ERR(1, 1759, __pyx_L1_error))
  __pyx_v_x40 = (__pyx_v_Nu * __pyx_v_r);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1760
 *         cdef double x39 =2.0*r
 *         cdef double x40 =Nu*r
 *         cdef double x41 =Nu*x0             # <<<<<<<<<<<<<<
 *         cdef double x42 =1822680546449.21*x7
 *         cdef double x43 =5787938193408.0*x15
 */
  __Pyx_TraceLine(1760,0,__PYX_ERR(1, 1760, __pyx_L1_error))
  __pyx_v_x41 = (__pyx_v_Nu * __pyx_v_x0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1761
 *         cdef double x40 =Nu*r
 *         cdef double x41 =Nu*x0
 *         cdef double x42 =1822680546449.21*x7             # <<<<<<<<<<<<<<
 *         cdef double x43 =5787938193408.0*x15
 *         cdef double x44 =14700.0*Nu + 42911.0
 */
  __Pyx_TraceLine(1761,0,__PYX_ERR(1, 1761, __pyx_L1_error))
  __pyx_v_x42 = (1822680546449.21 * __pyx_v_x7);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1762
 *         cdef double x41 =Nu*x0
 *         cdef double x42 =1822680546449.21*x7
 *         cdef double x43 =5787938193408.0*x15             # <<<<<<<<<<<<<<
 *         cdef double x44 =14700.0*Nu + 42911.0
 *         cdef double x45 =r*x44
 */
  __Pyx_TraceLine(1762,0,__PYX_ERR(1, 1762, __pyx_L1_error))
  __pyx_v_x43 = (5787938193408.0 * __pyx_v_x15);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1763
 *         cdef double x42 =1822680546449.21*x7
 *         cdef double x43 =5787938193408.0*x15
 *         cdef double x44 =14700.0*Nu + 42911.0             # <<<<<<<<<<<<<<
 *         cdef double x45 =r*x44
 *         cdef double x46 =x0*x7
 */
  __Pyx_TraceLine(1763,0,__PYX_ERR(1, 1763, __pyx_L1_error))
  __pyx_v_x44 = ((14700.0 * __pyx_v_Nu) + 42911.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1764
 *         cdef double x43 =5787938193408.0*x15
 *         cdef double x44 =14700.0*Nu + 42911.0
 *         cdef double x45 =r*x44             # <<<<<<<<<<<<<<
 *         cdef double x46 =x0*x7
 *         cdef double x47 =283115520.0*x44
 */
  __Pyx_TraceLine(1764,0,__PYX_ERR(1, 1764, __pyx_L1_error))
  __pyx_v_x45 = (__pyx_v_r * __pyx_v_x44);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1765
 *         cdef double x44 =14700.0*Nu + 42911.0
 *         cdef double x45 =r*x44
 *         cdef double x46 =x0*x7             # <<<<<<<<<<<<<<
 *         cdef double x47 =283115520.0*x44
 *         cdef double x48 =5041721180160.0*x7 - 104186110149937.0
 */
  __Pyx_TraceLine(1765,0,__PYX_ERR(1, 1765, __pyx_L1_error))
  __pyx_v_x46 = (__pyx_v_x0 * __pyx_v_x7);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1766
 *         cdef double x45 =r*x44
 *         cdef double x46 =x0*x7
 *         cdef double x47 =283115520.0*x44             # <<<<<<<<<<<<<<
 *         cdef double x48 =5041721180160.0*x7 - 104186110149937.0
 *         cdef double x49 =-25392914995744.3*Nu - r*x47 - 879923036160.0*x0 - x48
 */
  __Pyx_TraceLine(1766,0,__PYX_ERR(1, 1766, __pyx_L1_error))
  __pyx_v_x47 = (283115520.0 * __pyx_v_x44);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1767
 *         cdef double x46 =x0*x7
 *         cdef double x47 =283115520.0*x44
 *         cdef double x48 =5041721180160.0*x7 - 104186110149937.0             # <<<<<<<<<<<<<<
 *         cdef double x49 =-25392914995744.3*Nu - r*x47 - 879923036160.0*x0 - x48
 *         cdef double x50 =-12049908701745.2*Nu + r*x42 - 39476764256925.6*r + 5107745331375.71*x0 + 6730497718123.02*x17 + 10611661054566.2*x40 + 2589101062873.81*x41 + x43 - 326837426.241486*x45 + 133772083200.0*x46 - x49*x8 + 80059249540278.2*x7 + 275059053208689.0
 */
  __Pyx_TraceLine(1767,0,__PYX_ERR(1, 1767, __pyx_L1_error))
  __pyx_v_x48 = ((5041721180160.0 * __pyx_v_x7) - 104186110149937.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1768
 *         cdef double x47 =283115520.0*x44
 *         cdef double x48 =5041721180160.0*x7 - 104186110149937.0
 *         cdef double x49 =-25392914995744.3*Nu - r*x47 - 879923036160.0*x0 - x48             # <<<<<<<<<<<<<<
 *         cdef double x50 =-12049908701745.2*Nu + r*x42 - 39476764256925.6*r + 5107745331375.71*x0 + 6730497718123.02*x17 + 10611661054566.2*x40 + 2589101062873.81*x41 + x43 - 326837426.241486*x45 + 133772083200.0*x46 - x49*x8 + 80059249540278.2*x7 + 275059053208689.0
 *         cdef double x51 =-630116198.873299*Nu - 197773496.793534*x7 + 5805304367.87913
 */
  __Pyx_TraceLine(1768,0,__PYX_ERR(1, 1768, __pyx_L1_error))
  __pyx_v_x49 = ((((-25392914995744.3 * __pyx_v_Nu) - (__pyx_v_r * __pyx_v_x47)) - (879923036160.0 * __pyx_v_x0)) - __pyx_v_x48);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1769
 *         cdef double x48 =5041721180160.0*x7 - 104186110149937.0
 *         cdef double x49 =-25392914995744.3*Nu - r*x47 - 879923036160.0*x0 - x48
 *         cdef double x50 =-12049908701745.2*Nu + r*x42 - 39476764256925.6*r + 5107745331375.71*x0 + 6730497718123.02*x17 + 10611661054566.2*x40 + 2589101062873.81*x41 + x43 - 326837426.241486*x45 + 133772083200.0*x46 - x49*x8 + 80059249540278.2*x7 + 275059053208689.0             # <<<<<<<<<<<<<<
 *         cdef double x51 =-630116198.873299*Nu - 197773496.793534*x7 + 5805304367.87913
 *         cdef double x52 =x0*x51
 */
  __Pyx_TraceLine(1769,0,__PYX_ERR(1, 1769, __pyx_L1_error))
  __pyx_v_x50 = (((((((((((((-12049908701745.2 * __pyx_v_Nu) + (__pyx_v_r * __pyx_v_x42)) - (39476764256925.6 * __pyx_v_r)) + (5107745331375.71 * __pyx_v_x0)) + (6730497718123.02 * __pyx_v_x17)) + (10611661054566.2 * __pyx_v_x40)) + (2589101062873.81 * __pyx_v_x41)) + __pyx_v_x43) - (326837426.241486 * __pyx_v_x45)) + (133772083200.0 * __pyx_v_x46)) - (__pyx_v_x49 * __pyx_v_x8)) + (80059249540278.2 * __pyx_v_x7)) + 275059053208689.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1770
 *         cdef double x49 =-25392914995744.3*Nu - r*x47 - 879923036160.0*x0 - x48
 *         cdef double x50 =-12049908701745.2*Nu + r*x42 - 39476764256925.6*r + 5107745331375.71*x0 + 6730497718123.02*x17 + 10611661054566.2*x40 + 2589101062873.81*x41 + x43 - 326837426.241486*x45 + 133772083200.0*x46 - x49*x8 + 80059249540278.2*x7 + 275059053208689.0
 *         cdef double x51 =-630116198.873299*Nu - 197773496.793534*x7 + 5805304367.87913             # <<<<<<<<<<<<<<
 *         cdef double x52 =x0*x51
 *         cdef double x53 =-2675575.66847905*Nu - 138240.0*x7 - 5278341.3229329
 */
  __Pyx_TraceLine(1770,0,__PYX_ERR(1, 1770, __pyx_L1_error))
  __pyx_v_x51 = (((-630116198.873299 * __pyx_v_Nu) - (197773496.793534 * __pyx_v_x7)) + 5805304367.87913);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1771
 *         cdef double x50 =-12049908701745.2*Nu + r*x42 - 39476764256925.6*r + 5107745331375.71*x0 + 6730497718123.02*x17 + 10611661054566.2*x40 + 2589101062873.81*x41 + x43 - 326837426.241486*x45 + 133772083200.0*x46 - x49*x8 + 80059249540278.2*x7 + 275059053208689.0
 *         cdef double x51 =-630116198.873299*Nu - 197773496.793534*x7 + 5805304367.87913
 *         cdef double x52 =x0*x51             # <<<<<<<<<<<<<<
 *         cdef double x53 =-2675575.66847905*Nu - 138240.0*x7 - 5278341.3229329
 *         cdef double x54 =x19*x53
 */
  __Pyx_TraceLine(1771,0,__PYX_ERR(1, 1771, __pyx_L1_error))
  __pyx_v_x52 = (__pyx_v_x0 * __pyx_v_x51);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1772
 *         cdef double x51 =-630116198.873299*Nu - 197773496.793534*x7 + 5805304367.87913
 *         cdef double x52 =x0*x51
 *         cdef double x53 =-2675575.66847905*Nu - 138240.0*x7 - 5278341.3229329             # <<<<<<<<<<<<<<
 *         cdef double x54 =x19*x53
 *         cdef double x55 =Nu*(-2510664218.28128*Nu + 14515200.0*x17 - 42636451.6032331*x7 + 1002013764.01019)
 */
  __Pyx_TraceLine(1772,0,__PYX_ERR(1, 1772, __pyx_L1_error))
  __pyx_v_x53 = (((-2675575.66847905 * __pyx_v_Nu) - (138240.0 * __pyx_v_x7)) - 5278341.3229329);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1773
 *         cdef double x52 =x0*x51
 *         cdef double x53 =-2675575.66847905*Nu - 138240.0*x7 - 5278341.3229329
 *         cdef double x54 =x19*x53             # <<<<<<<<<<<<<<
 *         cdef double x55 =Nu*(-2510664218.28128*Nu + 14515200.0*x17 - 42636451.6032331*x7 + 1002013764.01019)
 *         cdef double x56 =43393301259014.8*Nu + 5927865218923.02*x17 + 43133561885859.3*x7 + 86618264430493.3*(1.0 - 0.496948781616935*Nu)**2 + 188440788778196.0
 */
  __Pyx_TraceLine(1773,0,__PYX_ERR(1, 1773, __pyx_L1_error))
  __pyx_v_x54 = (__pyx_v_x19 * __pyx_v_x53);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1774
 *         cdef double x53 =-2675575.66847905*Nu - 138240.0*x7 - 5278341.3229329
 *         cdef double x54 =x19*x53
 *         cdef double x55 =Nu*(-2510664218.28128*Nu + 14515200.0*x17 - 42636451.6032331*x7 + 1002013764.01019)             # <<<<<<<<<<<<<<
 *         cdef double x56 =43393301259014.8*Nu + 5927865218923.02*x17 + 43133561885859.3*x7 + 86618264430493.3*(1.0 - 0.496948781616935*Nu)**2 + 188440788778196.0
 *         cdef double x57 =r*x56
 */
  __Pyx_TraceLine(1774,0,__PYX_ERR(1, 1774, __pyx_L1_error))
  __pyx_v_x55 = (__pyx_v_Nu * ((((-2510664218.28128 * __pyx_v_Nu) + (14515200.0 * __pyx_v_x17)) - (42636451.6032331 * __pyx_v_x7)) + 1002013764.01019));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1775
 *         cdef double x54 =x19*x53
 *         cdef double x55 =Nu*(-2510664218.28128*Nu + 14515200.0*x17 - 42636451.6032331*x7 + 1002013764.01019)
 *         cdef double x56 =43393301259014.8*Nu + 5927865218923.02*x17 + 43133561885859.3*x7 + 86618264430493.3*(1.0 - 0.496948781616935*Nu)**2 + 188440788778196.0             # <<<<<<<<<<<<<<
 *         cdef double x57 =r*x56
 *         cdef double x58 =Nu*(11592.0*Nu + 69847.0)
 */
  __Pyx_TraceLine(1775,0,__PYX_ERR(1, 1775, __pyx_L1_error))
  __pyx_v_x56 = (((((43393301259014.8 * __pyx_v_Nu) + (5927865218923.02 * __pyx_v_x17)) + (43133561885859.3 * __pyx_v_x7)) + (86618264430493.3 * pow((1.0 - (0.496948781616935 * __pyx_v_Nu)), 2.0))) + 188440788778196.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1776
 *         cdef double x55 =Nu*(-2510664218.28128*Nu + 14515200.0*x17 - 42636451.6032331*x7 + 1002013764.01019)
 *         cdef double x56 =43393301259014.8*Nu + 5927865218923.02*x17 + 43133561885859.3*x7 + 86618264430493.3*(1.0 - 0.496948781616935*Nu)**2 + 188440788778196.0
 *         cdef double x57 =r*x56             # <<<<<<<<<<<<<<
 *         cdef double x58 =Nu*(11592.0*Nu + 69847.0)
 *         cdef double x59 =r*(409207698.136075*Nu + 102574080.0*x7 - 2119671837.36038)
 */
  __Pyx_TraceLine(1776,0,__PYX_ERR(1, 1776, __pyx_L1_error))
  __pyx_v_x57 = (__pyx_v_r * __pyx_v_x56);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1777
 *         cdef double x56 =43393301259014.8*Nu + 5927865218923.02*x17 + 43133561885859.3*x7 + 86618264430493.3*(1.0 - 0.496948781616935*Nu)**2 + 188440788778196.0
 *         cdef double x57 =r*x56
 *         cdef double x58 =Nu*(11592.0*Nu + 69847.0)             # <<<<<<<<<<<<<<
 *         cdef double x59 =r*(409207698.136075*Nu + 102574080.0*x7 - 2119671837.36038)
 *         cdef double x60 =x0*x47 + 879923036160.0*x19 - 1698693120.0*x58 + 49152.0*x59
 */
  __Pyx_TraceLine(1777,0,__PYX_ERR(1, 1777, __pyx_L1_error))
  __pyx_v_x58 = (__pyx_v_Nu * ((11592.0 * __pyx_v_Nu) + 69847.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1778
 *         cdef double x57 =r*x56
 *         cdef double x58 =Nu*(11592.0*Nu + 69847.0)
 *         cdef double x59 =r*(409207698.136075*Nu + 102574080.0*x7 - 2119671837.36038)             # <<<<<<<<<<<<<<
 *         cdef double x60 =x0*x47 + 879923036160.0*x19 - 1698693120.0*x58 + 49152.0*x59
 *         cdef double x61 =r*x43 - 9216.0*x52 - 967680.0*x54 + 55296.0*x55 + x57 + x60*x8
 */
  __Pyx_TraceLine(1778,0,__PYX_ERR(1, 1778, __pyx_L1_error))
  __pyx_v_x59 = (__pyx_v_r * (((409207698.136075 * __pyx_v_Nu) + (102574080.0 * __pyx_v_x7)) - 2119671837.36038));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1779
 *         cdef double x58 =Nu*(11592.0*Nu + 69847.0)
 *         cdef double x59 =r*(409207698.136075*Nu + 102574080.0*x7 - 2119671837.36038)
 *         cdef double x60 =x0*x47 + 879923036160.0*x19 - 1698693120.0*x58 + 49152.0*x59             # <<<<<<<<<<<<<<
 *         cdef double x61 =r*x43 - 9216.0*x52 - 967680.0*x54 + 55296.0*x55 + x57 + x60*x8
 *         cdef double x62 =1/x61
 */
  __Pyx_TraceLine(1779,0,__PYX_ERR(1, 1779, __pyx_L1_error))
  __pyx_v_x60 = ((((__pyx_v_x0 * __pyx_v_x47) + (879923036160.0 * __pyx_v_x19)) - (1698693120.0 * __pyx_v_x58)) + (49152.0 * __pyx_v_x59));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1780
 *         cdef double x59 =r*(409207698.136075*Nu + 102574080.0*x7 - 2119671837.36038)
 *         cdef double x60 =x0*x47 + 879923036160.0*x19 - 1698693120.0*x58 + 49152.0*x59
 *         cdef double x61 =r*x43 - 9216.0*x52 - 967680.0*x54 + 55296.0*x55 + x57 + x60*x8             # <<<<<<<<<<<<<<
 *         cdef double x62 =1/x61
 *         cdef double x63 =x50*x62
 */
  __Pyx_TraceLine(1780,0,__PYX_ERR(1, 1780, __pyx_L1_error))
  __pyx_v_x61 = ((((((__pyx_v_r * __pyx_v_x43) - (9216.0 * __pyx_v_x52)) - (967680.0 * __pyx_v_x54)) + (55296.0 * __pyx_v_x55)) + __pyx_v_x57) + (__pyx_v_x60 * __pyx_v_x8));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1781
 *         cdef double x60 =x0*x47 + 879923036160.0*x19 - 1698693120.0*x58 + 49152.0*x59
 *         cdef double x61 =r*x43 - 9216.0*x52 - 967680.0*x54 + 55296.0*x55 + x57 + x60*x8
 *         cdef double x62 =1/x61             # <<<<<<<<<<<<<<
 *         cdef double x63 =x50*x62
 *         cdef double x64 = sqrt(r*x63)
 */
  __Pyx_TraceLine(1781,0,__PYX_ERR(1, 1781, __pyx_L1_error))
  __pyx_v_x62 = (1.0 / __pyx_v_x61);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1782
 *         cdef double x61 =r*x43 - 9216.0*x52 - 967680.0*x54 + 55296.0*x55 + x57 + x60*x8
 *         cdef double x62 =1/x61
 *         cdef double x63 =x50*x62             # <<<<<<<<<<<<<<
 *         cdef double x64 = sqrt(r*x63)
 *         cdef double x65 =x0 + x5
 */
  __Pyx_TraceLine(1782,0,__PYX_ERR(1, 1782, __pyx_L1_error))
  __pyx_v_x63 = (__pyx_v_x50 * __pyx_v_x62);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1783
 *         cdef double x62 =1/x61
 *         cdef double x63 =x50*x62
 *         cdef double x64 = sqrt(r*x63)             # <<<<<<<<<<<<<<
 *         cdef double x65 =x0 + x5
 *         cdef double x66 =x64/x65
 */
  __Pyx_TraceLine(1783,0,__PYX_ERR(1, 1783, __pyx_L1_error))
  __pyx_v_x64 = sqrt((__pyx_v_r * __pyx_v_x63));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1784
 *         cdef double x63 =x50*x62
 *         cdef double x64 = sqrt(r*x63)
 *         cdef double x65 =x0 + x5             # <<<<<<<<<<<<<<
 *         cdef double x66 =x64/x65
 *         cdef double x67 =2.0*x5
 */
  __Pyx_TraceLine(1784,0,__PYX_ERR(1, 1784, __pyx_L1_error))
  __pyx_v_x65 = (__pyx_v_x0 + __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1785
 *         cdef double x64 = sqrt(r*x63)
 *         cdef double x65 =x0 + x5
 *         cdef double x66 =x64/x65             # <<<<<<<<<<<<<<
 *         cdef double x67 =2.0*x5
 *         cdef double x68 =2.0*x0 + x67
 */
  __Pyx_TraceLine(1785,0,__PYX_ERR(1, 1785, __pyx_L1_error))
  __pyx_v_x66 = (__pyx_v_x64 / __pyx_v_x65);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1786
 *         cdef double x65 =x0 + x5
 *         cdef double x66 =x64/x65
 *         cdef double x67 =2.0*x5             # <<<<<<<<<<<<<<
 *         cdef double x68 =2.0*x0 + x67
 *         cdef double x69 =r*x7
 */
  __Pyx_TraceLine(1786,0,__PYX_ERR(1, 1786, __pyx_L1_error))
  __pyx_v_x67 = (2.0 * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1787
 *         cdef double x66 =x64/x65
 *         cdef double x67 =2.0*x5
 *         cdef double x68 =2.0*x0 + x67             # <<<<<<<<<<<<<<
 *         cdef double x69 =r*x7
 *         cdef double x70 =r**(-1)
 */
  __Pyx_TraceLine(1787,0,__PYX_ERR(1, 1787, __pyx_L1_error))
  __pyx_v_x68 = ((2.0 * __pyx_v_x0) + __pyx_v_x67);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1788
 *         cdef double x67 =2.0*x5
 *         cdef double x68 =2.0*x0 + x67
 *         cdef double x69 =r*x7             # <<<<<<<<<<<<<<
 *         cdef double x70 =r**(-1)
 *         cdef double x71 =11575876386816.0*x8
 */
  __Pyx_TraceLine(1788,0,__PYX_ERR(1, 1788, __pyx_L1_error))
  __pyx_v_x69 = (__pyx_v_r * __pyx_v_x7);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1789
 *         cdef double x68 =2.0*x0 + x67
 *         cdef double x69 =r*x7
 *         cdef double x70 =r**(-1)             # <<<<<<<<<<<<<<
 *         cdef double x71 =11575876386816.0*x8
 *         cdef double x72 =5807150888816.34*Nu + 10215490662751.4*r + 5178202125747.62*x40 + x42 - x49*x70 + 267544166400.0*x69 + x70*x71 + x8*(4161798144000.0*Nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 */
  __Pyx_TraceLine(1789,0,__PYX_ERR(1, 1789, __pyx_L1_error))
  __pyx_v_x70 = pow(__pyx_v_r, -1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1790
 *         cdef double x69 =r*x7
 *         cdef double x70 =r**(-1)
 *         cdef double x71 =11575876386816.0*x8             # <<<<<<<<<<<<<<
 *         cdef double x72 =5807150888816.34*Nu + 10215490662751.4*r + 5178202125747.62*x40 + x42 - x49*x70 + 267544166400.0*x69 + x70*x71 + x8*(4161798144000.0*Nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x73 =(r*x15 - 1.59227685093395e-9*x52 - 1.67189069348064e-7*x54 + 9.55366110560367e-9*x55 + 1.72773095804465e-13*x57 + x8*(4.89147448606909e-5*x0*x44 + 0.152027027027027*x19 - 0.000293488469164146*x58 + 8.49214320498106e-9*x59))**2
 */
  __Pyx_TraceLine(1790,0,__PYX_ERR(1, 1790, __pyx_L1_error))
  __pyx_v_x71 = (11575876386816.0 * __pyx_v_x8);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1791
 *         cdef double x70 =r**(-1)
 *         cdef double x71 =11575876386816.0*x8
 *         cdef double x72 =5807150888816.34*Nu + 10215490662751.4*r + 5178202125747.62*x40 + x42 - x49*x70 + 267544166400.0*x69 + x70*x71 + x8*(4161798144000.0*Nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1             # <<<<<<<<<<<<<<
 *         cdef double x73 =(r*x15 - 1.59227685093395e-9*x52 - 1.67189069348064e-7*x54 + 9.55366110560367e-9*x55 + 1.72773095804465e-13*x57 + x8*(4.89147448606909e-5*x0*x44 + 0.152027027027027*x19 - 0.000293488469164146*x58 + 8.49214320498106e-9*x59))**2
 *         cdef double x74 =-18432.0*r*x51 - 2903040.0*x0*x53 + x43 + x56 + x60*x70 + x71 + x8*(20113376778784.3*Nu + 2639769108480.0*x0 + 566231040.0*x45 + x48)
 */
  __Pyx_TraceLine(1791,0,__PYX_ERR(1, 1791, __pyx_L1_error))
  __pyx_v_x72 = (((((((((5807150888816.34 * __pyx_v_Nu) + (10215490662751.4 * __pyx_v_r)) + (5178202125747.62 * __pyx_v_x40)) + __pyx_v_x42) - (__pyx_v_x49 * __pyx_v_x70)) + (267544166400.0 * __pyx_v_x69)) + (__pyx_v_x70 * __pyx_v_x71)) + (__pyx_v_x8 * (((4161798144000.0 * __pyx_v_Nu) + (1759846072320.0 * __pyx_v_r)) + 12148770078720.0))) - 53501685054374.1);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1792
 *         cdef double x71 =11575876386816.0*x8
 *         cdef double x72 =5807150888816.34*Nu + 10215490662751.4*r + 5178202125747.62*x40 + x42 - x49*x70 + 267544166400.0*x69 + x70*x71 + x8*(4161798144000.0*Nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x73 =(r*x15 - 1.59227685093395e-9*x52 - 1.67189069348064e-7*x54 + 9.55366110560367e-9*x55 + 1.72773095804465e-13*x57 + x8*(4.89147448606909e-5*x0*x44 + 0.152027027027027*x19 - 0.000293488469164146*x58 + 8.49214320498106e-9*x59))**2             # <<<<<<<<<<<<<<
 *         cdef double x74 =-18432.0*r*x51 - 2903040.0*x0*x53 + x43 + x56 + x60*x70 + x71 + x8*(20113376778784.3*Nu + 2639769108480.0*x0 + 566231040.0*x45 + x48)
 *         cdef double x75 =x50*x74/x73
 */
  __Pyx_TraceLine(1792,0,__PYX_ERR(1, 1792, __pyx_L1_error))
  __pyx_v_x73 = pow(((((((__pyx_v_r * __pyx_v_x15) - (1.59227685093395e-9 * __pyx_v_x52)) - (1.67189069348064e-7 * __pyx_v_x54)) + (9.55366110560367e-9 * __pyx_v_x55)) + (1.72773095804465e-13 * __pyx_v_x57)) + (__pyx_v_x8 * (((((4.89147448606909e-5 * __pyx_v_x0) * __pyx_v_x44) + (0.152027027027027 * __pyx_v_x19)) - (0.000293488469164146 * __pyx_v_x58)) + (8.49214320498106e-9 * __pyx_v_x59)))), 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1793
 *         cdef double x72 =5807150888816.34*Nu + 10215490662751.4*r + 5178202125747.62*x40 + x42 - x49*x70 + 267544166400.0*x69 + x70*x71 + x8*(4161798144000.0*Nu + 1759846072320.0*r + 12148770078720.0) - 53501685054374.1
 *         cdef double x73 =(r*x15 - 1.59227685093395e-9*x52 - 1.67189069348064e-7*x54 + 9.55366110560367e-9*x55 + 1.72773095804465e-13*x57 + x8*(4.89147448606909e-5*x0*x44 + 0.152027027027027*x19 - 0.000293488469164146*x58 + 8.49214320498106e-9*x59))**2
 *         cdef double x74 =-18432.0*r*x51 - 2903040.0*x0*x53 + x43 + x56 + x60*x70 + x71 + x8*(20113376778784.3*Nu + 2639769108480.0*x0 + 566231040.0*x45 + x48)             # <<<<<<<<<<<<<<
 *         cdef double x75 =x50*x74/x73
 *         cdef double x76 =1/x19
 */
  __Pyx_TraceLine(1793,0,__PYX_ERR(1, 1793, __pyx_L1_error))
  __pyx_v_x74 = ((((((((-18432.0 * __pyx_v_r) * __pyx_v_x51) - ((2903040.0 * __pyx_v_x0) * __pyx_v_x53)) + __pyx_v_x43) + __pyx_v_x56) + (__pyx_v_x60 * __pyx_v_x70)) + __pyx_v_x71) + (__pyx_v_x8 * ((((20113376778784.3 * __pyx_v_Nu) + (2639769108480.0 * __pyx_v_x0)) + (566231040.0 * __pyx_v_x45)) + __pyx_v_x48)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1794
 *         cdef double x73 =(r*x15 - 1.59227685093395e-9*x52 - 1.67189069348064e-7*x54 + 9.55366110560367e-9*x55 + 1.72773095804465e-13*x57 + x8*(4.89147448606909e-5*x0*x44 + 0.152027027027027*x19 - 0.000293488469164146*x58 + 8.49214320498106e-9*x59))**2
 *         cdef double x74 =-18432.0*r*x51 - 2903040.0*x0*x53 + x43 + x56 + x60*x70 + x71 + x8*(20113376778784.3*Nu + 2639769108480.0*x0 + 566231040.0*x45 + x48)
 *         cdef double x75 =x50*x74/x73             # <<<<<<<<<<<<<<
 *         cdef double x76 =1/x19
 *         cdef double x77 =x67*x76
 */
  __Pyx_TraceLine(1794,0,__PYX_ERR(1, 1794, __pyx_L1_error))
  __pyx_v_x75 = ((__pyx_v_x50 * __pyx_v_x74) / __pyx_v_x73);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1795
 *         cdef double x74 =-18432.0*r*x51 - 2903040.0*x0*x53 + x43 + x56 + x60*x70 + x71 + x8*(20113376778784.3*Nu + 2639769108480.0*x0 + 566231040.0*x45 + x48)
 *         cdef double x75 =x50*x74/x73
 *         cdef double x76 =1/x19             # <<<<<<<<<<<<<<
 *         cdef double x77 =x67*x76
 *         cdef double x78 =Nu*x70
 */
  __Pyx_TraceLine(1795,0,__PYX_ERR(1, 1795, __pyx_L1_error))
  __pyx_v_x76 = (1.0 / __pyx_v_x19);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1796
 *         cdef double x75 =x50*x74/x73
 *         cdef double x76 =1/x19
 *         cdef double x77 =x67*x76             # <<<<<<<<<<<<<<
 *         cdef double x78 =Nu*x70
 *         cdef double x79 =-6572428.80109422*Nu + 2048.0*x10*x78 + 688128.0*x25 + 1300341.64885296*x7 + 1720320.0
 */
  __Pyx_TraceLine(1796,0,__PYX_ERR(1, 1796, __pyx_L1_error))
  __pyx_v_x77 = (__pyx_v_x67 * __pyx_v_x76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1797
 *         cdef double x76 =1/x19
 *         cdef double x77 =x67*x76
 *         cdef double x78 =Nu*x70             # <<<<<<<<<<<<<<
 *         cdef double x79 =-6572428.80109422*Nu + 2048.0*x10*x78 + 688128.0*x25 + 1300341.64885296*x7 + 1720320.0
 *         cdef double x80 =x7*x70
 */
  __Pyx_TraceLine(1797,0,__PYX_ERR(1, 1797, __pyx_L1_error))
  __pyx_v_x78 = (__pyx_v_Nu * __pyx_v_x70);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1798
 *         cdef double x77 =x67*x76
 *         cdef double x78 =Nu*x70
 *         cdef double x79 =-6572428.80109422*Nu + 2048.0*x10*x78 + 688128.0*x25 + 1300341.64885296*x7 + 1720320.0             # <<<<<<<<<<<<<<
 *         cdef double x80 =x7*x70
 *         cdef double x81 =4.0*x19
 */
  __Pyx_TraceLine(1798,0,__PYX_ERR(1, 1798, __pyx_L1_error))
  __pyx_v_x79 = (((((-6572428.80109422 * __pyx_v_Nu) + ((2048.0 * __pyx_v_x10) * __pyx_v_x78)) + (688128.0 * __pyx_v_x25)) + (1300341.64885296 * __pyx_v_x7)) + 1720320.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1799
 *         cdef double x78 =Nu*x70
 *         cdef double x79 =-6572428.80109422*Nu + 2048.0*x10*x78 + 688128.0*x25 + 1300341.64885296*x7 + 1720320.0
 *         cdef double x80 =x7*x70             # <<<<<<<<<<<<<<
 *         cdef double x81 =4.0*x19
 *         cdef double x82 =6.0*x0 + x27 + 8.0
 */
  __Pyx_TraceLine(1799,0,__PYX_ERR(1, 1799, __pyx_L1_error))
  __pyx_v_x80 = (__pyx_v_x7 * __pyx_v_x70);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1800
 *         cdef double x79 =-6572428.80109422*Nu + 2048.0*x10*x78 + 688128.0*x25 + 1300341.64885296*x7 + 1720320.0
 *         cdef double x80 =x7*x70
 *         cdef double x81 =4.0*x19             # <<<<<<<<<<<<<<
 *         cdef double x82 =6.0*x0 + x27 + 8.0
 *         cdef double x83 =1.31621673590926e-19*x11*(53760.0*Nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x12 + 1057984.42953951*x19 + x30*(x81 + x82) + x31*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x19 + 13218.7851094412) + x33*(5778.0*x0 + 1396.0*x19 + x32 + 7704.0) + x34*(-x81 + x82) + 2888096.47013111) + 66060288000.0*x12 + 7.0*x17*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x24*x78 + 32768.0*x25*(-1791904.9465589*Nu + 3840.0*r*x21 + 2880.0*x0*x22 + 806400.0*x12 + 1920.0*x23 - 725760.0*x7 + 4143360.0) + 7.0*x7*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x12 - 12357002815.0752*x19 + 122635399361.987) + 135291469824.0*x8*x80)/(x13 + 0.0546957463279941*x14 + 0.28004222119933*x16 + 4.63661586574928e-9*x18 + 2.8978849160933e-11*x20 + 1.35654132757922e-7*x26 + 2.22557561555966e-7*x35)**2
 */
  __Pyx_TraceLine(1800,0,__PYX_ERR(1, 1800, __pyx_L1_error))
  __pyx_v_x81 = (4.0 * __pyx_v_x19);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1801
 *         cdef double x80 =x7*x70
 *         cdef double x81 =4.0*x19
 *         cdef double x82 =6.0*x0 + x27 + 8.0             # <<<<<<<<<<<<<<
 *         cdef double x83 =1.31621673590926e-19*x11*(53760.0*Nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x12 + 1057984.42953951*x19 + x30*(x81 + x82) + x31*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x19 + 13218.7851094412) + x33*(5778.0*x0 + 1396.0*x19 + x32 + 7704.0) + x34*(-x81 + x82) + 2888096.47013111) + 66060288000.0*x12 + 7.0*x17*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x24*x78 + 32768.0*x25*(-1791904.9465589*Nu + 3840.0*r*x21 + 2880.0*x0*x22 + 806400.0*x12 + 1920.0*x23 - 725760.0*x7 + 4143360.0) + 7.0*x7*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x12 - 12357002815.0752*x19 + 122635399361.987) + 135291469824.0*x8*x80)/(x13 + 0.0546957463279941*x14 + 0.28004222119933*x16 + 4.63661586574928e-9*x18 + 2.8978849160933e-11*x20 + 1.35654132757922e-7*x26 + 2.22557561555966e-7*x35)**2
 *         cdef double x84 =-30720.0*x11*x19*x36 - 7680.0*x12*x36*x79 + x12*x83 + x77
 */
  __Pyx_TraceLine(1801,0,__PYX_ERR(1, 1801, __pyx_L1_error))
  __pyx_v_x82 = (((6.0 * __pyx_v_x0) + __pyx_v_x27) + 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1802
 *         cdef double x81 =4.0*x19
 *         cdef double x82 =6.0*x0 + x27 + 8.0
 *         cdef double x83 =1.31621673590926e-19*x11*(53760.0*Nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x12 + 1057984.42953951*x19 + x30*(x81 + x82) + x31*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x19 + 13218.7851094412) + x33*(5778.0*x0 + 1396.0*x19 + x32 + 7704.0) + x34*(-x81 + x82) + 2888096.47013111) + 66060288000.0*x12 + 7.0*x17*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x24*x78 + 32768.0*x25*(-1791904.9465589*Nu + 3840.0*r*x21 + 2880.0*x0*x22 + 806400.0*x12 + 1920.0*x23 - 725760.0*x7 + 4143360.0) + 7.0*x7*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x12 - 12357002815.0752*x19 + 122635399361.987) + 135291469824.0*x8*x80)/(x13 + 0.0546957463279941*x14 + 0.28004222119933*x16 + 4.63661586574928e-9*x18 + 2.8978849160933e-11*x20 + 1.35654132757922e-7*x26 + 2.22557561555966e-7*x35)**2             # <<<<<<<<<<<<<<
 *         cdef double x84 =-30720.0*x11*x19*x36 - 7680.0*x12*x36*x79 + x12*x83 + x77
 *         cdef double x85 =-x84
 */
  __Pyx_TraceLine(1802,0,__PYX_ERR(1, 1802, __pyx_L1_error))
  __pyx_v_x83 = (((1.31621673590926e-19 * __pyx_v_x11) * ((((((((53760.0 * __pyx_v_Nu) * (((((((((3740417.71815805 * __pyx_v_r) + (2115968.85907902 * __pyx_v_x0)) - (938918.400156317 * __pyx_v_x12)) + (1057984.42953951 * __pyx_v_x19)) + (__pyx_v_x30 * (__pyx_v_x81 + __pyx_v_x82))) + (__pyx_v_x31 * ((((17058.7851094412 * __pyx_v_r) + (12794.0888320809 * __pyx_v_x0)) - (27409.3925547206 * __pyx_v_x19)) + 13218.7851094412))) + (__pyx_v_x33 * ((((5778.0 * __pyx_v_x0) + (1396.0 * __pyx_v_x19)) + __pyx_v_x32) + 7704.0))) + (__pyx_v_x34 * ((-__pyx_v_x81) + __pyx_v_x82))) + 2888096.47013111)) + (66060288000.0 * __pyx_v_x12)) + ((7.0 * __pyx_v_x17) * ((-5706642207.53758 * __pyx_v_r) - 26189434371.6082))) + ((32768.0 * __pyx_v_x24) * __pyx_v_x78)) + ((32768.0 * __pyx_v_x25) * (((((((-1791904.9465589 * __pyx_v_Nu) + ((3840.0 * __pyx_v_r) * __pyx_v_x21)) + ((2880.0 * __pyx_v_x0) * __pyx_v_x22)) + (806400.0 * __pyx_v_x12)) + (1920.0 * __pyx_v_x23)) - (725760.0 * __pyx_v_x7)) + 4143360.0))) + ((7.0 * __pyx_v_x7) * ((((((-117964800.0 * __pyx_v_a6) + (4129567622.65173 * __pyx_v_r)) - (18535504222.6128 * __pyx_v_x0)) + (7133302759.42198 * __pyx_v_x12)) - (12357002815.0752 * __pyx_v_x19)) + 122635399361.987))) + ((135291469824.0 * __pyx_v_x8) * __pyx_v_x80))) / pow(((((((__pyx_v_x13 + (0.0546957463279941 * __pyx_v_x14)) + (0.28004222119933 * __pyx_v_x16)) + (4.63661586574928e-9 * __pyx_v_x18)) + (2.8978849160933e-11 * __pyx_v_x20)) + (1.35654132757922e-7 * __pyx_v_x26)) + (2.22557561555966e-7 * __pyx_v_x35)), 2.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1803
 *         cdef double x82 =6.0*x0 + x27 + 8.0
 *         cdef double x83 =1.31621673590926e-19*x11*(53760.0*Nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x12 + 1057984.42953951*x19 + x30*(x81 + x82) + x31*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x19 + 13218.7851094412) + x33*(5778.0*x0 + 1396.0*x19 + x32 + 7704.0) + x34*(-x81 + x82) + 2888096.47013111) + 66060288000.0*x12 + 7.0*x17*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x24*x78 + 32768.0*x25*(-1791904.9465589*Nu + 3840.0*r*x21 + 2880.0*x0*x22 + 806400.0*x12 + 1920.0*x23 - 725760.0*x7 + 4143360.0) + 7.0*x7*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x12 - 12357002815.0752*x19 + 122635399361.987) + 135291469824.0*x8*x80)/(x13 + 0.0546957463279941*x14 + 0.28004222119933*x16 + 4.63661586574928e-9*x18 + 2.8978849160933e-11*x20 + 1.35654132757922e-7*x26 + 2.22557561555966e-7*x35)**2
 *         cdef double x84 =-30720.0*x11*x19*x36 - 7680.0*x12*x36*x79 + x12*x83 + x77             # <<<<<<<<<<<<<<
 *         cdef double x85 =-x84
 *         cdef double x86 =r*(-x39 + x65)
 */
  __Pyx_TraceLine(1803,0,__PYX_ERR(1, 1803, __pyx_L1_error))
  __pyx_v_x84 = ((((((-30720.0 * __pyx_v_x11) * __pyx_v_x19) * __pyx_v_x36) - (((7680.0 * __pyx_v_x12) * __pyx_v_x36) * __pyx_v_x79)) + (__pyx_v_x12 * __pyx_v_x83)) + __pyx_v_x77);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1804
 *         cdef double x83 =1.31621673590926e-19*x11*(53760.0*Nu*(3740417.71815805*r + 2115968.85907902*x0 - 938918.400156317*x12 + 1057984.42953951*x19 + x30*(x81 + x82) + x31*(17058.7851094412*r + 12794.0888320809*x0 - 27409.3925547206*x19 + 13218.7851094412) + x33*(5778.0*x0 + 1396.0*x19 + x32 + 7704.0) + x34*(-x81 + x82) + 2888096.47013111) + 66060288000.0*x12 + 7.0*x17*(-5706642207.53758*r - 26189434371.6082) + 32768.0*x24*x78 + 32768.0*x25*(-1791904.9465589*Nu + 3840.0*r*x21 + 2880.0*x0*x22 + 806400.0*x12 + 1920.0*x23 - 725760.0*x7 + 4143360.0) + 7.0*x7*(-117964800.0*a6 + 4129567622.65173*r - 18535504222.6128*x0 + 7133302759.42198*x12 - 12357002815.0752*x19 + 122635399361.987) + 135291469824.0*x8*x80)/(x13 + 0.0546957463279941*x14 + 0.28004222119933*x16 + 4.63661586574928e-9*x18 + 2.8978849160933e-11*x20 + 1.35654132757922e-7*x26 + 2.22557561555966e-7*x35)**2
 *         cdef double x84 =-30720.0*x11*x19*x36 - 7680.0*x12*x36*x79 + x12*x83 + x77
 *         cdef double x85 =-x84             # <<<<<<<<<<<<<<
 *         cdef double x86 =r*(-x39 + x65)
 *         cdef double x87 =1/x12
 */
  __Pyx_TraceLine(1804,0,__PYX_ERR(1, 1804, __pyx_L1_error))
  __pyx_v_x85 = (-__pyx_v_x84);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1805
 *         cdef double x84 =-30720.0*x11*x19*x36 - 7680.0*x12*x36*x79 + x12*x83 + x77
 *         cdef double x85 =-x84
 *         cdef double x86 =r*(-x39 + x65)             # <<<<<<<<<<<<<<
 *         cdef double x87 =1/x12
 *         cdef double x88 =3.0*x87
 */
  __Pyx_TraceLine(1805,0,__PYX_ERR(1, 1805, __pyx_L1_error))
  __pyx_v_x86 = (__pyx_v_r * ((-__pyx_v_x39) + __pyx_v_x65));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1806
 *         cdef double x85 =-x84
 *         cdef double x86 =r*(-x39 + x65)
 *         cdef double x87 =1/x12             # <<<<<<<<<<<<<<
 *         cdef double x88 =3.0*x87
 *         cdef double x89 =L*x4
 */
  __Pyx_TraceLine(1806,0,__PYX_ERR(1, 1806, __pyx_L1_error))
  __pyx_v_x87 = (1.0 / __pyx_v_x12);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1807
 *         cdef double x86 =r*(-x39 + x65)
 *         cdef double x87 =1/x12
 *         cdef double x88 =3.0*x87             # <<<<<<<<<<<<<<
 *         cdef double x89 =L*x4
 *         cdef double x90 =Nu*dSO*x89
 */
  __Pyx_TraceLine(1807,0,__PYX_ERR(1, 1807, __pyx_L1_error))
  __pyx_v_x88 = (3.0 * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1808
 *         cdef double x87 =1/x12
 *         cdef double x88 =3.0*x87
 *         cdef double x89 =L*x4             # <<<<<<<<<<<<<<
 *         cdef double x90 =Nu*dSO*x89
 *         cdef double x91 =x5*x76
 */
  __Pyx_TraceLine(1808,0,__PYX_ERR(1, 1808, __pyx_L1_error))
  __pyx_v_x89 = (__pyx_v_L * __pyx_v_x4);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1809
 *         cdef double x88 =3.0*x87
 *         cdef double x89 =L*x4
 *         cdef double x90 =Nu*dSO*x89             # <<<<<<<<<<<<<<
 *         cdef double x91 =x5*x76
 *         cdef double x92 =x2 - x3
 */
  __Pyx_TraceLine(1809,0,__PYX_ERR(1, 1809, __pyx_L1_error))
  __pyx_v_x90 = ((__pyx_v_Nu * __pyx_v_dSO) * __pyx_v_x89);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1810
 *         cdef double x89 =L*x4
 *         cdef double x90 =Nu*dSO*x89
 *         cdef double x91 =x5*x76             # <<<<<<<<<<<<<<
 *         cdef double x92 =x2 - x3
 *         cdef double x93 =X1 - X2
 */
  __Pyx_TraceLine(1810,0,__PYX_ERR(1, 1810, __pyx_L1_error))
  __pyx_v_x91 = (__pyx_v_x5 * __pyx_v_x76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1811
 *         cdef double x90 =Nu*dSO*x89
 *         cdef double x91 =x5*x76
 *         cdef double x92 =x2 - x3             # <<<<<<<<<<<<<<
 *         cdef double x93 =X1 - X2
 *         cdef double x94 =L*x92*x93
 */
  __Pyx_TraceLine(1811,0,__PYX_ERR(1, 1811, __pyx_L1_error))
  __pyx_v_x92 = (__pyx_v_x2 - __pyx_v_x3);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1812
 *         cdef double x91 =x5*x76
 *         cdef double x92 =x2 - x3
 *         cdef double x93 =X1 - X2             # <<<<<<<<<<<<<<
 *         cdef double x94 =L*x92*x93
 *         cdef double x95 =0.25*x5
 */
  __Pyx_TraceLine(1812,0,__PYX_ERR(1, 1812, __pyx_L1_error))
  __pyx_v_x93 = (__pyx_v_X1 - __pyx_v_X2);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1813
 *         cdef double x92 =x2 - x3
 *         cdef double x93 =X1 - X2
 *         cdef double x94 =L*x92*x93             # <<<<<<<<<<<<<<
 *         cdef double x95 =0.25*x5
 *         cdef double x96 =x4*x92
 */
  __Pyx_TraceLine(1813,0,__PYX_ERR(1, 1813, __pyx_L1_error))
  __pyx_v_x94 = ((__pyx_v_L * __pyx_v_x92) * __pyx_v_x93);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1814
 *         cdef double x93 =X1 - X2
 *         cdef double x94 =L*x92*x93
 *         cdef double x95 =0.25*x5             # <<<<<<<<<<<<<<
 *         cdef double x96 =x4*x92
 *         cdef double x97 =x89*(-x95 + x96*(0.208333333333333*X1 - 0.208333333333333*X2))
 */
  __Pyx_TraceLine(1814,0,__PYX_ERR(1, 1814, __pyx_L1_error))
  __pyx_v_x95 = (0.25 * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1815
 *         cdef double x94 =L*x92*x93
 *         cdef double x95 =0.25*x5
 *         cdef double x96 =x4*x92             # <<<<<<<<<<<<<<
 *         cdef double x97 =x89*(-x95 + x96*(0.208333333333333*X1 - 0.208333333333333*X2))
 *         cdef double x98 =2.0*x76
 */
  __Pyx_TraceLine(1815,0,__PYX_ERR(1, 1815, __pyx_L1_error))
  __pyx_v_x96 = (__pyx_v_x4 * __pyx_v_x92);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1816
 *         cdef double x95 =0.25*x5
 *         cdef double x96 =x4*x92
 *         cdef double x97 =x89*(-x95 + x96*(0.208333333333333*X1 - 0.208333333333333*X2))             # <<<<<<<<<<<<<<
 *         cdef double x98 =2.0*x76
 *         cdef double x99 =0.71875*Nu - 0.09375
 */
  __Pyx_TraceLine(1816,0,__PYX_ERR(1, 1816, __pyx_L1_error))
  __pyx_v_x97 = (__pyx_v_x89 * ((-__pyx_v_x95) + (__pyx_v_x96 * ((0.208333333333333 * __pyx_v_X1) - (0.208333333333333 * __pyx_v_X2)))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1817
 *         cdef double x96 =x4*x92
 *         cdef double x97 =x89*(-x95 + x96*(0.208333333333333*X1 - 0.208333333333333*X2))
 *         cdef double x98 =2.0*x76             # <<<<<<<<<<<<<<
 *         cdef double x99 =0.71875*Nu - 0.09375
 *         cdef double x100 =-1.40625*Nu - 0.46875
 */
  __Pyx_TraceLine(1817,0,__PYX_ERR(1, 1817, __pyx_L1_error))
  __pyx_v_x98 = (2.0 * __pyx_v_x76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1818
 *         cdef double x97 =x89*(-x95 + x96*(0.208333333333333*X1 - 0.208333333333333*X2))
 *         cdef double x98 =2.0*x76
 *         cdef double x99 =0.71875*Nu - 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x100 =-1.40625*Nu - 0.46875
 *         cdef double x101 =L**2
 */
  __Pyx_TraceLine(1818,0,__PYX_ERR(1, 1818, __pyx_L1_error))
  __pyx_v_x99 = ((0.71875 * __pyx_v_Nu) - 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1819
 *         cdef double x98 =2.0*x76
 *         cdef double x99 =0.71875*Nu - 0.09375
 *         cdef double x100 =-1.40625*Nu - 0.46875             # <<<<<<<<<<<<<<
 *         cdef double x101 =L**2
 *         cdef double x102 =x101*x76
 */
  __Pyx_TraceLine(1819,0,__PYX_ERR(1, 1819, __pyx_L1_error))
  __pyx_v_x100 = ((-1.40625 * __pyx_v_Nu) - 0.46875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1820
 *         cdef double x99 =0.71875*Nu - 0.09375
 *         cdef double x100 =-1.40625*Nu - 0.46875
 *         cdef double x101 =L**2             # <<<<<<<<<<<<<<
 *         cdef double x102 =x101*x76
 *         cdef double x103 =2.0*x102
 */
  __Pyx_TraceLine(1820,0,__PYX_ERR(1, 1820, __pyx_L1_error))
  __pyx_v_x101 = pow(__pyx_v_L, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1821
 *         cdef double x100 =-1.40625*Nu - 0.46875
 *         cdef double x101 =L**2
 *         cdef double x102 =x101*x76             # <<<<<<<<<<<<<<
 *         cdef double x103 =2.0*x102
 *         cdef double x104 =-2.0859375*Nu - 2.07161458333333*x7 + 0.23046875
 */
  __Pyx_TraceLine(1821,0,__PYX_ERR(1, 1821, __pyx_L1_error))
  __pyx_v_x102 = (__pyx_v_x101 * __pyx_v_x76);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1822
 *         cdef double x101 =L**2
 *         cdef double x102 =x101*x76
 *         cdef double x103 =2.0*x102             # <<<<<<<<<<<<<<
 *         cdef double x104 =-2.0859375*Nu - 2.07161458333333*x7 + 0.23046875
 *         cdef double x105 =x101*x88
 */
  __Pyx_TraceLine(1822,0,__PYX_ERR(1, 1822, __pyx_L1_error))
  __pyx_v_x103 = (2.0 * __pyx_v_x102);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1823
 *         cdef double x102 =x101*x76
 *         cdef double x103 =2.0*x102
 *         cdef double x104 =-2.0859375*Nu - 2.07161458333333*x7 + 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x105 =x101*x88
 *         cdef double x106 =0.5859375*Nu + 1.34765625*x7 + 0.41015625
 */
  __Pyx_TraceLine(1823,0,__PYX_ERR(1, 1823, __pyx_L1_error))
  __pyx_v_x104 = (((-2.0859375 * __pyx_v_Nu) - (2.07161458333333 * __pyx_v_x7)) + 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1824
 *         cdef double x103 =2.0*x102
 *         cdef double x104 =-2.0859375*Nu - 2.07161458333333*x7 + 0.23046875
 *         cdef double x105 =x101*x88             # <<<<<<<<<<<<<<
 *         cdef double x106 =0.5859375*Nu + 1.34765625*x7 + 0.41015625
 *         cdef double x107 =L**4
 */
  __Pyx_TraceLine(1824,0,__PYX_ERR(1, 1824, __pyx_L1_error))
  __pyx_v_x105 = (__pyx_v_x101 * __pyx_v_x88);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1825
 *         cdef double x104 =-2.0859375*Nu - 2.07161458333333*x7 + 0.23046875
 *         cdef double x105 =x101*x88
 *         cdef double x106 =0.5859375*Nu + 1.34765625*x7 + 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x107 =L**4
 *         cdef double x108 =1/x14
 */
  __Pyx_TraceLine(1825,0,__PYX_ERR(1, 1825, __pyx_L1_error))
  __pyx_v_x106 = (((0.5859375 * __pyx_v_Nu) + (1.34765625 * __pyx_v_x7)) + 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1826
 *         cdef double x105 =x101*x88
 *         cdef double x106 =0.5859375*Nu + 1.34765625*x7 + 0.41015625
 *         cdef double x107 =L**4             # <<<<<<<<<<<<<<
 *         cdef double x108 =1/x14
 *         cdef double x109 =4.0*x108
 */
  __Pyx_TraceLine(1826,0,__PYX_ERR(1, 1826, __pyx_L1_error))
  __pyx_v_x107 = pow(__pyx_v_L, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1827
 *         cdef double x106 =0.5859375*Nu + 1.34765625*x7 + 0.41015625
 *         cdef double x107 =L**4
 *         cdef double x108 =1/x14             # <<<<<<<<<<<<<<
 *         cdef double x109 =4.0*x108
 *         cdef double x110 =x107*x109
 */
  __Pyx_TraceLine(1827,0,__PYX_ERR(1, 1827, __pyx_L1_error))
  __pyx_v_x108 = (1.0 / __pyx_v_x14);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1828
 *         cdef double x107 =L**4
 *         cdef double x108 =1/x14
 *         cdef double x109 =4.0*x108             # <<<<<<<<<<<<<<
 *         cdef double x110 =x107*x109
 *         cdef double x111 =0.34375*Nu + 0.09375
 */
  __Pyx_TraceLine(1828,0,__PYX_ERR(1, 1828, __pyx_L1_error))
  __pyx_v_x109 = (4.0 * __pyx_v_x108);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1829
 *         cdef double x108 =1/x14
 *         cdef double x109 =4.0*x108
 *         cdef double x110 =x107*x109             # <<<<<<<<<<<<<<
 *         cdef double x111 =0.34375*Nu + 0.09375
 *         cdef double x112 =0.46875 - 0.28125*Nu
 */
  __Pyx_TraceLine(1829,0,__PYX_ERR(1, 1829, __pyx_L1_error))
  __pyx_v_x110 = (__pyx_v_x107 * __pyx_v_x109);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1830
 *         cdef double x109 =4.0*x108
 *         cdef double x110 =x107*x109
 *         cdef double x111 =0.34375*Nu + 0.09375             # <<<<<<<<<<<<<<
 *         cdef double x112 =0.46875 - 0.28125*Nu
 *         cdef double x113 =0.0625*Nu
 */
  __Pyx_TraceLine(1830,0,__PYX_ERR(1, 1830, __pyx_L1_error))
  __pyx_v_x111 = ((0.34375 * __pyx_v_Nu) + 0.09375);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1831
 *         cdef double x110 =x107*x109
 *         cdef double x111 =0.34375*Nu + 0.09375
 *         cdef double x112 =0.46875 - 0.28125*Nu             # <<<<<<<<<<<<<<
 *         cdef double x113 =0.0625*Nu
 *         cdef double x114 =-0.2734375*Nu - 0.798177083333333*x7 - 0.23046875
 */
  __Pyx_TraceLine(1831,0,__PYX_ERR(1, 1831, __pyx_L1_error))
  __pyx_v_x112 = (0.46875 - (0.28125 * __pyx_v_Nu));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1832
 *         cdef double x111 =0.34375*Nu + 0.09375
 *         cdef double x112 =0.46875 - 0.28125*Nu
 *         cdef double x113 =0.0625*Nu             # <<<<<<<<<<<<<<
 *         cdef double x114 =-0.2734375*Nu - 0.798177083333333*x7 - 0.23046875
 *         cdef double x115 =-0.3515625*Nu + 0.29296875*x7 - 0.41015625
 */
  __Pyx_TraceLine(1832,0,__PYX_ERR(1, 1832, __pyx_L1_error))
  __pyx_v_x113 = (0.0625 * __pyx_v_Nu);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1833
 *         cdef double x112 =0.46875 - 0.28125*Nu
 *         cdef double x113 =0.0625*Nu
 *         cdef double x114 =-0.2734375*Nu - 0.798177083333333*x7 - 0.23046875             # <<<<<<<<<<<<<<
 *         cdef double x115 =-0.3515625*Nu + 0.29296875*x7 - 0.41015625
 *         cdef double x116 =x1*x101
 */
  __Pyx_TraceLine(1833,0,__PYX_ERR(1, 1833, __pyx_L1_error))
  __pyx_v_x114 = (((-0.2734375 * __pyx_v_Nu) - (0.798177083333333 * __pyx_v_x7)) - 0.23046875);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1834
 *         cdef double x113 =0.0625*Nu
 *         cdef double x114 =-0.2734375*Nu - 0.798177083333333*x7 - 0.23046875
 *         cdef double x115 =-0.3515625*Nu + 0.29296875*x7 - 0.41015625             # <<<<<<<<<<<<<<
 *         cdef double x116 =x1*x101
 *         cdef double x117 =x107*x87
 */
  __Pyx_TraceLine(1834,0,__PYX_ERR(1, 1834, __pyx_L1_error))
  __pyx_v_x115 = (((-0.3515625 * __pyx_v_Nu) + (0.29296875 * __pyx_v_x7)) - 0.41015625);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1835
 *         cdef double x114 =-0.2734375*Nu - 0.798177083333333*x7 - 0.23046875
 *         cdef double x115 =-0.3515625*Nu + 0.29296875*x7 - 0.41015625
 *         cdef double x116 =x1*x101             # <<<<<<<<<<<<<<
 *         cdef double x117 =x107*x87
 *         cdef double x118 =prst**3
 */
  __Pyx_TraceLine(1835,0,__PYX_ERR(1, 1835, __pyx_L1_error))
  __pyx_v_x116 = (__pyx_v_x1 * __pyx_v_x101);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1836
 *         cdef double x115 =-0.3515625*Nu + 0.29296875*x7 - 0.41015625
 *         cdef double x116 =x1*x101
 *         cdef double x117 =x107*x87             # <<<<<<<<<<<<<<
 *         cdef double x118 =prst**3
 *         cdef double x119 =r**(-4.5)
 */
  __Pyx_TraceLine(1836,0,__PYX_ERR(1, 1836, __pyx_L1_error))
  __pyx_v_x117 = (__pyx_v_x107 * __pyx_v_x87);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1837
 *         cdef double x116 =x1*x101
 *         cdef double x117 =x107*x87
 *         cdef double x118 =prst**3             # <<<<<<<<<<<<<<
 *         cdef double x119 =r**(-4.5)
 *         cdef double x120 =prst**5
 */
  __Pyx_TraceLine(1837,0,__PYX_ERR(1, 1837, __pyx_L1_error))
  __pyx_v_x118 = pow(__pyx_v_prst, 3.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1838
 *         cdef double x117 =x107*x87
 *         cdef double x118 =prst**3
 *         cdef double x119 =r**(-4.5)             # <<<<<<<<<<<<<<
 *         cdef double x120 =prst**5
 *         cdef double x121 =Nu*r**(-3.5)
 */
  __Pyx_TraceLine(1838,0,__PYX_ERR(1, 1838, __pyx_L1_error))
  __pyx_v_x119 = pow(__pyx_v_r, -4.5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1839
 *         cdef double x118 =prst**3
 *         cdef double x119 =r**(-4.5)
 *         cdef double x120 =prst**5             # <<<<<<<<<<<<<<
 *         cdef double x121 =Nu*r**(-3.5)
 *         cdef double x122 =prst**7
 */
  __Pyx_TraceLine(1839,0,__PYX_ERR(1, 1839, __pyx_L1_error))
  __pyx_v_x120 = pow(__pyx_v_prst, 5.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1840
 *         cdef double x119 =r**(-4.5)
 *         cdef double x120 =prst**5
 *         cdef double x121 =Nu*r**(-3.5)             # <<<<<<<<<<<<<<
 *         cdef double x122 =prst**7
 *         cdef double x123 =8.0*Nu - 6.0*x7
 */
  __Pyx_TraceLine(1840,0,__PYX_ERR(1, 1840, __pyx_L1_error))
  __pyx_t_13 = __Pyx_SoftComplexToDouble(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts(__pyx_v_Nu, 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-3.5, 0))), 1); if (unlikely(__pyx_t_13 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1840, __pyx_L1_error)
  __pyx_v_x121 = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1841
 *         cdef double x120 =prst**5
 *         cdef double x121 =Nu*r**(-3.5)
 *         cdef double x122 =prst**7             # <<<<<<<<<<<<<<
 *         cdef double x123 =8.0*Nu - 6.0*x7
 *         cdef double x124 =4.0*x118
 */
  __Pyx_TraceLine(1841,0,__PYX_ERR(1, 1841, __pyx_L1_error))
  __pyx_v_x122 = pow(__pyx_v_prst, 7.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1842
 *         cdef double x121 =Nu*r**(-3.5)
 *         cdef double x122 =prst**7
 *         cdef double x123 =8.0*Nu - 6.0*x7             # <<<<<<<<<<<<<<
 *         cdef double x124 =4.0*x118
 *         cdef double x125 =92.7110442849544*Nu + 10.0*x17 - 131.0*x7
 */
  __Pyx_TraceLine(1842,0,__PYX_ERR(1, 1842, __pyx_L1_error))
  __pyx_v_x123 = ((8.0 * __pyx_v_Nu) - (6.0 * __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1843
 *         cdef double x122 =prst**7
 *         cdef double x123 =8.0*Nu - 6.0*x7
 *         cdef double x124 =4.0*x118             # <<<<<<<<<<<<<<
 *         cdef double x125 =92.7110442849544*Nu + 10.0*x17 - 131.0*x7
 *         cdef double x126 =-2.78300763695006*Nu + 6.0*x17 - 5.4*x7
 */
  __Pyx_TraceLine(1843,0,__PYX_ERR(1, 1843, __pyx_L1_error))
  __pyx_v_x124 = (4.0 * __pyx_v_x118);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1844
 *         cdef double x123 =8.0*Nu - 6.0*x7
 *         cdef double x124 =4.0*x118
 *         cdef double x125 =92.7110442849544*Nu + 10.0*x17 - 131.0*x7             # <<<<<<<<<<<<<<
 *         cdef double x126 =-2.78300763695006*Nu + 6.0*x17 - 5.4*x7
 *         cdef double x127 =6.0*x120
 */
  __Pyx_TraceLine(1844,0,__PYX_ERR(1, 1844, __pyx_L1_error))
  __pyx_v_x125 = (((92.7110442849544 * __pyx_v_Nu) + (10.0 * __pyx_v_x17)) - (131.0 * __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1845
 *         cdef double x124 =4.0*x118
 *         cdef double x125 =92.7110442849544*Nu + 10.0*x17 - 131.0*x7
 *         cdef double x126 =-2.78300763695006*Nu + 6.0*x17 - 5.4*x7             # <<<<<<<<<<<<<<
 *         cdef double x127 =6.0*x120
 *         cdef double x128 =-33.9782122170436*Nu - 14.0*x13 + 188.0*x17 - 89.5298327361234*x7
 */
  __Pyx_TraceLine(1845,0,__PYX_ERR(1, 1845, __pyx_L1_error))
  __pyx_v_x126 = (((-2.78300763695006 * __pyx_v_Nu) + (6.0 * __pyx_v_x17)) - (5.4 * __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1846
 *         cdef double x125 =92.7110442849544*Nu + 10.0*x17 - 131.0*x7
 *         cdef double x126 =-2.78300763695006*Nu + 6.0*x17 - 5.4*x7
 *         cdef double x127 =6.0*x120             # <<<<<<<<<<<<<<
 *         cdef double x128 =-33.9782122170436*Nu - 14.0*x13 + 188.0*x17 - 89.5298327361234*x7
 *         cdef double x129 =1.38977750996128*Nu - 6.0*x13 + 3.42857142857143*x17 + 3.33842023648322*x7
 */
  __Pyx_TraceLine(1846,0,__PYX_ERR(1, 1846, __pyx_L1_error))
  __pyx_v_x127 = (6.0 * __pyx_v_x120);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1847
 *         cdef double x126 =-2.78300763695006*Nu + 6.0*x17 - 5.4*x7
 *         cdef double x127 =6.0*x120
 *         cdef double x128 =-33.9782122170436*Nu - 14.0*x13 + 188.0*x17 - 89.5298327361234*x7             # <<<<<<<<<<<<<<
 *         cdef double x129 =1.38977750996128*Nu - 6.0*x13 + 3.42857142857143*x17 + 3.33842023648322*x7
 *         cdef double x130 =Nu*(452.542166996693 - 51.6952380952381*x8) + 602.318540416564*x17 + x7*(118.4*x8 - 1796.13660498019)
 */
  __Pyx_TraceLine(1847,0,__PYX_ERR(1, 1847, __pyx_L1_error))
  __pyx_v_x128 = ((((-33.9782122170436 * __pyx_v_Nu) - (14.0 * __pyx_v_x13)) + (188.0 * __pyx_v_x17)) - (89.5298327361234 * __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1848
 *         cdef double x127 =6.0*x120
 *         cdef double x128 =-33.9782122170436*Nu - 14.0*x13 + 188.0*x17 - 89.5298327361234*x7
 *         cdef double x129 =1.38977750996128*Nu - 6.0*x13 + 3.42857142857143*x17 + 3.33842023648322*x7             # <<<<<<<<<<<<<<
 *         cdef double x130 =Nu*(452.542166996693 - 51.6952380952381*x8) + 602.318540416564*x17 + x7*(118.4*x8 - 1796.13660498019)
 *         cdef double x131 =r**(-13)
 */
  __Pyx_TraceLine(1848,0,__PYX_ERR(1, 1848, __pyx_L1_error))
  __pyx_v_x129 = ((((1.38977750996128 * __pyx_v_Nu) - (6.0 * __pyx_v_x13)) + (3.42857142857143 * __pyx_v_x17)) + (3.33842023648322 * __pyx_v_x7));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1849
 *         cdef double x128 =-33.9782122170436*Nu - 14.0*x13 + 188.0*x17 - 89.5298327361234*x7
 *         cdef double x129 =1.38977750996128*Nu - 6.0*x13 + 3.42857142857143*x17 + 3.33842023648322*x7
 *         cdef double x130 =Nu*(452.542166996693 - 51.6952380952381*x8) + 602.318540416564*x17 + x7*(118.4*x8 - 1796.13660498019)             # <<<<<<<<<<<<<<
 *         cdef double x131 =r**(-13)
 *         cdef double x132 =x65**4
 */
  __Pyx_TraceLine(1849,0,__PYX_ERR(1, 1849, __pyx_L1_error))
  __pyx_v_x130 = (((__pyx_v_Nu * (452.542166996693 - (51.6952380952381 * __pyx_v_x8))) + (602.318540416564 * __pyx_v_x17)) + (__pyx_v_x7 * ((118.4 * __pyx_v_x8) - 1796.13660498019)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1850
 *         cdef double x129 =1.38977750996128*Nu - 6.0*x13 + 3.42857142857143*x17 + 3.33842023648322*x7
 *         cdef double x130 =Nu*(452.542166996693 - 51.6952380952381*x8) + 602.318540416564*x17 + x7*(118.4*x8 - 1796.13660498019)
 *         cdef double x131 =r**(-13)             # <<<<<<<<<<<<<<
 *         cdef double x132 =x65**4
 *         cdef double x133 =x37 + 0.000130208333333333*x6
 */
  __Pyx_TraceLine(1850,0,__PYX_ERR(1, 1850, __pyx_L1_error))
  __pyx_v_x131 = pow(__pyx_v_r, -13.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1851
 *         cdef double x130 =Nu*(452.542166996693 - 51.6952380952381*x8) + 602.318540416564*x17 + x7*(118.4*x8 - 1796.13660498019)
 *         cdef double x131 =r**(-13)
 *         cdef double x132 =x65**4             # <<<<<<<<<<<<<<
 *         cdef double x133 =x37 + 0.000130208333333333*x6
 *         cdef double x134 =x133**(-4)
 */
  __Pyx_TraceLine(1851,0,__PYX_ERR(1, 1851, __pyx_L1_error))
  __pyx_v_x132 = pow(__pyx_v_x65, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1852
 *         cdef double x131 =r**(-13)
 *         cdef double x132 =x65**4
 *         cdef double x133 =x37 + 0.000130208333333333*x6             # <<<<<<<<<<<<<<
 *         cdef double x134 =x133**(-4)
 *         cdef double x135 =-0.0438084424460039*Nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0210425293255724*x15 + 0.0244692826489756*x17 + 0.0385795738434214*x40 + 0.00941289164152486*x41 - 1.18824456940711e-6*x45 + 0.000486339502879429*x46 + 0.00662650629087394*x69 + 0.291062041428379*x7 - x8*(-0.092318048431871*Nu - 0.0031990331744958*x0 - 1.02928995318398e-6*x45 - 0.0183295954863003*x7 + 0.378777244139245) + 1.0
 */
  __Pyx_TraceLine(1852,0,__PYX_ERR(1, 1852, __pyx_L1_error))
  __pyx_v_x133 = (__pyx_v_x37 + (0.000130208333333333 * __pyx_v_x6));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1853
 *         cdef double x132 =x65**4
 *         cdef double x133 =x37 + 0.000130208333333333*x6
 *         cdef double x134 =x133**(-4)             # <<<<<<<<<<<<<<
 *         cdef double x135 =-0.0438084424460039*Nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0210425293255724*x15 + 0.0244692826489756*x17 + 0.0385795738434214*x40 + 0.00941289164152486*x41 - 1.18824456940711e-6*x45 + 0.000486339502879429*x46 + 0.00662650629087394*x69 + 0.291062041428379*x7 - x8*(-0.092318048431871*Nu - 0.0031990331744958*x0 - 1.02928995318398e-6*x45 - 0.0183295954863003*x7 + 0.378777244139245) + 1.0
 *         cdef double x136 =x135**(-2)
 */
  __Pyx_TraceLine(1853,0,__PYX_ERR(1, 1853, __pyx_L1_error))
  __pyx_v_x134 = pow(__pyx_v_x133, -4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1854
 *         cdef double x133 =x37 + 0.000130208333333333*x6
 *         cdef double x134 =x133**(-4)
 *         cdef double x135 =-0.0438084424460039*Nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0210425293255724*x15 + 0.0244692826489756*x17 + 0.0385795738434214*x40 + 0.00941289164152486*x41 - 1.18824456940711e-6*x45 + 0.000486339502879429*x46 + 0.00662650629087394*x69 + 0.291062041428379*x7 - x8*(-0.092318048431871*Nu - 0.0031990331744958*x0 - 1.02928995318398e-6*x45 - 0.0183295954863003*x7 + 0.378777244139245) + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x136 =x135**(-2)
 *         cdef double x137 =4.0*x7
 */
  __Pyx_TraceLine(1854,0,__PYX_ERR(1, 1854, __pyx_L1_error))
  __pyx_v_x135 = (((((((((((((-0.0438084424460039 * __pyx_v_Nu) - (0.143521050466841 * __pyx_v_r)) + (0.0185696317637669 * __pyx_v_x0)) + (0.0210425293255724 * __pyx_v_x15)) + (0.0244692826489756 * __pyx_v_x17)) + (0.0385795738434214 * __pyx_v_x40)) + (0.00941289164152486 * __pyx_v_x41)) - (1.18824456940711e-6 * __pyx_v_x45)) + (0.000486339502879429 * __pyx_v_x46)) + (0.00662650629087394 * __pyx_v_x69)) + (0.291062041428379 * __pyx_v_x7)) - (__pyx_v_x8 * (((((-0.092318048431871 * __pyx_v_Nu) - (0.0031990331744958 * __pyx_v_x0)) - (1.02928995318398e-6 * __pyx_v_x45)) - (0.0183295954863003 * __pyx_v_x7)) + 0.378777244139245))) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1855
 *         cdef double x134 =x133**(-4)
 *         cdef double x135 =-0.0438084424460039*Nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0210425293255724*x15 + 0.0244692826489756*x17 + 0.0385795738434214*x40 + 0.00941289164152486*x41 - 1.18824456940711e-6*x45 + 0.000486339502879429*x46 + 0.00662650629087394*x69 + 0.291062041428379*x7 - x8*(-0.092318048431871*Nu - 0.0031990331744958*x0 - 1.02928995318398e-6*x45 - 0.0183295954863003*x7 + 0.378777244139245) + 1.0
 *         cdef double x136 =x135**(-2)             # <<<<<<<<<<<<<<
 *         cdef double x137 =4.0*x7
 *         cdef double x138 =x92**2
 */
  __Pyx_TraceLine(1855,0,__PYX_ERR(1, 1855, __pyx_L1_error))
  __pyx_v_x136 = pow(__pyx_v_x135, -2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1856
 *         cdef double x135 =-0.0438084424460039*Nu - 0.143521050466841*r + 0.0185696317637669*x0 + 0.0210425293255724*x15 + 0.0244692826489756*x17 + 0.0385795738434214*x40 + 0.00941289164152486*x41 - 1.18824456940711e-6*x45 + 0.000486339502879429*x46 + 0.00662650629087394*x69 + 0.291062041428379*x7 - x8*(-0.092318048431871*Nu - 0.0031990331744958*x0 - 1.02928995318398e-6*x45 - 0.0183295954863003*x7 + 0.378777244139245) + 1.0
 *         cdef double x136 =x135**(-2)
 *         cdef double x137 =4.0*x7             # <<<<<<<<<<<<<<
 *         cdef double x138 =x92**2
 *         cdef double x139 =5.0*X1 - 5.0*X2
 */
  __Pyx_TraceLine(1856,0,__PYX_ERR(1, 1856, __pyx_L1_error))
  __pyx_v_x137 = (4.0 * __pyx_v_x7);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1857
 *         cdef double x136 =x135**(-2)
 *         cdef double x137 =4.0*x7
 *         cdef double x138 =x92**2             # <<<<<<<<<<<<<<
 *         cdef double x139 =5.0*X1 - 5.0*X2
 *         cdef double x140 =-0.46875*x138*(-5.0*Nu + x137 + 1.0) + x139*x4*x92*(1.125*Nu - 0.0625) - 0.15625*x5*(-33.0*Nu + 32.0*x7 - 5.0)
 */
  __Pyx_TraceLine(1857,0,__PYX_ERR(1, 1857, __pyx_L1_error))
  __pyx_v_x138 = pow(__pyx_v_x92, 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1858
 *         cdef double x137 =4.0*x7
 *         cdef double x138 =x92**2
 *         cdef double x139 =5.0*X1 - 5.0*X2             # <<<<<<<<<<<<<<
 *         cdef double x140 =-0.46875*x138*(-5.0*Nu + x137 + 1.0) + x139*x4*x92*(1.125*Nu - 0.0625) - 0.15625*x5*(-33.0*Nu + 32.0*x7 - 5.0)
 *         cdef double x141 =x132*x134*x136*x140*x73
 */
  __Pyx_TraceLine(1858,0,__PYX_ERR(1, 1858, __pyx_L1_error))
  __pyx_v_x139 = ((5.0 * __pyx_v_X1) - (5.0 * __pyx_v_X2));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1859
 *         cdef double x138 =x92**2
 *         cdef double x139 =5.0*X1 - 5.0*X2
 *         cdef double x140 =-0.46875*x138*(-5.0*Nu + x137 + 1.0) + x139*x4*x92*(1.125*Nu - 0.0625) - 0.15625*x5*(-33.0*Nu + 32.0*x7 - 5.0)             # <<<<<<<<<<<<<<
 *         cdef double x141 =x132*x134*x136*x140*x73
 *         cdef double x142 =prst**4
 */
  __Pyx_TraceLine(1859,0,__PYX_ERR(1, 1859, __pyx_L1_error))
  __pyx_v_x140 = ((((-0.46875 * __pyx_v_x138) * (((-5.0 * __pyx_v_Nu) + __pyx_v_x137) + 1.0)) + (((__pyx_v_x139 * __pyx_v_x4) * __pyx_v_x92) * ((1.125 * __pyx_v_Nu) - 0.0625))) - ((0.15625 * __pyx_v_x5) * (((-33.0 * __pyx_v_Nu) + (32.0 * __pyx_v_x7)) - 5.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1860
 *         cdef double x139 =5.0*X1 - 5.0*X2
 *         cdef double x140 =-0.46875*x138*(-5.0*Nu + x137 + 1.0) + x139*x4*x92*(1.125*Nu - 0.0625) - 0.15625*x5*(-33.0*Nu + 32.0*x7 - 5.0)
 *         cdef double x141 =x132*x134*x136*x140*x73             # <<<<<<<<<<<<<<
 *         cdef double x142 =prst**4
 *         cdef double x143 =prst**6
 */
  __Pyx_TraceLine(1860,0,__PYX_ERR(1, 1860, __pyx_L1_error))
  __pyx_v_x141 = ((((__pyx_v_x132 * __pyx_v_x134) * __pyx_v_x136) * __pyx_v_x140) * __pyx_v_x73);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1861
 *         cdef double x140 =-0.46875*x138*(-5.0*Nu + x137 + 1.0) + x139*x4*x92*(1.125*Nu - 0.0625) - 0.15625*x5*(-33.0*Nu + 32.0*x7 - 5.0)
 *         cdef double x141 =x132*x134*x136*x140*x73
 *         cdef double x142 =prst**4             # <<<<<<<<<<<<<<
 *         cdef double x143 =prst**6
 *         cdef double x144 =prst**8
 */
  __Pyx_TraceLine(1861,0,__PYX_ERR(1, 1861, __pyx_L1_error))
  __pyx_v_x142 = pow(__pyx_v_prst, 4.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1862
 *         cdef double x141 =x132*x134*x136*x140*x73
 *         cdef double x142 =prst**4
 *         cdef double x143 =prst**6             # <<<<<<<<<<<<<<
 *         cdef double x144 =prst**8
 *         cdef double x145 =r + 2.0
 */
  __Pyx_TraceLine(1862,0,__PYX_ERR(1, 1862, __pyx_L1_error))
  __pyx_v_x143 = pow(__pyx_v_prst, 6.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1863
 *         cdef double x142 =prst**4
 *         cdef double x143 =prst**6
 *         cdef double x144 =prst**8             # <<<<<<<<<<<<<<
 *         cdef double x145 =r + 2.0
 *         cdef double x146 =r*x5
 */
  __Pyx_TraceLine(1863,0,__PYX_ERR(1, 1863, __pyx_L1_error))
  __pyx_v_x144 = pow(__pyx_v_prst, 8.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1864
 *         cdef double x143 =prst**6
 *         cdef double x144 =prst**8
 *         cdef double x145 =r + 2.0             # <<<<<<<<<<<<<<
 *         cdef double x146 =r*x5
 *         cdef double x147 =x12 + x145*x146
 */
  __Pyx_TraceLine(1864,0,__PYX_ERR(1, 1864, __pyx_L1_error))
  __pyx_v_x145 = (__pyx_v_r + 2.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1865
 *         cdef double x144 =prst**8
 *         cdef double x145 =r + 2.0
 *         cdef double x146 =r*x5             # <<<<<<<<<<<<<<
 *         cdef double x147 =x12 + x145*x146
 *         cdef double x148 =1/x147
 */
  __Pyx_TraceLine(1865,0,__PYX_ERR(1, 1865, __pyx_L1_error))
  __pyx_v_x146 = (__pyx_v_r * __pyx_v_x5);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1866
 *         cdef double x145 =r + 2.0
 *         cdef double x146 =r*x5
 *         cdef double x147 =x12 + x145*x146             # <<<<<<<<<<<<<<
 *         cdef double x148 =1/x147
 *         cdef double x149 =x6*(2.0*x70 + 1.0) + 1.0
 */
  __Pyx_TraceLine(1866,0,__PYX_ERR(1, 1866, __pyx_L1_error))
  __pyx_v_x147 = (__pyx_v_x12 + (__pyx_v_x145 * __pyx_v_x146));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1867
 *         cdef double x146 =r*x5
 *         cdef double x147 =x12 + x145*x146
 *         cdef double x148 =1/x147             # <<<<<<<<<<<<<<
 *         cdef double x149 =x6*(2.0*x70 + 1.0) + 1.0
 *         cdef double x150 =x138*(-27.0*Nu + 28.0*x7 - 3.0)
 */
  __Pyx_TraceLine(1867,0,__PYX_ERR(1, 1867, __pyx_L1_error))
  __pyx_v_x148 = (1.0 / __pyx_v_x147);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1868
 *         cdef double x147 =x12 + x145*x146
 *         cdef double x148 =1/x147
 *         cdef double x149 =x6*(2.0*x70 + 1.0) + 1.0             # <<<<<<<<<<<<<<
 *         cdef double x150 =x138*(-27.0*Nu + 28.0*x7 - 3.0)
 *         cdef double x151 =x96*(-39.0*X1 + 39.0*X2)
 */
  __Pyx_TraceLine(1868,0,__PYX_ERR(1, 1868, __pyx_L1_error))
  __pyx_v_x149 = ((__pyx_v_x6 * ((2.0 * __pyx_v_x70) + 1.0)) + 1.0);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1869
 *         cdef double x148 =1/x147
 *         cdef double x149 =x6*(2.0*x70 + 1.0) + 1.0
 *         cdef double x150 =x138*(-27.0*Nu + 28.0*x7 - 3.0)             # <<<<<<<<<<<<<<
 *         cdef double x151 =x96*(-39.0*X1 + 39.0*X2)
 *         cdef double dxidr=x0*x38*(r*x62*x72 - 2.98505426338587e-26*r*x75 + x63)/(x64*x68) + x0*x66*x85 - x28*x38*x64/x65**2 + x38*x39*x66
 */
  __Pyx_TraceLine(1869,0,__PYX_ERR(1, 1869, __pyx_L1_error))
  __pyx_v_x150 = (__pyx_v_x138 * (((-27.0 * __pyx_v_Nu) + (28.0 * __pyx_v_x7)) - 3.0));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1870
 *         cdef double x149 =x6*(2.0*x70 + 1.0) + 1.0
 *         cdef double x150 =x138*(-27.0*Nu + 28.0*x7 - 3.0)
 *         cdef double x151 =x96*(-39.0*X1 + 39.0*X2)             # <<<<<<<<<<<<<<
 *         cdef double dxidr=x0*x38*(r*x62*x72 - 2.98505426338587e-26*r*x75 + x63)/(x64*x68) + x0*x66*x85 - x28*x38*x64/x65**2 + x38*x39*x66
 *         cdef double dHodddr=(L*x4*(-x1*x99 - x100*x103 - x104*x105 - x106*x110 - x76*(-11.0625*Nu + 1.13541666666667*x7 - 0.15625)) + L*x92*x93*(-x1*x111 - x103*x112 - x105*x114 - x110*x115 - x76*(-x113 + 1.07291666666667*x7 + 0.15625)) - x88*x90 - 0.0833333333333333*x91*x94 - x97*x98)/(x68 + x86) - (0.25*r*(x39 - 2.0) + 0.5*r + 0.25*x0 + x95)*(x1*x97 + 0.0416666666666667*x6*x94 + x76*x90 + x89*(x1*(-5.53125*Nu + 0.567708333333333*x7 - 0.078125) + x100*x116 + x102*x104 + x106*x117 + x70*x99 + 1.75) + x94*(x1*(-0.03125*Nu + 0.536458333333333*x7 + 0.078125) + x102*x114 + x111*x70 + x112*x116 + x115*x117 + 0.25))/(x65 + 0.5*x86)**2
 */
  __Pyx_TraceLine(1870,0,__PYX_ERR(1, 1870, __pyx_L1_error))
  __pyx_v_x151 = (__pyx_v_x96 * ((-39.0 * __pyx_v_X1) + (39.0 * __pyx_v_X2)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1871
 *         cdef double x150 =x138*(-27.0*Nu + 28.0*x7 - 3.0)
 *         cdef double x151 =x96*(-39.0*X1 + 39.0*X2)
 *         cdef double dxidr=x0*x38*(r*x62*x72 - 2.98505426338587e-26*r*x75 + x63)/(x64*x68) + x0*x66*x85 - x28*x38*x64/x65**2 + x38*x39*x66             # <<<<<<<<<<<<<<
 *         cdef double dHodddr=(L*x4*(-x1*x99 - x100*x103 - x104*x105 - x106*x110 - x76*(-11.0625*Nu + 1.13541666666667*x7 - 0.15625)) + L*x92*x93*(-x1*x111 - x103*x112 - x105*x114 - x110*x115 - x76*(-x113 + 1.07291666666667*x7 + 0.15625)) - x88*x90 - 0.0833333333333333*x91*x94 - x97*x98)/(x68 + x86) - (0.25*r*(x39 - 2.0) + 0.5*r + 0.25*x0 + x95)*(x1*x97 + 0.0416666666666667*x6*x94 + x76*x90 + x89*(x1*(-5.53125*Nu + 0.567708333333333*x7 - 0.078125) + x100*x116 + x102*x104 + x106*x117 + x70*x99 + 1.75) + x94*(x1*(-0.03125*Nu + 0.536458333333333*x7 + 0.078125) + x102*x114 + x111*x70 + x112*x116 + x115*x117 + 0.25))/(x65 + 0.5*x86)**2
 *         cdef double dQdprst=11.8620273619492*Nu*r**(-2.5)*x122 + 589.775011960583*Nu*x118*x119 + 8.0*x1*x122*x129 + x1*x123*x124 + x1*x126*x127 + 5.09109256556341e-19*x118*x131*x141 - 67.9050514751178*x120*x121 + 0.975638950243592*x122*x78 + x124*x125*x76 + x124*x130*x87 + x127*x128*x76
 */
  __Pyx_TraceLine(1871,0,__PYX_ERR(1, 1871, __pyx_L1_error))
  __pyx_v_dxidr = ((((((__pyx_v_x0 * __pyx_v_x38) * ((((__pyx_v_r * __pyx_v_x62) * __pyx_v_x72) - ((2.98505426338587e-26 * __pyx_v_r) * __pyx_v_x75)) + __pyx_v_x63)) / (__pyx_v_x64 * __pyx_v_x68)) + ((__pyx_v_x0 * __pyx_v_x66) * __pyx_v_x85)) - (((__pyx_v_x28 * __pyx_v_x38) * __pyx_v_x64) / pow(__pyx_v_x65, 2.0))) + ((__pyx_v_x38 * __pyx_v_x39) * __pyx_v_x66));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1872
 *         cdef double x151 =x96*(-39.0*X1 + 39.0*X2)
 *         cdef double dxidr=x0*x38*(r*x62*x72 - 2.98505426338587e-26*r*x75 + x63)/(x64*x68) + x0*x66*x85 - x28*x38*x64/x65**2 + x38*x39*x66
 *         cdef double dHodddr=(L*x4*(-x1*x99 - x100*x103 - x104*x105 - x106*x110 - x76*(-11.0625*Nu + 1.13541666666667*x7 - 0.15625)) + L*x92*x93*(-x1*x111 - x103*x112 - x105*x114 - x110*x115 - x76*(-x113 + 1.07291666666667*x7 + 0.15625)) - x88*x90 - 0.0833333333333333*x91*x94 - x97*x98)/(x68 + x86) - (0.25*r*(x39 - 2.0) + 0.5*r + 0.25*x0 + x95)*(x1*x97 + 0.0416666666666667*x6*x94 + x76*x90 + x89*(x1*(-5.53125*Nu + 0.567708333333333*x7 - 0.078125) + x100*x116 + x102*x104 + x106*x117 + x70*x99 + 1.75) + x94*(x1*(-0.03125*Nu + 0.536458333333333*x7 + 0.078125) + x102*x114 + x111*x70 + x112*x116 + x115*x117 + 0.25))/(x65 + 0.5*x86)**2             # <<<<<<<<<<<<<<
 *         cdef double dQdprst=11.8620273619492*Nu*r**(-2.5)*x122 + 589.775011960583*Nu*x118*x119 + 8.0*x1*x122*x129 + x1*x123*x124 + x1*x126*x127 + 5.09109256556341e-19*x118*x131*x141 - 67.9050514751178*x120*x121 + 0.975638950243592*x122*x78 + x124*x125*x76 + x124*x130*x87 + x127*x128*x76
 *         cdef double dQdr=-663.496888455656*Nu*r**(-5.5)*x142 - 0.121954868780449*Nu*x1*x144 + 39.6112800271521*Nu*x119*x143 - x109*x130*x142 - 3.70688355060912*x121*x144 - x123*x142*x98 - 3.0*x125*x142*x87 - x126*x143*x98 - x128*x143*x88 - x129*x144*x98 + 7.59859378406358e-45*x131*x132*x134*x136*x140*x142*x61*x74 - 9.25454462627843e-34*x131*x132*x134*x140*x142*x72*x73/x135**3 - 6.62902677807736e-23*x131*x132*x136*x140*x142*x73*x85/x133**5 + x142*x87*(-51.6952380952381*x78 + 118.4*x80) + 1.01821851311268e-18*x134*x136*x140*x142*x65**3*x73/r**12 - 1.65460508380811e-18*x141*x142/r**14
 */
  __Pyx_TraceLine(1872,0,__PYX_ERR(1, 1872, __pyx_L1_error))
  __pyx_v_dHodddr = ((((((((__pyx_v_L * __pyx_v_x4) * ((((((-__pyx_v_x1) * __pyx_v_x99) - (__pyx_v_x100 * __pyx_v_x103)) - (__pyx_v_x104 * __pyx_v_x105)) - (__pyx_v_x106 * __pyx_v_x110)) - (__pyx_v_x76 * (((-11.0625 * __pyx_v_Nu) + (1.13541666666667 * __pyx_v_x7)) - 0.15625)))) + (((__pyx_v_L * __pyx_v_x92) * __pyx_v_x93) * ((((((-__pyx_v_x1) * __pyx_v_x111) - (__pyx_v_x103 * __pyx_v_x112)) - (__pyx_v_x105 * __pyx_v_x114)) - (__pyx_v_x110 * __pyx_v_x115)) - (__pyx_v_x76 * (((-__pyx_v_x113) + (1.07291666666667 * __pyx_v_x7)) + 0.15625))))) - (__pyx_v_x88 * __pyx_v_x90)) - ((0.0833333333333333 * __pyx_v_x91) * __pyx_v_x94)) - (__pyx_v_x97 * __pyx_v_x98)) / (__pyx_v_x68 + __pyx_v_x86)) - (((((((0.25 * __pyx_v_r) * (__pyx_v_x39 - 2.0)) + (0.5 * __pyx_v_r)) + (0.25 * __pyx_v_x0)) + __pyx_v_x95) * (((((__pyx_v_x1 * __pyx_v_x97) + ((0.0416666666666667 * __pyx_v_x6) * __pyx_v_x94)) + (__pyx_v_x76 * __pyx_v_x90)) + (__pyx_v_x89 * ((((((__pyx_v_x1 * (((-5.53125 * __pyx_v_Nu) + (0.567708333333333 * __pyx_v_x7)) - 0.078125)) + (__pyx_v_x100 * __pyx_v_x116)) + (__pyx_v_x102 * __pyx_v_x104)) + (__pyx_v_x106 * __pyx_v_x117)) + (__pyx_v_x70 * __pyx_v_x99)) + 1.75))) + (__pyx_v_x94 * ((((((__pyx_v_x1 * (((-0.03125 * __pyx_v_Nu) + (0.536458333333333 * __pyx_v_x7)) + 0.078125)) + (__pyx_v_x102 * __pyx_v_x114)) + (__pyx_v_x111 * __pyx_v_x70)) + (__pyx_v_x112 * __pyx_v_x116)) + (__pyx_v_x115 * __pyx_v_x117)) + 0.25)))) / pow((__pyx_v_x65 + (0.5 * __pyx_v_x86)), 2.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1873
 *         cdef double dxidr=x0*x38*(r*x62*x72 - 2.98505426338587e-26*r*x75 + x63)/(x64*x68) + x0*x66*x85 - x28*x38*x64/x65**2 + x38*x39*x66
 *         cdef double dHodddr=(L*x4*(-x1*x99 - x100*x103 - x104*x105 - x106*x110 - x76*(-11.0625*Nu + 1.13541666666667*x7 - 0.15625)) + L*x92*x93*(-x1*x111 - x103*x112 - x105*x114 - x110*x115 - x76*(-x113 + 1.07291666666667*x7 + 0.15625)) - x88*x90 - 0.0833333333333333*x91*x94 - x97*x98)/(x68 + x86) - (0.25*r*(x39 - 2.0) + 0.5*r + 0.25*x0 + x95)*(x1*x97 + 0.0416666666666667*x6*x94 + x76*x90 + x89*(x1*(-5.53125*Nu + 0.567708333333333*x7 - 0.078125) + x100*x116 + x102*x104 + x106*x117 + x70*x99 + 1.75) + x94*(x1*(-0.03125*Nu + 0.536458333333333*x7 + 0.078125) + x102*x114 + x111*x70 + x112*x116 + x115*x117 + 0.25))/(x65 + 0.5*x86)**2
 *         cdef double dQdprst=11.8620273619492*Nu*r**(-2.5)*x122 + 589.775011960583*Nu*x118*x119 + 8.0*x1*x122*x129 + x1*x123*x124 + x1*x126*x127 + 5.09109256556341e-19*x118*x131*x141 - 67.9050514751178*x120*x121 + 0.975638950243592*x122*x78 + x124*x125*x76 + x124*x130*x87 + x127*x128*x76             # <<<<<<<<<<<<<<
 *         cdef double dQdr=-663.496888455656*Nu*r**(-5.5)*x142 - 0.121954868780449*Nu*x1*x144 + 39.6112800271521*Nu*x119*x143 - x109*x130*x142 - 3.70688355060912*x121*x144 - x123*x142*x98 - 3.0*x125*x142*x87 - x126*x143*x98 - x128*x143*x88 - x129*x144*x98 + 7.59859378406358e-45*x131*x132*x134*x136*x140*x142*x61*x74 - 9.25454462627843e-34*x131*x132*x134*x140*x142*x72*x73/x135**3 - 6.62902677807736e-23*x131*x132*x136*x140*x142*x73*x85/x133**5 + x142*x87*(-51.6952380952381*x78 + 118.4*x80) + 1.01821851311268e-18*x134*x136*x140*x142*x65**3*x73/r**12 - 1.65460508380811e-18*x141*x142/r**14
 *         cdef double dBnpadr=r*x145*(x145*x5 + x146 + x81)/x147**2 - r*x148 - x145*x148
 */
  __Pyx_TraceLine(1873,0,__PYX_ERR(1, 1873, __pyx_L1_error))
  __pyx_t_13 = __Pyx_SoftComplexToDouble(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((11.8620273619492 * __pyx_v_Nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-2.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_x122, 0)), __pyx_t_double_complex_from_parts((((589.775011960583 * __pyx_v_Nu) * __pyx_v_x118) * __pyx_v_x119), 0)), __pyx_t_double_complex_from_parts((((8.0 * __pyx_v_x1) * __pyx_v_x122) * __pyx_v_x129), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x1 * __pyx_v_x123) * __pyx_v_x124), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x1 * __pyx_v_x126) * __pyx_v_x127), 0)), __pyx_t_double_complex_from_parts((((5.09109256556341e-19 * __pyx_v_x118) * __pyx_v_x131) * __pyx_v_x141), 0)), __pyx_t_double_complex_from_parts(((67.9050514751178 * __pyx_v_x120) * __pyx_v_x121), 0)), __pyx_t_double_complex_from_parts(((0.975638950243592 * __pyx_v_x122) * __pyx_v_x78), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x124 * __pyx_v_x125) * __pyx_v_x76), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x124 * __pyx_v_x130) * __pyx_v_x87), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x127 * __pyx_v_x128) * __pyx_v_x76), 0)), 1); if (unlikely(__pyx_t_13 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1873, __pyx_L1_error)
  __pyx_v_dQdprst = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1874
 *         cdef double dHodddr=(L*x4*(-x1*x99 - x100*x103 - x104*x105 - x106*x110 - x76*(-11.0625*Nu + 1.13541666666667*x7 - 0.15625)) + L*x92*x93*(-x1*x111 - x103*x112 - x105*x114 - x110*x115 - x76*(-x113 + 1.07291666666667*x7 + 0.15625)) - x88*x90 - 0.0833333333333333*x91*x94 - x97*x98)/(x68 + x86) - (0.25*r*(x39 - 2.0) + 0.5*r + 0.25*x0 + x95)*(x1*x97 + 0.0416666666666667*x6*x94 + x76*x90 + x89*(x1*(-5.53125*Nu + 0.567708333333333*x7 - 0.078125) + x100*x116 + x102*x104 + x106*x117 + x70*x99 + 1.75) + x94*(x1*(-0.03125*Nu + 0.536458333333333*x7 + 0.078125) + x102*x114 + x111*x70 + x112*x116 + x115*x117 + 0.25))/(x65 + 0.5*x86)**2
 *         cdef double dQdprst=11.8620273619492*Nu*r**(-2.5)*x122 + 589.775011960583*Nu*x118*x119 + 8.0*x1*x122*x129 + x1*x123*x124 + x1*x126*x127 + 5.09109256556341e-19*x118*x131*x141 - 67.9050514751178*x120*x121 + 0.975638950243592*x122*x78 + x124*x125*x76 + x124*x130*x87 + x127*x128*x76
 *         cdef double dQdr=-663.496888455656*Nu*r**(-5.5)*x142 - 0.121954868780449*Nu*x1*x144 + 39.6112800271521*Nu*x119*x143 - x109*x130*x142 - 3.70688355060912*x121*x144 - x123*x142*x98 - 3.0*x125*x142*x87 - x126*x143*x98 - x128*x143*x88 - x129*x144*x98 + 7.59859378406358e-45*x131*x132*x134*x136*x140*x142*x61*x74 - 9.25454462627843e-34*x131*x132*x134*x140*x142*x72*x73/x135**3 - 6.62902677807736e-23*x131*x132*x136*x140*x142*x73*x85/x133**5 + x142*x87*(-51.6952380952381*x78 + 118.4*x80) + 1.01821851311268e-18*x134*x136*x140*x142*x65**3*x73/r**12 - 1.65460508380811e-18*x141*x142/r**14             # <<<<<<<<<<<<<<
 *         cdef double dBnpadr=r*x145*(x145*x5 + x146 + x81)/x147**2 - r*x148 - x145*x148
 *         cdef double dBnpdr=-x108*(0.0625*x138*(115.0*Nu + x137 - 37.0) + x5*(-73.1875*Nu - 53.8125) + x93*x96*(3.25*Nu + 56.125)) + 38400.0*x11*x12*x36*x50*x62 + 7680.0*x11*x14*x36*x62*x72 - 2.29252167428035e-22*x11*x14*x36*x75 + 7680.0*x14*x36*x50*x62*x79 - x14*x63*x83 - x77 - x87*(x138*(2.25*Nu - 0.5625) + x5*(9.0*Nu + 8.4375) + x96*(-7.875*X1 + 7.875*X2))
 */
  __Pyx_TraceLine(1874,0,__PYX_ERR(1, 1874, __pyx_L1_error))
  __pyx_t_13 = __Pyx_SoftComplexToDouble(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_diff_double(__Pyx_c_sum_double(__Pyx_c_diff_double(__Pyx_c_prod_double(__Pyx_c_prod_double(__pyx_t_double_complex_from_parts((-663.496888455656 * __pyx_v_Nu), 0), __Pyx_c_pow_double(__pyx_t_double_complex_from_parts(__pyx_v_r, 0), __pyx_t_double_complex_from_parts(-5.5, 0))), __pyx_t_double_complex_from_parts(__pyx_v_x142, 0)), __pyx_t_double_complex_from_parts((((0.121954868780449 * __pyx_v_Nu) * __pyx_v_x1) * __pyx_v_x144), 0)), __pyx_t_double_complex_from_parts((((39.6112800271521 * __pyx_v_Nu) * __pyx_v_x119) * __pyx_v_x143), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x109 * __pyx_v_x130) * __pyx_v_x142), 0)), __pyx_t_double_complex_from_parts(((3.70688355060912 * __pyx_v_x121) * __pyx_v_x144), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x123 * __pyx_v_x142) * __pyx_v_x98), 0)), __pyx_t_double_complex_from_parts((((3.0 * __pyx_v_x125) * __pyx_v_x142) * __pyx_v_x87), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x126 * __pyx_v_x143) * __pyx_v_x98), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x128 * __pyx_v_x143) * __pyx_v_x88), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x129 * __pyx_v_x144) * __pyx_v_x98), 0)), __pyx_t_double_complex_from_parts(((((((((7.59859378406358e-45 * __pyx_v_x131) * __pyx_v_x132) * __pyx_v_x134) * __pyx_v_x136) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x61) * __pyx_v_x74), 0)), __pyx_t_double_complex_from_parts(((((((((9.25454462627843e-34 * __pyx_v_x131) * __pyx_v_x132) * __pyx_v_x134) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x72) * __pyx_v_x73) / pow(__pyx_v_x135, 3.0)), 0)), __pyx_t_double_complex_from_parts(((((((((6.62902677807736e-23 * __pyx_v_x131) * __pyx_v_x132) * __pyx_v_x136) * __pyx_v_x140) * __pyx_v_x142) * __pyx_v_x73) * __pyx_v_x85) / pow(__pyx_v_x133, 5.0)), 0)), __pyx_t_double_complex_from_parts(((__pyx_v_x142 * __pyx_v_x87) * ((-51.6952380952381 * __pyx_v_x78) + (118.4 * __pyx_v_x80))), 0)), __pyx_t_double_complex_from_parts((((((((1.01821851311268e-18 * __pyx_v_x134) * __pyx_v_x136) * __pyx_v_x140) * __pyx_v_x142) * pow(__pyx_v_x65, 3.0)) * __pyx_v_x73) / pow(__pyx_v_r, 12.0)), 0)), __pyx_t_double_complex_from_parts((((1.65460508380811e-18 * __pyx_v_x141) * __pyx_v_x142) / pow(__pyx_v_r, 14.0)), 0)), 1); if (unlikely(__pyx_t_13 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1874, __pyx_L1_error)
  __pyx_v_dQdr = __pyx_t_13;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1875
 *         cdef double dQdprst=11.8620273619492*Nu*r**(-2.5)*x122 + 589.775011960583*Nu*x118*x119 + 8.0*x1*x122*x129 + x1*x123*x124 + x1*x126*x127 + 5.09109256556341e-19*x118*x131*x141 - 67.9050514751178*x120*x121 + 0.975638950243592*x122*x78 + x124*x125*x76 + x124*x130*x87 + x127*x128*x76
 *         cdef double dQdr=-663.496888455656*Nu*r**(-5.5)*x142 - 0.121954868780449*Nu*x1*x144 + 39.6112800271521*Nu*x119*x143 - x109*x130*x142 - 3.70688355060912*x121*x144 - x123*x142*x98 - 3.0*x125*x142*x87 - x126*x143*x98 - x128*x143*x88 - x129*x144*x98 + 7.59859378406358e-45*x131*x132*x134*x136*x140*x142*x61*x74 - 9.25454462627843e-34*x131*x132*x134*x140*x142*x72*x73/x135**3 - 6.62902677807736e-23*x131*x132*x136*x140*x142*x73*x85/x133**5 + x142*x87*(-51.6952380952381*x78 + 118.4*x80) + 1.01821851311268e-18*x134*x136*x140*x142*x65**3*x73/r**12 - 1.65460508380811e-18*x141*x142/r**14
 *         cdef double dBnpadr=r*x145*(x145*x5 + x146 + x81)/x147**2 - r*x148 - x145*x148             # <<<<<<<<<<<<<<
 *         cdef double dBnpdr=-x108*(0.0625*x138*(115.0*Nu + x137 - 37.0) + x5*(-73.1875*Nu - 53.8125) + x93*x96*(3.25*Nu + 56.125)) + 38400.0*x11*x12*x36*x50*x62 + 7680.0*x11*x14*x36*x62*x72 - 2.29252167428035e-22*x11*x14*x36*x75 + 7680.0*x14*x36*x50*x62*x79 - x14*x63*x83 - x77 - x87*(x138*(2.25*Nu - 0.5625) + x5*(9.0*Nu + 8.4375) + x96*(-7.875*X1 + 7.875*X2))
 *         cdef double dAdr=(-x108*(x138*(2.0*Nu + 0.5) - x139*x96 + 4.5*x5) - x84 - (0.234375*x150 + x151*(0.3125*Nu - 0.46875) - x5*(13.671875*Nu + 17.578125))/r**6)/x149 - (-x67*x87 + x91*(-4.0*x70 - 2.0))*(x108*(0.046875*x150 + x151*(x113 - 0.09375) - x5*(2.734375*Nu + 3.515625)) + x38 + x87*(x138*(0.5*Nu + 0.125) + 1.125*x5 + x96*(-1.25*X1 + 1.25*X2)))/x149**2
 */
  __Pyx_TraceLine(1875,0,__PYX_ERR(1, 1875, __pyx_L1_error))
  __pyx_v_dBnpadr = (((((__pyx_v_r * __pyx_v_x145) * (((__pyx_v_x145 * __pyx_v_x5) + __pyx_v_x146) + __pyx_v_x81)) / pow(__pyx_v_x147, 2.0)) - (__pyx_v_r * __pyx_v_x148)) - (__pyx_v_x145 * __pyx_v_x148));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1876
 *         cdef double dQdr=-663.496888455656*Nu*r**(-5.5)*x142 - 0.121954868780449*Nu*x1*x144 + 39.6112800271521*Nu*x119*x143 - x109*x130*x142 - 3.70688355060912*x121*x144 - x123*x142*x98 - 3.0*x125*x142*x87 - x126*x143*x98 - x128*x143*x88 - x129*x144*x98 + 7.59859378406358e-45*x131*x132*x134*x136*x140*x142*x61*x74 - 9.25454462627843e-34*x131*x132*x134*x140*x142*x72*x73/x135**3 - 6.62902677807736e-23*x131*x132*x136*x140*x142*x73*x85/x133**5 + x142*x87*(-51.6952380952381*x78 + 118.4*x80) + 1.01821851311268e-18*x134*x136*x140*x142*x65**3*x73/r**12 - 1.65460508380811e-18*x141*x142/r**14
 *         cdef double dBnpadr=r*x145*(x145*x5 + x146 + x81)/x147**2 - r*x148 - x145*x148
 *         cdef double dBnpdr=-x108*(0.0625*x138*(115.0*Nu + x137 - 37.0) + x5*(-73.1875*Nu - 53.8125) + x93*x96*(3.25*Nu + 56.125)) + 38400.0*x11*x12*x36*x50*x62 + 7680.0*x11*x14*x36*x62*x72 - 2.29252167428035e-22*x11*x14*x36*x75 + 7680.0*x14*x36*x50*x62*x79 - x14*x63*x83 - x77 - x87*(x138*(2.25*Nu - 0.5625) + x5*(9.0*Nu + 8.4375) + x96*(-7.875*X1 + 7.875*X2))             # <<<<<<<<<<<<<<
 *         cdef double dAdr=(-x108*(x138*(2.0*Nu + 0.5) - x139*x96 + 4.5*x5) - x84 - (0.234375*x150 + x151*(0.3125*Nu - 0.46875) - x5*(13.671875*Nu + 17.578125))/r**6)/x149 - (-x67*x87 + x91*(-4.0*x70 - 2.0))*(x108*(0.046875*x150 + x151*(x113 - 0.09375) - x5*(2.734375*Nu + 3.515625)) + x38 + x87*(x138*(0.5*Nu + 0.125) + 1.125*x5 + x96*(-1.25*X1 + 1.25*X2)))/x149**2
 * 
 */
  __Pyx_TraceLine(1876,0,__PYX_ERR(1, 1876, __pyx_L1_error))
  __pyx_v_dBnpdr = (((((((((-__pyx_v_x108) * ((((0.0625 * __pyx_v_x138) * (((115.0 * __pyx_v_Nu) + __pyx_v_x137) - 37.0)) + (__pyx_v_x5 * ((-73.1875 * __pyx_v_Nu) - 53.8125))) + ((__pyx_v_x93 * __pyx_v_x96) * ((3.25 * __pyx_v_Nu) + 56.125)))) + (((((38400.0 * __pyx_v_x11) * __pyx_v_x12) * __pyx_v_x36) * __pyx_v_x50) * __pyx_v_x62)) + (((((7680.0 * __pyx_v_x11) * __pyx_v_x14) * __pyx_v_x36) * __pyx_v_x62) * __pyx_v_x72)) - ((((2.29252167428035e-22 * __pyx_v_x11) * __pyx_v_x14) * __pyx_v_x36) * __pyx_v_x75)) + (((((7680.0 * __pyx_v_x14) * __pyx_v_x36) * __pyx_v_x50) * __pyx_v_x62) * __pyx_v_x79)) - ((__pyx_v_x14 * __pyx_v_x63) * __pyx_v_x83)) - __pyx_v_x77) - (__pyx_v_x87 * (((__pyx_v_x138 * ((2.25 * __pyx_v_Nu) - 0.5625)) + (__pyx_v_x5 * ((9.0 * __pyx_v_Nu) + 8.4375))) + (__pyx_v_x96 * ((-7.875 * __pyx_v_X1) + (7.875 * __pyx_v_X2))))));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1877
 *         cdef double dBnpadr=r*x145*(x145*x5 + x146 + x81)/x147**2 - r*x148 - x145*x148
 *         cdef double dBnpdr=-x108*(0.0625*x138*(115.0*Nu + x137 - 37.0) + x5*(-73.1875*Nu - 53.8125) + x93*x96*(3.25*Nu + 56.125)) + 38400.0*x11*x12*x36*x50*x62 + 7680.0*x11*x14*x36*x62*x72 - 2.29252167428035e-22*x11*x14*x36*x75 + 7680.0*x14*x36*x50*x62*x79 - x14*x63*x83 - x77 - x87*(x138*(2.25*Nu - 0.5625) + x5*(9.0*Nu + 8.4375) + x96*(-7.875*X1 + 7.875*X2))
 *         cdef double dAdr=(-x108*(x138*(2.0*Nu + 0.5) - x139*x96 + 4.5*x5) - x84 - (0.234375*x150 + x151*(0.3125*Nu - 0.46875) - x5*(13.671875*Nu + 17.578125))/r**6)/x149 - (-x67*x87 + x91*(-4.0*x70 - 2.0))*(x108*(0.046875*x150 + x151*(x113 - 0.09375) - x5*(2.734375*Nu + 3.515625)) + x38 + x87*(x138*(0.5*Nu + 0.125) + 1.125*x5 + x96*(-1.25*X1 + 1.25*X2)))/x149**2             # <<<<<<<<<<<<<<
 * 
 *         return dAdr,dBnpdr,dBnpadr,dxidr,dQdr,dQdprst,dHodddr
 */
  __Pyx_TraceLine(1877,0,__PYX_ERR(1, 1877, __pyx_L1_error))
  __pyx_v_dAdr = ((((((-__pyx_v_x108) * (((__pyx_v_x138 * ((2.0 * __pyx_v_Nu) + 0.5)) - (__pyx_v_x139 * __pyx_v_x96)) + (4.5 * __pyx_v_x5))) - __pyx_v_x84) - ((((0.234375 * __pyx_v_x150) + (__pyx_v_x151 * ((0.3125 * __pyx_v_Nu) - 0.46875))) - (__pyx_v_x5 * ((13.671875 * __pyx_v_Nu) + 17.578125))) / pow(__pyx_v_r, 6.0))) / __pyx_v_x149) - (((((-__pyx_v_x67) * __pyx_v_x87) + (__pyx_v_x91 * ((-4.0 * __pyx_v_x70) - 2.0))) * (((__pyx_v_x108 * (((0.046875 * __pyx_v_x150) + (__pyx_v_x151 * (__pyx_v_x113 - 0.09375))) - (__pyx_v_x5 * ((2.734375 * __pyx_v_Nu) + 3.515625)))) + __pyx_v_x38) + (__pyx_v_x87 * (((__pyx_v_x138 * ((0.5 * __pyx_v_Nu) + 0.125)) + (1.125 * __pyx_v_x5)) + (__pyx_v_x96 * ((-1.25 * __pyx_v_X1) + (1.25 * __pyx_v_X2))))))) / pow(__pyx_v_x149, 2.0)));

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1879
 *         cdef double dAdr=(-x108*(x138*(2.0*Nu + 0.5) - x139*x96 + 4.5*x5) - x84 - (0.234375*x150 + x151*(0.3125*Nu - 0.46875) - x5*(13.671875*Nu + 17.578125))/r**6)/x149 - (-x67*x87 + x91*(-4.0*x70 - 2.0))*(x108*(0.046875*x150 + x151*(x113 - 0.09375) - x5*(2.734375*Nu + 3.515625)) + x38 + x87*(x138*(0.5*Nu + 0.125) + 1.125*x5 + x96*(-1.25*X1 + 1.25*X2)))/x149**2
 * 
 *         return dAdr,dBnpdr,dBnpadr,dxidr,dQdr,dQdprst,dHodddr             # <<<<<<<<<<<<<<
 */
  __Pyx_TraceLine(1879,0,__PYX_ERR(1, 1879, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_dAdr); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_dBnpdr); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyFloat_FromDouble(__pyx_v_dBnpadr); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = PyFloat_FromDouble(__pyx_v_dxidr); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyFloat_FromDouble(__pyx_v_dQdr); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_dQdprst); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_dHodddr); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyTuple_New(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 6, __pyx_t_5);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_9 = 0;
  __pyx_t_8 = 0;
  __pyx_t_7 = 0;
  __pyx_t_6 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1682
 *         return omega
 * 
 *     cpdef auxderivs(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.auxderivs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c_coeffs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_14auxderivs, "\n        Compute derivatives of the potentials which are used in the post-adiabatic approximation.\n\n        Args:\n          q (double[:]): Canonical positions (r,phi).\n          p (double[:]): Canonical momenta  (prstar,pphi).\n          chi1 (double): Dimensionless z-spin of the primary.\n          chi2 (double): Dimensionless z-spin of the secondary.\n          m_1 (double): Primary mass component.\n          m_2 (double): Secondary mass component.\n\n        Returns:\n           (tuple) dAdr, dBnpdr, dBnpadr, dxidr, dQdr, dQdprst, dHodddr\n\n        ");
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs = {"auxderivs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_14auxderivs};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_q = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_p = { 0, 0, { 0 }, { 0 }, { 0 } };
  double __pyx_v_chi_1;
  double __pyx_v_chi_2;
  double __pyx_v_m_1;
  double __pyx_v_m_2;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("auxderivs (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_q,&__pyx_n_s_p,&__pyx_n_s_chi_1,&__pyx_n_s_chi_2,&__pyx_n_s_m_1,&__pyx_n_s_m_2,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_q)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("auxderivs", 1, 6, 6, 1); __PYX_ERR(1, 1682, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("auxderivs", 1, 6, 6, 2); __PYX_ERR(1, 1682, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("auxderivs", 1, 6, 6, 3); __PYX_ERR(1, 1682, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_1)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("auxderivs", 1, 6, 6, 4); __PYX_ERR(1, 1682, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_2)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("auxderivs", 1, 6, 6, 5); __PYX_ERR(1, 1682, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "auxderivs") < 0)) __PYX_ERR(1, 1682, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
    }
    __pyx_v_q = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_q.memview)) __PYX_ERR(1, 1682, __pyx_L3_error)
    __pyx_v_p = __Pyx_PyObject_to_MemoryviewSlice_ds_double(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_p.memview)) __PYX_ERR(1, 1682, __pyx_L3_error)
    __pyx_v_chi_1 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_chi_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
    __pyx_v_chi_2 = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_chi_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
    __pyx_v_m_1 = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_m_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
    __pyx_v_m_2 = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_m_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(1, 1682, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("auxderivs", 1, 6, 6, __pyx_nargs); __PYX_ERR(1, 1682, __pyx_L3_error)
  __pyx_L3_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.auxderivs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_14auxderivs(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_q, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_p, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_14auxderivs(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, __Pyx_memviewslice __pyx_v_q, __Pyx_memviewslice __pyx_v_p, double __pyx_v_chi_1, double __pyx_v_chi_2, double __pyx_v_m_1, double __pyx_v_m_2) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__18)
  __Pyx_RefNannySetupContext("auxderivs", 0);
  __Pyx_TraceCall("auxderivs (wrapper)", __pyx_f[1], 1682, 0, __PYX_ERR(1, 1682, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_q.memview)) { __Pyx_RaiseUnboundLocalError("q"); __PYX_ERR(1, 1682, __pyx_L1_error) }
  if (unlikely(!__pyx_v_p.memview)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(1, 1682, __pyx_L1_error) }
  __pyx_t_1 = __pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_auxderivs(__pyx_v_self, __pyx_v_q, __pyx_v_p, __pyx_v_chi_1, __pyx_v_chi_2, __pyx_v_m_1, __pyx_v_m_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.auxderivs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":146
 * 
 * cdef class Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(Hamiltonian_C):
 *     cdef public CalibCoeffs calibration_coeffs             # <<<<<<<<<<<<<<
 *     #cdef public EOBParams EOBpars
 *     def __cinit__(self,EOBParams params):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs___get__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs___get__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[1], 146, 0, __PYX_ERR(1, 146, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->calibration_coeffs);
  __pyx_r = ((PyObject *)__pyx_v_self->calibration_coeffs);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.calibration_coeffs.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_2__set__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_2__set__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[1], 146, 0, __PYX_ERR(1, 146, __pyx_L1_error));
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs))))) __PYX_ERR(1, 146, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_DECREF((PyObject *)__pyx_v_self->calibration_coeffs);
  __pyx_v_self->calibration_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.calibration_coeffs.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_4__del__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_4__del__(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[1], 146, 0, __PYX_ERR(1, 146, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->calibration_coeffs);
  __Pyx_DECREF((PyObject *)__pyx_v_self->calibration_coeffs);
  __pyx_v_self->calibration_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.calibration_coeffs.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_17__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_17__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_17__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_17__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_16__reduce_cython__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__19)
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);
  __Pyx_TraceCall("__reduce_cython__", __pyx_f[0], 1, 0, __PYX_ERR(0, 1, __pyx_L1_error));

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_TraceLine(2,0,__PYX_ERR(0, 2, __pyx_L1_error))
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_19__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_19__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_19__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_19__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(0, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18__setstate_cython__(((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__20)
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);
  __Pyx_TraceCall("__setstate_cython__", __pyx_f[0], 3, 0, __PYX_ERR(0, 3, __pyx_L1_error));

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_TraceLine(4,0,__PYX_ERR(0, 4, __pyx_L1_error))
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(0, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;

static PyObject *__pyx_tp_new_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C*)__pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
  p->calibration_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyObject *o) {
  struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *p = (struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->calibration_coeffs);
  PyObject_GC_Track(o);
  if (likely(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C)) __Pyx_PyType_GetSlot(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);
}

static int __pyx_tp_traverse_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *p = (struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)o;
  e = ((likely(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C)) ? ((__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C->tp_traverse) ? __pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C)); if (e) return e;
  if (p->calibration_coeffs) {
    e = (*v)(((PyObject *)p->calibration_coeffs), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *p = (struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *)o;
  if (likely(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C)) { if (__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C->tp_clear) __pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);
  tmp = ((PyObject*)p->calibration_coeffs);
  p->calibration_coeffs = ((struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_calibration_coeffs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_1__get__(o);
}

static int __pyx_setprop_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_calibration_coeffs(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_3__set__(o, v);
  }
  else {
    return __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_18calibration_coeffs_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_17__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_19__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C[] = {
  {(char *)"calibration_coeffs", __pyx_getprop_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_calibration_coeffs, __pyx_setprop_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_calibration_coeffs, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {Py_tp_call, (void *)__pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_3__call__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {Py_tp_clear, (void *)__pyx_tp_clear_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {Py_tp_methods, (void *)__pyx_methods_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {Py_tp_getset, (void *)__pyx_getsets_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {Py_tp_new, (void *)__pyx_tp_new_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {0, 0},
};
static PyType_Spec __pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_spec = {
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C",
  sizeof(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_slots,
};
#else

static PyTypeObject __pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.""Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C", /*tp_name*/
  sizeof(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, /*tp_traverse*/
  __pyx_tp_clear_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_array __pyx_vtable_array;

static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_array_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_array_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_array;
  p->mode = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_format = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_array___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_array(PyObject *o) {
  struct __pyx_array_obj *p = (struct __pyx_array_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_array) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_array___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->mode);
  Py_CLEAR(p->_format);
  (*Py_TYPE(o)->tp_free)(o);
}
static PyObject *__pyx_sq_item_array(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_array(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_array___setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static PyObject *__pyx_tp_getattro_array(PyObject *o, PyObject *n) {
  PyObject *v = __Pyx_PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_array___getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_getprop___pyx_array_memview(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(o);
}

static PyMethodDef __pyx_methods_array[] = {
  {"__getattr__", (PyCFunction)__pyx_array___getattr__, METH_O|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_array_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_array_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_array[] = {
  {(char *)"memview", __pyx_getprop___pyx_array_memview, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
#if !CYTHON_COMPILING_IN_LIMITED_API

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};
#endif
static PyType_Slot __pyx_type___pyx_array_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_array},
  {Py_sq_length, (void *)__pyx_array___len__},
  {Py_sq_item, (void *)__pyx_sq_item_array},
  {Py_mp_length, (void *)__pyx_array___len__},
  {Py_mp_subscript, (void *)__pyx_array___getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_array},
  {Py_tp_getattro, (void *)__pyx_tp_getattro_array},
  #if defined(Py_bf_getbuffer)
  {Py_bf_getbuffer, (void *)__pyx_array_getbuffer},
  #endif
  {Py_tp_methods, (void *)__pyx_methods_array},
  {Py_tp_getset, (void *)__pyx_getsets_array},
  {Py_tp_new, (void *)__pyx_tp_new_array},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_array_spec = {
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.array",
  sizeof(struct __pyx_array_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_SEQUENCE,
  __pyx_type___pyx_array_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_array = {
  __pyx_array___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_array, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_array = {
  __pyx_array___len__, /*mp_length*/
  __pyx_array___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_array, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_array = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.""array", /*tp_name*/
  sizeof(struct __pyx_array_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_array, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_array, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_array, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_array, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_array, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_SEQUENCE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_array, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_array, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_array, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_MemviewEnum_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_MemviewEnum_obj *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_Enum(PyObject *o) {
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_Enum) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_Enum(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_Enum(PyObject *o) {
  PyObject* tmp;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_specialmethod___pyx_MemviewEnum___repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_MemviewEnum___repr__(self);
}

static PyMethodDef __pyx_methods_Enum[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_MemviewEnum___repr__, METH_NOARGS|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_MemviewEnum_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_MemviewEnum_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type___pyx_MemviewEnum_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_Enum},
  {Py_tp_repr, (void *)__pyx_MemviewEnum___repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_Enum},
  {Py_tp_clear, (void *)__pyx_tp_clear_Enum},
  {Py_tp_methods, (void *)__pyx_methods_Enum},
  {Py_tp_init, (void *)__pyx_MemviewEnum___init__},
  {Py_tp_new, (void *)__pyx_tp_new_Enum},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_MemviewEnum_spec = {
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.Enum",
  sizeof(struct __pyx_MemviewEnum_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type___pyx_MemviewEnum_slots,
};
#else

static PyTypeObject __pyx_type___pyx_MemviewEnum = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.""Enum", /*tp_name*/
  sizeof(struct __pyx_MemviewEnum_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_Enum, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_MemviewEnum___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_Enum, /*tp_traverse*/
  __pyx_tp_clear_Enum, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_Enum, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_MemviewEnum___init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_Enum, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_memoryview __pyx_vtable_memoryview;

static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryview_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_memoryview_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_memoryview;
  p->obj = Py_None; Py_INCREF(Py_None);
  p->_size = Py_None; Py_INCREF(Py_None);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  p->view.obj = NULL;
  if (unlikely(__pyx_memoryview___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_memoryview(PyObject *o) {
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_memoryview) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryview___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->obj);
  Py_CLEAR(p->_size);
  Py_CLEAR(p->_array_interface);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_memoryview(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  if (p->obj) {
    e = (*v)(p->obj, a); if (e) return e;
  }
  if (p->_size) {
    e = (*v)(p->_size, a); if (e) return e;
  }
  if (p->_array_interface) {
    e = (*v)(p->_array_interface, a); if (e) return e;
  }
  if (p->view.obj) {
    e = (*v)(p->view.obj, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_memoryview(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  tmp = ((PyObject*)p->obj);
  p->obj = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_size);
  p->_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_array_interface);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  Py_CLEAR(p->view.obj);
  return 0;
}
static PyObject *__pyx_sq_item_memoryview(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_memoryview(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_memoryview___setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static PyObject *__pyx_getprop___pyx_memoryview_T(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_base(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_shape(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_strides(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_suboffsets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_ndim(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_itemsize(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_nbytes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(o);
}

static PyObject *__pyx_specialmethod___pyx_memoryview___repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_memoryview___repr__(self);
}

static PyMethodDef __pyx_methods_memoryview[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_memoryview___repr__, METH_NOARGS|METH_COEXIST, 0},
  {"is_c_contig", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_is_c_contig, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_f_contig", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_is_f_contig, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"copy_fortran", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_copy_fortran, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryview_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryview_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_memoryview[] = {
  {(char *)"T", __pyx_getprop___pyx_memoryview_T, 0, (char *)0, 0},
  {(char *)"base", __pyx_getprop___pyx_memoryview_base, 0, (char *)0, 0},
  {(char *)"shape", __pyx_getprop___pyx_memoryview_shape, 0, (char *)0, 0},
  {(char *)"strides", __pyx_getprop___pyx_memoryview_strides, 0, (char *)0, 0},
  {(char *)"suboffsets", __pyx_getprop___pyx_memoryview_suboffsets, 0, (char *)0, 0},
  {(char *)"ndim", __pyx_getprop___pyx_memoryview_ndim, 0, (char *)0, 0},
  {(char *)"itemsize", __pyx_getprop___pyx_memoryview_itemsize, 0, (char *)0, 0},
  {(char *)"nbytes", __pyx_getprop___pyx_memoryview_nbytes, 0, (char *)0, 0},
  {(char *)"size", __pyx_getprop___pyx_memoryview_size, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
#if !CYTHON_COMPILING_IN_LIMITED_API

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};
#endif
static PyType_Slot __pyx_type___pyx_memoryview_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_memoryview},
  {Py_tp_repr, (void *)__pyx_memoryview___repr__},
  {Py_sq_length, (void *)__pyx_memoryview___len__},
  {Py_sq_item, (void *)__pyx_sq_item_memoryview},
  {Py_mp_length, (void *)__pyx_memoryview___len__},
  {Py_mp_subscript, (void *)__pyx_memoryview___getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_memoryview},
  {Py_tp_str, (void *)__pyx_memoryview___str__},
  #if defined(Py_bf_getbuffer)
  {Py_bf_getbuffer, (void *)__pyx_memoryview_getbuffer},
  #endif
  {Py_tp_traverse, (void *)__pyx_tp_traverse_memoryview},
  {Py_tp_clear, (void *)__pyx_tp_clear_memoryview},
  {Py_tp_methods, (void *)__pyx_methods_memoryview},
  {Py_tp_getset, (void *)__pyx_getsets_memoryview},
  {Py_tp_new, (void *)__pyx_tp_new_memoryview},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_memoryview_spec = {
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.memoryview",
  sizeof(struct __pyx_memoryview_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type___pyx_memoryview_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_memoryview = {
  __pyx_memoryview___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_memoryview, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_memoryview = {
  __pyx_memoryview___len__, /*mp_length*/
  __pyx_memoryview___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_memoryview, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_memoryview = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.""memoryview", /*tp_name*/
  sizeof(struct __pyx_memoryview_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_memoryview, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_memoryview___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_memoryview, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_memoryview, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_memoryview___str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_memoryview, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_memoryview, /*tp_traverse*/
  __pyx_tp_clear_memoryview, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_memoryview, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_memoryview, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_memoryview, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct__memoryviewslice __pyx_vtable__memoryviewslice;

static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryviewslice_obj *p;
  PyObject *o = __pyx_tp_new_memoryview(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_memoryviewslice_obj *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_memoryview*)__pyx_vtabptr__memoryviewslice;
  p->from_object = Py_None; Py_INCREF(Py_None);
  p->from_slice.memview = NULL;
  return o;
}

static void __pyx_tp_dealloc__memoryviewslice(PyObject *o) {
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc__memoryviewslice) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryviewslice___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->from_object);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_memoryview(o);
}

static int __pyx_tp_traverse__memoryviewslice(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  e = __pyx_tp_traverse_memoryview(o, v, a); if (e) return e;
  if (p->from_object) {
    e = (*v)(p->from_object, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear__memoryviewslice(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  __pyx_tp_clear_memoryview(o);
  tmp = ((PyObject*)p->from_object);
  p->from_object = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  __PYX_XCLEAR_MEMVIEW(&p->from_slice, 1);
  return 0;
}

static PyMethodDef __pyx_methods__memoryviewslice[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryviewslice_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryviewslice_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type___pyx_memoryviewslice_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc__memoryviewslice},
  {Py_tp_doc, (void *)PyDoc_STR("Internal class for passing memoryview slices to Python")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse__memoryviewslice},
  {Py_tp_clear, (void *)__pyx_tp_clear__memoryviewslice},
  {Py_tp_methods, (void *)__pyx_methods__memoryviewslice},
  {Py_tp_new, (void *)__pyx_tp_new__memoryviewslice},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_memoryviewslice_spec = {
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C._memoryviewslice",
  sizeof(struct __pyx_memoryviewslice_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_SEQUENCE,
  __pyx_type___pyx_memoryviewslice_slots,
};
#else

static PyTypeObject __pyx_type___pyx_memoryviewslice = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.""_memoryviewslice", /*tp_name*/
  sizeof(struct __pyx_memoryviewslice_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc__memoryviewslice, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_memoryview___repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_memoryview___str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_SEQUENCE, /*tp_flags*/
  PyDoc_STR("Internal class for passing memoryview slices to Python"), /*tp_doc*/
  __pyx_tp_traverse__memoryviewslice, /*tp_traverse*/
  __pyx_tp_clear__memoryviewslice, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods__memoryviewslice, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new__memoryviewslice, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
    {&__pyx_n_s_ASCII, __pyx_k_ASCII, sizeof(__pyx_k_ASCII), 0, 0, 1, 1},
    {&__pyx_kp_s_All_dimensions_preceding_dimensi, __pyx_k_All_dimensions_preceding_dimensi, sizeof(__pyx_k_All_dimensions_preceding_dimensi), 0, 0, 1, 0},
    {&__pyx_n_s_AssertionError, __pyx_k_AssertionError, sizeof(__pyx_k_AssertionError), 0, 0, 1, 1},
    {&__pyx_kp_s_Buffer_view_does_not_expose_stri, __pyx_k_Buffer_view_does_not_expose_stri, sizeof(__pyx_k_Buffer_view_does_not_expose_stri), 0, 0, 1, 0},
    {&__pyx_kp_s_Can_only_create_a_buffer_that_is, __pyx_k_Can_only_create_a_buffer_that_is, sizeof(__pyx_k_Can_only_create_a_buffer_that_is), 0, 0, 1, 0},
    {&__pyx_kp_s_Cannot_assign_to_read_only_memor, __pyx_k_Cannot_assign_to_read_only_memor, sizeof(__pyx_k_Cannot_assign_to_read_only_memor), 0, 0, 1, 0},
    {&__pyx_kp_s_Cannot_create_writable_memory_vi, __pyx_k_Cannot_create_writable_memory_vi, sizeof(__pyx_k_Cannot_create_writable_memory_vi), 0, 0, 1, 0},
    {&__pyx_kp_u_Cannot_index_with_type, __pyx_k_Cannot_index_with_type, sizeof(__pyx_k_Cannot_index_with_type), 0, 1, 0, 0},
    {&__pyx_kp_s_Cannot_transpose_memoryview_with, __pyx_k_Cannot_transpose_memoryview_with, sizeof(__pyx_k_Cannot_transpose_memoryview_with), 0, 0, 1, 0},
    {&__pyx_kp_s_Dimension_d_is_not_direct, __pyx_k_Dimension_d_is_not_direct, sizeof(__pyx_k_Dimension_d_is_not_direct), 0, 0, 1, 0},
    {&__pyx_n_s_Ellipsis, __pyx_k_Ellipsis, sizeof(__pyx_k_Ellipsis), 0, 0, 1, 1},
    {&__pyx_kp_s_Empty_shape_tuple_for_cython_arr, __pyx_k_Empty_shape_tuple_for_cython_arr, sizeof(__pyx_k_Empty_shape_tuple_for_cython_arr), 0, 0, 1, 0},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_2, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_2), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_3, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_3), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_4, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_4), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_5, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_5), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_6, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_6), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_7, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_7), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_8, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_8), 0, 0, 1, 1},
    {&__pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9, __pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_9, sizeof(__pyx_k_Ham_align_a6_apm_AP15_DP23_gauge_9), 0, 0, 1, 1},
    {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
    {&__pyx_kp_s_Index_out_of_bounds_axis_d, __pyx_k_Index_out_of_bounds_axis_d, sizeof(__pyx_k_Index_out_of_bounds_axis_d), 0, 0, 1, 0},
    {&__pyx_kp_s_Indirect_dimensions_not_supporte, __pyx_k_Indirect_dimensions_not_supporte, sizeof(__pyx_k_Indirect_dimensions_not_supporte), 0, 0, 1, 0},
    {&__pyx_kp_u_Invalid_mode_expected_c_or_fortr, __pyx_k_Invalid_mode_expected_c_or_fortr, sizeof(__pyx_k_Invalid_mode_expected_c_or_fortr), 0, 1, 0, 0},
    {&__pyx_kp_u_Invalid_shape_in_axis, __pyx_k_Invalid_shape_in_axis, sizeof(__pyx_k_Invalid_shape_in_axis), 0, 1, 0, 0},
    {&__pyx_n_s_M, __pyx_k_M, sizeof(__pyx_k_M), 0, 0, 1, 1},
    {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
    {&__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_k_MemoryView_of_r_at_0x_x, sizeof(__pyx_k_MemoryView_of_r_at_0x_x), 0, 0, 1, 0},
    {&__pyx_kp_s_MemoryView_of_r_object, __pyx_k_MemoryView_of_r_object, sizeof(__pyx_k_MemoryView_of_r_object), 0, 0, 1, 0},
    {&__pyx_n_b_O, __pyx_k_O, sizeof(__pyx_k_O), 0, 0, 0, 1},
    {&__pyx_kp_u_Out_of_bounds_on_buffer_access_a, __pyx_k_Out_of_bounds_on_buffer_access_a, sizeof(__pyx_k_Out_of_bounds_on_buffer_access_a), 0, 1, 0, 0},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_Sequence, __pyx_k_Sequence, sizeof(__pyx_k_Sequence), 0, 0, 1, 1},
    {&__pyx_kp_s_Step_may_not_be_zero_axis_d, __pyx_k_Step_may_not_be_zero_axis_d, sizeof(__pyx_k_Step_may_not_be_zero_axis_d), 0, 0, 1, 0},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_kp_s_Unable_to_convert_item_to_object, __pyx_k_Unable_to_convert_item_to_object, sizeof(__pyx_k_Unable_to_convert_item_to_object), 0, 0, 1, 0},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_View_MemoryView, __pyx_k_View_MemoryView, sizeof(__pyx_k_View_MemoryView), 0, 0, 1, 1},
    {&__pyx_n_s_X_1, __pyx_k_X_1, sizeof(__pyx_k_X_1), 0, 0, 1, 1},
    {&__pyx_n_s_X_2, __pyx_k_X_2, sizeof(__pyx_k_X_2), 0, 0, 1, 1},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_n_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 1},
    {&__pyx_n_s__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 0, 1, 1},
    {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_n_s_a6, __pyx_k_a6, sizeof(__pyx_k_a6), 0, 0, 1, 1},
    {&__pyx_n_u_a6, __pyx_k_a6, sizeof(__pyx_k_a6), 0, 1, 0, 1},
    {&__pyx_n_s_abc, __pyx_k_abc, sizeof(__pyx_k_abc), 0, 0, 1, 1},
    {&__pyx_n_s_allocate_buffer, __pyx_k_allocate_buffer, sizeof(__pyx_k_allocate_buffer), 0, 0, 1, 1},
    {&__pyx_kp_u_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 1, 0, 0},
    {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_auxderivs, __pyx_k_auxderivs, sizeof(__pyx_k_auxderivs), 0, 0, 1, 1},
    {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
    {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
    {&__pyx_n_u_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 1, 0, 1},
    {&__pyx_n_s_call, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
    {&__pyx_n_s_chi_1, __pyx_k_chi_1, sizeof(__pyx_k_chi_1), 0, 0, 1, 1},
    {&__pyx_n_s_chi_2, __pyx_k_chi_2, sizeof(__pyx_k_chi_2), 0, 0, 1, 1},
    {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
    {&__pyx_kp_s_collections_abc, __pyx_k_collections_abc, sizeof(__pyx_k_collections_abc), 0, 0, 1, 0},
    {&__pyx_kp_s_contiguous_and_direct, __pyx_k_contiguous_and_direct, sizeof(__pyx_k_contiguous_and_direct), 0, 0, 1, 0},
    {&__pyx_kp_s_contiguous_and_indirect, __pyx_k_contiguous_and_indirect, sizeof(__pyx_k_contiguous_and_indirect), 0, 0, 1, 0},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_dSO, __pyx_k_dSO, sizeof(__pyx_k_dSO), 0, 0, 1, 1},
    {&__pyx_n_u_dSO, __pyx_k_dSO, sizeof(__pyx_k_dSO), 0, 1, 0, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_dtype_is_object, __pyx_k_dtype_is_object, sizeof(__pyx_k_dtype_is_object), 0, 0, 1, 1},
    {&__pyx_n_s_dynamics, __pyx_k_dynamics, sizeof(__pyx_k_dynamics), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_n_s_evaluate_H, __pyx_k_evaluate_H, sizeof(__pyx_k_evaluate_H), 0, 0, 1, 1},
    {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 0, 1, 1},
    {&__pyx_n_u_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 1, 0, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_kp_u_got, __pyx_k_got, sizeof(__pyx_k_got), 0, 1, 0, 0},
    {&__pyx_kp_u_got_differing_extents_in_dimensi, __pyx_k_got_differing_extents_in_dimensi, sizeof(__pyx_k_got_differing_extents_in_dimensi), 0, 1, 0, 0},
    {&__pyx_n_s_grad, __pyx_k_grad, sizeof(__pyx_k_grad), 0, 0, 1, 1},
    {&__pyx_n_s_hessian, __pyx_k_hessian, sizeof(__pyx_k_hessian), 0, 0, 1, 1},
    {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_itemsize, __pyx_k_itemsize, sizeof(__pyx_k_itemsize), 0, 0, 1, 1},
    {&__pyx_kp_s_itemsize_0_for_cython_array, __pyx_k_itemsize_0_for_cython_array, sizeof(__pyx_k_itemsize_0_for_cython_array), 0, 0, 1, 0},
    {&__pyx_n_s_m_1, __pyx_k_m_1, sizeof(__pyx_k_m_1), 0, 0, 1, 1},
    {&__pyx_n_s_m_2, __pyx_k_m_2, sizeof(__pyx_k_m_2), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_memview, __pyx_k_memview, sizeof(__pyx_k_memview), 0, 0, 1, 1},
    {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_ndim, __pyx_k_ndim, sizeof(__pyx_k_ndim), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
    {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
    {&__pyx_n_s_nu, __pyx_k_nu, sizeof(__pyx_k_nu), 0, 0, 1, 1},
    {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
    {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
    {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_omega, __pyx_k_omega, sizeof(__pyx_k_omega), 0, 0, 1, 1},
    {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
    {&__pyx_n_s_pack, __pyx_k_pack, sizeof(__pyx_k_pack), 0, 0, 1, 1},
    {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_k_pyseobnr_eob_hamiltonian_Ham_ali, sizeof(__pyx_k_pyseobnr_eob_hamiltonian_Ham_ali), 0, 0, 1, 0},
    {&__pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_k_pyseobnr_eob_hamiltonian_Ham_ali_2, sizeof(__pyx_k_pyseobnr_eob_hamiltonian_Ham_ali_2), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_Enum, __pyx_k_pyx_unpickle_Enum, sizeof(__pyx_k_pyx_unpickle_Enum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
    {&__pyx_n_s_reshape, __pyx_k_reshape, sizeof(__pyx_k_reshape), 0, 0, 1, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
    {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
    {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
    {&__pyx_kp_s_strided_and_direct, __pyx_k_strided_and_direct, sizeof(__pyx_k_strided_and_direct), 0, 0, 1, 0},
    {&__pyx_kp_s_strided_and_direct_or_indirect, __pyx_k_strided_and_direct_or_indirect, sizeof(__pyx_k_strided_and_direct_or_indirect), 0, 0, 1, 0},
    {&__pyx_kp_s_strided_and_indirect, __pyx_k_strided_and_indirect, sizeof(__pyx_k_strided_and_indirect), 0, 0, 1, 0},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_struct, __pyx_k_struct, sizeof(__pyx_k_struct), 0, 0, 1, 1},
    {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_kp_s_unable_to_allocate_array_data, __pyx_k_unable_to_allocate_array_data, sizeof(__pyx_k_unable_to_allocate_array_data), 0, 0, 1, 0},
    {&__pyx_kp_s_unable_to_allocate_shape_and_str, __pyx_k_unable_to_allocate_shape_and_str, sizeof(__pyx_k_unable_to_allocate_shape_and_str), 0, 0, 1, 0},
    {&__pyx_n_s_unpack, __pyx_k_unpack, sizeof(__pyx_k_unpack), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_verbose, __pyx_k_verbose, sizeof(__pyx_k_verbose), 0, 0, 1, 1},
    {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 118, __pyx_L1_error)
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_n_s_import); if (!__pyx_builtin___import__) __PYX_ERR(0, 100, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 141, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(0, 156, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 159, __pyx_L1_error)
  __pyx_builtin_AssertionError = __Pyx_GetBuiltinName(__pyx_n_s_AssertionError); if (!__pyx_builtin_AssertionError) __PYX_ERR(0, 373, __pyx_L1_error)
  __pyx_builtin_Ellipsis = __Pyx_GetBuiltinName(__pyx_n_s_Ellipsis); if (!__pyx_builtin_Ellipsis) __PYX_ERR(0, 408, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(0, 618, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 914, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(2, 983, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "View.MemoryView":582
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
  __pyx_tuple__4 = PyTuple_New(1); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_INCREF(__pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_int_neg_1);
  PyTuple_SET_ITEM(__pyx_tuple__4, 0, __pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "View.MemoryView":679
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)
 * 
 *     result = [slice(None)] * ndim             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_slice__5 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__5)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__5);
  __Pyx_GIVEREF(__pyx_slice__5);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  __pyx_tuple__8 = PyTuple_Pack(3, __pyx_int_136983863, __pyx_int_112105877, __pyx_int_184977713); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":983
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "../../../../tmp/build-env-xrzlv6nl/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":989
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(2, 989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1244
 *         cdef double d2Hdprdpphi = (-(dHeffdpr*dHeffdpphi/H**3)*(M**2/nu) + d2Heffdprdpphi/H) * M*M / nu
 * 
 *         return np.array([d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2]).reshape(4, 4)             # <<<<<<<<<<<<<<
 * 
 *     cdef double xi(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):
 */
  __pyx_tuple__15 = PyTuple_Pack(2, __pyx_int_4, __pyx_int_4); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(1, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_n_s_sys); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);
  __pyx_tuple__22 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_3); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "View.MemoryView":101
 * try:
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence             # <<<<<<<<<<<<<<
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_collections_abc); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "View.MemoryView":103
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence             # <<<<<<<<<<<<<<
 * except:
 * 
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_n_s_collections); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "View.MemoryView":309
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct_or_indirect); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "View.MemoryView":310
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "View.MemoryView":311
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_s_strided_and_indirect); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "View.MemoryView":314
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_direct); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "View.MemoryView":315
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_indirect); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__30 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Enum, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(0, 1, __pyx_L1_error)

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":11
 * from libc.math cimport log, sqrt, exp, abs, tgamma,sin,cos
 * 
 * cpdef (double,double) evaluate_H(double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,double M, double nu,             # <<<<<<<<<<<<<<
 * double X_1, double X_2, double a6, double dSO):
 *         """
 */
  __pyx_tuple__32 = PyTuple_Pack(12, __pyx_n_s_q, __pyx_n_s_p, __pyx_n_s_chi_1, __pyx_n_s_chi_2, __pyx_n_s_m_1, __pyx_n_s_m_2, __pyx_n_s_M, __pyx_n_s_nu, __pyx_n_s_X_1, __pyx_n_s_X_2, __pyx_n_s_a6, __pyx_n_s_dSO); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);
  __pyx_codeobj__11 = (PyObject*)__Pyx_PyCode_New(12, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_evaluate_H, 11, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__11)) __PYX_ERR(1, 11, __pyx_L1_error)

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":154
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __pyx_tuple__33 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_q, __pyx_n_s_p, __pyx_n_s_chi_1, __pyx_n_s_chi_2, __pyx_n_s_m_1, __pyx_n_s_m_2, __pyx_n_s_verbose); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(1, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_codeobj__12 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__33, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_call, 154, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__12)) __PYX_ERR(1, 154, __pyx_L1_error)
  __pyx_tuple__34 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(1, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":290
 *             return H,xi,A,Bnp,Bnpa,Qq,Heven,Hodd
 * 
 *     cpdef grad(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __pyx_tuple__35 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_q, __pyx_n_s_p, __pyx_n_s_chi_1, __pyx_n_s_chi_2, __pyx_n_s_m_1, __pyx_n_s_m_2); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(1, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);
  __pyx_codeobj__13 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_grad, 290, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__13)) __PYX_ERR(1, 290, __pyx_L1_error)

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":547
 *         return dHdr, dHdphi, dHdpr, dHdpphi
 * 
 *     cpdef hessian(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __pyx_codeobj__14 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_hessian, 547, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__14)) __PYX_ERR(1, 547, __pyx_L1_error)

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1299
 *         return xi
 * 
 *     cpdef dynamics(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_dynamics, 1299, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(1, 1299, __pyx_L1_error)

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1557
 *         #return dHdr, dHdphi, dHdpr, dHdpphi,H,xi
 * 
 *     cpdef double omega(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_omega, 1557, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(1, 1557, __pyx_L1_error)

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1682
 *         return omega
 * 
 *     cpdef auxderivs(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __pyx_codeobj__18 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pyseobnr_eob_hamiltonian_Ham_ali, __pyx_n_s_auxderivs, 1682, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__18)) __PYX_ERR(1, 1682, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);
  __pyx_codeobj__19 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__36, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__19)) __PYX_ERR(0, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_tuple__37 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);
  __pyx_codeobj__20 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__37, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__20)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(1, 2, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_112105877 = PyInt_FromLong(112105877L); if (unlikely(!__pyx_int_112105877)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_136983863 = PyInt_FromLong(136983863L); if (unlikely(!__pyx_int_136983863)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_184977713 = PyInt_FromLong(184977713L); if (unlikely(!__pyx_int_184977713)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  /* AssertionsEnabled.init */
  __Pyx_init_assertions_enabled();

if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 2, __pyx_L1_error)

  /* NumpyImportArray.init */
  /*
 * Cython has automatically inserted a call to _import_array since
 * you didn't include one when you cimported numpy. To disable this
 * add the line
 *   <void>numpy._import_array
 */
#ifdef NPY_FEATURE_VERSION
#if !NO_IMPORT_ARRAY
if (unlikely(_import_array() == -1)) {
    PyErr_SetString(PyExc_ImportError, "numpy.core.multiarray failed to import "
    "(auto-generated because you didn't call 'numpy.import_array()' after cimporting numpy; "
    "use '<void>numpy._import_array' to disable if you are certain you don't need it).");
}
#endif
#endif

if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 2, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_collections_abc_Sequence = Py_None; Py_INCREF(Py_None);
  generic = Py_None; Py_INCREF(Py_None);
  strided = Py_None; Py_INCREF(Py_None);
  indirect = Py_None; Py_INCREF(Py_None);
  contiguous = Py_None; Py_INCREF(Py_None);
  indirect_contiguous = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_t_1 = PyImport_ImportModule("pyseobnr.eob.hamiltonian.Hamiltonian_C"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C = __Pyx_ImportType_3_0_0(__pyx_t_1, "pyseobnr.eob.hamiltonian.Hamiltonian_C", "Hamiltonian_C", sizeof(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C = (struct __pyx_vtabstruct_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C*)__Pyx_GetVtable(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C); if (unlikely(!__pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C = &__pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base = *__pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base._call = (PyObject *(*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call__pyx_wrap_1;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base.grad = (PyObject *(*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_grad;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base.hessian = (PyObject *(*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_hessian;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base.dynamics = (PyObject *(*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_dynamics;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base.omega = (double (*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_omega;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.__pyx_base.auxderivs = (PyObject *(*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_auxderivs;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C._call = (PyObject *(*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double, int __pyx_skip_dispatch, struct __pyx_opt_args_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call *__pyx_optional_args))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C__call;
  __pyx_vtable_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.xi = (double (*)(struct __pyx_obj_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C *, __Pyx_memviewslice, __Pyx_memviewslice, double, double, double, double))__pyx_f_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_xi;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C)) __PYX_ERR(1, 145, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_spec, __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) < 0) __PYX_ERR(1, 145, __pyx_L1_error)
  #else
  __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C = &__pyx_type_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_base = __pyx_ptype_8pyseobnr_3eob_11hamiltonian_13Hamiltonian_C_Hamiltonian_C;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) < 0) __PYX_ERR(1, 145, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dictoffset && __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C, __pyx_vtabptr_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) < 0) __PYX_ERR(1, 145, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) < 0) __PYX_ERR(1, 145, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge, (PyObject *) __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) < 0) __PYX_ERR(1, 145, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) < 0) __PYX_ERR(1, 145, __pyx_L1_error)
  #endif
  __pyx_vtabptr_array = &__pyx_vtable_array;
  __pyx_vtable_array.get_memview = (PyObject *(*)(struct __pyx_array_obj *))__pyx_array_get_memview;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_array_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_array_spec, NULL); if (unlikely(!__pyx_array_type)) __PYX_ERR(0, 114, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_array_type->tp_as_buffer = &__pyx_tp_as_buffer_array;
  if (!__pyx_array_type->tp_as_buffer->bf_releasebuffer && __pyx_array_type->tp_base->tp_as_buffer && __pyx_array_type->tp_base->tp_as_buffer->bf_releasebuffer) {
    __pyx_array_type->tp_as_buffer->bf_releasebuffer = __pyx_array_type->tp_base->tp_as_buffer->bf_releasebuffer;
  }
  #elif defined(Py_bf_getbuffer) && defined(Py_bf_releasebuffer)
  /* PY_VERSION_HEX >= 0x03090000 || Py_LIMITED_API >= 0x030B0000 */
  #elif defined(_MSC_VER)
  #pragma message ("The buffer protocol is not supported in the Limited C-API < 3.11.")
  #else
  #warning "The buffer protocol is not supported in the Limited C-API < 3.11."
  #endif
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_array_spec, __pyx_array_type) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  #else
  __pyx_array_type = &__pyx_type___pyx_array;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_array_type) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_array_type->tp_print = 0;
  #endif
  if (__Pyx_SetVtable(__pyx_array_type, __pyx_vtabptr_array) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_array_type) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_array_type) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_MemviewEnum_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_MemviewEnum_spec, NULL); if (unlikely(!__pyx_MemviewEnum_type)) __PYX_ERR(0, 302, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_MemviewEnum_spec, __pyx_MemviewEnum_type) < 0) __PYX_ERR(0, 302, __pyx_L1_error)
  #else
  __pyx_MemviewEnum_type = &__pyx_type___pyx_MemviewEnum;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_MemviewEnum_type) < 0) __PYX_ERR(0, 302, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_MemviewEnum_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_MemviewEnum_type->tp_dictoffset && __pyx_MemviewEnum_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_MemviewEnum_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_MemviewEnum_type) < 0) __PYX_ERR(0, 302, __pyx_L1_error)
  #endif
  __pyx_vtabptr_memoryview = &__pyx_vtable_memoryview;
  __pyx_vtable_memoryview.get_item_pointer = (char *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_get_item_pointer;
  __pyx_vtable_memoryview.is_slice = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_is_slice;
  __pyx_vtable_memoryview.setitem_slice_assignment = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_slice_assignment;
  __pyx_vtable_memoryview.setitem_slice_assign_scalar = (PyObject *(*)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_setitem_slice_assign_scalar;
  __pyx_vtable_memoryview.setitem_indexed = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_indexed;
  __pyx_vtable_memoryview.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryview_convert_item_to_object;
  __pyx_vtable_memoryview.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryview_assign_item_from_object;
  __pyx_vtable_memoryview._get_base = (PyObject *(*)(struct __pyx_memoryview_obj *))__pyx_memoryview__get_base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_memoryview_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_memoryview_spec, NULL); if (unlikely(!__pyx_memoryview_type)) __PYX_ERR(0, 337, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_memoryview_type->tp_as_buffer = &__pyx_tp_as_buffer_memoryview;
  if (!__pyx_memoryview_type->tp_as_buffer->bf_releasebuffer && __pyx_memoryview_type->tp_base->tp_as_buffer && __pyx_memoryview_type->tp_base->tp_as_buffer->bf_releasebuffer) {
    __pyx_memoryview_type->tp_as_buffer->bf_releasebuffer = __pyx_memoryview_type->tp_base->tp_as_buffer->bf_releasebuffer;
  }
  #elif defined(Py_bf_getbuffer) && defined(Py_bf_releasebuffer)
  /* PY_VERSION_HEX >= 0x03090000 || Py_LIMITED_API >= 0x030B0000 */
  #elif defined(_MSC_VER)
  #pragma message ("The buffer protocol is not supported in the Limited C-API < 3.11.")
  #else
  #warning "The buffer protocol is not supported in the Limited C-API < 3.11."
  #endif
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_memoryview_spec, __pyx_memoryview_type) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #else
  __pyx_memoryview_type = &__pyx_type___pyx_memoryview;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_memoryview_type) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_memoryview_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_memoryview_type->tp_dictoffset && __pyx_memoryview_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_memoryview_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_memoryview_type, __pyx_vtabptr_memoryview) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_memoryview_type) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_memoryview_type) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #endif
  __pyx_vtabptr__memoryviewslice = &__pyx_vtable__memoryviewslice;
  __pyx_vtable__memoryviewslice.__pyx_base = *__pyx_vtabptr_memoryview;
  __pyx_vtable__memoryviewslice.__pyx_base.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryviewslice_convert_item_to_object;
  __pyx_vtable__memoryviewslice.__pyx_base.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryviewslice_assign_item_from_object;
  __pyx_vtable__memoryviewslice.__pyx_base._get_base = (PyObject *(*)(struct __pyx_memoryview_obj *))__pyx_memoryviewslice__get_base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_memoryview_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_memoryviewslice_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_memoryviewslice_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_memoryviewslice_type)) __PYX_ERR(0, 952, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_memoryviewslice_spec, __pyx_memoryviewslice_type) < 0) __PYX_ERR(0, 952, __pyx_L1_error)
  #else
  __pyx_memoryviewslice_type = &__pyx_type___pyx_memoryviewslice;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_memoryviewslice_type->tp_base = __pyx_memoryview_type;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_memoryviewslice_type) < 0) __PYX_ERR(0, 952, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_memoryviewslice_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_memoryviewslice_type->tp_dictoffset && __pyx_memoryviewslice_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_memoryviewslice_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_memoryviewslice_type, __pyx_vtabptr__memoryviewslice) < 0) __PYX_ERR(0, 952, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_memoryviewslice_type) < 0) __PYX_ERR(0, 952, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_memoryviewslice_type) < 0) __PYX_ERR(0, 952, __pyx_L1_error)
  #endif
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_0_0(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyArray_Descr),__Pyx_ImportType_CheckSize_Ignore_3_0_0); if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(2, 202, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyArrayIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_0); if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(2, 225, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyArrayMultiIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_0); if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(2, 229, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyArrayObject),__Pyx_ImportType_CheckSize_Ignore_3_0_0); if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(2, 238, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_generic) __PYX_ERR(2, 809, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "number", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_number) __PYX_ERR(2, 811, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_integer) __PYX_ERR(2, 813, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(2, 815, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(2, 817, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(2, 819, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_floating) __PYX_ERR(2, 821, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(2, 823, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(2, 825, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "character", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_5numpy_character) __PYX_ERR(2, 827, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType_3_0_0(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyUFuncObject),__Pyx_ImportType_CheckSize_Ignore_3_0_0); if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(2, 865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pyseobnr.eob.utils.containers"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams = __Pyx_ImportType_3_0_0(__pyx_t_1, "pyseobnr.eob.utils.containers", "PhysicalParams", sizeof(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_PhysicalParams),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams) __PYX_ERR(4, 8, __pyx_L1_error)
  __pyx_vtabptr_8pyseobnr_3eob_5utils_10containers_PhysicalParams = (struct __pyx_vtabstruct_8pyseobnr_3eob_5utils_10containers_PhysicalParams*)__Pyx_GetVtable(__pyx_ptype_8pyseobnr_3eob_5utils_10containers_PhysicalParams); if (unlikely(!__pyx_vtabptr_8pyseobnr_3eob_5utils_10containers_PhysicalParams)) __PYX_ERR(4, 8, __pyx_L1_error)
  __pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs = __Pyx_ImportType_3_0_0(__pyx_t_1, "pyseobnr.eob.utils.containers", "CalibCoeffs", sizeof(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_CalibCoeffs),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_8pyseobnr_3eob_5utils_10containers_CalibCoeffs) __PYX_ERR(4, 23, __pyx_L1_error)
  __pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics = __Pyx_ImportType_3_0_0(__pyx_t_1, "pyseobnr.eob.utils.containers", "Dynamics", sizeof(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_Dynamics), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_Dynamics),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_8pyseobnr_3eob_5utils_10containers_Dynamics) __PYX_ERR(4, 26, __pyx_L1_error)
  __pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams = __Pyx_ImportType_3_0_0(__pyx_t_1, "pyseobnr.eob.utils.containers", "FluxParams", sizeof(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_FluxParams), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_FluxParams),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_8pyseobnr_3eob_5utils_10containers_FluxParams) __PYX_ERR(4, 29, __pyx_L1_error)
  __pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams = __Pyx_ImportType_3_0_0(__pyx_t_1, "pyseobnr.eob.utils.containers", "EOBParams", sizeof(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(struct __pyx_obj_8pyseobnr_3eob_5utils_10containers_EOBParams),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_8pyseobnr_3eob_5utils_10containers_EOBParams) __PYX_ERR(4, 67, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initHam_align_a6_apm_AP15_DP23_gaugeL_Tay_C(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initHam_align_a6_apm_AP15_DP23_gaugeL_Tay_C(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __Pyx_TraceDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  static PyThread_type_lock __pyx_t_8[8];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(1, 2, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(1, 2, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(1, 2, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(1, 2, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(1, 2, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(1, 2, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_pyseobnr__eob__hamiltonian__Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(1, 2, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C")) {
      if (unlikely((PyDict_SetItemString(modules, "pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C", __pyx_m) < 0))) __PYX_ERR(1, 2, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(1, 2, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code() < 0))) __PYX_ERR(1, 2, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  #endif
  __Pyx_TraceCall("__Pyx_PyMODINIT_FUNC PyInit_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C(void)", __pyx_f[1], 2, 0, __PYX_ERR(1, 2, __pyx_L1_error));

  /* "carray.to_py":114
 * 
 * @cname("__Pyx_carray_to_py_double")
 * cdef inline list __Pyx_carray_to_py_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */
  __Pyx_TraceLine(114,0,__PYX_ERR(0, 114, __pyx_L1_error))


  /* "carray.to_py":126
 * 
 * @cname("__Pyx_carray_to_tuple_double")
 * cdef inline tuple __Pyx_carray_to_tuple_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */
  __Pyx_TraceLine(126,0,__PYX_ERR(0, 126, __pyx_L1_error))


  /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 100, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_version_info); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 100, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_tuple__22, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 100, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 100, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "View.MemoryView":101
 * try:
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence             # <<<<<<<<<<<<<<
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_abc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Sequence); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
        __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;

        /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
        goto __pyx_L8;
      }

      /* "View.MemoryView":103
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence             # <<<<<<<<<<<<<<
 * except:
 * 
 */
      /*else*/ {
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_Sequence); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 103, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
        __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
      }
      __pyx_L8:;

      /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "View.MemoryView":104
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 * except:             # <<<<<<<<<<<<<<
 * 
 *     __pyx_collections_abc_Sequence = None
 */
    /*except:*/ {
      __Pyx_AddTraceback("View.MemoryView", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 104, __pyx_L4_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "View.MemoryView":106
 * except:
 * 
 *     __pyx_collections_abc_Sequence = None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
      __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L3_exception_handled;
    }

    /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L7_try_end:;
  }

  /* "View.MemoryView":241
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "View.MemoryView":242
 * 
 *     try:
 *         count = __pyx_collections_abc_Sequence.count             # <<<<<<<<<<<<<<
 *         index = __pyx_collections_abc_Sequence.index
 *     except:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 242, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_array_type->tp_dict, __pyx_n_s_count, __pyx_t_7) < 0) __PYX_ERR(0, 242, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_array_type);

      /* "View.MemoryView":243
 *     try:
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index             # <<<<<<<<<<<<<<
 *     except:
 *         pass
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 243, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_array_type->tp_dict, __pyx_n_s_index, __pyx_t_7) < 0) __PYX_ERR(0, 243, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_array_type);

      /* "View.MemoryView":241
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":244
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 *     except:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L12_exception_handled;
    }
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L16_try_end:;
  }

  /* "View.MemoryView":309
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(generic);
  __Pyx_DECREF_SET(generic, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":310
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(strided);
  __Pyx_DECREF_SET(strided, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":311
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(indirect);
  __Pyx_DECREF_SET(indirect, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":314
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(contiguous);
  __Pyx_DECREF_SET(contiguous, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":315
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(indirect_contiguous);
  __Pyx_DECREF_SET(indirect_contiguous, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":323
 * 
 * 
 * cdef int __pyx_memoryview_thread_locks_used = 0             # <<<<<<<<<<<<<<
 * cdef PyThread_type_lock[8] __pyx_memoryview_thread_locks = [
 *     PyThread_allocate_lock(),
 */
  __pyx_memoryview_thread_locks_used = 0;

  /* "View.MemoryView":324
 * 
 * cdef int __pyx_memoryview_thread_locks_used = 0
 * cdef PyThread_type_lock[8] __pyx_memoryview_thread_locks = [             # <<<<<<<<<<<<<<
 *     PyThread_allocate_lock(),
 *     PyThread_allocate_lock(),
 */
  __pyx_t_8[0] = PyThread_allocate_lock();
  __pyx_t_8[1] = PyThread_allocate_lock();
  __pyx_t_8[2] = PyThread_allocate_lock();
  __pyx_t_8[3] = PyThread_allocate_lock();
  __pyx_t_8[4] = PyThread_allocate_lock();
  __pyx_t_8[5] = PyThread_allocate_lock();
  __pyx_t_8[6] = PyThread_allocate_lock();
  __pyx_t_8[7] = PyThread_allocate_lock();
  memcpy(&(__pyx_memoryview_thread_locks[0]), __pyx_t_8, sizeof(__pyx_memoryview_thread_locks[0]) * (8));

  /* "View.MemoryView":982
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "View.MemoryView":983
 * 
 *     try:
 *         count = __pyx_collections_abc_Sequence.count             # <<<<<<<<<<<<<<
 *         index = __pyx_collections_abc_Sequence.index
 *     except:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 983, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_memoryviewslice_type->tp_dict, __pyx_n_s_count, __pyx_t_7) < 0) __PYX_ERR(0, 983, __pyx_L17_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_memoryviewslice_type);

      /* "View.MemoryView":984
 *     try:
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index             # <<<<<<<<<<<<<<
 *     except:
 *         pass
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 984, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_memoryviewslice_type->tp_dict, __pyx_n_s_index, __pyx_t_7) < 0) __PYX_ERR(0, 984, __pyx_L17_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_memoryviewslice_type);

      /* "View.MemoryView":982
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L22_try_end;
    __pyx_L17_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":985
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 *     except:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L18_exception_handled;
    }
    __pyx_L18_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L22_try_end:;
  }

  /* "View.MemoryView":988
 *         pass
 * 
 * try:             # <<<<<<<<<<<<<<
 *     if __pyx_collections_abc_Sequence:
 * 
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "View.MemoryView":989
 * 
 * try:
 *     if __pyx_collections_abc_Sequence:             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_collections_abc_Sequence); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 989, __pyx_L23_error)
      if (__pyx_t_6) {

        /* "View.MemoryView":993
 * 
 * 
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence.register(array)
 * except:
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_register); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 993, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)__pyx_memoryviewslice_type)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 993, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "View.MemoryView":994
 * 
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)
 *         __pyx_collections_abc_Sequence.register(array)             # <<<<<<<<<<<<<<
 * except:
 *     pass  # ignore failure, it's a minor issue
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_register); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 994, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_array_type)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 994, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "View.MemoryView":989
 * 
 * try:
 *     if __pyx_collections_abc_Sequence:             # <<<<<<<<<<<<<<
 * 
 * 
 */
      }

      /* "View.MemoryView":988
 *         pass
 * 
 * try:             # <<<<<<<<<<<<<<
 *     if __pyx_collections_abc_Sequence:
 * 
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L28_try_end;
    __pyx_L23_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":995
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)
 *         __pyx_collections_abc_Sequence.register(array)
 * except:             # <<<<<<<<<<<<<<
 *     pass  # ignore failure, it's a minor issue
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L24_exception_handled;
    }
    __pyx_L24_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L28_try_end:;
  }

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum, NULL, __pyx_n_s_View_MemoryView); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Enum, __pyx_t_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":4
 * # cython: language_level=3, boundscheck=False, cdivision=True, wraparound=False, profile=True,linetrace=True,binding=True
 * cimport cython
 * import numpy as np             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * from pyseobnr.eob.utils.containers cimport EOBParams,CalibCoeffs
 */
  __Pyx_TraceLine(4,0,__PYX_ERR(1, 4, __pyx_L1_error))
  __pyx_t_7 = __Pyx_ImportDottedModule(__pyx_n_s_numpy, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_7) < 0) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":11
 * from libc.math cimport log, sqrt, exp, abs, tgamma,sin,cos
 * 
 * cpdef (double,double) evaluate_H(double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,double M, double nu,             # <<<<<<<<<<<<<<
 * double X_1, double X_2, double a6, double dSO):
 *         """
 */
  __Pyx_TraceLine(11,0,__PYX_ERR(1, 11, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_1evaluate_H, 0, __pyx_n_s_evaluate_H, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__11)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_evaluate_H, __pyx_t_7) < 0) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":154
 *         return self._call(q,p,chi_1,chi_2,m_1,m_2,verbose=verbose)
 * 
 *     cpdef _call(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2,bint verbose=False):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(154,0,__PYX_ERR(1, 154, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_5_call, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_2, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__12)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__34);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dict, __pyx_n_s_call, __pyx_t_7) < 0) __PYX_ERR(1, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":290
 *             return H,xi,A,Bnp,Bnpa,Qq,Heven,Hodd
 * 
 *     cpdef grad(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(290,0,__PYX_ERR(1, 290, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_7grad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_3, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__13)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dict, __pyx_n_s_grad, __pyx_t_7) < 0) __PYX_ERR(1, 290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":547
 *         return dHdr, dHdphi, dHdpr, dHdpphi
 * 
 *     cpdef hessian(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(547,0,__PYX_ERR(1, 547, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_9hessian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_4, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__14)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dict, __pyx_n_s_hessian, __pyx_t_7) < 0) __PYX_ERR(1, 547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1246
 *         return np.array([d2Hdr2, d2Hdrdphi, d2Hdrdpr, d2Hdrdpphi, d2Hdrdphi, d2Hdphi2, d2Hdphidpr, d2Hdphidpphi, d2Hdrdpr, d2Hdphidpr, d2Hdpr2, d2Hdprdpphi, d2Hdrdpphi, d2Hdphidpphi, d2Hdprdpphi, d2Hdpphi2]).reshape(4, 4)
 * 
 *     cdef double xi(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(1246,0,__PYX_ERR(1, 1246, __pyx_L1_error))


  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1299
 *         return xi
 * 
 *     cpdef dynamics(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(1299,0,__PYX_ERR(1, 1299, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_11dynamics, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_5, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dict, __pyx_n_s_dynamics, __pyx_t_7) < 0) __PYX_ERR(1, 1299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1557
 *         #return dHdr, dHdphi, dHdpr, dHdpphi,H,xi
 * 
 *     cpdef double omega(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(1557,0,__PYX_ERR(1, 1557, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_13omega, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_6, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__17)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dict, __pyx_n_s_omega, __pyx_t_7) < 0) __PYX_ERR(1, 1557, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":1682
 *         return omega
 * 
 *     cpdef auxderivs(self, double[:]q,double[:]p,double chi_1,double chi_2,double m_1,double m_2):             # <<<<<<<<<<<<<<
 * 
 *         """
 */
  __Pyx_TraceLine(1682,0,__PYX_ERR(1, 1682, __pyx_L1_error))

  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_15auxderivs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_7, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__18)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C->tp_dict, __pyx_n_s_auxderivs, __pyx_t_7) < 0) __PYX_ERR(1, 1682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __Pyx_TraceLine(1,0,__PYX_ERR(0, 1, __pyx_L1_error))
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_17__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_8, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__19)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_TraceLine(3,0,__PYX_ERR(0, 3, __pyx_L1_error))
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_8pyseobnr_3eob_11hamiltonian_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_39Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C_19__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Ham_align_a6_apm_AP15_DP23_gauge_9, NULL, __pyx_n_s_pyseobnr_eob_hamiltonian_Ham_ali_2, __pyx_d, ((PyObject *)__pyx_codeobj__20)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyseobnr/eob/hamiltonian/Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C.pyx":2
 * 
 * # cython: language_level=3, boundscheck=False, cdivision=True, wraparound=False, profile=True,linetrace=True,binding=True             # <<<<<<<<<<<<<<
 * cimport cython
 * import numpy as np
 */
  __Pyx_TraceLine(2,0,__PYX_ERR(1, 2, __pyx_L1_error))
  __pyx_t_7 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_7) < 0) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_TraceReturn(Py_None, 0);

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pyseobnr.eob.hamiltonian.Ham_align_a6_apm_AP15_DP23_gaugeL_Tay_C");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* Profile */
#if CYTHON_PROFILE
static int __Pyx_TraceSetupAndCall(PyCodeObject** code,
                                   PyFrameObject** frame,
                                   PyThreadState* tstate,
                                   const char *funcname,
                                   const char *srcfile,
                                   int firstlineno) {
    PyObject *type, *value, *traceback;
    int retval;
    if (*frame == NULL || !CYTHON_PROFILE_REUSE_FRAME) {
        if (*code == NULL) {
            *code = __Pyx_createFrameCodeObject(funcname, srcfile, firstlineno);
            if (*code == NULL) return 0;
        }
        *frame = PyFrame_New(
            tstate,                          /*PyThreadState *tstate*/
            *code,                           /*PyCodeObject *code*/
            __pyx_d,                  /*PyObject *globals*/
            0                                /*PyObject *locals*/
        );
        if (*frame == NULL) return 0;
        if (CYTHON_TRACE && (*frame)->f_trace == NULL) {
            Py_INCREF(Py_None);
            (*frame)->f_trace = Py_None;
        }
#if PY_VERSION_HEX < 0x030400B1
    } else {
        (*frame)->f_tstate = tstate;
#endif
    }
    __Pyx_PyFrame_SetLineNumber(*frame, firstlineno);
    retval = 1;
    __Pyx_EnterTracing(tstate);
    __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
    #if CYTHON_TRACE
    if (tstate->c_tracefunc)
        retval = tstate->c_tracefunc(tstate->c_traceobj, *frame, PyTrace_CALL, NULL) == 0;
    if (retval && tstate->c_profilefunc)
    #endif
        retval = tstate->c_profilefunc(tstate->c_profileobj, *frame, PyTrace_CALL, NULL) == 0;
    __Pyx_LeaveTracing(tstate);
    if (retval) {
        __Pyx_ErrRestoreInState(tstate, type, value, traceback);
        return __Pyx_IsTracing(tstate, 0, 0) && retval;
    } else {
        Py_XDECREF(type);
        Py_XDECREF(value);
        Py_XDECREF(traceback);
        return -1;
    }
}
static PyCodeObject *__Pyx_createFrameCodeObject(const char *funcname, const char *srcfile, int firstlineno) {
    PyCodeObject *py_code = 0;
#if PY_MAJOR_VERSION >= 3
    py_code = PyCode_NewEmpty(srcfile, funcname, firstlineno);
    if (likely(py_code)) {
        py_code->co_flags |= CO_OPTIMIZED | CO_NEWLOCALS;
    }
#else
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    py_funcname = PyString_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    py_srcfile = PyString_FromString(srcfile);
    if (unlikely(!py_srcfile)) goto bad;
    py_code = PyCode_New(
        0,
        0,
        0,
        CO_OPTIMIZED | CO_NEWLOCALS,
        __pyx_empty_bytes,     /*PyObject *code,*/
        __pyx_empty_tuple,     /*PyObject *consts,*/
        __pyx_empty_tuple,     /*PyObject *names,*/
        __pyx_empty_tuple,     /*PyObject *varnames,*/
        __pyx_empty_tuple,     /*PyObject *freevars,*/
        __pyx_empty_tuple,     /*PyObject *cellvars,*/
        py_srcfile,       /*PyObject *filename,*/
        py_funcname,      /*PyObject *name,*/
        firstlineno,
        __pyx_empty_bytes      /*PyObject *lnotab*/
    );
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
#endif
    return py_code;
}
#endif

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;  // error
            return kwvalues[i];
        }
    }
    return NULL;  // not found (no exception set)
}
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        if (kwds_is_tuple) {
            if (pos >= PyTuple_GET_SIZE(kwds)) break;
            key = PyTuple_GET_ITEM(kwds, pos);
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]);
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
    Py_DECREF(argstuple);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
#if defined(__Pyx_CyFunction_USED) && defined(NDEBUG)
        if (__Pyx_IsCyOrPyCFunction(func))
#else
        if (PyCFunction_Check(func))
#endif
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
                return __Pyx_PyObject_CallMethO(func, NULL);
            }
        }
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (PyCFunction_Check(func))
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
                return __Pyx_PyObject_CallMethO(func, args[0]);
            }
        }
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    #if CYTHON_VECTORCALL
    vectorcallfunc f = _PyVectorcall_Function(func);
    if (f) {
        return f(func, args, (size_t)nargs, kwargs);
    }
    #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
    if (__Pyx_CyFunction_CheckExact(func)) {
        __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
        if (f) return f(func, args, (size_t)nargs, kwargs);
    }
    #endif
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSsize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(Py_ssize_t)*3+2];
    char *dpos, *end = digits + sizeof(Py_ssize_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    Py_ssize_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (Py_ssize_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (Py_ssize_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (Py_ssize_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (meth) {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        if (unlikely(PyTuple_GET_SIZE(kw) == 0))
            return 1;
        if (!kw_allowed) {
            key = PyTuple_GET_ITEM(kw, 0);
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < PyTuple_GET_SIZE(kw); pos++) {
            key = PyTuple_GET_ITEM(kw, pos);
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* DivInt[Py_ssize_t] */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t a, Py_ssize_t b) {
    Py_ssize_t q = a / b;
    Py_ssize_t r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
#endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                #if CYTHON_COMPILING_IN_LIMITED_API
                module = PyImport_ImportModuleLevelObject(
                    name, empty_dict, empty_dict, from_list, 1);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                #endif
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            #if CYTHON_COMPILING_IN_LIMITED_API
            module = PyImport_ImportModuleLevelObject(
                name, empty_dict, empty_dict, from_list, level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__3;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* ssize_strlen */
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* PySequenceMultiply */
static PyObject* __Pyx_PySequence_Multiply_Generic(PyObject *seq, Py_ssize_t mul) {
    PyObject *result, *pymul = PyInt_FromSsize_t(mul);
    if (unlikely(!pymul))
        return NULL;
    result = PyNumber_Multiply(seq, pymul);
    Py_DECREF(pymul);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul) {
#if CYTHON_USE_TYPE_SLOTS
    PyTypeObject *type = Py_TYPE(seq);
    if (likely(type->tp_as_sequence && type->tp_as_sequence->sq_repeat)) {
        return type->tp_as_sequence->sq_repeat(seq, mul);
    } else
#endif
    {
        return __Pyx_PySequence_Multiply_Generic(seq, mul);
    }
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_ass_subscript) {
            int r;
            PyObject *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return -1;
            r = mm->mp_ass_subscript(o, key, v);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return sm->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* DivInt[long] */
static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__2);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* SoftComplexToDouble */
static double __Pyx_SoftComplexToDouble(__pyx_t_double_complex value, int have_gil) {
    if (unlikely(__Pyx_CIMAG(value))) {
        PyGILState_STATE gilstate;
        if (!have_gil)
            gilstate = PyGILState_Ensure();
        PyErr_SetString(PyExc_TypeError,
            "Cannot convert 'complex' with non-zero imaginary component to 'double' "
            "(this most likely comes from the '**' operator; "
            "use 'cython.cpow(True)' to return 'nan' instead of a "
            "complex number).");
        if (!have_gil)
            PyGILState_Release(gilstate);
        return -1.;
    }
    return __Pyx_CREAL(value);
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    PyObject* exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_0_0
#define __PYX_HAVE_RT_ImportType_3_0_0
static PyTypeObject *__Pyx_ImportType_3_0_0(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_0 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_0 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_0 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg = NULL;
    return __Pyx_PyObject_FastCall(func, (&arg)+1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n = PyTuple_GET_SIZE(bases);
    for (i = 1; i < n; i++)
    {
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
            return -1;
        }
        if (dictoffset == 0 && b->tp_dictoffset)
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "extension type '%.200s' has no __dict__ slot, "
                "but base type '" __Pyx_FMT_TYPENAME "' has: "
                "either add 'cdef dict __dict__' to the extension type "
                "or add '__slots__ = [...]' to the base type",
                type_name, b_name);
            __Pyx_DECREF_TypeName(b_name);
            return -1;
        }
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* MergeVTables */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    PyObject *abi_module = PyImport_AddModule((char*) __PYX_ABI_MODULE_NAME);
    if (unlikely(!abi_module)) return NULL;
    Py_INCREF(abi_module);
    return abi_module;
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
        PyList_SET_ITEM(fromlist, 0, marker);
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    cf->m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#ifdef _Py_TPFLAGS_HAVE_VECTORCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    _PyTraceback_Add(funcname, filename, py_line);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    __Pyx_TypeName obj_type_name;
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_array_type)) return __pyx_array_getbuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_memoryview_type)) return __pyx_memoryview_getbuffer(obj, view, flags);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
                 "'" __Pyx_FMT_TYPENAME "' does not have the buffer interface",
                 obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
    if ((0)) {}
    view->obj = NULL;
    Py_DECREF(obj);
}
#endif


/* MemviewSliceIsContig */
static int
__pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim)
{
    int i, index, step, start;
    Py_ssize_t itemsize = mvs.memview->view.itemsize;
    if (order == 'F') {
        step = 1;
        start = 0;
    } else {
        step = -1;
        start = ndim - 1;
    }
    for (i = 0; i < ndim; i++) {
        index = start + step * i;
        if (mvs.suboffsets[index] >= 0 || mvs.strides[index] != itemsize)
            return 0;
        itemsize *= mvs.shape[index];
    }
    return 1;
}

/* OverlappingSlices */
static void
__pyx_get_array_memory_extents(__Pyx_memviewslice *slice,
                               void **out_start, void **out_end,
                               int ndim, size_t itemsize)
{
    char *start, *end;
    int i;
    start = end = slice->data;
    for (i = 0; i < ndim; i++) {
        Py_ssize_t stride = slice->strides[i];
        Py_ssize_t extent = slice->shape[i];
        if (extent == 0) {
            *out_start = *out_end = start;
            return;
        } else {
            if (stride > 0)
                end += stride * (extent - 1);
            else
                start += stride * (extent - 1);
        }
    }
    *out_start = start;
    *out_end = end + itemsize;
}
static int
__pyx_slices_overlap(__Pyx_memviewslice *slice1,
                     __Pyx_memviewslice *slice2,
                     int ndim, size_t itemsize)
{
    void *start1, *end1, *start2, *end2;
    __pyx_get_array_memory_extents(slice1, &start1, &end1, ndim, itemsize);
    __pyx_get_array_memory_extents(slice2, &start2, &end2, ndim, itemsize);
    return (start1 < end2) && (start2 < end1);
}

/* IsLittleEndian */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void)
{
  union {
    uint32_t u32;
    uint8_t u8[4];
  } S;
  S.u32 = 0x01020304;
  return S.u8[0] == 4;
}

/* BufferFormatCheck */
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t <= '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case '?': return "'bool'";
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparsable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, int is_complex) {
  CYTHON_UNUSED_VAR(is_complex);
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, int is_complex) {
  CYTHON_UNUSED_VAR(is_complex);
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case '?': case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number, ndim;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    ndim = ctx->head->field->type->ndim;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
        CYTHON_FALLTHROUGH;
      case '?': case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if ((ctx->enc_type == *ts) && (got_Z == ctx->is_complex) &&
            (ctx->enc_packmode == ctx->new_packmode) && (!ctx->is_valid_array)) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
        CYTHON_FALLTHROUGH;
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}

/* TypeInfoCompare */
  static int
__pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b)
{
    int i;
    if (!a || !b)
        return 0;
    if (a == b)
        return 1;
    if (a->size != b->size || a->typegroup != b->typegroup ||
            a->is_unsigned != b->is_unsigned || a->ndim != b->ndim) {
        if (a->typegroup == 'H' || b->typegroup == 'H') {
            return a->size == b->size;
        } else {
            return 0;
        }
    }
    if (a->ndim) {
        for (i = 0; i < a->ndim; i++)
            if (a->arraysize[i] != b->arraysize[i])
                return 0;
    }
    if (a->typegroup == 'S') {
        if (a->flags != b->flags)
            return 0;
        if (a->fields || b->fields) {
            if (!(a->fields && b->fields))
                return 0;
            for (i = 0; a->fields[i].type && b->fields[i].type; i++) {
                __Pyx_StructField *field_a = a->fields + i;
                __Pyx_StructField *field_b = b->fields + i;
                if (field_a->offset != field_b->offset ||
                    !__pyx_typeinfo_cmp(field_a->type, field_b->type))
                    return 0;
            }
            return !a->fields[i].type && !b->fields[i].type;
        }
    }
    return 1;
}

/* MemviewSliceValidateAndInit */
  static int
__pyx_check_strides(Py_buffer *buf, int dim, int ndim, int spec)
{
    if (buf->shape[dim] <= 1)
        return 1;
    if (buf->strides) {
        if (spec & __Pyx_MEMVIEW_CONTIG) {
            if (spec & (__Pyx_MEMVIEW_PTR|__Pyx_MEMVIEW_FULL)) {
                if (unlikely(buf->strides[dim] != sizeof(void *))) {
                    PyErr_Format(PyExc_ValueError,
                                 "Buffer is not indirectly contiguous "
                                 "in dimension %d.", dim);
                    goto fail;
                }
            } else if (unlikely(buf->strides[dim] != buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
        if (spec & __Pyx_MEMVIEW_FOLLOW) {
            Py_ssize_t stride = buf->strides[dim];
            if (stride < 0)
                stride = -stride;
            if (unlikely(stride < buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
    } else {
        if (unlikely(spec & __Pyx_MEMVIEW_CONTIG && dim != ndim - 1)) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not contiguous in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(spec & (__Pyx_MEMVIEW_PTR))) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not indirect in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(buf->suboffsets)) {
            PyErr_SetString(PyExc_ValueError,
                            "Buffer exposes suboffsets but no strides");
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_check_suboffsets(Py_buffer *buf, int dim, int ndim, int spec)
{
    CYTHON_UNUSED_VAR(ndim);
    if (spec & __Pyx_MEMVIEW_DIRECT) {
        if (unlikely(buf->suboffsets && buf->suboffsets[dim] >= 0)) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer not compatible with direct access "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    if (spec & __Pyx_MEMVIEW_PTR) {
        if (unlikely(!buf->suboffsets || (buf->suboffsets[dim] < 0))) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer is not indirectly accessible "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_verify_contig(Py_buffer *buf, int ndim, int c_or_f_flag)
{
    int i;
    if (c_or_f_flag & __Pyx_IS_F_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = 0; i < ndim; i++) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not fortran contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    } else if (c_or_f_flag & __Pyx_IS_C_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = ndim - 1; i >- 1; i--) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not C contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    }
    return 1;
fail:
    return 0;
}
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj)
{
    struct __pyx_memoryview_obj *memview, *new_memview;
    __Pyx_RefNannyDeclarations
    Py_buffer *buf;
    int i, spec = 0, retval = -1;
    __Pyx_BufFmt_Context ctx;
    int from_memoryview = __pyx_memoryview_check(original_obj);
    __Pyx_RefNannySetupContext("ValidateAndInit_memviewslice", 0);
    if (from_memoryview && __pyx_typeinfo_cmp(dtype, ((struct __pyx_memoryview_obj *)
                                                            original_obj)->typeinfo)) {
        memview = (struct __pyx_memoryview_obj *) original_obj;
        new_memview = NULL;
    } else {
        memview = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                            original_obj, buf_flags, 0, dtype);
        new_memview = memview;
        if (unlikely(!memview))
            goto fail;
    }
    buf = &memview->view;
    if (unlikely(buf->ndim != ndim)) {
        PyErr_Format(PyExc_ValueError,
                "Buffer has wrong number of dimensions (expected %d, got %d)",
                ndim, buf->ndim);
        goto fail;
    }
    if (new_memview) {
        __Pyx_BufFmt_Init(&ctx, stack, dtype);
        if (unlikely(!__Pyx_BufFmt_CheckString(&ctx, buf->format))) goto fail;
    }
    if (unlikely((unsigned) buf->itemsize != dtype->size)) {
        PyErr_Format(PyExc_ValueError,
                     "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "u byte%s) "
                     "does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "u byte%s)",
                     buf->itemsize,
                     (buf->itemsize > 1) ? "s" : "",
                     dtype->name,
                     dtype->size,
                     (dtype->size > 1) ? "s" : "");
        goto fail;
    }
    if (buf->len > 0) {
        for (i = 0; i < ndim; i++) {
            spec = axes_specs[i];
            if (unlikely(!__pyx_check_strides(buf, i, ndim, spec)))
                goto fail;
            if (unlikely(!__pyx_check_suboffsets(buf, i, ndim, spec)))
                goto fail;
        }
        if (unlikely(buf->strides && !__pyx_verify_contig(buf, ndim, c_or_f_flag)))
            goto fail;
    }
    if (unlikely(__Pyx_init_memviewslice(memview, ndim, memviewslice,
                                         new_memview != NULL) == -1)) {
        goto fail;
    }
    retval = 0;
    goto no_fail;
fail:
    Py_XDECREF(new_memview);
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_double(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_double, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* ToPyCTupleUtility */
  static PyObject* __pyx_convert__to_py___pyx_ctuple_double__and_double(__pyx_ctuple_double__and_double value) {
    PyObject* item = NULL;
    PyObject* result = PyTuple_New(2);
    if (!result) goto bad;
        item = PyFloat_FromDouble(value.f0);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 0, item);
        item = PyFloat_FromDouble(value.f1);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 1, item);
    return result;
bad:
    Py_XDECREF(item);
    Py_XDECREF(result);
    return NULL;
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_double(const char *itemp) {
    return (PyObject *) PyFloat_FromDouble(*(double *) itemp);
}
static CYTHON_INLINE int __pyx_memview_set_double(const char *itemp, PyObject *obj) {
    double value = __pyx_PyFloat_AsDouble(obj);
    if (unlikely((value == (double)-1) && PyErr_Occurred()))
        return 0;
    *(double *) itemp = value;
    return 1;
}

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* MemviewSliceCopyTemplate */
  static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object)
{
    __Pyx_RefNannyDeclarations
    int i;
    __Pyx_memviewslice new_mvs = { 0, 0, { 0 }, { 0 }, { 0 } };
    struct __pyx_memoryview_obj *from_memview = from_mvs->memview;
    Py_buffer *buf = &from_memview->view;
    PyObject *shape_tuple = NULL;
    PyObject *temp_int = NULL;
    struct __pyx_array_obj *array_obj = NULL;
    struct __pyx_memoryview_obj *memview_obj = NULL;
    __Pyx_RefNannySetupContext("__pyx_memoryview_copy_new_contig", 0);
    for (i = 0; i < ndim; i++) {
        if (unlikely(from_mvs->suboffsets[i] >= 0)) {
            PyErr_Format(PyExc_ValueError, "Cannot copy memoryview slice with "
                                           "indirect dimensions (axis %d)", i);
            goto fail;
        }
    }
    shape_tuple = PyTuple_New(ndim);
    if (unlikely(!shape_tuple)) {
        goto fail;
    }
    __Pyx_GOTREF(shape_tuple);
    for(i = 0; i < ndim; i++) {
        temp_int = PyInt_FromSsize_t(from_mvs->shape[i]);
        if(unlikely(!temp_int)) {
            goto fail;
        } else {
            PyTuple_SET_ITEM(shape_tuple, i, temp_int);
            temp_int = NULL;
        }
    }
    array_obj = __pyx_array_new(shape_tuple, sizeof_dtype, buf->format, (char *) mode, NULL);
    if (unlikely(!array_obj)) {
        goto fail;
    }
    __Pyx_GOTREF(array_obj);
    memview_obj = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                    (PyObject *) array_obj, contig_flag,
                                    dtype_is_object,
                                    from_mvs->memview->typeinfo);
    if (unlikely(!memview_obj))
        goto fail;
    if (unlikely(__Pyx_init_memviewslice(memview_obj, ndim, &new_mvs, 1) < 0))
        goto fail;
    if (unlikely(__pyx_memoryview_copy_contents(*from_mvs, new_mvs, ndim, ndim,
                                                dtype_is_object) < 0))
        goto fail;
    goto no_fail;
fail:
    __Pyx_XDECREF(new_mvs.memview);
    new_mvs.memview = NULL;
    new_mvs.data = NULL;
no_fail:
    __Pyx_XDECREF(shape_tuple);
    __Pyx_XDECREF(temp_int);
    __Pyx_XDECREF(array_obj);
    __Pyx_RefNannyFinishContext();
    return new_mvs;
}

/* MemviewSliceInit */
  static int
__Pyx_init_memviewslice(struct __pyx_memoryview_obj *memview,
                        int ndim,
                        __Pyx_memviewslice *memviewslice,
                        int memview_is_new_reference)
{
    __Pyx_RefNannyDeclarations
    int i, retval=-1;
    Py_buffer *buf = &memview->view;
    __Pyx_RefNannySetupContext("init_memviewslice", 0);
    if (unlikely(memviewslice->memview || memviewslice->data)) {
        PyErr_SetString(PyExc_ValueError,
            "memviewslice is already initialized!");
        goto fail;
    }
    if (buf->strides) {
        for (i = 0; i < ndim; i++) {
            memviewslice->strides[i] = buf->strides[i];
        }
    } else {
        Py_ssize_t stride = buf->itemsize;
        for (i = ndim - 1; i >= 0; i--) {
            memviewslice->strides[i] = stride;
            stride *= buf->shape[i];
        }
    }
    for (i = 0; i < ndim; i++) {
        memviewslice->shape[i]   = buf->shape[i];
        if (buf->suboffsets) {
            memviewslice->suboffsets[i] = buf->suboffsets[i];
        } else {
            memviewslice->suboffsets[i] = -1;
        }
    }
    memviewslice->memview = memview;
    memviewslice->data = (char *)buf->buf;
    if (__pyx_add_acquisition_count(memview) == 0 && !memview_is_new_reference) {
        Py_INCREF(memview);
    }
    retval = 0;
    goto no_fail;
fail:
    memviewslice->memview = 0;
    memviewslice->data = 0;
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}
#ifndef Py_NO_RETURN
#define Py_NO_RETURN
#endif
static void __pyx_fatalerror(const char *fmt, ...) Py_NO_RETURN {
    va_list vargs;
    char msg[200];
#if PY_VERSION_HEX >= 0x030A0000 || defined(HAVE_STDARG_PROTOTYPES)
    va_start(vargs, fmt);
#else
    va_start(vargs);
#endif
    vsnprintf(msg, 200, fmt, vargs);
    va_end(vargs);
    Py_FatalError(msg);
}
static CYTHON_INLINE int
__pyx_add_acquisition_count_locked(__pyx_atomic_int_type *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)++;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE int
__pyx_sub_acquisition_count_locked(__pyx_atomic_int_type *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)--;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE void
__Pyx_INC_MEMVIEW(__Pyx_memviewslice *memslice, int have_gil, int lineno)
{
    __pyx_nonatomic_int_type old_acquisition_count;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        return;
    }
    old_acquisition_count = __pyx_add_acquisition_count(memview);
    if (unlikely(old_acquisition_count <= 0)) {
        if (likely(old_acquisition_count == 0)) {
            if (have_gil) {
                Py_INCREF((PyObject *) memview);
            } else {
                PyGILState_STATE _gilstate = PyGILState_Ensure();
                Py_INCREF((PyObject *) memview);
                PyGILState_Release(_gilstate);
            }
        } else {
            __pyx_fatalerror("Acquisition count is %d (line %d)",
                             old_acquisition_count+1, lineno);
        }
    }
}
static CYTHON_INLINE void __Pyx_XCLEAR_MEMVIEW(__Pyx_memviewslice *memslice,
                                             int have_gil, int lineno) {
    __pyx_nonatomic_int_type old_acquisition_count;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        memslice->memview = NULL;
        return;
    }
    old_acquisition_count = __pyx_sub_acquisition_count(memview);
    memslice->data = NULL;
    if (likely(old_acquisition_count > 1)) {
        memslice->memview = NULL;
    } else if (likely(old_acquisition_count == 1)) {
        if (have_gil) {
            Py_CLEAR(memslice->memview);
        } else {
            PyGILState_STATE _gilstate = PyGILState_Ensure();
            Py_CLEAR(memslice->memview);
            PyGILState_Release(_gilstate);
        }
    } else {
        __pyx_fatalerror("Acquisition count is %d (line %d)",
                         old_acquisition_count-1, lineno);
    }
}

/* CIntFromPyVerify */
  #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
  static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(size_t) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 2 * PyLong_SHIFT)) {
                                return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 3 * PyLong_SHIFT)) {
                                return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 4 * PyLong_SHIFT)) {
                                return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(size_t) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(size_t) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(size_t) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (size_t) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (size_t) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (size_t) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (size_t) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (size_t) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(size_t) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((size_t) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(size_t) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((size_t) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((size_t) 1) << (sizeof(size_t) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
  static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(char) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(char, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (char) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) >= 2 * PyLong_SHIFT)) {
                                return (char) (((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) >= 3 * PyLong_SHIFT)) {
                                return (char) (((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) >= 4 * PyLong_SHIFT)) {
                                return (char) (((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (char) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(char) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(char) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(char) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                                return (char) (((char)-1)*(((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                                return (char) ((((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                                return (char) (((char)-1)*(((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                                return (char) ((((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                                return (char) (((char)-1)*(((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                                return (char) ((((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(char) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(char) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            char val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (char) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (char) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (char) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (char) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (char) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(char) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((char) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(char) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((char) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((char) 1) << (sizeof(char) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (char) -1;
        }
    } else {
        char val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (char) -1;
        val = __Pyx_PyInt_As_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to char");
    return (char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to char");
    return (char) -1;
}

/* FormatTypeName */
  #if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XSETREF(name, __Pyx_NewRef(__pyx_n_s__38));
    }
    return name;
}
#endif

/* CheckBinaryVersion */
  static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compile time version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
  #if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
